
from skyciv.constants.skyciv_sections import SkyCivSections
from skyciv.classes.api_object.api_object import ApiObject
from skyciv.classes.model.model import Model
from skyciv.lib.request import request

sections = SkyCivSections
