

class SkyCivFunctions():
    S3D_session_start = "S3D.session.start"
    S3D_model_set = "S3D.model.set"
    S3D_model_get = "S3D.model.get"
    S3D_model_repair = "S3D.model.repair"
    S3D_model_solve = "S3D.model.solve"
    S3D_model_takeScreenshot = "S3D.model.takeScreenshot"
    S3D_model_mesh = "S3D.model.mesh"
    S3D_results_set = "S3D.results.set"
    S3D_results_get = "S3D.results.get"
    S3D_results_fetchMemberResult = "S3D.results.fetchMemberResult"
    S3D_results_getAnalysisReport = "S3D.results.getAnalysisReport"
    S3D_design_member_getInput = "S3D.design.member.getInput"
    S3D_design_member_check = "S3D.design.member.check"
    S3D_design_member_optimize = "S3D.design.member.optimize"
    standalone_member_check = "standalone.member.check"
    S3D_design_rc_getInput = "S3D.design.rc.getInput"
    S3D_design_rc_check = "S3D.design.rc.check"
    S3D_SB_loadLibraryShape = "S3D.SB.loadLibraryShape"
    S3D_SB_getLibraryTree = "S3D.SB.getLibraryTree"
    S3D_SB_buildCustomShape = "S3D.SB.buildCustomShape"
    S3D_SB_solve = "S3D.SB.solve"
    S3D_SB_runGSD = "S3D.SB.runGSD"
    S3D_file_save = "S3D.file.save"
    S3D_file_open = "S3D.file.open"
    S3D_file_share = "S3D.file.share"
    S3D_file_getFileDirectory = "S3D.file.getFileDirectory"
