class SkyCivSections:
	American_AISC_2C_Shapes_2C3x3_5x0 = ["American","AISC","2C Shapes","2C3x3.5x0"]
	American_AISC_2C_Shapes_2C3x3_5x0_75 = ["American","AISC","2C Shapes","2C3x3.5x0.75"]
	American_AISC_2C_Shapes_2C3x3_5x0_375 = ["American","AISC","2C Shapes","2C3x3.5x0.375"]
	American_AISC_2C_Shapes_2C3x4_1x0 = ["American","AISC","2C Shapes","2C3x4.1x0"]
	American_AISC_2C_Shapes_2C3x4_1x0_75 = ["American","AISC","2C Shapes","2C3x4.1x0.75"]
	American_AISC_2C_Shapes_2C3x4_1x0_375 = ["American","AISC","2C Shapes","2C3x4.1x0.375"]
	American_AISC_2C_Shapes_2C3x5x0 = ["American","AISC","2C Shapes","2C3x5x0"]
	American_AISC_2C_Shapes_2C3x5x0_75 = ["American","AISC","2C Shapes","2C3x5x0.75"]
	American_AISC_2C_Shapes_2C3x5x0_375 = ["American","AISC","2C Shapes","2C3x5x0.375"]
	American_AISC_2C_Shapes_2C3x6x0 = ["American","AISC","2C Shapes","2C3x6x0"]
	American_AISC_2C_Shapes_2C3x6x0_75 = ["American","AISC","2C Shapes","2C3x6x0.75"]
	American_AISC_2C_Shapes_2C3x6x0_375 = ["American","AISC","2C Shapes","2C3x6x0.375"]
	American_AISC_2C_Shapes_2C4x4_5x0 = ["American","AISC","2C Shapes","2C4x4.5x0"]
	American_AISC_2C_Shapes_2C4x4_5x0_75 = ["American","AISC","2C Shapes","2C4x4.5x0.75"]
	American_AISC_2C_Shapes_2C4x4_5x0_375 = ["American","AISC","2C Shapes","2C4x4.5x0.375"]
	American_AISC_2C_Shapes_2C4x5_4x0 = ["American","AISC","2C Shapes","2C4x5.4x0"]
	American_AISC_2C_Shapes_2C4x5_4x0_75 = ["American","AISC","2C Shapes","2C4x5.4x0.75"]
	American_AISC_2C_Shapes_2C4x5_4x0_375 = ["American","AISC","2C Shapes","2C4x5.4x0.375"]
	American_AISC_2C_Shapes_2C4x6_25x0 = ["American","AISC","2C Shapes","2C4x6.25x0"]
	American_AISC_2C_Shapes_2C4x6_25x0_75 = ["American","AISC","2C Shapes","2C4x6.25x0.75"]
	American_AISC_2C_Shapes_2C4x6_25x0_375 = ["American","AISC","2C Shapes","2C4x6.25x0.375"]
	American_AISC_2C_Shapes_2C4x7_25x0 = ["American","AISC","2C Shapes","2C4x7.25x0"]
	American_AISC_2C_Shapes_2C4x7_25x0_75 = ["American","AISC","2C Shapes","2C4x7.25x0.75"]
	American_AISC_2C_Shapes_2C4x7_25x0_375 = ["American","AISC","2C Shapes","2C4x7.25x0.375"]
	American_AISC_2C_Shapes_2C5x6_7x0 = ["American","AISC","2C Shapes","2C5x6.7x0"]
	American_AISC_2C_Shapes_2C5x6_7x0_75 = ["American","AISC","2C Shapes","2C5x6.7x0.75"]
	American_AISC_2C_Shapes_2C5x6_7x0_375 = ["American","AISC","2C Shapes","2C5x6.7x0.375"]
	American_AISC_2C_Shapes_2C5x9x0 = ["American","AISC","2C Shapes","2C5x9x0"]
	American_AISC_2C_Shapes_2C5x9x0_75 = ["American","AISC","2C Shapes","2C5x9x0.75"]
	American_AISC_2C_Shapes_2C5x9x0_375 = ["American","AISC","2C Shapes","2C5x9x0.375"]
	American_AISC_2C_Shapes_2C6x8_2x0 = ["American","AISC","2C Shapes","2C6x8.2x0"]
	American_AISC_2C_Shapes_2C6x8_2x0_75 = ["American","AISC","2C Shapes","2C6x8.2x0.75"]
	American_AISC_2C_Shapes_2C6x8_2x0_375 = ["American","AISC","2C Shapes","2C6x8.2x0.375"]
	American_AISC_2C_Shapes_2C6x10_5x0 = ["American","AISC","2C Shapes","2C6x10.5x0"]
	American_AISC_2C_Shapes_2C6x10_5x0_75 = ["American","AISC","2C Shapes","2C6x10.5x0.75"]
	American_AISC_2C_Shapes_2C6x10_5x0_375 = ["American","AISC","2C Shapes","2C6x10.5x0.375"]
	American_AISC_2C_Shapes_2C6x13x0 = ["American","AISC","2C Shapes","2C6x13x0"]
	American_AISC_2C_Shapes_2C6x13x0_75 = ["American","AISC","2C Shapes","2C6x13x0.75"]
	American_AISC_2C_Shapes_2C6x13x0_375 = ["American","AISC","2C Shapes","2C6x13x0.375"]
	American_AISC_2C_Shapes_2C7x9_8x0 = ["American","AISC","2C Shapes","2C7x9.8x0"]
	American_AISC_2C_Shapes_2C7x9_8x0_75 = ["American","AISC","2C Shapes","2C7x9.8x0.75"]
	American_AISC_2C_Shapes_2C7x9_8x0_375 = ["American","AISC","2C Shapes","2C7x9.8x0.375"]
	American_AISC_2C_Shapes_2C7x12_25x0 = ["American","AISC","2C Shapes","2C7x12.25x0"]
	American_AISC_2C_Shapes_2C7x12_25x0_75 = ["American","AISC","2C Shapes","2C7x12.25x0.75"]
	American_AISC_2C_Shapes_2C7x12_25x0_375 = ["American","AISC","2C Shapes","2C7x12.25x0.375"]
	American_AISC_2C_Shapes_2C7x14_75x0 = ["American","AISC","2C Shapes","2C7x14.75x0"]
	American_AISC_2C_Shapes_2C7x14_75x0_75 = ["American","AISC","2C Shapes","2C7x14.75x0.75"]
	American_AISC_2C_Shapes_2C7x14_75x0_375 = ["American","AISC","2C Shapes","2C7x14.75x0.375"]
	American_AISC_2C_Shapes_2C8x11_5x0 = ["American","AISC","2C Shapes","2C8x11.5x0"]
	American_AISC_2C_Shapes_2C8x11_5x0_75 = ["American","AISC","2C Shapes","2C8x11.5x0.75"]
	American_AISC_2C_Shapes_2C8x11_5x0_375 = ["American","AISC","2C Shapes","2C8x11.5x0.375"]
	American_AISC_2C_Shapes_2C8x13_75x0 = ["American","AISC","2C Shapes","2C8x13.75x0"]
	American_AISC_2C_Shapes_2C8x13_75x0_75 = ["American","AISC","2C Shapes","2C8x13.75x0.75"]
	American_AISC_2C_Shapes_2C8x13_75x0_375 = ["American","AISC","2C Shapes","2C8x13.75x0.375"]
	American_AISC_2C_Shapes_2C8x18_75x0 = ["American","AISC","2C Shapes","2C8x18.75x0"]
	American_AISC_2C_Shapes_2C8x18_75x0_75 = ["American","AISC","2C Shapes","2C8x18.75x0.75"]
	American_AISC_2C_Shapes_2C8x18_75x0_375 = ["American","AISC","2C Shapes","2C8x18.75x0.375"]
	American_AISC_2C_Shapes_2C9x13_4x0 = ["American","AISC","2C Shapes","2C9x13.4x0"]
	American_AISC_2C_Shapes_2C9x13_4x0_75 = ["American","AISC","2C Shapes","2C9x13.4x0.75"]
	American_AISC_2C_Shapes_2C9x13_4x0_375 = ["American","AISC","2C Shapes","2C9x13.4x0.375"]
	American_AISC_2C_Shapes_2C9x15x0 = ["American","AISC","2C Shapes","2C9x15x0"]
	American_AISC_2C_Shapes_2C9x15x0_75 = ["American","AISC","2C Shapes","2C9x15x0.75"]
	American_AISC_2C_Shapes_2C9x15x0_375 = ["American","AISC","2C Shapes","2C9x15x0.375"]
	American_AISC_2C_Shapes_2C9x20x0 = ["American","AISC","2C Shapes","2C9x20x0"]
	American_AISC_2C_Shapes_2C9x20x0_75 = ["American","AISC","2C Shapes","2C9x20x0.75"]
	American_AISC_2C_Shapes_2C9x20x0_375 = ["American","AISC","2C Shapes","2C9x20x0.375"]
	American_AISC_2C_Shapes_2C10x15_3x0 = ["American","AISC","2C Shapes","2C10x15.3x0"]
	American_AISC_2C_Shapes_2C10x15_3x0_75 = ["American","AISC","2C Shapes","2C10x15.3x0.75"]
	American_AISC_2C_Shapes_2C10x15_3x0_375 = ["American","AISC","2C Shapes","2C10x15.3x0.375"]
	American_AISC_2C_Shapes_2C10x20x0 = ["American","AISC","2C Shapes","2C10x20x0"]
	American_AISC_2C_Shapes_2C10x20x0_75 = ["American","AISC","2C Shapes","2C10x20x0.75"]
	American_AISC_2C_Shapes_2C10x20x0_375 = ["American","AISC","2C Shapes","2C10x20x0.375"]
	American_AISC_2C_Shapes_2C10x25x0 = ["American","AISC","2C Shapes","2C10x25x0"]
	American_AISC_2C_Shapes_2C10x25x0_75 = ["American","AISC","2C Shapes","2C10x25x0.75"]
	American_AISC_2C_Shapes_2C10x25x0_375 = ["American","AISC","2C Shapes","2C10x25x0.375"]
	American_AISC_2C_Shapes_2C10x30x0 = ["American","AISC","2C Shapes","2C10x30x0"]
	American_AISC_2C_Shapes_2C10x30x0_75 = ["American","AISC","2C Shapes","2C10x30x0.75"]
	American_AISC_2C_Shapes_2C10x30x0_375 = ["American","AISC","2C Shapes","2C10x30x0.375"]
	American_AISC_2C_Shapes_2C12x20_7x0 = ["American","AISC","2C Shapes","2C12x20.7x0"]
	American_AISC_2C_Shapes_2C12x20_7x0_75 = ["American","AISC","2C Shapes","2C12x20.7x0.75"]
	American_AISC_2C_Shapes_2C12x20_7x0_375 = ["American","AISC","2C Shapes","2C12x20.7x0.375"]
	American_AISC_2C_Shapes_2C12x25x0 = ["American","AISC","2C Shapes","2C12x25x0"]
	American_AISC_2C_Shapes_2C12x25x0_75 = ["American","AISC","2C Shapes","2C12x25x0.75"]
	American_AISC_2C_Shapes_2C12x25x0_375 = ["American","AISC","2C Shapes","2C12x25x0.375"]
	American_AISC_2C_Shapes_2C12x30x0 = ["American","AISC","2C Shapes","2C12x30x0"]
	American_AISC_2C_Shapes_2C12x30x0_75 = ["American","AISC","2C Shapes","2C12x30x0.75"]
	American_AISC_2C_Shapes_2C12x30x0_375 = ["American","AISC","2C Shapes","2C12x30x0.375"]
	American_AISC_2C_Shapes_2C15x33_9x0 = ["American","AISC","2C Shapes","2C15x33.9x0"]
	American_AISC_2C_Shapes_2C15x33_9x0_75 = ["American","AISC","2C Shapes","2C15x33.9x0.75"]
	American_AISC_2C_Shapes_2C15x33_9x0_375 = ["American","AISC","2C Shapes","2C15x33.9x0.375"]
	American_AISC_2C_Shapes_2C15x40x0 = ["American","AISC","2C Shapes","2C15x40x0"]
	American_AISC_2C_Shapes_2C15x40x0_75 = ["American","AISC","2C Shapes","2C15x40x0.75"]
	American_AISC_2C_Shapes_2C15x40x0_375 = ["American","AISC","2C Shapes","2C15x40x0.375"]
	American_AISC_2C_Shapes_2C15x50x0 = ["American","AISC","2C Shapes","2C15x50x0"]
	American_AISC_2C_Shapes_2C15x50x0_75 = ["American","AISC","2C Shapes","2C15x50x0.75"]
	American_AISC_2C_Shapes_2C15x50x0_375 = ["American","AISC","2C Shapes","2C15x50x0.375"]
	American_AISC_2MC_Shapes_2MC3x7_1x0 = ["American","AISC","2MC Shapes","2MC3x7.1x0"]
	American_AISC_2MC_Shapes_2MC3x7_1x0_75 = ["American","AISC","2MC Shapes","2MC3x7.1x0.75"]
	American_AISC_2MC_Shapes_2MC3x7_1x0_375 = ["American","AISC","2MC Shapes","2MC3x7.1x0.375"]
	American_AISC_2MC_Shapes_2MC4x13_8x0 = ["American","AISC","2MC Shapes","2MC4x13.8x0"]
	American_AISC_2MC_Shapes_2MC4x13_8x0_75 = ["American","AISC","2MC Shapes","2MC4x13.8x0.75"]
	American_AISC_2MC_Shapes_2MC4x13_8x0_375 = ["American","AISC","2MC Shapes","2MC4x13.8x0.375"]
	American_AISC_2MC_Shapes_2MC6x6_5x0 = ["American","AISC","2MC Shapes","2MC6x6.5x0"]
	American_AISC_2MC_Shapes_2MC6x6_5x0_75 = ["American","AISC","2MC Shapes","2MC6x6.5x0.75"]
	American_AISC_2MC_Shapes_2MC6x6_5x0_375 = ["American","AISC","2MC Shapes","2MC6x6.5x0.375"]
	American_AISC_2MC_Shapes_2MC6x7x0 = ["American","AISC","2MC Shapes","2MC6x7x0"]
	American_AISC_2MC_Shapes_2MC6x7x0_75 = ["American","AISC","2MC Shapes","2MC6x7x0.75"]
	American_AISC_2MC_Shapes_2MC6x7x0_375 = ["American","AISC","2MC Shapes","2MC6x7x0.375"]
	American_AISC_2MC_Shapes_2MC6x12x0 = ["American","AISC","2MC Shapes","2MC6x12x0"]
	American_AISC_2MC_Shapes_2MC6x12x0_75 = ["American","AISC","2MC Shapes","2MC6x12x0.75"]
	American_AISC_2MC_Shapes_2MC6x12x0_375 = ["American","AISC","2MC Shapes","2MC6x12x0.375"]
	American_AISC_2MC_Shapes_2MC6x15_1x0 = ["American","AISC","2MC Shapes","2MC6x15.1x0"]
	American_AISC_2MC_Shapes_2MC6x15_1x0_75 = ["American","AISC","2MC Shapes","2MC6x15.1x0.75"]
	American_AISC_2MC_Shapes_2MC6x15_1x0_375 = ["American","AISC","2MC Shapes","2MC6x15.1x0.375"]
	American_AISC_2MC_Shapes_2MC6x15_3x0 = ["American","AISC","2MC Shapes","2MC6x15.3x0"]
	American_AISC_2MC_Shapes_2MC6x15_3x0_75 = ["American","AISC","2MC Shapes","2MC6x15.3x0.75"]
	American_AISC_2MC_Shapes_2MC6x15_3x0_375 = ["American","AISC","2MC Shapes","2MC6x15.3x0.375"]
	American_AISC_2MC_Shapes_2MC6x16_3x0 = ["American","AISC","2MC Shapes","2MC6x16.3x0"]
	American_AISC_2MC_Shapes_2MC6x16_3x0_75 = ["American","AISC","2MC Shapes","2MC6x16.3x0.75"]
	American_AISC_2MC_Shapes_2MC6x16_3x0_375 = ["American","AISC","2MC Shapes","2MC6x16.3x0.375"]
	American_AISC_2MC_Shapes_2MC6x18x0 = ["American","AISC","2MC Shapes","2MC6x18x0"]
	American_AISC_2MC_Shapes_2MC6x18x0_75 = ["American","AISC","2MC Shapes","2MC6x18x0.75"]
	American_AISC_2MC_Shapes_2MC6x18x0_375 = ["American","AISC","2MC Shapes","2MC6x18x0.375"]
	American_AISC_2MC_Shapes_2MC7x19_1x0 = ["American","AISC","2MC Shapes","2MC7x19.1x0"]
	American_AISC_2MC_Shapes_2MC7x19_1x0_75 = ["American","AISC","2MC Shapes","2MC7x19.1x0.75"]
	American_AISC_2MC_Shapes_2MC7x19_1x0_375 = ["American","AISC","2MC Shapes","2MC7x19.1x0.375"]
	American_AISC_2MC_Shapes_2MC7x22_7x0 = ["American","AISC","2MC Shapes","2MC7x22.7x0"]
	American_AISC_2MC_Shapes_2MC7x22_7x0_75 = ["American","AISC","2MC Shapes","2MC7x22.7x0.75"]
	American_AISC_2MC_Shapes_2MC7x22_7x0_375 = ["American","AISC","2MC Shapes","2MC7x22.7x0.375"]
	American_AISC_2MC_Shapes_2MC8x8_5x0 = ["American","AISC","2MC Shapes","2MC8x8.5x0"]
	American_AISC_2MC_Shapes_2MC8x8_5x0_75 = ["American","AISC","2MC Shapes","2MC8x8.5x0.75"]
	American_AISC_2MC_Shapes_2MC8x8_5x0_375 = ["American","AISC","2MC Shapes","2MC8x8.5x0.375"]
	American_AISC_2MC_Shapes_2MC8x18_7x0 = ["American","AISC","2MC Shapes","2MC8x18.7x0"]
	American_AISC_2MC_Shapes_2MC8x18_7x0_75 = ["American","AISC","2MC Shapes","2MC8x18.7x0.75"]
	American_AISC_2MC_Shapes_2MC8x18_7x0_375 = ["American","AISC","2MC Shapes","2MC8x18.7x0.375"]
	American_AISC_2MC_Shapes_2MC8x20x0 = ["American","AISC","2MC Shapes","2MC8x20x0"]
	American_AISC_2MC_Shapes_2MC8x20x0_75 = ["American","AISC","2MC Shapes","2MC8x20x0.75"]
	American_AISC_2MC_Shapes_2MC8x20x0_375 = ["American","AISC","2MC Shapes","2MC8x20x0.375"]
	American_AISC_2MC_Shapes_2MC8x21_4x0 = ["American","AISC","2MC Shapes","2MC8x21.4x0"]
	American_AISC_2MC_Shapes_2MC8x21_4x0_75 = ["American","AISC","2MC Shapes","2MC8x21.4x0.75"]
	American_AISC_2MC_Shapes_2MC8x21_4x0_375 = ["American","AISC","2MC Shapes","2MC8x21.4x0.375"]
	American_AISC_2MC_Shapes_2MC8x22_8x0 = ["American","AISC","2MC Shapes","2MC8x22.8x0"]
	American_AISC_2MC_Shapes_2MC8x22_8x0_75 = ["American","AISC","2MC Shapes","2MC8x22.8x0.75"]
	American_AISC_2MC_Shapes_2MC8x22_8x0_375 = ["American","AISC","2MC Shapes","2MC8x22.8x0.375"]
	American_AISC_2MC_Shapes_2MC9x23_9x0 = ["American","AISC","2MC Shapes","2MC9x23.9x0"]
	American_AISC_2MC_Shapes_2MC9x23_9x0_75 = ["American","AISC","2MC Shapes","2MC9x23.9x0.75"]
	American_AISC_2MC_Shapes_2MC9x23_9x0_375 = ["American","AISC","2MC Shapes","2MC9x23.9x0.375"]
	American_AISC_2MC_Shapes_2MC9x25_4x0 = ["American","AISC","2MC Shapes","2MC9x25.4x0"]
	American_AISC_2MC_Shapes_2MC9x25_4x0_75 = ["American","AISC","2MC Shapes","2MC9x25.4x0.75"]
	American_AISC_2MC_Shapes_2MC9x25_4x0_375 = ["American","AISC","2MC Shapes","2MC9x25.4x0.375"]
	American_AISC_2MC_Shapes_2MC10x6_5x0 = ["American","AISC","2MC Shapes","2MC10x6.5x0"]
	American_AISC_2MC_Shapes_2MC10x6_5x0_75 = ["American","AISC","2MC Shapes","2MC10x6.5x0.75"]
	American_AISC_2MC_Shapes_2MC10x6_5x0_375 = ["American","AISC","2MC Shapes","2MC10x6.5x0.375"]
	American_AISC_2MC_Shapes_2MC10x8_4x0 = ["American","AISC","2MC Shapes","2MC10x8.4x0"]
	American_AISC_2MC_Shapes_2MC10x8_4x0_75 = ["American","AISC","2MC Shapes","2MC10x8.4x0.75"]
	American_AISC_2MC_Shapes_2MC10x8_4x0_375 = ["American","AISC","2MC Shapes","2MC10x8.4x0.375"]
	American_AISC_2MC_Shapes_2MC10x22x0 = ["American","AISC","2MC Shapes","2MC10x22x0"]
	American_AISC_2MC_Shapes_2MC10x22x0_75 = ["American","AISC","2MC Shapes","2MC10x22x0.75"]
	American_AISC_2MC_Shapes_2MC10x22x0_375 = ["American","AISC","2MC Shapes","2MC10x22x0.375"]
	American_AISC_2MC_Shapes_2MC10x25x0 = ["American","AISC","2MC Shapes","2MC10x25x0"]
	American_AISC_2MC_Shapes_2MC10x25x0_75 = ["American","AISC","2MC Shapes","2MC10x25x0.75"]
	American_AISC_2MC_Shapes_2MC10x25x0_375 = ["American","AISC","2MC Shapes","2MC10x25x0.375"]
	American_AISC_2MC_Shapes_2MC10x28_5x0 = ["American","AISC","2MC Shapes","2MC10x28.5x0"]
	American_AISC_2MC_Shapes_2MC10x28_5x0_75 = ["American","AISC","2MC Shapes","2MC10x28.5x0.75"]
	American_AISC_2MC_Shapes_2MC10x28_5x0_375 = ["American","AISC","2MC Shapes","2MC10x28.5x0.375"]
	American_AISC_2MC_Shapes_2MC10x33_6x0 = ["American","AISC","2MC Shapes","2MC10x33.6x0"]
	American_AISC_2MC_Shapes_2MC10x33_6x0_75 = ["American","AISC","2MC Shapes","2MC10x33.6x0.75"]
	American_AISC_2MC_Shapes_2MC10x33_6x0_375 = ["American","AISC","2MC Shapes","2MC10x33.6x0.375"]
	American_AISC_2MC_Shapes_2MC10x41_1x0 = ["American","AISC","2MC Shapes","2MC10x41.1x0"]
	American_AISC_2MC_Shapes_2MC10x41_1x0_75 = ["American","AISC","2MC Shapes","2MC10x41.1x0.75"]
	American_AISC_2MC_Shapes_2MC10x41_1x0_375 = ["American","AISC","2MC Shapes","2MC10x41.1x0.375"]
	American_AISC_2MC_Shapes_2MC12x10_6x0 = ["American","AISC","2MC Shapes","2MC12x10.6x0"]
	American_AISC_2MC_Shapes_2MC12x10_6x0_75 = ["American","AISC","2MC Shapes","2MC12x10.6x0.75"]
	American_AISC_2MC_Shapes_2MC12x10_6x0_375 = ["American","AISC","2MC Shapes","2MC12x10.6x0.375"]
	American_AISC_2MC_Shapes_2MC12x14_3x0 = ["American","AISC","2MC Shapes","2MC12x14.3x0"]
	American_AISC_2MC_Shapes_2MC12x14_3x0_75 = ["American","AISC","2MC Shapes","2MC12x14.3x0.75"]
	American_AISC_2MC_Shapes_2MC12x14_3x0_375 = ["American","AISC","2MC Shapes","2MC12x14.3x0.375"]
	American_AISC_2MC_Shapes_2MC12x31x0 = ["American","AISC","2MC Shapes","2MC12x31x0"]
	American_AISC_2MC_Shapes_2MC12x31x0_75 = ["American","AISC","2MC Shapes","2MC12x31x0.75"]
	American_AISC_2MC_Shapes_2MC12x31x0_375 = ["American","AISC","2MC Shapes","2MC12x31x0.375"]
	American_AISC_2MC_Shapes_2MC12x35x0 = ["American","AISC","2MC Shapes","2MC12x35x0"]
	American_AISC_2MC_Shapes_2MC12x35x0_75 = ["American","AISC","2MC Shapes","2MC12x35x0.75"]
	American_AISC_2MC_Shapes_2MC12x35x0_375 = ["American","AISC","2MC Shapes","2MC12x35x0.375"]
	American_AISC_2MC_Shapes_2MC12x40x0 = ["American","AISC","2MC Shapes","2MC12x40x0"]
	American_AISC_2MC_Shapes_2MC12x40x0_75 = ["American","AISC","2MC Shapes","2MC12x40x0.75"]
	American_AISC_2MC_Shapes_2MC12x40x0_375 = ["American","AISC","2MC Shapes","2MC12x40x0.375"]
	American_AISC_2MC_Shapes_2MC12x45x0 = ["American","AISC","2MC Shapes","2MC12x45x0"]
	American_AISC_2MC_Shapes_2MC12x45x0_75 = ["American","AISC","2MC Shapes","2MC12x45x0.75"]
	American_AISC_2MC_Shapes_2MC12x45x0_375 = ["American","AISC","2MC Shapes","2MC12x45x0.375"]
	American_AISC_2MC_Shapes_2MC12x50x0 = ["American","AISC","2MC Shapes","2MC12x50x0"]
	American_AISC_2MC_Shapes_2MC12x50x0_75 = ["American","AISC","2MC Shapes","2MC12x50x0.75"]
	American_AISC_2MC_Shapes_2MC12x50x0_375 = ["American","AISC","2MC Shapes","2MC12x50x0.375"]
	American_AISC_2MC_Shapes_2MC13x31_8x0 = ["American","AISC","2MC Shapes","2MC13x31.8x0"]
	American_AISC_2MC_Shapes_2MC13x31_8x0_75 = ["American","AISC","2MC Shapes","2MC13x31.8x0.75"]
	American_AISC_2MC_Shapes_2MC13x31_8x0_375 = ["American","AISC","2MC Shapes","2MC13x31.8x0.375"]
	American_AISC_2MC_Shapes_2MC13x35x0 = ["American","AISC","2MC Shapes","2MC13x35x0"]
	American_AISC_2MC_Shapes_2MC13x35x0_75 = ["American","AISC","2MC Shapes","2MC13x35x0.75"]
	American_AISC_2MC_Shapes_2MC13x35x0_375 = ["American","AISC","2MC Shapes","2MC13x35x0.375"]
	American_AISC_2MC_Shapes_2MC13x40x0 = ["American","AISC","2MC Shapes","2MC13x40x0"]
	American_AISC_2MC_Shapes_2MC13x40x0_75 = ["American","AISC","2MC Shapes","2MC13x40x0.75"]
	American_AISC_2MC_Shapes_2MC13x40x0_375 = ["American","AISC","2MC Shapes","2MC13x40x0.375"]
	American_AISC_2MC_Shapes_2MC13x50x0 = ["American","AISC","2MC Shapes","2MC13x50x0"]
	American_AISC_2MC_Shapes_2MC13x50x0_75 = ["American","AISC","2MC Shapes","2MC13x50x0.75"]
	American_AISC_2MC_Shapes_2MC13x50x0_375 = ["American","AISC","2MC Shapes","2MC13x50x0.375"]
	American_AISC_2MC_Shapes_2MC18x42_7x0 = ["American","AISC","2MC Shapes","2MC18x42.7x0"]
	American_AISC_2MC_Shapes_2MC18x42_7x0_75 = ["American","AISC","2MC Shapes","2MC18x42.7x0.75"]
	American_AISC_2MC_Shapes_2MC18x42_7x0_375 = ["American","AISC","2MC Shapes","2MC18x42.7x0.375"]
	American_AISC_2MC_Shapes_2MC18x45_8x0 = ["American","AISC","2MC Shapes","2MC18x45.8x0"]
	American_AISC_2MC_Shapes_2MC18x45_8x0_75 = ["American","AISC","2MC Shapes","2MC18x45.8x0.75"]
	American_AISC_2MC_Shapes_2MC18x45_8x0_375 = ["American","AISC","2MC Shapes","2MC18x45.8x0.375"]
	American_AISC_2MC_Shapes_2MC18x51_9x0 = ["American","AISC","2MC Shapes","2MC18x51.9x0"]
	American_AISC_2MC_Shapes_2MC18x51_9x0_75 = ["American","AISC","2MC Shapes","2MC18x51.9x0.75"]
	American_AISC_2MC_Shapes_2MC18x51_9x0_375 = ["American","AISC","2MC Shapes","2MC18x51.9x0.375"]
	American_AISC_2MC_Shapes_2MC18x58x0 = ["American","AISC","2MC Shapes","2MC18x58x0"]
	American_AISC_2MC_Shapes_2MC18x58x0_75 = ["American","AISC","2MC Shapes","2MC18x58x0.75"]
	American_AISC_2MC_Shapes_2MC18x58x0_375 = ["American","AISC","2MC Shapes","2MC18x58x0.375"]
	American_AISC_American_standard_channels_C3x3_5 = ["American","AISC","American standard channels","C3x3.5"]
	American_AISC_American_standard_channels_C3x4_1 = ["American","AISC","American standard channels","C3x4.1"]
	American_AISC_American_standard_channels_C3x5 = ["American","AISC","American standard channels","C3x5"]
	American_AISC_American_standard_channels_C3x6 = ["American","AISC","American standard channels","C3x6"]
	American_AISC_American_standard_channels_C4x4_5 = ["American","AISC","American standard channels","C4x4.5"]
	American_AISC_American_standard_channels_C4x5_4 = ["American","AISC","American standard channels","C4x5.4"]
	American_AISC_American_standard_channels_C4x6_25 = ["American","AISC","American standard channels","C4x6.25"]
	American_AISC_American_standard_channels_C4x7_25 = ["American","AISC","American standard channels","C4x7.25"]
	American_AISC_American_standard_channels_C5x6_7 = ["American","AISC","American standard channels","C5x6.7"]
	American_AISC_American_standard_channels_C5x9 = ["American","AISC","American standard channels","C5x9"]
	American_AISC_American_standard_channels_C6x8_2 = ["American","AISC","American standard channels","C6x8.2"]
	American_AISC_American_standard_channels_C6x10_5 = ["American","AISC","American standard channels","C6x10.5"]
	American_AISC_American_standard_channels_C6x13 = ["American","AISC","American standard channels","C6x13"]
	American_AISC_American_standard_channels_C7x9_8 = ["American","AISC","American standard channels","C7x9.8"]
	American_AISC_American_standard_channels_C7x12_25 = ["American","AISC","American standard channels","C7x12.25"]
	American_AISC_American_standard_channels_C7x14_75 = ["American","AISC","American standard channels","C7x14.75"]
	American_AISC_American_standard_channels_C8x11_5 = ["American","AISC","American standard channels","C8x11.5"]
	American_AISC_American_standard_channels_C8x13_75 = ["American","AISC","American standard channels","C8x13.75"]
	American_AISC_American_standard_channels_C8x18_75 = ["American","AISC","American standard channels","C8x18.75"]
	American_AISC_American_standard_channels_C9x13_4 = ["American","AISC","American standard channels","C9x13.4"]
	American_AISC_American_standard_channels_C9x15 = ["American","AISC","American standard channels","C9x15"]
	American_AISC_American_standard_channels_C9x20 = ["American","AISC","American standard channels","C9x20"]
	American_AISC_American_standard_channels_C10x15_3 = ["American","AISC","American standard channels","C10x15.3"]
	American_AISC_American_standard_channels_C10x20 = ["American","AISC","American standard channels","C10x20"]
	American_AISC_American_standard_channels_C10x25 = ["American","AISC","American standard channels","C10x25"]
	American_AISC_American_standard_channels_C10x30 = ["American","AISC","American standard channels","C10x30"]
	American_AISC_American_standard_channels_C12x20_7 = ["American","AISC","American standard channels","C12x20.7"]
	American_AISC_American_standard_channels_C12x25 = ["American","AISC","American standard channels","C12x25"]
	American_AISC_American_standard_channels_C12x30 = ["American","AISC","American standard channels","C12x30"]
	American_AISC_American_standard_channels_C15x33_9 = ["American","AISC","American standard channels","C15x33.9"]
	American_AISC_American_standard_channels_C15x40 = ["American","AISC","American standard channels","C15x40"]
	American_AISC_American_standard_channels_C15x50 = ["American","AISC","American standard channels","C15x50"]
	American_AISC_Column_Tees_ST1_5x2_85 = ["American","AISC","Column Tees","ST1.5x2.85"]
	American_AISC_Column_Tees_ST1_5x3_75 = ["American","AISC","Column Tees","ST1.5x3.75"]
	American_AISC_Column_Tees_ST2x3_85 = ["American","AISC","Column Tees","ST2x3.85"]
	American_AISC_Column_Tees_WT2_5x8 = ["American","AISC","Column Tees","WT2.5x8"]
	American_AISC_Column_Tees_WT2_5x9_5 = ["American","AISC","Column Tees","WT2.5x9.5"]
	American_AISC_Column_Tees_WT2x6_5 = ["American","AISC","Column Tees","WT2x6.5"]
	American_AISC_Column_Tees_WT3x4_5 = ["American","AISC","Column Tees","WT3x4.5"]
	American_AISC_Column_Tees_WT3x4_25 = ["American","AISC","Column Tees","WT3x4.25"]
	American_AISC_Column_Tees_WT3x6 = ["American","AISC","Column Tees","WT3x6"]
	American_AISC_Column_Tees_WT3x7_5 = ["American","AISC","Column Tees","WT3x7.5"]
	American_AISC_Column_Tees_WT3x8 = ["American","AISC","Column Tees","WT3x8"]
	American_AISC_Column_Tees_WT3x10 = ["American","AISC","Column Tees","WT3x10"]
	American_AISC_Column_Tees_WT3x12_5 = ["American","AISC","Column Tees","WT3x12.5"]
	American_AISC_Column_Tees_WT4x9 = ["American","AISC","Column Tees","WT4x9"]
	American_AISC_Column_Tees_WT4x10_5 = ["American","AISC","Column Tees","WT4x10.5"]
	American_AISC_Column_Tees_WT4x12 = ["American","AISC","Column Tees","WT4x12"]
	American_AISC_Column_Tees_WT4x14 = ["American","AISC","Column Tees","WT4x14"]
	American_AISC_Column_Tees_WT4x15_5 = ["American","AISC","Column Tees","WT4x15.5"]
	American_AISC_Column_Tees_WT4x17_5 = ["American","AISC","Column Tees","WT4x17.5"]
	American_AISC_Column_Tees_WT4x20 = ["American","AISC","Column Tees","WT4x20"]
	American_AISC_Column_Tees_WT4x24 = ["American","AISC","Column Tees","WT4x24"]
	American_AISC_Column_Tees_WT4x29 = ["American","AISC","Column Tees","WT4x29"]
	American_AISC_Column_Tees_WT4x33_5 = ["American","AISC","Column Tees","WT4x33.5"]
	American_AISC_Column_Tees_WT5x16_5 = ["American","AISC","Column Tees","WT5x16.5"]
	American_AISC_Column_Tees_WT5x19_5 = ["American","AISC","Column Tees","WT5x19.5"]
	American_AISC_Column_Tees_WT5x22_5 = ["American","AISC","Column Tees","WT5x22.5"]
	American_AISC_Column_Tees_WT5x24_5 = ["American","AISC","Column Tees","WT5x24.5"]
	American_AISC_Column_Tees_WT5x27 = ["American","AISC","Column Tees","WT5x27"]
	American_AISC_Column_Tees_WT5x30 = ["American","AISC","Column Tees","WT5x30"]
	American_AISC_Column_Tees_WT5x34 = ["American","AISC","Column Tees","WT5x34"]
	American_AISC_Column_Tees_WT5x38_5 = ["American","AISC","Column Tees","WT5x38.5"]
	American_AISC_Column_Tees_WT5x44 = ["American","AISC","Column Tees","WT5x44"]
	American_AISC_Column_Tees_WT5x50 = ["American","AISC","Column Tees","WT5x50"]
	American_AISC_Column_Tees_WT5x56 = ["American","AISC","Column Tees","WT5x56"]
	American_AISC_Column_Tees_WT6x20 = ["American","AISC","Column Tees","WT6x20"]
	American_AISC_Column_Tees_WT6x22_5 = ["American","AISC","Column Tees","WT6x22.5"]
	American_AISC_Column_Tees_WT6x25 = ["American","AISC","Column Tees","WT6x25"]
	American_AISC_Column_Tees_WT6x26_5 = ["American","AISC","Column Tees","WT6x26.5"]
	American_AISC_Column_Tees_WT6x29 = ["American","AISC","Column Tees","WT6x29"]
	American_AISC_Column_Tees_WT6x32_5 = ["American","AISC","Column Tees","WT6x32.5"]
	American_AISC_Column_Tees_WT6x36 = ["American","AISC","Column Tees","WT6x36"]
	American_AISC_Column_Tees_WT6x39_5 = ["American","AISC","Column Tees","WT6x39.5"]
	American_AISC_Column_Tees_WT6x43_5 = ["American","AISC","Column Tees","WT6x43.5"]
	American_AISC_Column_Tees_WT6x48 = ["American","AISC","Column Tees","WT6x48"]
	American_AISC_Column_Tees_WT6x53 = ["American","AISC","Column Tees","WT6x53"]
	American_AISC_Column_Tees_WT6x60 = ["American","AISC","Column Tees","WT6x60"]
	American_AISC_Column_Tees_WT6x68 = ["American","AISC","Column Tees","WT6x68"]
	American_AISC_Column_Tees_WT6x76 = ["American","AISC","Column Tees","WT6x76"]
	American_AISC_Column_Tees_WT6x85 = ["American","AISC","Column Tees","WT6x85"]
	American_AISC_Column_Tees_WT6x95 = ["American","AISC","Column Tees","WT6x95"]
	American_AISC_Column_Tees_WT6x105 = ["American","AISC","Column Tees","WT6x105"]
	American_AISC_Column_Tees_WT6x115 = ["American","AISC","Column Tees","WT6x115"]
	American_AISC_Column_Tees_WT6x126 = ["American","AISC","Column Tees","WT6x126"]
	American_AISC_Column_Tees_WT6x139_5 = ["American","AISC","Column Tees","WT6x139.5"]
	American_AISC_Column_Tees_WT6x152_5 = ["American","AISC","Column Tees","WT6x152.5"]
	American_AISC_Column_Tees_WT6x168 = ["American","AISC","Column Tees","WT6x168"]
	American_AISC_Column_Tees_WT7x21_5 = ["American","AISC","Column Tees","WT7x21.5"]
	American_AISC_Column_Tees_WT7x24 = ["American","AISC","Column Tees","WT7x24"]
	American_AISC_Column_Tees_WT7x26_5 = ["American","AISC","Column Tees","WT7x26.5"]
	American_AISC_Column_Tees_WT7x30_5 = ["American","AISC","Column Tees","WT7x30.5"]
	American_AISC_Column_Tees_WT7x34 = ["American","AISC","Column Tees","WT7x34"]
	American_AISC_Column_Tees_WT7x37 = ["American","AISC","Column Tees","WT7x37"]
	American_AISC_Column_Tees_WT7x41 = ["American","AISC","Column Tees","WT7x41"]
	American_AISC_Column_Tees_WT7x45 = ["American","AISC","Column Tees","WT7x45"]
	American_AISC_Column_Tees_WT7x49_5 = ["American","AISC","Column Tees","WT7x49.5"]
	American_AISC_Column_Tees_WT7x54_5 = ["American","AISC","Column Tees","WT7x54.5"]
	American_AISC_Column_Tees_WT7x60 = ["American","AISC","Column Tees","WT7x60"]
	American_AISC_Column_Tees_WT7x66 = ["American","AISC","Column Tees","WT7x66"]
	American_AISC_Column_Tees_WT7x72_5 = ["American","AISC","Column Tees","WT7x72.5"]
	American_AISC_Column_Tees_WT7x79_5 = ["American","AISC","Column Tees","WT7x79.5"]
	American_AISC_Column_Tees_WT7x88 = ["American","AISC","Column Tees","WT7x88"]
	American_AISC_Column_Tees_WT7x96_5 = ["American","AISC","Column Tees","WT7x96.5"]
	American_AISC_Column_Tees_WT7x105_5 = ["American","AISC","Column Tees","WT7x105.5"]
	American_AISC_Column_Tees_WT7x116_5 = ["American","AISC","Column Tees","WT7x116.5"]
	American_AISC_Column_Tees_WT7x128_5 = ["American","AISC","Column Tees","WT7x128.5"]
	American_AISC_Column_Tees_WT7x141_5 = ["American","AISC","Column Tees","WT7x141.5"]
	American_AISC_Column_Tees_WT7x155_5 = ["American","AISC","Column Tees","WT7x155.5"]
	American_AISC_Column_Tees_WT7x171 = ["American","AISC","Column Tees","WT7x171"]
	American_AISC_Column_Tees_WT7x185 = ["American","AISC","Column Tees","WT7x185"]
	American_AISC_Column_Tees_WT7x199 = ["American","AISC","Column Tees","WT7x199"]
	American_AISC_Column_Tees_WT7x213 = ["American","AISC","Column Tees","WT7x213"]
	American_AISC_Column_Tees_WT7x227_5 = ["American","AISC","Column Tees","WT7x227.5"]
	American_AISC_Column_Tees_WT7x250 = ["American","AISC","Column Tees","WT7x250"]
	American_AISC_Column_Tees_WT7x275 = ["American","AISC","Column Tees","WT7x275"]
	American_AISC_Column_Tees_WT7x302_5 = ["American","AISC","Column Tees","WT7x302.5"]
	American_AISC_Column_Tees_WT7x332_5 = ["American","AISC","Column Tees","WT7x332.5"]
	American_AISC_Column_Tees_WT7x365 = ["American","AISC","Column Tees","WT7x365"]
	American_AISC_Column_Tees_WT7x404 = ["American","AISC","Column Tees","WT7x404"]
	American_AISC_Column_Tees_WT8x33_5 = ["American","AISC","Column Tees","WT8x33.5"]
	American_AISC_Column_Tees_WT8x38_5 = ["American","AISC","Column Tees","WT8x38.5"]
	American_AISC_Column_Tees_WT8x44_5 = ["American","AISC","Column Tees","WT8x44.5"]
	American_AISC_Column_Tees_WT8x50 = ["American","AISC","Column Tees","WT8x50"]
	American_AISC_Column_Tees_WT9x38 = ["American","AISC","Column Tees","WT9x38"]
	American_AISC_Column_Tees_WT9x43 = ["American","AISC","Column Tees","WT9x43"]
	American_AISC_Column_Tees_WT9x48_5 = ["American","AISC","Column Tees","WT9x48.5"]
	American_AISC_Column_Tees_WT9x53 = ["American","AISC","Column Tees","WT9x53"]
	American_AISC_Column_Tees_WT9x59_5 = ["American","AISC","Column Tees","WT9x59.5"]
	American_AISC_Column_Tees_WT9x65 = ["American","AISC","Column Tees","WT9x65"]
	American_AISC_Column_Tees_WT9x71_5 = ["American","AISC","Column Tees","WT9x71.5"]
	American_AISC_Column_Tees_WT9x79 = ["American","AISC","Column Tees","WT9x79"]
	American_AISC_Column_Tees_WT9x87_5 = ["American","AISC","Column Tees","WT9x87.5"]
	American_AISC_Column_Tees_WT9x96 = ["American","AISC","Column Tees","WT9x96"]
	American_AISC_Column_Tees_WT9x105_5 = ["American","AISC","Column Tees","WT9x105.5"]
	American_AISC_Column_Tees_WT9x117 = ["American","AISC","Column Tees","WT9x117"]
	American_AISC_Column_Tees_WT9x129 = ["American","AISC","Column Tees","WT9x129"]
	American_AISC_Column_Tees_WT9x141_5 = ["American","AISC","Column Tees","WT9x141.5"]
	American_AISC_Column_Tees_WT9x155_5 = ["American","AISC","Column Tees","WT9x155.5"]
	American_AISC_Double_Angle_2L2_12x1_12x14LLBB = ["American","AISC","Double Angle","2L2-1/2x1-1/2x1/4LLBB"]
	American_AISC_Double_Angle_2L2_12x1_12x14SLBB = ["American","AISC","Double Angle","2L2-1/2x1-1/2x1/4SLBB"]
	American_AISC_Double_Angle_2L2_12x1_12x14x34LLBB = ["American","AISC","Double Angle","2L2-1/2x1-1/2x1/4x3/4LLBB"]
	American_AISC_Double_Angle_2L2_12x1_12x14x34SLBB = ["American","AISC","Double Angle","2L2-1/2x1-1/2x1/4x3/4SLBB"]
	American_AISC_Double_Angle_2L2_12x1_12x14x38LLBB = ["American","AISC","Double Angle","2L2-1/2x1-1/2x1/4x3/8LLBB"]
	American_AISC_Double_Angle_2L2_12x1_12x14x38SLBB = ["American","AISC","Double Angle","2L2-1/2x1-1/2x1/4x3/8SLBB"]
	American_AISC_Double_Angle_2L2_12x1_12x316LLBB = ["American","AISC","Double Angle","2L2-1/2x1-1/2x3/16LLBB"]
	American_AISC_Double_Angle_2L2_12x1_12x316SLBB = ["American","AISC","Double Angle","2L2-1/2x1-1/2x3/16SLBB"]
	American_AISC_Double_Angle_2L2_12x1_12x316x34LLBB = ["American","AISC","Double Angle","2L2-1/2x1-1/2x3/16x3/4LLBB"]
	American_AISC_Double_Angle_2L2_12x1_12x316x34SLBB = ["American","AISC","Double Angle","2L2-1/2x1-1/2x3/16x3/4SLBB"]
	American_AISC_Double_Angle_2L2_12x1_12x316x38LLBB = ["American","AISC","Double Angle","2L2-1/2x1-1/2x3/16x3/8LLBB"]
	American_AISC_Double_Angle_2L2_12x1_12x316x38SLBB = ["American","AISC","Double Angle","2L2-1/2x1-1/2x3/16x3/8SLBB"]
	American_AISC_Double_Angle_2L2_12x2_12x12 = ["American","AISC","Double Angle","2L2-1/2x2-1/2x1/2"]
	American_AISC_Double_Angle_2L2_12x2_12x12x34 = ["American","AISC","Double Angle","2L2-1/2x2-1/2x1/2x3/4"]
	American_AISC_Double_Angle_2L2_12x2_12x12x38 = ["American","AISC","Double Angle","2L2-1/2x2-1/2x1/2x3/8"]
	American_AISC_Double_Angle_2L2_12x2_12x14 = ["American","AISC","Double Angle","2L2-1/2x2-1/2x1/4"]
	American_AISC_Double_Angle_2L2_12x2_12x14x34 = ["American","AISC","Double Angle","2L2-1/2x2-1/2x1/4x3/4"]
	American_AISC_Double_Angle_2L2_12x2_12x14x38 = ["American","AISC","Double Angle","2L2-1/2x2-1/2x1/4x3/8"]
	American_AISC_Double_Angle_2L2_12x2_12x38 = ["American","AISC","Double Angle","2L2-1/2x2-1/2x3/8"]
	American_AISC_Double_Angle_2L2_12x2_12x38x34 = ["American","AISC","Double Angle","2L2-1/2x2-1/2x3/8x3/4"]
	American_AISC_Double_Angle_2L2_12x2_12x38x38 = ["American","AISC","Double Angle","2L2-1/2x2-1/2x3/8x3/8"]
	American_AISC_Double_Angle_2L2_12x2_12x316 = ["American","AISC","Double Angle","2L2-1/2x2-1/2x3/16"]
	American_AISC_Double_Angle_2L2_12x2_12x316x34 = ["American","AISC","Double Angle","2L2-1/2x2-1/2x3/16x3/4"]
	American_AISC_Double_Angle_2L2_12x2_12x316x38 = ["American","AISC","Double Angle","2L2-1/2x2-1/2x3/16x3/8"]
	American_AISC_Double_Angle_2L2_12x2_12x516 = ["American","AISC","Double Angle","2L2-1/2x2-1/2x5/16"]
	American_AISC_Double_Angle_2L2_12x2_12x516x34 = ["American","AISC","Double Angle","2L2-1/2x2-1/2x5/16x3/4"]
	American_AISC_Double_Angle_2L2_12x2_12x516x38 = ["American","AISC","Double Angle","2L2-1/2x2-1/2x5/16x3/8"]
	American_AISC_Double_Angle_2L2_12x2x14LLBB = ["American","AISC","Double Angle","2L2-1/2x2x1/4LLBB"]
	American_AISC_Double_Angle_2L2_12x2x14SLBB = ["American","AISC","Double Angle","2L2-1/2x2x1/4SLBB"]
	American_AISC_Double_Angle_2L2_12x2x14x34LLBB = ["American","AISC","Double Angle","2L2-1/2x2x1/4x3/4LLBB"]
	American_AISC_Double_Angle_2L2_12x2x14x34SLBB = ["American","AISC","Double Angle","2L2-1/2x2x1/4x3/4SLBB"]
	American_AISC_Double_Angle_2L2_12x2x14x38LLBB = ["American","AISC","Double Angle","2L2-1/2x2x1/4x3/8LLBB"]
	American_AISC_Double_Angle_2L2_12x2x14x38SLBB = ["American","AISC","Double Angle","2L2-1/2x2x1/4x3/8SLBB"]
	American_AISC_Double_Angle_2L2_12x2x38LLBB = ["American","AISC","Double Angle","2L2-1/2x2x3/8LLBB"]
	American_AISC_Double_Angle_2L2_12x2x38SLBB = ["American","AISC","Double Angle","2L2-1/2x2x3/8SLBB"]
	American_AISC_Double_Angle_2L2_12x2x38x34LLBB = ["American","AISC","Double Angle","2L2-1/2x2x3/8x3/4LLBB"]
	American_AISC_Double_Angle_2L2_12x2x38x34SLBB = ["American","AISC","Double Angle","2L2-1/2x2x3/8x3/4SLBB"]
	American_AISC_Double_Angle_2L2_12x2x38x38LLBB = ["American","AISC","Double Angle","2L2-1/2x2x3/8x3/8LLBB"]
	American_AISC_Double_Angle_2L2_12x2x38x38SLBB = ["American","AISC","Double Angle","2L2-1/2x2x3/8x3/8SLBB"]
	American_AISC_Double_Angle_2L2_12x2x316LLBB = ["American","AISC","Double Angle","2L2-1/2x2x3/16LLBB"]
	American_AISC_Double_Angle_2L2_12x2x316SLBB = ["American","AISC","Double Angle","2L2-1/2x2x3/16SLBB"]
	American_AISC_Double_Angle_2L2_12x2x316x34LLBB = ["American","AISC","Double Angle","2L2-1/2x2x3/16x3/4LLBB"]
	American_AISC_Double_Angle_2L2_12x2x316x34SLBB = ["American","AISC","Double Angle","2L2-1/2x2x3/16x3/4SLBB"]
	American_AISC_Double_Angle_2L2_12x2x316x38LLBB = ["American","AISC","Double Angle","2L2-1/2x2x3/16x3/8LLBB"]
	American_AISC_Double_Angle_2L2_12x2x316x38SLBB = ["American","AISC","Double Angle","2L2-1/2x2x3/16x3/8SLBB"]
	American_AISC_Double_Angle_2L2_12x2x516LLBB = ["American","AISC","Double Angle","2L2-1/2x2x5/16LLBB"]
	American_AISC_Double_Angle_2L2_12x2x516SLBB = ["American","AISC","Double Angle","2L2-1/2x2x5/16SLBB"]
	American_AISC_Double_Angle_2L2_12x2x516x34LLBB = ["American","AISC","Double Angle","2L2-1/2x2x5/16x3/4LLBB"]
	American_AISC_Double_Angle_2L2_12x2x516x34SLBB = ["American","AISC","Double Angle","2L2-1/2x2x5/16x3/4SLBB"]
	American_AISC_Double_Angle_2L2_12x2x516x38LLBB = ["American","AISC","Double Angle","2L2-1/2x2x5/16x3/8LLBB"]
	American_AISC_Double_Angle_2L2_12x2x516x38SLBB = ["American","AISC","Double Angle","2L2-1/2x2x5/16x3/8SLBB"]
	American_AISC_Double_Angle_2L2x2x14 = ["American","AISC","Double Angle","2L2x2x1/4"]
	American_AISC_Double_Angle_2L2x2x14x34 = ["American","AISC","Double Angle","2L2x2x1/4x3/4"]
	American_AISC_Double_Angle_2L2x2x14x38 = ["American","AISC","Double Angle","2L2x2x1/4x3/8"]
	American_AISC_Double_Angle_2L2x2x18 = ["American","AISC","Double Angle","2L2x2x1/8"]
	American_AISC_Double_Angle_2L2x2x18x34 = ["American","AISC","Double Angle","2L2x2x1/8x3/4"]
	American_AISC_Double_Angle_2L2x2x18x38 = ["American","AISC","Double Angle","2L2x2x1/8x3/8"]
	American_AISC_Double_Angle_2L2x2x38 = ["American","AISC","Double Angle","2L2x2x3/8"]
	American_AISC_Double_Angle_2L2x2x38x34 = ["American","AISC","Double Angle","2L2x2x3/8x3/4"]
	American_AISC_Double_Angle_2L2x2x38x38 = ["American","AISC","Double Angle","2L2x2x3/8x3/8"]
	American_AISC_Double_Angle_2L2x2x316 = ["American","AISC","Double Angle","2L2x2x3/16"]
	American_AISC_Double_Angle_2L2x2x316x34 = ["American","AISC","Double Angle","2L2x2x3/16x3/4"]
	American_AISC_Double_Angle_2L2x2x316x38 = ["American","AISC","Double Angle","2L2x2x3/16x3/8"]
	American_AISC_Double_Angle_2L2x2x516 = ["American","AISC","Double Angle","2L2x2x5/16"]
	American_AISC_Double_Angle_2L2x2x516x34 = ["American","AISC","Double Angle","2L2x2x5/16x3/4"]
	American_AISC_Double_Angle_2L2x2x516x38 = ["American","AISC","Double Angle","2L2x2x5/16x3/8"]
	American_AISC_Double_Angle_2L3_12x2_12x12LLBB = ["American","AISC","Double Angle","2L3-1/2x2-1/2x1/2LLBB"]
	American_AISC_Double_Angle_2L3_12x2_12x12SLBB = ["American","AISC","Double Angle","2L3-1/2x2-1/2x1/2SLBB"]
	American_AISC_Double_Angle_2L3_12x2_12x12x34LLBB = ["American","AISC","Double Angle","2L3-1/2x2-1/2x1/2x3/4LLBB"]
	American_AISC_Double_Angle_2L3_12x2_12x12x34SLBB = ["American","AISC","Double Angle","2L3-1/2x2-1/2x1/2x3/4SLBB"]
	American_AISC_Double_Angle_2L3_12x2_12x12x38LLBB = ["American","AISC","Double Angle","2L3-1/2x2-1/2x1/2x3/8LLBB"]
	American_AISC_Double_Angle_2L3_12x2_12x12x38SLBB = ["American","AISC","Double Angle","2L3-1/2x2-1/2x1/2x3/8SLBB"]
	American_AISC_Double_Angle_2L3_12x2_12x14LLBB = ["American","AISC","Double Angle","2L3-1/2x2-1/2x1/4LLBB"]
	American_AISC_Double_Angle_2L3_12x2_12x14SLBB = ["American","AISC","Double Angle","2L3-1/2x2-1/2x1/4SLBB"]
	American_AISC_Double_Angle_2L3_12x2_12x14x34LLBB = ["American","AISC","Double Angle","2L3-1/2x2-1/2x1/4x3/4LLBB"]
	American_AISC_Double_Angle_2L3_12x2_12x14x34SLBB = ["American","AISC","Double Angle","2L3-1/2x2-1/2x1/4x3/4SLBB"]
	American_AISC_Double_Angle_2L3_12x2_12x14x38LLBB = ["American","AISC","Double Angle","2L3-1/2x2-1/2x1/4x3/8LLBB"]
	American_AISC_Double_Angle_2L3_12x2_12x14x38SLBB = ["American","AISC","Double Angle","2L3-1/2x2-1/2x1/4x3/8SLBB"]
	American_AISC_Double_Angle_2L3_12x2_12x38LLBB = ["American","AISC","Double Angle","2L3-1/2x2-1/2x3/8LLBB"]
	American_AISC_Double_Angle_2L3_12x2_12x38SLBB = ["American","AISC","Double Angle","2L3-1/2x2-1/2x3/8SLBB"]
	American_AISC_Double_Angle_2L3_12x2_12x38x34LLBB = ["American","AISC","Double Angle","2L3-1/2x2-1/2x3/8x3/4LLBB"]
	American_AISC_Double_Angle_2L3_12x2_12x38x34SLBB = ["American","AISC","Double Angle","2L3-1/2x2-1/2x3/8x3/4SLBB"]
	American_AISC_Double_Angle_2L3_12x2_12x38x38LLBB = ["American","AISC","Double Angle","2L3-1/2x2-1/2x3/8x3/8LLBB"]
	American_AISC_Double_Angle_2L3_12x2_12x38x38SLBB = ["American","AISC","Double Angle","2L3-1/2x2-1/2x3/8x3/8SLBB"]
	American_AISC_Double_Angle_2L3_12x2_12x516LLBB = ["American","AISC","Double Angle","2L3-1/2x2-1/2x5/16LLBB"]
	American_AISC_Double_Angle_2L3_12x2_12x516SLBB = ["American","AISC","Double Angle","2L3-1/2x2-1/2x5/16SLBB"]
	American_AISC_Double_Angle_2L3_12x2_12x516x34LLBB = ["American","AISC","Double Angle","2L3-1/2x2-1/2x5/16x3/4LLBB"]
	American_AISC_Double_Angle_2L3_12x2_12x516x34SLBB = ["American","AISC","Double Angle","2L3-1/2x2-1/2x5/16x3/4SLBB"]
	American_AISC_Double_Angle_2L3_12x2_12x516x38LLBB = ["American","AISC","Double Angle","2L3-1/2x2-1/2x5/16x3/8LLBB"]
	American_AISC_Double_Angle_2L3_12x2_12x516x38SLBB = ["American","AISC","Double Angle","2L3-1/2x2-1/2x5/16x3/8SLBB"]
	American_AISC_Double_Angle_2L3_12x3_12x12 = ["American","AISC","Double Angle","2L3-1/2x3-1/2x1/2"]
	American_AISC_Double_Angle_2L3_12x3_12x12x34 = ["American","AISC","Double Angle","2L3-1/2x3-1/2x1/2x3/4"]
	American_AISC_Double_Angle_2L3_12x3_12x12x38 = ["American","AISC","Double Angle","2L3-1/2x3-1/2x1/2x3/8"]
	American_AISC_Double_Angle_2L3_12x3_12x14 = ["American","AISC","Double Angle","2L3-1/2x3-1/2x1/4"]
	American_AISC_Double_Angle_2L3_12x3_12x14x34 = ["American","AISC","Double Angle","2L3-1/2x3-1/2x1/4x3/4"]
	American_AISC_Double_Angle_2L3_12x3_12x14x38 = ["American","AISC","Double Angle","2L3-1/2x3-1/2x1/4x3/8"]
	American_AISC_Double_Angle_2L3_12x3_12x38 = ["American","AISC","Double Angle","2L3-1/2x3-1/2x3/8"]
	American_AISC_Double_Angle_2L3_12x3_12x38x34 = ["American","AISC","Double Angle","2L3-1/2x3-1/2x3/8x3/4"]
	American_AISC_Double_Angle_2L3_12x3_12x38x38 = ["American","AISC","Double Angle","2L3-1/2x3-1/2x3/8x3/8"]
	American_AISC_Double_Angle_2L3_12x3_12x516 = ["American","AISC","Double Angle","2L3-1/2x3-1/2x5/16"]
	American_AISC_Double_Angle_2L3_12x3_12x516x34 = ["American","AISC","Double Angle","2L3-1/2x3-1/2x5/16x3/4"]
	American_AISC_Double_Angle_2L3_12x3_12x516x38 = ["American","AISC","Double Angle","2L3-1/2x3-1/2x5/16x3/8"]
	American_AISC_Double_Angle_2L3_12x3_12x716 = ["American","AISC","Double Angle","2L3-1/2x3-1/2x7/16"]
	American_AISC_Double_Angle_2L3_12x3_12x716x34 = ["American","AISC","Double Angle","2L3-1/2x3-1/2x7/16x3/4"]
	American_AISC_Double_Angle_2L3_12x3_12x716x38 = ["American","AISC","Double Angle","2L3-1/2x3-1/2x7/16x3/8"]
	American_AISC_Double_Angle_2L3_12x3x12LLBB = ["American","AISC","Double Angle","2L3-1/2x3x1/2LLBB"]
	American_AISC_Double_Angle_2L3_12x3x12SLBB = ["American","AISC","Double Angle","2L3-1/2x3x1/2SLBB"]
	American_AISC_Double_Angle_2L3_12x3x12x34LLBB = ["American","AISC","Double Angle","2L3-1/2x3x1/2x3/4LLBB"]
	American_AISC_Double_Angle_2L3_12x3x12x34SLBB = ["American","AISC","Double Angle","2L3-1/2x3x1/2x3/4SLBB"]
	American_AISC_Double_Angle_2L3_12x3x12x38LLBB = ["American","AISC","Double Angle","2L3-1/2x3x1/2x3/8LLBB"]
	American_AISC_Double_Angle_2L3_12x3x12x38SLBB = ["American","AISC","Double Angle","2L3-1/2x3x1/2x3/8SLBB"]
	American_AISC_Double_Angle_2L3_12x3x14LLBB = ["American","AISC","Double Angle","2L3-1/2x3x1/4LLBB"]
	American_AISC_Double_Angle_2L3_12x3x14SLBB = ["American","AISC","Double Angle","2L3-1/2x3x1/4SLBB"]
	American_AISC_Double_Angle_2L3_12x3x14x34LLBB = ["American","AISC","Double Angle","2L3-1/2x3x1/4x3/4LLBB"]
	American_AISC_Double_Angle_2L3_12x3x14x34SLBB = ["American","AISC","Double Angle","2L3-1/2x3x1/4x3/4SLBB"]
	American_AISC_Double_Angle_2L3_12x3x14x38LLBB = ["American","AISC","Double Angle","2L3-1/2x3x1/4x3/8LLBB"]
	American_AISC_Double_Angle_2L3_12x3x14x38SLBB = ["American","AISC","Double Angle","2L3-1/2x3x1/4x3/8SLBB"]
	American_AISC_Double_Angle_2L3_12x3x38LLBB = ["American","AISC","Double Angle","2L3-1/2x3x3/8LLBB"]
	American_AISC_Double_Angle_2L3_12x3x38SLBB = ["American","AISC","Double Angle","2L3-1/2x3x3/8SLBB"]
	American_AISC_Double_Angle_2L3_12x3x38x34LLBB = ["American","AISC","Double Angle","2L3-1/2x3x3/8x3/4LLBB"]
	American_AISC_Double_Angle_2L3_12x3x38x34SLBB = ["American","AISC","Double Angle","2L3-1/2x3x3/8x3/4SLBB"]
	American_AISC_Double_Angle_2L3_12x3x38x38LLBB = ["American","AISC","Double Angle","2L3-1/2x3x3/8x3/8LLBB"]
	American_AISC_Double_Angle_2L3_12x3x38x38SLBB = ["American","AISC","Double Angle","2L3-1/2x3x3/8x3/8SLBB"]
	American_AISC_Double_Angle_2L3_12x3x516LLBB = ["American","AISC","Double Angle","2L3-1/2x3x5/16LLBB"]
	American_AISC_Double_Angle_2L3_12x3x516SLBB = ["American","AISC","Double Angle","2L3-1/2x3x5/16SLBB"]
	American_AISC_Double_Angle_2L3_12x3x516x34LLBB = ["American","AISC","Double Angle","2L3-1/2x3x5/16x3/4LLBB"]
	American_AISC_Double_Angle_2L3_12x3x516x34SLBB = ["American","AISC","Double Angle","2L3-1/2x3x5/16x3/4SLBB"]
	American_AISC_Double_Angle_2L3_12x3x516x38LLBB = ["American","AISC","Double Angle","2L3-1/2x3x5/16x3/8LLBB"]
	American_AISC_Double_Angle_2L3_12x3x516x38SLBB = ["American","AISC","Double Angle","2L3-1/2x3x5/16x3/8SLBB"]
	American_AISC_Double_Angle_2L3_12x3x716LLBB = ["American","AISC","Double Angle","2L3-1/2x3x7/16LLBB"]
	American_AISC_Double_Angle_2L3_12x3x716SLBB = ["American","AISC","Double Angle","2L3-1/2x3x7/16SLBB"]
	American_AISC_Double_Angle_2L3_12x3x716x34LLBB = ["American","AISC","Double Angle","2L3-1/2x3x7/16x3/4LLBB"]
	American_AISC_Double_Angle_2L3_12x3x716x34SLBB = ["American","AISC","Double Angle","2L3-1/2x3x7/16x3/4SLBB"]
	American_AISC_Double_Angle_2L3_12x3x716x38LLBB = ["American","AISC","Double Angle","2L3-1/2x3x7/16x3/8LLBB"]
	American_AISC_Double_Angle_2L3_12x3x716x38SLBB = ["American","AISC","Double Angle","2L3-1/2x3x7/16x3/8SLBB"]
	American_AISC_Double_Angle_2L3x2_12x12LLBB = ["American","AISC","Double Angle","2L3x2-1/2x1/2LLBB"]
	American_AISC_Double_Angle_2L3x2_12x12SLBB = ["American","AISC","Double Angle","2L3x2-1/2x1/2SLBB"]
	American_AISC_Double_Angle_2L3x2_12x12x34LLBB = ["American","AISC","Double Angle","2L3x2-1/2x1/2x3/4LLBB"]
	American_AISC_Double_Angle_2L3x2_12x12x34SLBB = ["American","AISC","Double Angle","2L3x2-1/2x1/2x3/4SLBB"]
	American_AISC_Double_Angle_2L3x2_12x12x38LLBB = ["American","AISC","Double Angle","2L3x2-1/2x1/2x3/8LLBB"]
	American_AISC_Double_Angle_2L3x2_12x12x38SLBB = ["American","AISC","Double Angle","2L3x2-1/2x1/2x3/8SLBB"]
	American_AISC_Double_Angle_2L3x2_12x14LLBB = ["American","AISC","Double Angle","2L3x2-1/2x1/4LLBB"]
	American_AISC_Double_Angle_2L3x2_12x14SLBB = ["American","AISC","Double Angle","2L3x2-1/2x1/4SLBB"]
	American_AISC_Double_Angle_2L3x2_12x14x34LLBB = ["American","AISC","Double Angle","2L3x2-1/2x1/4x3/4LLBB"]
	American_AISC_Double_Angle_2L3x2_12x14x34SLBB = ["American","AISC","Double Angle","2L3x2-1/2x1/4x3/4SLBB"]
	American_AISC_Double_Angle_2L3x2_12x14x38LLBB = ["American","AISC","Double Angle","2L3x2-1/2x1/4x3/8LLBB"]
	American_AISC_Double_Angle_2L3x2_12x14x38SLBB = ["American","AISC","Double Angle","2L3x2-1/2x1/4x3/8SLBB"]
	American_AISC_Double_Angle_2L3x2_12x38LLBB = ["American","AISC","Double Angle","2L3x2-1/2x3/8LLBB"]
	American_AISC_Double_Angle_2L3x2_12x38SLBB = ["American","AISC","Double Angle","2L3x2-1/2x3/8SLBB"]
	American_AISC_Double_Angle_2L3x2_12x38x34LLBB = ["American","AISC","Double Angle","2L3x2-1/2x3/8x3/4LLBB"]
	American_AISC_Double_Angle_2L3x2_12x38x34SLBB = ["American","AISC","Double Angle","2L3x2-1/2x3/8x3/4SLBB"]
	American_AISC_Double_Angle_2L3x2_12x38x38LLBB = ["American","AISC","Double Angle","2L3x2-1/2x3/8x3/8LLBB"]
	American_AISC_Double_Angle_2L3x2_12x38x38SLBB = ["American","AISC","Double Angle","2L3x2-1/2x3/8x3/8SLBB"]
	American_AISC_Double_Angle_2L3x2_12x316LLBB = ["American","AISC","Double Angle","2L3x2-1/2x3/16LLBB"]
	American_AISC_Double_Angle_2L3x2_12x316SLBB = ["American","AISC","Double Angle","2L3x2-1/2x3/16SLBB"]
	American_AISC_Double_Angle_2L3x2_12x316x34LLBB = ["American","AISC","Double Angle","2L3x2-1/2x3/16x3/4LLBB"]
	American_AISC_Double_Angle_2L3x2_12x316x34SLBB = ["American","AISC","Double Angle","2L3x2-1/2x3/16x3/4SLBB"]
	American_AISC_Double_Angle_2L3x2_12x316x38LLBB = ["American","AISC","Double Angle","2L3x2-1/2x3/16x3/8LLBB"]
	American_AISC_Double_Angle_2L3x2_12x316x38SLBB = ["American","AISC","Double Angle","2L3x2-1/2x3/16x3/8SLBB"]
	American_AISC_Double_Angle_2L3x2_12x516LLBB = ["American","AISC","Double Angle","2L3x2-1/2x5/16LLBB"]
	American_AISC_Double_Angle_2L3x2_12x516SLBB = ["American","AISC","Double Angle","2L3x2-1/2x5/16SLBB"]
	American_AISC_Double_Angle_2L3x2_12x516x34LLBB = ["American","AISC","Double Angle","2L3x2-1/2x5/16x3/4LLBB"]
	American_AISC_Double_Angle_2L3x2_12x516x34SLBB = ["American","AISC","Double Angle","2L3x2-1/2x5/16x3/4SLBB"]
	American_AISC_Double_Angle_2L3x2_12x516x38LLBB = ["American","AISC","Double Angle","2L3x2-1/2x5/16x3/8LLBB"]
	American_AISC_Double_Angle_2L3x2_12x516x38SLBB = ["American","AISC","Double Angle","2L3x2-1/2x5/16x3/8SLBB"]
	American_AISC_Double_Angle_2L3x2_12x716LLBB = ["American","AISC","Double Angle","2L3x2-1/2x7/16LLBB"]
	American_AISC_Double_Angle_2L3x2_12x716SLBB = ["American","AISC","Double Angle","2L3x2-1/2x7/16SLBB"]
	American_AISC_Double_Angle_2L3x2_12x716x34LLBB = ["American","AISC","Double Angle","2L3x2-1/2x7/16x3/4LLBB"]
	American_AISC_Double_Angle_2L3x2_12x716x34SLBB = ["American","AISC","Double Angle","2L3x2-1/2x7/16x3/4SLBB"]
	American_AISC_Double_Angle_2L3x2_12x716x38LLBB = ["American","AISC","Double Angle","2L3x2-1/2x7/16x3/8LLBB"]
	American_AISC_Double_Angle_2L3x2_12x716x38SLBB = ["American","AISC","Double Angle","2L3x2-1/2x7/16x3/8SLBB"]
	American_AISC_Double_Angle_2L3x2x12LLBB = ["American","AISC","Double Angle","2L3x2x1/2LLBB"]
	American_AISC_Double_Angle_2L3x2x12SLBB = ["American","AISC","Double Angle","2L3x2x1/2SLBB"]
	American_AISC_Double_Angle_2L3x2x12x34LLBB = ["American","AISC","Double Angle","2L3x2x1/2x3/4LLBB"]
	American_AISC_Double_Angle_2L3x2x12x34SLBB = ["American","AISC","Double Angle","2L3x2x1/2x3/4SLBB"]
	American_AISC_Double_Angle_2L3x2x12x38LLBB = ["American","AISC","Double Angle","2L3x2x1/2x3/8LLBB"]
	American_AISC_Double_Angle_2L3x2x12x38SLBB = ["American","AISC","Double Angle","2L3x2x1/2x3/8SLBB"]
	American_AISC_Double_Angle_2L3x2x14LLBB = ["American","AISC","Double Angle","2L3x2x1/4LLBB"]
	American_AISC_Double_Angle_2L3x2x14SLBB = ["American","AISC","Double Angle","2L3x2x1/4SLBB"]
	American_AISC_Double_Angle_2L3x2x14x34LLBB = ["American","AISC","Double Angle","2L3x2x1/4x3/4LLBB"]
	American_AISC_Double_Angle_2L3x2x14x34SLBB = ["American","AISC","Double Angle","2L3x2x1/4x3/4SLBB"]
	American_AISC_Double_Angle_2L3x2x14x38LLBB = ["American","AISC","Double Angle","2L3x2x1/4x3/8LLBB"]
	American_AISC_Double_Angle_2L3x2x14x38SLBB = ["American","AISC","Double Angle","2L3x2x1/4x3/8SLBB"]
	American_AISC_Double_Angle_2L3x2x38LLBB = ["American","AISC","Double Angle","2L3x2x3/8LLBB"]
	American_AISC_Double_Angle_2L3x2x38SLBB = ["American","AISC","Double Angle","2L3x2x3/8SLBB"]
	American_AISC_Double_Angle_2L3x2x38x34LLBB = ["American","AISC","Double Angle","2L3x2x3/8x3/4LLBB"]
	American_AISC_Double_Angle_2L3x2x38x34SLBB = ["American","AISC","Double Angle","2L3x2x3/8x3/4SLBB"]
	American_AISC_Double_Angle_2L3x2x38x38LLBB = ["American","AISC","Double Angle","2L3x2x3/8x3/8LLBB"]
	American_AISC_Double_Angle_2L3x2x38x38SLBB = ["American","AISC","Double Angle","2L3x2x3/8x3/8SLBB"]
	American_AISC_Double_Angle_2L3x2x316LLBB = ["American","AISC","Double Angle","2L3x2x3/16LLBB"]
	American_AISC_Double_Angle_2L3x2x316SLBB = ["American","AISC","Double Angle","2L3x2x3/16SLBB"]
	American_AISC_Double_Angle_2L3x2x316x34LLBB = ["American","AISC","Double Angle","2L3x2x3/16x3/4LLBB"]
	American_AISC_Double_Angle_2L3x2x316x34SLBB = ["American","AISC","Double Angle","2L3x2x3/16x3/4SLBB"]
	American_AISC_Double_Angle_2L3x2x316x38LLBB = ["American","AISC","Double Angle","2L3x2x3/16x3/8LLBB"]
	American_AISC_Double_Angle_2L3x2x316x38SLBB = ["American","AISC","Double Angle","2L3x2x3/16x3/8SLBB"]
	American_AISC_Double_Angle_2L3x2x516LLBB = ["American","AISC","Double Angle","2L3x2x5/16LLBB"]
	American_AISC_Double_Angle_2L3x2x516SLBB = ["American","AISC","Double Angle","2L3x2x5/16SLBB"]
	American_AISC_Double_Angle_2L3x2x516x34LLBB = ["American","AISC","Double Angle","2L3x2x5/16x3/4LLBB"]
	American_AISC_Double_Angle_2L3x2x516x34SLBB = ["American","AISC","Double Angle","2L3x2x5/16x3/4SLBB"]
	American_AISC_Double_Angle_2L3x2x516x38LLBB = ["American","AISC","Double Angle","2L3x2x5/16x3/8LLBB"]
	American_AISC_Double_Angle_2L3x2x516x38SLBB = ["American","AISC","Double Angle","2L3x2x5/16x3/8SLBB"]
	American_AISC_Double_Angle_2L3x3x12 = ["American","AISC","Double Angle","2L3x3x1/2"]
	American_AISC_Double_Angle_2L3x3x12x34 = ["American","AISC","Double Angle","2L3x3x1/2x3/4"]
	American_AISC_Double_Angle_2L3x3x12x38 = ["American","AISC","Double Angle","2L3x3x1/2x3/8"]
	American_AISC_Double_Angle_2L3x3x14 = ["American","AISC","Double Angle","2L3x3x1/4"]
	American_AISC_Double_Angle_2L3x3x14x34 = ["American","AISC","Double Angle","2L3x3x1/4x3/4"]
	American_AISC_Double_Angle_2L3x3x14x38 = ["American","AISC","Double Angle","2L3x3x1/4x3/8"]
	American_AISC_Double_Angle_2L3x3x38 = ["American","AISC","Double Angle","2L3x3x3/8"]
	American_AISC_Double_Angle_2L3x3x38x34 = ["American","AISC","Double Angle","2L3x3x3/8x3/4"]
	American_AISC_Double_Angle_2L3x3x38x38 = ["American","AISC","Double Angle","2L3x3x3/8x3/8"]
	American_AISC_Double_Angle_2L3x3x316 = ["American","AISC","Double Angle","2L3x3x3/16"]
	American_AISC_Double_Angle_2L3x3x316x34 = ["American","AISC","Double Angle","2L3x3x3/16x3/4"]
	American_AISC_Double_Angle_2L3x3x316x38 = ["American","AISC","Double Angle","2L3x3x3/16x3/8"]
	American_AISC_Double_Angle_2L3x3x516 = ["American","AISC","Double Angle","2L3x3x5/16"]
	American_AISC_Double_Angle_2L3x3x516x34 = ["American","AISC","Double Angle","2L3x3x5/16x3/4"]
	American_AISC_Double_Angle_2L3x3x516x38 = ["American","AISC","Double Angle","2L3x3x5/16x3/8"]
	American_AISC_Double_Angle_2L3x3x716 = ["American","AISC","Double Angle","2L3x3x7/16"]
	American_AISC_Double_Angle_2L3x3x716x34 = ["American","AISC","Double Angle","2L3x3x7/16x3/4"]
	American_AISC_Double_Angle_2L3x3x716x38 = ["American","AISC","Double Angle","2L3x3x7/16x3/8"]
	American_AISC_Double_Angle_2L4x3_12x12LLBB = ["American","AISC","Double Angle","2L4x3-1/2x1/2LLBB"]
	American_AISC_Double_Angle_2L4x3_12x12SLBB = ["American","AISC","Double Angle","2L4x3-1/2x1/2SLBB"]
	American_AISC_Double_Angle_2L4x3_12x12x34LLBB = ["American","AISC","Double Angle","2L4x3-1/2x1/2x3/4LLBB"]
	American_AISC_Double_Angle_2L4x3_12x12x34SLBB = ["American","AISC","Double Angle","2L4x3-1/2x1/2x3/4SLBB"]
	American_AISC_Double_Angle_2L4x3_12x12x38LLBB = ["American","AISC","Double Angle","2L4x3-1/2x1/2x3/8LLBB"]
	American_AISC_Double_Angle_2L4x3_12x12x38SLBB = ["American","AISC","Double Angle","2L4x3-1/2x1/2x3/8SLBB"]
	American_AISC_Double_Angle_2L4x3_12x14LLBB = ["American","AISC","Double Angle","2L4x3-1/2x1/4LLBB"]
	American_AISC_Double_Angle_2L4x3_12x14SLBB = ["American","AISC","Double Angle","2L4x3-1/2x1/4SLBB"]
	American_AISC_Double_Angle_2L4x3_12x14x34LLBB = ["American","AISC","Double Angle","2L4x3-1/2x1/4x3/4LLBB"]
	American_AISC_Double_Angle_2L4x3_12x14x34SLBB = ["American","AISC","Double Angle","2L4x3-1/2x1/4x3/4SLBB"]
	American_AISC_Double_Angle_2L4x3_12x14x38LLBB = ["American","AISC","Double Angle","2L4x3-1/2x1/4x3/8LLBB"]
	American_AISC_Double_Angle_2L4x3_12x14x38SLBB = ["American","AISC","Double Angle","2L4x3-1/2x1/4x3/8SLBB"]
	American_AISC_Double_Angle_2L4x3_12x38LLBB = ["American","AISC","Double Angle","2L4x3-1/2x3/8LLBB"]
	American_AISC_Double_Angle_2L4x3_12x38SLBB = ["American","AISC","Double Angle","2L4x3-1/2x3/8SLBB"]
	American_AISC_Double_Angle_2L4x3_12x38x34LLBB = ["American","AISC","Double Angle","2L4x3-1/2x3/8x3/4LLBB"]
	American_AISC_Double_Angle_2L4x3_12x38x34SLBB = ["American","AISC","Double Angle","2L4x3-1/2x3/8x3/4SLBB"]
	American_AISC_Double_Angle_2L4x3_12x38x38LLBB = ["American","AISC","Double Angle","2L4x3-1/2x3/8x3/8LLBB"]
	American_AISC_Double_Angle_2L4x3_12x38x38SLBB = ["American","AISC","Double Angle","2L4x3-1/2x3/8x3/8SLBB"]
	American_AISC_Double_Angle_2L4x3_12x516LLBB = ["American","AISC","Double Angle","2L4x3-1/2x5/16LLBB"]
	American_AISC_Double_Angle_2L4x3_12x516SLBB = ["American","AISC","Double Angle","2L4x3-1/2x5/16SLBB"]
	American_AISC_Double_Angle_2L4x3_12x516x34LLBB = ["American","AISC","Double Angle","2L4x3-1/2x5/16x3/4LLBB"]
	American_AISC_Double_Angle_2L4x3_12x516x34SLBB = ["American","AISC","Double Angle","2L4x3-1/2x5/16x3/4SLBB"]
	American_AISC_Double_Angle_2L4x3_12x516x38LLBB = ["American","AISC","Double Angle","2L4x3-1/2x5/16x3/8LLBB"]
	American_AISC_Double_Angle_2L4x3_12x516x38SLBB = ["American","AISC","Double Angle","2L4x3-1/2x5/16x3/8SLBB"]
	American_AISC_Double_Angle_2L4x3x12LLBB = ["American","AISC","Double Angle","2L4x3x1/2LLBB"]
	American_AISC_Double_Angle_2L4x3x12SLBB = ["American","AISC","Double Angle","2L4x3x1/2SLBB"]
	American_AISC_Double_Angle_2L4x3x12x34LLBB = ["American","AISC","Double Angle","2L4x3x1/2x3/4LLBB"]
	American_AISC_Double_Angle_2L4x3x12x34SLBB = ["American","AISC","Double Angle","2L4x3x1/2x3/4SLBB"]
	American_AISC_Double_Angle_2L4x3x12x38LLBB = ["American","AISC","Double Angle","2L4x3x1/2x3/8LLBB"]
	American_AISC_Double_Angle_2L4x3x12x38SLBB = ["American","AISC","Double Angle","2L4x3x1/2x3/8SLBB"]
	American_AISC_Double_Angle_2L4x3x14LLBB = ["American","AISC","Double Angle","2L4x3x1/4LLBB"]
	American_AISC_Double_Angle_2L4x3x14SLBB = ["American","AISC","Double Angle","2L4x3x1/4SLBB"]
	American_AISC_Double_Angle_2L4x3x14x34LLBB = ["American","AISC","Double Angle","2L4x3x1/4x3/4LLBB"]
	American_AISC_Double_Angle_2L4x3x14x34SLBB = ["American","AISC","Double Angle","2L4x3x1/4x3/4SLBB"]
	American_AISC_Double_Angle_2L4x3x14x38LLBB = ["American","AISC","Double Angle","2L4x3x1/4x3/8LLBB"]
	American_AISC_Double_Angle_2L4x3x14x38SLBB = ["American","AISC","Double Angle","2L4x3x1/4x3/8SLBB"]
	American_AISC_Double_Angle_2L4x3x38LLBB = ["American","AISC","Double Angle","2L4x3x3/8LLBB"]
	American_AISC_Double_Angle_2L4x3x38SLBB = ["American","AISC","Double Angle","2L4x3x3/8SLBB"]
	American_AISC_Double_Angle_2L4x3x38x34LLBB = ["American","AISC","Double Angle","2L4x3x3/8x3/4LLBB"]
	American_AISC_Double_Angle_2L4x3x38x34SLBB = ["American","AISC","Double Angle","2L4x3x3/8x3/4SLBB"]
	American_AISC_Double_Angle_2L4x3x38x38LLBB = ["American","AISC","Double Angle","2L4x3x3/8x3/8LLBB"]
	American_AISC_Double_Angle_2L4x3x38x38SLBB = ["American","AISC","Double Angle","2L4x3x3/8x3/8SLBB"]
	American_AISC_Double_Angle_2L4x3x58LLBB = ["American","AISC","Double Angle","2L4x3x5/8LLBB"]
	American_AISC_Double_Angle_2L4x3x58SLBB = ["American","AISC","Double Angle","2L4x3x5/8SLBB"]
	American_AISC_Double_Angle_2L4x3x58x34LLBB = ["American","AISC","Double Angle","2L4x3x5/8x3/4LLBB"]
	American_AISC_Double_Angle_2L4x3x58x34SLBB = ["American","AISC","Double Angle","2L4x3x5/8x3/4SLBB"]
	American_AISC_Double_Angle_2L4x3x58x38LLBB = ["American","AISC","Double Angle","2L4x3x5/8x3/8LLBB"]
	American_AISC_Double_Angle_2L4x3x58x38SLBB = ["American","AISC","Double Angle","2L4x3x5/8x3/8SLBB"]
	American_AISC_Double_Angle_2L4x3x516LLBB = ["American","AISC","Double Angle","2L4x3x5/16LLBB"]
	American_AISC_Double_Angle_2L4x3x516SLBB = ["American","AISC","Double Angle","2L4x3x5/16SLBB"]
	American_AISC_Double_Angle_2L4x3x516x34LLBB = ["American","AISC","Double Angle","2L4x3x5/16x3/4LLBB"]
	American_AISC_Double_Angle_2L4x3x516x34SLBB = ["American","AISC","Double Angle","2L4x3x5/16x3/4SLBB"]
	American_AISC_Double_Angle_2L4x3x516x38LLBB = ["American","AISC","Double Angle","2L4x3x5/16x3/8LLBB"]
	American_AISC_Double_Angle_2L4x3x516x38SLBB = ["American","AISC","Double Angle","2L4x3x5/16x3/8SLBB"]
	American_AISC_Double_Angle_2L4x4x12 = ["American","AISC","Double Angle","2L4x4x1/2"]
	American_AISC_Double_Angle_2L4x4x12x34 = ["American","AISC","Double Angle","2L4x4x1/2x3/4"]
	American_AISC_Double_Angle_2L4x4x12x38 = ["American","AISC","Double Angle","2L4x4x1/2x3/8"]
	American_AISC_Double_Angle_2L4x4x14 = ["American","AISC","Double Angle","2L4x4x1/4"]
	American_AISC_Double_Angle_2L4x4x14x34 = ["American","AISC","Double Angle","2L4x4x1/4x3/4"]
	American_AISC_Double_Angle_2L4x4x14x38 = ["American","AISC","Double Angle","2L4x4x1/4x3/8"]
	American_AISC_Double_Angle_2L4x4x34 = ["American","AISC","Double Angle","2L4x4x3/4"]
	American_AISC_Double_Angle_2L4x4x34x34 = ["American","AISC","Double Angle","2L4x4x3/4x3/4"]
	American_AISC_Double_Angle_2L4x4x34x38 = ["American","AISC","Double Angle","2L4x4x3/4x3/8"]
	American_AISC_Double_Angle_2L4x4x38 = ["American","AISC","Double Angle","2L4x4x3/8"]
	American_AISC_Double_Angle_2L4x4x38x34 = ["American","AISC","Double Angle","2L4x4x3/8x3/4"]
	American_AISC_Double_Angle_2L4x4x38x38 = ["American","AISC","Double Angle","2L4x4x3/8x3/8"]
	American_AISC_Double_Angle_2L4x4x58 = ["American","AISC","Double Angle","2L4x4x5/8"]
	American_AISC_Double_Angle_2L4x4x58x34 = ["American","AISC","Double Angle","2L4x4x5/8x3/4"]
	American_AISC_Double_Angle_2L4x4x58x38 = ["American","AISC","Double Angle","2L4x4x5/8x3/8"]
	American_AISC_Double_Angle_2L4x4x516 = ["American","AISC","Double Angle","2L4x4x5/16"]
	American_AISC_Double_Angle_2L4x4x516x34 = ["American","AISC","Double Angle","2L4x4x5/16x3/4"]
	American_AISC_Double_Angle_2L4x4x516x38 = ["American","AISC","Double Angle","2L4x4x5/16x3/8"]
	American_AISC_Double_Angle_2L4x4x716 = ["American","AISC","Double Angle","2L4x4x7/16"]
	American_AISC_Double_Angle_2L4x4x716x34 = ["American","AISC","Double Angle","2L4x4x7/16x3/4"]
	American_AISC_Double_Angle_2L4x4x716x38 = ["American","AISC","Double Angle","2L4x4x7/16x3/8"]
	American_AISC_Double_Angle_2L5x3_12x12LLBB = ["American","AISC","Double Angle","2L5x3-1/2x1/2LLBB"]
	American_AISC_Double_Angle_2L5x3_12x12SLBB = ["American","AISC","Double Angle","2L5x3-1/2x1/2SLBB"]
	American_AISC_Double_Angle_2L5x3_12x12x34LLBB = ["American","AISC","Double Angle","2L5x3-1/2x1/2x3/4LLBB"]
	American_AISC_Double_Angle_2L5x3_12x12x34SLBB = ["American","AISC","Double Angle","2L5x3-1/2x1/2x3/4SLBB"]
	American_AISC_Double_Angle_2L5x3_12x12x38LLBB = ["American","AISC","Double Angle","2L5x3-1/2x1/2x3/8LLBB"]
	American_AISC_Double_Angle_2L5x3_12x12x38SLBB = ["American","AISC","Double Angle","2L5x3-1/2x1/2x3/8SLBB"]
	American_AISC_Double_Angle_2L5x3_12x14LLBB = ["American","AISC","Double Angle","2L5x3-1/2x1/4LLBB"]
	American_AISC_Double_Angle_2L5x3_12x14SLBB = ["American","AISC","Double Angle","2L5x3-1/2x1/4SLBB"]
	American_AISC_Double_Angle_2L5x3_12x14x34LLBB = ["American","AISC","Double Angle","2L5x3-1/2x1/4x3/4LLBB"]
	American_AISC_Double_Angle_2L5x3_12x14x34SLBB = ["American","AISC","Double Angle","2L5x3-1/2x1/4x3/4SLBB"]
	American_AISC_Double_Angle_2L5x3_12x14x38LLBB = ["American","AISC","Double Angle","2L5x3-1/2x1/4x3/8LLBB"]
	American_AISC_Double_Angle_2L5x3_12x14x38SLBB = ["American","AISC","Double Angle","2L5x3-1/2x1/4x3/8SLBB"]
	American_AISC_Double_Angle_2L5x3_12x34LLBB = ["American","AISC","Double Angle","2L5x3-1/2x3/4LLBB"]
	American_AISC_Double_Angle_2L5x3_12x34SLBB = ["American","AISC","Double Angle","2L5x3-1/2x3/4SLBB"]
	American_AISC_Double_Angle_2L5x3_12x34x34LLBB = ["American","AISC","Double Angle","2L5x3-1/2x3/4x3/4LLBB"]
	American_AISC_Double_Angle_2L5x3_12x34x34SLBB = ["American","AISC","Double Angle","2L5x3-1/2x3/4x3/4SLBB"]
	American_AISC_Double_Angle_2L5x3_12x34x38LLBB = ["American","AISC","Double Angle","2L5x3-1/2x3/4x3/8LLBB"]
	American_AISC_Double_Angle_2L5x3_12x34x38SLBB = ["American","AISC","Double Angle","2L5x3-1/2x3/4x3/8SLBB"]
	American_AISC_Double_Angle_2L5x3_12x38LLBB = ["American","AISC","Double Angle","2L5x3-1/2x3/8LLBB"]
	American_AISC_Double_Angle_2L5x3_12x38SLBB = ["American","AISC","Double Angle","2L5x3-1/2x3/8SLBB"]
	American_AISC_Double_Angle_2L5x3_12x38x34LLBB = ["American","AISC","Double Angle","2L5x3-1/2x3/8x3/4LLBB"]
	American_AISC_Double_Angle_2L5x3_12x38x34SLBB = ["American","AISC","Double Angle","2L5x3-1/2x3/8x3/4SLBB"]
	American_AISC_Double_Angle_2L5x3_12x38x38LLBB = ["American","AISC","Double Angle","2L5x3-1/2x3/8x3/8LLBB"]
	American_AISC_Double_Angle_2L5x3_12x38x38SLBB = ["American","AISC","Double Angle","2L5x3-1/2x3/8x3/8SLBB"]
	American_AISC_Double_Angle_2L5x3_12x58LLBB = ["American","AISC","Double Angle","2L5x3-1/2x5/8LLBB"]
	American_AISC_Double_Angle_2L5x3_12x58SLBB = ["American","AISC","Double Angle","2L5x3-1/2x5/8SLBB"]
	American_AISC_Double_Angle_2L5x3_12x58x34LLBB = ["American","AISC","Double Angle","2L5x3-1/2x5/8x3/4LLBB"]
	American_AISC_Double_Angle_2L5x3_12x58x34SLBB = ["American","AISC","Double Angle","2L5x3-1/2x5/8x3/4SLBB"]
	American_AISC_Double_Angle_2L5x3_12x58x38LLBB = ["American","AISC","Double Angle","2L5x3-1/2x5/8x3/8LLBB"]
	American_AISC_Double_Angle_2L5x3_12x58x38SLBB = ["American","AISC","Double Angle","2L5x3-1/2x5/8x3/8SLBB"]
	American_AISC_Double_Angle_2L5x3_12x516LLBB = ["American","AISC","Double Angle","2L5x3-1/2x5/16LLBB"]
	American_AISC_Double_Angle_2L5x3_12x516SLBB = ["American","AISC","Double Angle","2L5x3-1/2x5/16SLBB"]
	American_AISC_Double_Angle_2L5x3_12x516x34LLBB = ["American","AISC","Double Angle","2L5x3-1/2x5/16x3/4LLBB"]
	American_AISC_Double_Angle_2L5x3_12x516x34SLBB = ["American","AISC","Double Angle","2L5x3-1/2x5/16x3/4SLBB"]
	American_AISC_Double_Angle_2L5x3_12x516x38LLBB = ["American","AISC","Double Angle","2L5x3-1/2x5/16x3/8LLBB"]
	American_AISC_Double_Angle_2L5x3_12x516x38SLBB = ["American","AISC","Double Angle","2L5x3-1/2x5/16x3/8SLBB"]
	American_AISC_Double_Angle_2L5x3x12LLBB = ["American","AISC","Double Angle","2L5x3x1/2LLBB"]
	American_AISC_Double_Angle_2L5x3x12SLBB = ["American","AISC","Double Angle","2L5x3x1/2SLBB"]
	American_AISC_Double_Angle_2L5x3x12x34LLBB = ["American","AISC","Double Angle","2L5x3x1/2x3/4LLBB"]
	American_AISC_Double_Angle_2L5x3x12x34SLBB = ["American","AISC","Double Angle","2L5x3x1/2x3/4SLBB"]
	American_AISC_Double_Angle_2L5x3x12x38LLBB = ["American","AISC","Double Angle","2L5x3x1/2x3/8LLBB"]
	American_AISC_Double_Angle_2L5x3x12x38SLBB = ["American","AISC","Double Angle","2L5x3x1/2x3/8SLBB"]
	American_AISC_Double_Angle_2L5x3x14LLBB = ["American","AISC","Double Angle","2L5x3x1/4LLBB"]
	American_AISC_Double_Angle_2L5x3x14SLBB = ["American","AISC","Double Angle","2L5x3x1/4SLBB"]
	American_AISC_Double_Angle_2L5x3x14x34LLBB = ["American","AISC","Double Angle","2L5x3x1/4x3/4LLBB"]
	American_AISC_Double_Angle_2L5x3x14x34SLBB = ["American","AISC","Double Angle","2L5x3x1/4x3/4SLBB"]
	American_AISC_Double_Angle_2L5x3x14x38LLBB = ["American","AISC","Double Angle","2L5x3x1/4x3/8LLBB"]
	American_AISC_Double_Angle_2L5x3x14x38SLBB = ["American","AISC","Double Angle","2L5x3x1/4x3/8SLBB"]
	American_AISC_Double_Angle_2L5x3x38LLBB = ["American","AISC","Double Angle","2L5x3x3/8LLBB"]
	American_AISC_Double_Angle_2L5x3x38SLBB = ["American","AISC","Double Angle","2L5x3x3/8SLBB"]
	American_AISC_Double_Angle_2L5x3x38x34LLBB = ["American","AISC","Double Angle","2L5x3x3/8x3/4LLBB"]
	American_AISC_Double_Angle_2L5x3x38x34SLBB = ["American","AISC","Double Angle","2L5x3x3/8x3/4SLBB"]
	American_AISC_Double_Angle_2L5x3x38x38LLBB = ["American","AISC","Double Angle","2L5x3x3/8x3/8LLBB"]
	American_AISC_Double_Angle_2L5x3x38x38SLBB = ["American","AISC","Double Angle","2L5x3x3/8x3/8SLBB"]
	American_AISC_Double_Angle_2L5x3x516LLBB = ["American","AISC","Double Angle","2L5x3x5/16LLBB"]
	American_AISC_Double_Angle_2L5x3x516SLBB = ["American","AISC","Double Angle","2L5x3x5/16SLBB"]
	American_AISC_Double_Angle_2L5x3x516x34LLBB = ["American","AISC","Double Angle","2L5x3x5/16x3/4LLBB"]
	American_AISC_Double_Angle_2L5x3x516x34SLBB = ["American","AISC","Double Angle","2L5x3x5/16x3/4SLBB"]
	American_AISC_Double_Angle_2L5x3x516x38LLBB = ["American","AISC","Double Angle","2L5x3x5/16x3/8LLBB"]
	American_AISC_Double_Angle_2L5x3x516x38SLBB = ["American","AISC","Double Angle","2L5x3x5/16x3/8SLBB"]
	American_AISC_Double_Angle_2L5x3x716LLBB = ["American","AISC","Double Angle","2L5x3x7/16LLBB"]
	American_AISC_Double_Angle_2L5x3x716SLBB = ["American","AISC","Double Angle","2L5x3x7/16SLBB"]
	American_AISC_Double_Angle_2L5x3x716x34LLBB = ["American","AISC","Double Angle","2L5x3x7/16x3/4LLBB"]
	American_AISC_Double_Angle_2L5x3x716x34SLBB = ["American","AISC","Double Angle","2L5x3x7/16x3/4SLBB"]
	American_AISC_Double_Angle_2L5x3x716x38LLBB = ["American","AISC","Double Angle","2L5x3x7/16x3/8LLBB"]
	American_AISC_Double_Angle_2L5x3x716x38SLBB = ["American","AISC","Double Angle","2L5x3x7/16x3/8SLBB"]
	American_AISC_Double_Angle_2L5x5x12 = ["American","AISC","Double Angle","2L5x5x1/2"]
	American_AISC_Double_Angle_2L5x5x12x34 = ["American","AISC","Double Angle","2L5x5x1/2x3/4"]
	American_AISC_Double_Angle_2L5x5x12x38 = ["American","AISC","Double Angle","2L5x5x1/2x3/8"]
	American_AISC_Double_Angle_2L5x5x34 = ["American","AISC","Double Angle","2L5x5x3/4"]
	American_AISC_Double_Angle_2L5x5x34x34 = ["American","AISC","Double Angle","2L5x5x3/4x3/4"]
	American_AISC_Double_Angle_2L5x5x34x38 = ["American","AISC","Double Angle","2L5x5x3/4x3/8"]
	American_AISC_Double_Angle_2L5x5x38 = ["American","AISC","Double Angle","2L5x5x3/8"]
	American_AISC_Double_Angle_2L5x5x38x34 = ["American","AISC","Double Angle","2L5x5x3/8x3/4"]
	American_AISC_Double_Angle_2L5x5x38x38 = ["American","AISC","Double Angle","2L5x5x3/8x3/8"]
	American_AISC_Double_Angle_2L5x5x58 = ["American","AISC","Double Angle","2L5x5x5/8"]
	American_AISC_Double_Angle_2L5x5x58x34 = ["American","AISC","Double Angle","2L5x5x5/8x3/4"]
	American_AISC_Double_Angle_2L5x5x58x38 = ["American","AISC","Double Angle","2L5x5x5/8x3/8"]
	American_AISC_Double_Angle_2L5x5x516 = ["American","AISC","Double Angle","2L5x5x5/16"]
	American_AISC_Double_Angle_2L5x5x516x34 = ["American","AISC","Double Angle","2L5x5x5/16x3/4"]
	American_AISC_Double_Angle_2L5x5x516x38 = ["American","AISC","Double Angle","2L5x5x5/16x3/8"]
	American_AISC_Double_Angle_2L5x5x78 = ["American","AISC","Double Angle","2L5x5x7/8"]
	American_AISC_Double_Angle_2L5x5x78x34 = ["American","AISC","Double Angle","2L5x5x7/8x3/4"]
	American_AISC_Double_Angle_2L5x5x78x38 = ["American","AISC","Double Angle","2L5x5x7/8x3/8"]
	American_AISC_Double_Angle_2L5x5x716 = ["American","AISC","Double Angle","2L5x5x7/16"]
	American_AISC_Double_Angle_2L5x5x716x34 = ["American","AISC","Double Angle","2L5x5x7/16x3/4"]
	American_AISC_Double_Angle_2L5x5x716x38 = ["American","AISC","Double Angle","2L5x5x7/16x3/8"]
	American_AISC_Double_Angle_2L6x3_12x12LLBB = ["American","AISC","Double Angle","2L6x3-1/2x1/2LLBB"]
	American_AISC_Double_Angle_2L6x3_12x12SLBB = ["American","AISC","Double Angle","2L6x3-1/2x1/2SLBB"]
	American_AISC_Double_Angle_2L6x3_12x12x34LLBB = ["American","AISC","Double Angle","2L6x3-1/2x1/2x3/4LLBB"]
	American_AISC_Double_Angle_2L6x3_12x12x34SLBB = ["American","AISC","Double Angle","2L6x3-1/2x1/2x3/4SLBB"]
	American_AISC_Double_Angle_2L6x3_12x12x38LLBB = ["American","AISC","Double Angle","2L6x3-1/2x1/2x3/8LLBB"]
	American_AISC_Double_Angle_2L6x3_12x12x38SLBB = ["American","AISC","Double Angle","2L6x3-1/2x1/2x3/8SLBB"]
	American_AISC_Double_Angle_2L6x3_12x38LLBB = ["American","AISC","Double Angle","2L6x3-1/2x3/8LLBB"]
	American_AISC_Double_Angle_2L6x3_12x38SLBB = ["American","AISC","Double Angle","2L6x3-1/2x3/8SLBB"]
	American_AISC_Double_Angle_2L6x3_12x38x34LLBB = ["American","AISC","Double Angle","2L6x3-1/2x3/8x3/4LLBB"]
	American_AISC_Double_Angle_2L6x3_12x38x34SLBB = ["American","AISC","Double Angle","2L6x3-1/2x3/8x3/4SLBB"]
	American_AISC_Double_Angle_2L6x3_12x38x38LLBB = ["American","AISC","Double Angle","2L6x3-1/2x3/8x3/8LLBB"]
	American_AISC_Double_Angle_2L6x3_12x38x38SLBB = ["American","AISC","Double Angle","2L6x3-1/2x3/8x3/8SLBB"]
	American_AISC_Double_Angle_2L6x3_12x516LLBB = ["American","AISC","Double Angle","2L6x3-1/2x5/16LLBB"]
	American_AISC_Double_Angle_2L6x3_12x516SLBB = ["American","AISC","Double Angle","2L6x3-1/2x5/16SLBB"]
	American_AISC_Double_Angle_2L6x3_12x516x34LLBB = ["American","AISC","Double Angle","2L6x3-1/2x5/16x3/4LLBB"]
	American_AISC_Double_Angle_2L6x3_12x516x34SLBB = ["American","AISC","Double Angle","2L6x3-1/2x5/16x3/4SLBB"]
	American_AISC_Double_Angle_2L6x3_12x516x38LLBB = ["American","AISC","Double Angle","2L6x3-1/2x5/16x3/8LLBB"]
	American_AISC_Double_Angle_2L6x3_12x516x38SLBB = ["American","AISC","Double Angle","2L6x3-1/2x5/16x3/8SLBB"]
	American_AISC_Double_Angle_2L6x4x12LLBB = ["American","AISC","Double Angle","2L6x4x1/2LLBB"]
	American_AISC_Double_Angle_2L6x4x12SLBB = ["American","AISC","Double Angle","2L6x4x1/2SLBB"]
	American_AISC_Double_Angle_2L6x4x12x34LLBB = ["American","AISC","Double Angle","2L6x4x1/2x3/4LLBB"]
	American_AISC_Double_Angle_2L6x4x12x34SLBB = ["American","AISC","Double Angle","2L6x4x1/2x3/4SLBB"]
	American_AISC_Double_Angle_2L6x4x12x38LLBB = ["American","AISC","Double Angle","2L6x4x1/2x3/8LLBB"]
	American_AISC_Double_Angle_2L6x4x12x38SLBB = ["American","AISC","Double Angle","2L6x4x1/2x3/8SLBB"]
	American_AISC_Double_Angle_2L6x4x34LLBB = ["American","AISC","Double Angle","2L6x4x3/4LLBB"]
	American_AISC_Double_Angle_2L6x4x34SLBB = ["American","AISC","Double Angle","2L6x4x3/4SLBB"]
	American_AISC_Double_Angle_2L6x4x34x34LLBB = ["American","AISC","Double Angle","2L6x4x3/4x3/4LLBB"]
	American_AISC_Double_Angle_2L6x4x34x34SLBB = ["American","AISC","Double Angle","2L6x4x3/4x3/4SLBB"]
	American_AISC_Double_Angle_2L6x4x34x38LLBB = ["American","AISC","Double Angle","2L6x4x3/4x3/8LLBB"]
	American_AISC_Double_Angle_2L6x4x34x38SLBB = ["American","AISC","Double Angle","2L6x4x3/4x3/8SLBB"]
	American_AISC_Double_Angle_2L6x4x38LLBB = ["American","AISC","Double Angle","2L6x4x3/8LLBB"]
	American_AISC_Double_Angle_2L6x4x38SLBB = ["American","AISC","Double Angle","2L6x4x3/8SLBB"]
	American_AISC_Double_Angle_2L6x4x38x34LLBB = ["American","AISC","Double Angle","2L6x4x3/8x3/4LLBB"]
	American_AISC_Double_Angle_2L6x4x38x34SLBB = ["American","AISC","Double Angle","2L6x4x3/8x3/4SLBB"]
	American_AISC_Double_Angle_2L6x4x38x38LLBB = ["American","AISC","Double Angle","2L6x4x3/8x3/8LLBB"]
	American_AISC_Double_Angle_2L6x4x38x38SLBB = ["American","AISC","Double Angle","2L6x4x3/8x3/8SLBB"]
	American_AISC_Double_Angle_2L6x4x58LLBB = ["American","AISC","Double Angle","2L6x4x5/8LLBB"]
	American_AISC_Double_Angle_2L6x4x58SLBB = ["American","AISC","Double Angle","2L6x4x5/8SLBB"]
	American_AISC_Double_Angle_2L6x4x58x34LLBB = ["American","AISC","Double Angle","2L6x4x5/8x3/4LLBB"]
	American_AISC_Double_Angle_2L6x4x58x34SLBB = ["American","AISC","Double Angle","2L6x4x5/8x3/4SLBB"]
	American_AISC_Double_Angle_2L6x4x58x38LLBB = ["American","AISC","Double Angle","2L6x4x5/8x3/8LLBB"]
	American_AISC_Double_Angle_2L6x4x58x38SLBB = ["American","AISC","Double Angle","2L6x4x5/8x3/8SLBB"]
	American_AISC_Double_Angle_2L6x4x516LLBB = ["American","AISC","Double Angle","2L6x4x5/16LLBB"]
	American_AISC_Double_Angle_2L6x4x516SLBB = ["American","AISC","Double Angle","2L6x4x5/16SLBB"]
	American_AISC_Double_Angle_2L6x4x516x34LLBB = ["American","AISC","Double Angle","2L6x4x5/16x3/4LLBB"]
	American_AISC_Double_Angle_2L6x4x516x34SLBB = ["American","AISC","Double Angle","2L6x4x5/16x3/4SLBB"]
	American_AISC_Double_Angle_2L6x4x516x38LLBB = ["American","AISC","Double Angle","2L6x4x5/16x3/8LLBB"]
	American_AISC_Double_Angle_2L6x4x516x38SLBB = ["American","AISC","Double Angle","2L6x4x5/16x3/8SLBB"]
	American_AISC_Double_Angle_2L6x4x78LLBB = ["American","AISC","Double Angle","2L6x4x7/8LLBB"]
	American_AISC_Double_Angle_2L6x4x78SLBB = ["American","AISC","Double Angle","2L6x4x7/8SLBB"]
	American_AISC_Double_Angle_2L6x4x78x34LLBB = ["American","AISC","Double Angle","2L6x4x7/8x3/4LLBB"]
	American_AISC_Double_Angle_2L6x4x78x34SLBB = ["American","AISC","Double Angle","2L6x4x7/8x3/4SLBB"]
	American_AISC_Double_Angle_2L6x4x78x38LLBB = ["American","AISC","Double Angle","2L6x4x7/8x3/8LLBB"]
	American_AISC_Double_Angle_2L6x4x78x38SLBB = ["American","AISC","Double Angle","2L6x4x7/8x3/8SLBB"]
	American_AISC_Double_Angle_2L6x4x716LLBB = ["American","AISC","Double Angle","2L6x4x7/16LLBB"]
	American_AISC_Double_Angle_2L6x4x716SLBB = ["American","AISC","Double Angle","2L6x4x7/16SLBB"]
	American_AISC_Double_Angle_2L6x4x716x34LLBB = ["American","AISC","Double Angle","2L6x4x7/16x3/4LLBB"]
	American_AISC_Double_Angle_2L6x4x716x34SLBB = ["American","AISC","Double Angle","2L6x4x7/16x3/4SLBB"]
	American_AISC_Double_Angle_2L6x4x716x38LLBB = ["American","AISC","Double Angle","2L6x4x7/16x3/8LLBB"]
	American_AISC_Double_Angle_2L6x4x716x38SLBB = ["American","AISC","Double Angle","2L6x4x7/16x3/8SLBB"]
	American_AISC_Double_Angle_2L6x4x916LLBB = ["American","AISC","Double Angle","2L6x4x9/16LLBB"]
	American_AISC_Double_Angle_2L6x4x916SLBB = ["American","AISC","Double Angle","2L6x4x9/16SLBB"]
	American_AISC_Double_Angle_2L6x4x916x34LLBB = ["American","AISC","Double Angle","2L6x4x9/16x3/4LLBB"]
	American_AISC_Double_Angle_2L6x4x916x34SLBB = ["American","AISC","Double Angle","2L6x4x9/16x3/4SLBB"]
	American_AISC_Double_Angle_2L6x4x916x38LLBB = ["American","AISC","Double Angle","2L6x4x9/16x3/8LLBB"]
	American_AISC_Double_Angle_2L6x4x916x38SLBB = ["American","AISC","Double Angle","2L6x4x9/16x3/8SLBB"]
	American_AISC_Double_Angle_2L6x6x1 = ["American","AISC","Double Angle","2L6x6x1"]
	American_AISC_Double_Angle_2L6x6x12 = ["American","AISC","Double Angle","2L6x6x1/2"]
	American_AISC_Double_Angle_2L6x6x12x34 = ["American","AISC","Double Angle","2L6x6x1/2x3/4"]
	American_AISC_Double_Angle_2L6x6x12x38 = ["American","AISC","Double Angle","2L6x6x1/2x3/8"]
	American_AISC_Double_Angle_2L6x6x1x34 = ["American","AISC","Double Angle","2L6x6x1x3/4"]
	American_AISC_Double_Angle_2L6x6x1x38 = ["American","AISC","Double Angle","2L6x6x1x3/8"]
	American_AISC_Double_Angle_2L6x6x34 = ["American","AISC","Double Angle","2L6x6x3/4"]
	American_AISC_Double_Angle_2L6x6x34x34 = ["American","AISC","Double Angle","2L6x6x3/4x3/4"]
	American_AISC_Double_Angle_2L6x6x34x38 = ["American","AISC","Double Angle","2L6x6x3/4x3/8"]
	American_AISC_Double_Angle_2L6x6x38 = ["American","AISC","Double Angle","2L6x6x3/8"]
	American_AISC_Double_Angle_2L6x6x38x34 = ["American","AISC","Double Angle","2L6x6x3/8x3/4"]
	American_AISC_Double_Angle_2L6x6x38x38 = ["American","AISC","Double Angle","2L6x6x3/8x3/8"]
	American_AISC_Double_Angle_2L6x6x58 = ["American","AISC","Double Angle","2L6x6x5/8"]
	American_AISC_Double_Angle_2L6x6x58x34 = ["American","AISC","Double Angle","2L6x6x5/8x3/4"]
	American_AISC_Double_Angle_2L6x6x58x38 = ["American","AISC","Double Angle","2L6x6x5/8x3/8"]
	American_AISC_Double_Angle_2L6x6x516 = ["American","AISC","Double Angle","2L6x6x5/16"]
	American_AISC_Double_Angle_2L6x6x516x34 = ["American","AISC","Double Angle","2L6x6x5/16x3/4"]
	American_AISC_Double_Angle_2L6x6x516x38 = ["American","AISC","Double Angle","2L6x6x5/16x3/8"]
	American_AISC_Double_Angle_2L6x6x78 = ["American","AISC","Double Angle","2L6x6x7/8"]
	American_AISC_Double_Angle_2L6x6x78x34 = ["American","AISC","Double Angle","2L6x6x7/8x3/4"]
	American_AISC_Double_Angle_2L6x6x78x38 = ["American","AISC","Double Angle","2L6x6x7/8x3/8"]
	American_AISC_Double_Angle_2L6x6x716 = ["American","AISC","Double Angle","2L6x6x7/16"]
	American_AISC_Double_Angle_2L6x6x716x34 = ["American","AISC","Double Angle","2L6x6x7/16x3/4"]
	American_AISC_Double_Angle_2L6x6x716x38 = ["American","AISC","Double Angle","2L6x6x7/16x3/8"]
	American_AISC_Double_Angle_2L6x6x916 = ["American","AISC","Double Angle","2L6x6x9/16"]
	American_AISC_Double_Angle_2L6x6x916x34 = ["American","AISC","Double Angle","2L6x6x9/16x3/4"]
	American_AISC_Double_Angle_2L6x6x916x38 = ["American","AISC","Double Angle","2L6x6x9/16x3/8"]
	American_AISC_Double_Angle_2L7x4x12LLBB = ["American","AISC","Double Angle","2L7x4x1/2LLBB"]
	American_AISC_Double_Angle_2L7x4x12SLBB = ["American","AISC","Double Angle","2L7x4x1/2SLBB"]
	American_AISC_Double_Angle_2L7x4x12x34LLBB = ["American","AISC","Double Angle","2L7x4x1/2x3/4LLBB"]
	American_AISC_Double_Angle_2L7x4x12x34SLBB = ["American","AISC","Double Angle","2L7x4x1/2x3/4SLBB"]
	American_AISC_Double_Angle_2L7x4x12x38LLBB = ["American","AISC","Double Angle","2L7x4x1/2x3/8LLBB"]
	American_AISC_Double_Angle_2L7x4x12x38SLBB = ["American","AISC","Double Angle","2L7x4x1/2x3/8SLBB"]
	American_AISC_Double_Angle_2L7x4x34LLBB = ["American","AISC","Double Angle","2L7x4x3/4LLBB"]
	American_AISC_Double_Angle_2L7x4x34SLBB = ["American","AISC","Double Angle","2L7x4x3/4SLBB"]
	American_AISC_Double_Angle_2L7x4x34x34LLBB = ["American","AISC","Double Angle","2L7x4x3/4x3/4LLBB"]
	American_AISC_Double_Angle_2L7x4x34x34SLBB = ["American","AISC","Double Angle","2L7x4x3/4x3/4SLBB"]
	American_AISC_Double_Angle_2L7x4x34x38LLBB = ["American","AISC","Double Angle","2L7x4x3/4x3/8LLBB"]
	American_AISC_Double_Angle_2L7x4x34x38SLBB = ["American","AISC","Double Angle","2L7x4x3/4x3/8SLBB"]
	American_AISC_Double_Angle_2L7x4x38LLBB = ["American","AISC","Double Angle","2L7x4x3/8LLBB"]
	American_AISC_Double_Angle_2L7x4x38SLBB = ["American","AISC","Double Angle","2L7x4x3/8SLBB"]
	American_AISC_Double_Angle_2L7x4x38x34LLBB = ["American","AISC","Double Angle","2L7x4x3/8x3/4LLBB"]
	American_AISC_Double_Angle_2L7x4x38x34SLBB = ["American","AISC","Double Angle","2L7x4x3/8x3/4SLBB"]
	American_AISC_Double_Angle_2L7x4x38x38LLBB = ["American","AISC","Double Angle","2L7x4x3/8x3/8LLBB"]
	American_AISC_Double_Angle_2L7x4x38x38SLBB = ["American","AISC","Double Angle","2L7x4x3/8x3/8SLBB"]
	American_AISC_Double_Angle_2L7x4x58LLBB = ["American","AISC","Double Angle","2L7x4x5/8LLBB"]
	American_AISC_Double_Angle_2L7x4x58SLBB = ["American","AISC","Double Angle","2L7x4x5/8SLBB"]
	American_AISC_Double_Angle_2L7x4x58x34LLBB = ["American","AISC","Double Angle","2L7x4x5/8x3/4LLBB"]
	American_AISC_Double_Angle_2L7x4x58x34SLBB = ["American","AISC","Double Angle","2L7x4x5/8x3/4SLBB"]
	American_AISC_Double_Angle_2L7x4x58x38LLBB = ["American","AISC","Double Angle","2L7x4x5/8x3/8LLBB"]
	American_AISC_Double_Angle_2L7x4x58x38SLBB = ["American","AISC","Double Angle","2L7x4x5/8x3/8SLBB"]
	American_AISC_Double_Angle_2L7x4x716LLBB = ["American","AISC","Double Angle","2L7x4x7/16LLBB"]
	American_AISC_Double_Angle_2L7x4x716SLBB = ["American","AISC","Double Angle","2L7x4x7/16SLBB"]
	American_AISC_Double_Angle_2L7x4x716x34LLBB = ["American","AISC","Double Angle","2L7x4x7/16x3/4LLBB"]
	American_AISC_Double_Angle_2L7x4x716x34SLBB = ["American","AISC","Double Angle","2L7x4x7/16x3/4SLBB"]
	American_AISC_Double_Angle_2L7x4x716x38LLBB = ["American","AISC","Double Angle","2L7x4x7/16x3/8LLBB"]
	American_AISC_Double_Angle_2L7x4x716x38SLBB = ["American","AISC","Double Angle","2L7x4x7/16x3/8SLBB"]
	American_AISC_Double_Angle_2L8x4x12LLBB = ["American","AISC","Double Angle","2L8x4x1/2LLBB"]
	American_AISC_Double_Angle_2L8x4x12SLBB = ["American","AISC","Double Angle","2L8x4x1/2SLBB"]
	American_AISC_Double_Angle_2L8x4x12x34LLBB = ["American","AISC","Double Angle","2L8x4x1/2x3/4LLBB"]
	American_AISC_Double_Angle_2L8x4x12x34SLBB = ["American","AISC","Double Angle","2L8x4x1/2x3/4SLBB"]
	American_AISC_Double_Angle_2L8x4x12x38LLBB = ["American","AISC","Double Angle","2L8x4x1/2x3/8LLBB"]
	American_AISC_Double_Angle_2L8x4x12x38SLBB = ["American","AISC","Double Angle","2L8x4x1/2x3/8SLBB"]
	American_AISC_Double_Angle_2L8x4x1LLBB = ["American","AISC","Double Angle","2L8x4x1LLBB"]
	American_AISC_Double_Angle_2L8x4x1SLBB = ["American","AISC","Double Angle","2L8x4x1SLBB"]
	American_AISC_Double_Angle_2L8x4x1x34LLBB = ["American","AISC","Double Angle","2L8x4x1x3/4LLBB"]
	American_AISC_Double_Angle_2L8x4x1x34SLBB = ["American","AISC","Double Angle","2L8x4x1x3/4SLBB"]
	American_AISC_Double_Angle_2L8x4x1x38LLBB = ["American","AISC","Double Angle","2L8x4x1x3/8LLBB"]
	American_AISC_Double_Angle_2L8x4x1x38SLBB = ["American","AISC","Double Angle","2L8x4x1x3/8SLBB"]
	American_AISC_Double_Angle_2L8x4x34LLBB = ["American","AISC","Double Angle","2L8x4x3/4LLBB"]
	American_AISC_Double_Angle_2L8x4x34SLBB = ["American","AISC","Double Angle","2L8x4x3/4SLBB"]
	American_AISC_Double_Angle_2L8x4x34x34LLBB = ["American","AISC","Double Angle","2L8x4x3/4x3/4LLBB"]
	American_AISC_Double_Angle_2L8x4x34x34SLBB = ["American","AISC","Double Angle","2L8x4x3/4x3/4SLBB"]
	American_AISC_Double_Angle_2L8x4x34x38LLBB = ["American","AISC","Double Angle","2L8x4x3/4x3/8LLBB"]
	American_AISC_Double_Angle_2L8x4x34x38SLBB = ["American","AISC","Double Angle","2L8x4x3/4x3/8SLBB"]
	American_AISC_Double_Angle_2L8x4x58LLBB = ["American","AISC","Double Angle","2L8x4x5/8LLBB"]
	American_AISC_Double_Angle_2L8x4x58SLBB = ["American","AISC","Double Angle","2L8x4x5/8SLBB"]
	American_AISC_Double_Angle_2L8x4x58x34LLBB = ["American","AISC","Double Angle","2L8x4x5/8x3/4LLBB"]
	American_AISC_Double_Angle_2L8x4x58x34SLBB = ["American","AISC","Double Angle","2L8x4x5/8x3/4SLBB"]
	American_AISC_Double_Angle_2L8x4x58x38LLBB = ["American","AISC","Double Angle","2L8x4x5/8x3/8LLBB"]
	American_AISC_Double_Angle_2L8x4x58x38SLBB = ["American","AISC","Double Angle","2L8x4x5/8x3/8SLBB"]
	American_AISC_Double_Angle_2L8x4x78LLBB = ["American","AISC","Double Angle","2L8x4x7/8LLBB"]
	American_AISC_Double_Angle_2L8x4x78SLBB = ["American","AISC","Double Angle","2L8x4x7/8SLBB"]
	American_AISC_Double_Angle_2L8x4x78x34LLBB = ["American","AISC","Double Angle","2L8x4x7/8x3/4LLBB"]
	American_AISC_Double_Angle_2L8x4x78x34SLBB = ["American","AISC","Double Angle","2L8x4x7/8x3/4SLBB"]
	American_AISC_Double_Angle_2L8x4x78x38LLBB = ["American","AISC","Double Angle","2L8x4x7/8x3/8LLBB"]
	American_AISC_Double_Angle_2L8x4x78x38SLBB = ["American","AISC","Double Angle","2L8x4x7/8x3/8SLBB"]
	American_AISC_Double_Angle_2L8x4x716LLBB = ["American","AISC","Double Angle","2L8x4x7/16LLBB"]
	American_AISC_Double_Angle_2L8x4x716SLBB = ["American","AISC","Double Angle","2L8x4x7/16SLBB"]
	American_AISC_Double_Angle_2L8x4x716x34LLBB = ["American","AISC","Double Angle","2L8x4x7/16x3/4LLBB"]
	American_AISC_Double_Angle_2L8x4x716x34SLBB = ["American","AISC","Double Angle","2L8x4x7/16x3/4SLBB"]
	American_AISC_Double_Angle_2L8x4x716x38LLBB = ["American","AISC","Double Angle","2L8x4x7/16x3/8LLBB"]
	American_AISC_Double_Angle_2L8x4x716x38SLBB = ["American","AISC","Double Angle","2L8x4x7/16x3/8SLBB"]
	American_AISC_Double_Angle_2L8x4x916LLBB = ["American","AISC","Double Angle","2L8x4x9/16LLBB"]
	American_AISC_Double_Angle_2L8x4x916SLBB = ["American","AISC","Double Angle","2L8x4x9/16SLBB"]
	American_AISC_Double_Angle_2L8x4x916x34LLBB = ["American","AISC","Double Angle","2L8x4x9/16x3/4LLBB"]
	American_AISC_Double_Angle_2L8x4x916x34SLBB = ["American","AISC","Double Angle","2L8x4x9/16x3/4SLBB"]
	American_AISC_Double_Angle_2L8x4x916x38LLBB = ["American","AISC","Double Angle","2L8x4x9/16x3/8LLBB"]
	American_AISC_Double_Angle_2L8x4x916x38SLBB = ["American","AISC","Double Angle","2L8x4x9/16x3/8SLBB"]
	American_AISC_Double_Angle_2L8x6x12LLBB = ["American","AISC","Double Angle","2L8x6x1/2LLBB"]
	American_AISC_Double_Angle_2L8x6x12SLBB = ["American","AISC","Double Angle","2L8x6x1/2SLBB"]
	American_AISC_Double_Angle_2L8x6x12x34LLBB = ["American","AISC","Double Angle","2L8x6x1/2x3/4LLBB"]
	American_AISC_Double_Angle_2L8x6x12x34SLBB = ["American","AISC","Double Angle","2L8x6x1/2x3/4SLBB"]
	American_AISC_Double_Angle_2L8x6x12x38LLBB = ["American","AISC","Double Angle","2L8x6x1/2x3/8LLBB"]
	American_AISC_Double_Angle_2L8x6x12x38SLBB = ["American","AISC","Double Angle","2L8x6x1/2x3/8SLBB"]
	American_AISC_Double_Angle_2L8x6x1LLBB = ["American","AISC","Double Angle","2L8x6x1LLBB"]
	American_AISC_Double_Angle_2L8x6x1SLBB = ["American","AISC","Double Angle","2L8x6x1SLBB"]
	American_AISC_Double_Angle_2L8x6x1x34LLBB = ["American","AISC","Double Angle","2L8x6x1x3/4LLBB"]
	American_AISC_Double_Angle_2L8x6x1x34SLBB = ["American","AISC","Double Angle","2L8x6x1x3/4SLBB"]
	American_AISC_Double_Angle_2L8x6x1x38LLBB = ["American","AISC","Double Angle","2L8x6x1x3/8LLBB"]
	American_AISC_Double_Angle_2L8x6x1x38SLBB = ["American","AISC","Double Angle","2L8x6x1x3/8SLBB"]
	American_AISC_Double_Angle_2L8x6x34LLBB = ["American","AISC","Double Angle","2L8x6x3/4LLBB"]
	American_AISC_Double_Angle_2L8x6x34SLBB = ["American","AISC","Double Angle","2L8x6x3/4SLBB"]
	American_AISC_Double_Angle_2L8x6x34x34LLBB = ["American","AISC","Double Angle","2L8x6x3/4x3/4LLBB"]
	American_AISC_Double_Angle_2L8x6x34x34SLBB = ["American","AISC","Double Angle","2L8x6x3/4x3/4SLBB"]
	American_AISC_Double_Angle_2L8x6x34x38LLBB = ["American","AISC","Double Angle","2L8x6x3/4x3/8LLBB"]
	American_AISC_Double_Angle_2L8x6x34x38SLBB = ["American","AISC","Double Angle","2L8x6x3/4x3/8SLBB"]
	American_AISC_Double_Angle_2L8x6x58LLBB = ["American","AISC","Double Angle","2L8x6x5/8LLBB"]
	American_AISC_Double_Angle_2L8x6x58SLBB = ["American","AISC","Double Angle","2L8x6x5/8SLBB"]
	American_AISC_Double_Angle_2L8x6x58x34LLBB = ["American","AISC","Double Angle","2L8x6x5/8x3/4LLBB"]
	American_AISC_Double_Angle_2L8x6x58x34SLBB = ["American","AISC","Double Angle","2L8x6x5/8x3/4SLBB"]
	American_AISC_Double_Angle_2L8x6x58x38LLBB = ["American","AISC","Double Angle","2L8x6x5/8x3/8LLBB"]
	American_AISC_Double_Angle_2L8x6x58x38SLBB = ["American","AISC","Double Angle","2L8x6x5/8x3/8SLBB"]
	American_AISC_Double_Angle_2L8x6x78LLBB = ["American","AISC","Double Angle","2L8x6x7/8LLBB"]
	American_AISC_Double_Angle_2L8x6x78SLBB = ["American","AISC","Double Angle","2L8x6x7/8SLBB"]
	American_AISC_Double_Angle_2L8x6x78x34LLBB = ["American","AISC","Double Angle","2L8x6x7/8x3/4LLBB"]
	American_AISC_Double_Angle_2L8x6x78x34SLBB = ["American","AISC","Double Angle","2L8x6x7/8x3/4SLBB"]
	American_AISC_Double_Angle_2L8x6x78x38LLBB = ["American","AISC","Double Angle","2L8x6x7/8x3/8LLBB"]
	American_AISC_Double_Angle_2L8x6x78x38SLBB = ["American","AISC","Double Angle","2L8x6x7/8x3/8SLBB"]
	American_AISC_Double_Angle_2L8x6x716LLBB = ["American","AISC","Double Angle","2L8x6x7/16LLBB"]
	American_AISC_Double_Angle_2L8x6x716SLBB = ["American","AISC","Double Angle","2L8x6x7/16SLBB"]
	American_AISC_Double_Angle_2L8x6x716x34LLBB = ["American","AISC","Double Angle","2L8x6x7/16x3/4LLBB"]
	American_AISC_Double_Angle_2L8x6x716x34SLBB = ["American","AISC","Double Angle","2L8x6x7/16x3/4SLBB"]
	American_AISC_Double_Angle_2L8x6x716x38LLBB = ["American","AISC","Double Angle","2L8x6x7/16x3/8LLBB"]
	American_AISC_Double_Angle_2L8x6x716x38SLBB = ["American","AISC","Double Angle","2L8x6x7/16x3/8SLBB"]
	American_AISC_Double_Angle_2L8x6x916LLBB = ["American","AISC","Double Angle","2L8x6x9/16LLBB"]
	American_AISC_Double_Angle_2L8x6x916SLBB = ["American","AISC","Double Angle","2L8x6x9/16SLBB"]
	American_AISC_Double_Angle_2L8x6x916x34LLBB = ["American","AISC","Double Angle","2L8x6x9/16x3/4LLBB"]
	American_AISC_Double_Angle_2L8x6x916x34SLBB = ["American","AISC","Double Angle","2L8x6x9/16x3/4SLBB"]
	American_AISC_Double_Angle_2L8x6x916x38LLBB = ["American","AISC","Double Angle","2L8x6x9/16x3/8LLBB"]
	American_AISC_Double_Angle_2L8x6x916x38SLBB = ["American","AISC","Double Angle","2L8x6x9/16x3/8SLBB"]
	American_AISC_Double_Angle_2L8x8x1 = ["American","AISC","Double Angle","2L8x8x1"]
	American_AISC_Double_Angle_2L8x8x1_18 = ["American","AISC","Double Angle","2L8x8x1-1/8"]
	American_AISC_Double_Angle_2L8x8x1_18x34 = ["American","AISC","Double Angle","2L8x8x1-1/8x3/4"]
	American_AISC_Double_Angle_2L8x8x1_18x38 = ["American","AISC","Double Angle","2L8x8x1-1/8x3/8"]
	American_AISC_Double_Angle_2L8x8x12 = ["American","AISC","Double Angle","2L8x8x1/2"]
	American_AISC_Double_Angle_2L8x8x12x34 = ["American","AISC","Double Angle","2L8x8x1/2x3/4"]
	American_AISC_Double_Angle_2L8x8x12x38 = ["American","AISC","Double Angle","2L8x8x1/2x3/8"]
	American_AISC_Double_Angle_2L8x8x1x34 = ["American","AISC","Double Angle","2L8x8x1x3/4"]
	American_AISC_Double_Angle_2L8x8x1x38 = ["American","AISC","Double Angle","2L8x8x1x3/8"]
	American_AISC_Double_Angle_2L8x8x34 = ["American","AISC","Double Angle","2L8x8x3/4"]
	American_AISC_Double_Angle_2L8x8x34x34 = ["American","AISC","Double Angle","2L8x8x3/4x3/4"]
	American_AISC_Double_Angle_2L8x8x34x38 = ["American","AISC","Double Angle","2L8x8x3/4x3/8"]
	American_AISC_Double_Angle_2L8x8x58 = ["American","AISC","Double Angle","2L8x8x5/8"]
	American_AISC_Double_Angle_2L8x8x58x34 = ["American","AISC","Double Angle","2L8x8x5/8x3/4"]
	American_AISC_Double_Angle_2L8x8x58x38 = ["American","AISC","Double Angle","2L8x8x5/8x3/8"]
	American_AISC_Double_Angle_2L8x8x78 = ["American","AISC","Double Angle","2L8x8x7/8"]
	American_AISC_Double_Angle_2L8x8x78x34 = ["American","AISC","Double Angle","2L8x8x7/8x3/4"]
	American_AISC_Double_Angle_2L8x8x78x38 = ["American","AISC","Double Angle","2L8x8x7/8x3/8"]
	American_AISC_Double_Angle_2L8x8x916 = ["American","AISC","Double Angle","2L8x8x9/16"]
	American_AISC_Double_Angle_2L8x8x916x34 = ["American","AISC","Double Angle","2L8x8x9/16x3/4"]
	American_AISC_Double_Angle_2L8x8x916x38 = ["American","AISC","Double Angle","2L8x8x9/16x3/8"]
	American_AISC_Equal_angles_L2_5x2_5x12 = ["American","AISC","Equal angles","L2.5x2.5x1/2"]
	American_AISC_Equal_angles_L2_5x2_5x14 = ["American","AISC","Equal angles","L2.5x2.5x1/4"]
	American_AISC_Equal_angles_L2_5x2_5x38 = ["American","AISC","Equal angles","L2.5x2.5x3/8"]
	American_AISC_Equal_angles_L2_5x2_5x316 = ["American","AISC","Equal angles","L2.5x2.5x3/16"]
	American_AISC_Equal_angles_L2_5x2_5x516 = ["American","AISC","Equal angles","L2.5x2.5x5/16"]
	American_AISC_Equal_angles_L2x2x14 = ["American","AISC","Equal angles","L2x2x1/4"]
	American_AISC_Equal_angles_L2x2x18 = ["American","AISC","Equal angles","L2x2x1/8"]
	American_AISC_Equal_angles_L2x2x38 = ["American","AISC","Equal angles","L2x2x3/8"]
	American_AISC_Equal_angles_L2x2x316 = ["American","AISC","Equal angles","L2x2x3/16"]
	American_AISC_Equal_angles_L2x2x516 = ["American","AISC","Equal angles","L2x2x5/16"]
	American_AISC_Equal_angles_L3_5x3_5x12 = ["American","AISC","Equal angles","L3.5x3.5x1/2"]
	American_AISC_Equal_angles_L3_5x3_5x14 = ["American","AISC","Equal angles","L3.5x3.5x1/4"]
	American_AISC_Equal_angles_L3_5x3_5x38 = ["American","AISC","Equal angles","L3.5x3.5x3/8"]
	American_AISC_Equal_angles_L3_5x3_5x516 = ["American","AISC","Equal angles","L3.5x3.5x5/16"]
	American_AISC_Equal_angles_L3_5x3_5x716 = ["American","AISC","Equal angles","L3.5x3.5x7/16"]
	American_AISC_Equal_angles_L3x3x12 = ["American","AISC","Equal angles","L3x3x1/2"]
	American_AISC_Equal_angles_L3x3x14 = ["American","AISC","Equal angles","L3x3x1/4"]
	American_AISC_Equal_angles_L3x3x38 = ["American","AISC","Equal angles","L3x3x3/8"]
	American_AISC_Equal_angles_L3x3x316 = ["American","AISC","Equal angles","L3x3x3/16"]
	American_AISC_Equal_angles_L3x3x516 = ["American","AISC","Equal angles","L3x3x5/16"]
	American_AISC_Equal_angles_L3x3x716 = ["American","AISC","Equal angles","L3x3x7/16"]
	American_AISC_Equal_angles_L4x4x12 = ["American","AISC","Equal angles","L4x4x1/2"]
	American_AISC_Equal_angles_L4x4x14 = ["American","AISC","Equal angles","L4x4x1/4"]
	American_AISC_Equal_angles_L4x4x34 = ["American","AISC","Equal angles","L4x4x3/4"]
	American_AISC_Equal_angles_L4x4x38 = ["American","AISC","Equal angles","L4x4x3/8"]
	American_AISC_Equal_angles_L4x4x58 = ["American","AISC","Equal angles","L4x4x5/8"]
	American_AISC_Equal_angles_L4x4x516 = ["American","AISC","Equal angles","L4x4x5/16"]
	American_AISC_Equal_angles_L4x4x716 = ["American","AISC","Equal angles","L4x4x7/16"]
	American_AISC_Equal_angles_L5x5x12 = ["American","AISC","Equal angles","L5x5x1/2"]
	American_AISC_Equal_angles_L5x5x34 = ["American","AISC","Equal angles","L5x5x3/4"]
	American_AISC_Equal_angles_L5x5x38 = ["American","AISC","Equal angles","L5x5x3/8"]
	American_AISC_Equal_angles_L5x5x58 = ["American","AISC","Equal angles","L5x5x5/8"]
	American_AISC_Equal_angles_L5x5x516 = ["American","AISC","Equal angles","L5x5x5/16"]
	American_AISC_Equal_angles_L5x5x78 = ["American","AISC","Equal angles","L5x5x7/8"]
	American_AISC_Equal_angles_L5x5x716 = ["American","AISC","Equal angles","L5x5x7/16"]
	American_AISC_Equal_angles_L6x6x1 = ["American","AISC","Equal angles","L6x6x1"]
	American_AISC_Equal_angles_L6x6x12 = ["American","AISC","Equal angles","L6x6x1/2"]
	American_AISC_Equal_angles_L6x6x34 = ["American","AISC","Equal angles","L6x6x3/4"]
	American_AISC_Equal_angles_L6x6x38 = ["American","AISC","Equal angles","L6x6x3/8"]
	American_AISC_Equal_angles_L6x6x58 = ["American","AISC","Equal angles","L6x6x5/8"]
	American_AISC_Equal_angles_L6x6x516 = ["American","AISC","Equal angles","L6x6x5/16"]
	American_AISC_Equal_angles_L6x6x78 = ["American","AISC","Equal angles","L6x6x7/8"]
	American_AISC_Equal_angles_L6x6x716 = ["American","AISC","Equal angles","L6x6x7/16"]
	American_AISC_Equal_angles_L6x6x916 = ["American","AISC","Equal angles","L6x6x9/16"]
	American_AISC_Equal_angles_L8x8x1 = ["American","AISC","Equal angles","L8x8x1"]
	American_AISC_Equal_angles_L8x8x12 = ["American","AISC","Equal angles","L8x8x1/2"]
	American_AISC_Equal_angles_L8x8x34 = ["American","AISC","Equal angles","L8x8x3/4"]
	American_AISC_Equal_angles_L8x8x58 = ["American","AISC","Equal angles","L8x8x5/8"]
	American_AISC_Equal_angles_L8x8x78 = ["American","AISC","Equal angles","L8x8x7/8"]
	American_AISC_Equal_angles_L8x8x98 = ["American","AISC","Equal angles","L8x8x9/8"]
	American_AISC_Equal_angles_L8x8x916 = ["American","AISC","Equal angles","L8x8x9/16"]
	American_AISC_HP_shapes_HP8x36 = ["American","AISC","HP shapes","HP8x36"]
	American_AISC_HP_shapes_HP10x42 = ["American","AISC","HP shapes","HP10x42"]
	American_AISC_HP_shapes_HP10x57 = ["American","AISC","HP shapes","HP10x57"]
	American_AISC_HP_shapes_HP12x53 = ["American","AISC","HP shapes","HP12x53"]
	American_AISC_HP_shapes_HP12x63 = ["American","AISC","HP shapes","HP12x63"]
	American_AISC_HP_shapes_HP12x74 = ["American","AISC","HP shapes","HP12x74"]
	American_AISC_HP_shapes_HP12x84 = ["American","AISC","HP shapes","HP12x84"]
	American_AISC_HP_shapes_HP14x73 = ["American","AISC","HP shapes","HP14x73"]
	American_AISC_HP_shapes_HP14x89 = ["American","AISC","HP shapes","HP14x89"]
	American_AISC_HP_shapes_HP14x102 = ["American","AISC","HP shapes","HP14x102"]
	American_AISC_HP_shapes_HP14x117 = ["American","AISC","HP shapes","HP14x117"]
	American_AISC_HP_shapes_HP16x88 = ["American","AISC","HP shapes","HP16x88"]
	American_AISC_HP_shapes_HP16x101 = ["American","AISC","HP shapes","HP16x101"]
	American_AISC_HP_shapes_HP16x121 = ["American","AISC","HP shapes","HP16x121"]
	American_AISC_HP_shapes_HP16x141 = ["American","AISC","HP shapes","HP16x141"]
	American_AISC_HP_shapes_HP16x162 = ["American","AISC","HP shapes","HP16x162"]
	American_AISC_HP_shapes_HP16x183 = ["American","AISC","HP shapes","HP16x183"]
	American_AISC_HP_shapes_HP18x135 = ["American","AISC","HP shapes","HP18x135"]
	American_AISC_HP_shapes_HP18x157 = ["American","AISC","HP shapes","HP18x157"]
	American_AISC_HP_shapes_HP18x181 = ["American","AISC","HP shapes","HP18x181"]
	American_AISC_HP_shapes_HP18x204 = ["American","AISC","HP shapes","HP18x204"]
	American_AISC_M_shapes_M3x2_9 = ["American","AISC","M shapes","M3x2.9"]
	American_AISC_M_shapes_M4x3_2 = ["American","AISC","M shapes","M4x3.2"]
	American_AISC_M_shapes_M4x3_45 = ["American","AISC","M shapes","M4x3.45"]
	American_AISC_M_shapes_M4x4_08 = ["American","AISC","M shapes","M4x4.08"]
	American_AISC_M_shapes_M4x6 = ["American","AISC","M shapes","M4x6"]
	American_AISC_M_shapes_M5x18_9 = ["American","AISC","M shapes","M5x18.9"]
	American_AISC_M_shapes_M6x3_7 = ["American","AISC","M shapes","M6x3.7"]
	American_AISC_M_shapes_M6x4_4 = ["American","AISC","M shapes","M6x4.4"]
	American_AISC_M_shapes_M8x6_2 = ["American","AISC","M shapes","M8x6.2"]
	American_AISC_M_shapes_M8x6_5 = ["American","AISC","M shapes","M8x6.5"]
	American_AISC_M_shapes_M10x7_5 = ["American","AISC","M shapes","M10x7.5"]
	American_AISC_M_shapes_M10x8 = ["American","AISC","M shapes","M10x8"]
	American_AISC_M_shapes_M10x9 = ["American","AISC","M shapes","M10x9"]
	American_AISC_M_shapes_M12_5x11_6 = ["American","AISC","M shapes","M12.5x11.6"]
	American_AISC_M_shapes_M12_5x12_4 = ["American","AISC","M shapes","M12.5x12.4"]
	American_AISC_M_shapes_M12x10 = ["American","AISC","M shapes","M12x10"]
	American_AISC_M_shapes_M12x10_8 = ["American","AISC","M shapes","M12x10.8"]
	American_AISC_M_shapes_M12x11_8 = ["American","AISC","M shapes","M12x11.8"]
	American_AISC_Miscellaneous_channels_MC3x7_1 = ["American","AISC","Miscellaneous channels","MC3x7.1"]
	American_AISC_Miscellaneous_channels_MC4x13_8 = ["American","AISC","Miscellaneous channels","MC4x13.8"]
	American_AISC_Miscellaneous_channels_MC6x6_5 = ["American","AISC","Miscellaneous channels","MC6x6.5"]
	American_AISC_Miscellaneous_channels_MC6x7 = ["American","AISC","Miscellaneous channels","MC6x7"]
	American_AISC_Miscellaneous_channels_MC6x12 = ["American","AISC","Miscellaneous channels","MC6x12"]
	American_AISC_Miscellaneous_channels_MC6x15_1 = ["American","AISC","Miscellaneous channels","MC6x15.1"]
	American_AISC_Miscellaneous_channels_MC6x15_3 = ["American","AISC","Miscellaneous channels","MC6x15.3"]
	American_AISC_Miscellaneous_channels_MC6x16_3 = ["American","AISC","Miscellaneous channels","MC6x16.3"]
	American_AISC_Miscellaneous_channels_MC6x18 = ["American","AISC","Miscellaneous channels","MC6x18"]
	American_AISC_Miscellaneous_channels_MC7x19_1 = ["American","AISC","Miscellaneous channels","MC7x19.1"]
	American_AISC_Miscellaneous_channels_MC7x22_7 = ["American","AISC","Miscellaneous channels","MC7x22.7"]
	American_AISC_Miscellaneous_channels_MC8x8_5 = ["American","AISC","Miscellaneous channels","MC8x8.5"]
	American_AISC_Miscellaneous_channels_MC8x18_7 = ["American","AISC","Miscellaneous channels","MC8x18.7"]
	American_AISC_Miscellaneous_channels_MC8x20 = ["American","AISC","Miscellaneous channels","MC8x20"]
	American_AISC_Miscellaneous_channels_MC8x21_4 = ["American","AISC","Miscellaneous channels","MC8x21.4"]
	American_AISC_Miscellaneous_channels_MC8x22_8 = ["American","AISC","Miscellaneous channels","MC8x22.8"]
	American_AISC_Miscellaneous_channels_MC9x23_9 = ["American","AISC","Miscellaneous channels","MC9x23.9"]
	American_AISC_Miscellaneous_channels_MC9x25_4 = ["American","AISC","Miscellaneous channels","MC9x25.4"]
	American_AISC_Miscellaneous_channels_MC10x6_5 = ["American","AISC","Miscellaneous channels","MC10x6.5"]
	American_AISC_Miscellaneous_channels_MC10x8_4 = ["American","AISC","Miscellaneous channels","MC10x8.4"]
	American_AISC_Miscellaneous_channels_MC10x22 = ["American","AISC","Miscellaneous channels","MC10x22"]
	American_AISC_Miscellaneous_channels_MC10x25 = ["American","AISC","Miscellaneous channels","MC10x25"]
	American_AISC_Miscellaneous_channels_MC10x28_5 = ["American","AISC","Miscellaneous channels","MC10x28.5"]
	American_AISC_Miscellaneous_channels_MC10x33_6 = ["American","AISC","Miscellaneous channels","MC10x33.6"]
	American_AISC_Miscellaneous_channels_MC10x41_1 = ["American","AISC","Miscellaneous channels","MC10x41.1"]
	American_AISC_Miscellaneous_channels_MC12x10_6 = ["American","AISC","Miscellaneous channels","MC12x10.6"]
	American_AISC_Miscellaneous_channels_MC12x14_3 = ["American","AISC","Miscellaneous channels","MC12x14.3"]
	American_AISC_Miscellaneous_channels_MC12x31 = ["American","AISC","Miscellaneous channels","MC12x31"]
	American_AISC_Miscellaneous_channels_MC12x35 = ["American","AISC","Miscellaneous channels","MC12x35"]
	American_AISC_Miscellaneous_channels_MC12x40 = ["American","AISC","Miscellaneous channels","MC12x40"]
	American_AISC_Miscellaneous_channels_MC12x45 = ["American","AISC","Miscellaneous channels","MC12x45"]
	American_AISC_Miscellaneous_channels_MC12x50 = ["American","AISC","Miscellaneous channels","MC12x50"]
	American_AISC_Miscellaneous_channels_MC13x31_8 = ["American","AISC","Miscellaneous channels","MC13x31.8"]
	American_AISC_Miscellaneous_channels_MC13x35 = ["American","AISC","Miscellaneous channels","MC13x35"]
	American_AISC_Miscellaneous_channels_MC13x40 = ["American","AISC","Miscellaneous channels","MC13x40"]
	American_AISC_Miscellaneous_channels_MC13x50 = ["American","AISC","Miscellaneous channels","MC13x50"]
	American_AISC_Miscellaneous_channels_MC18x42_7 = ["American","AISC","Miscellaneous channels","MC18x42.7"]
	American_AISC_Miscellaneous_channels_MC18x45_8 = ["American","AISC","Miscellaneous channels","MC18x45.8"]
	American_AISC_Miscellaneous_channels_MC18x51_9 = ["American","AISC","Miscellaneous channels","MC18x51.9"]
	American_AISC_Miscellaneous_channels_MC18x58 = ["American","AISC","Miscellaneous channels","MC18x58"]
	American_AISC_MT_shapes_MT2_5x9_45 = ["American","AISC","MT shapes","MT2.5x9.45"]
	American_AISC_MT_shapes_MT2x3 = ["American","AISC","MT shapes","MT2x3"]
	American_AISC_MT_shapes_MT3x1_85 = ["American","AISC","MT shapes","MT3x1.85"]
	American_AISC_MT_shapes_MT3x2_2 = ["American","AISC","MT shapes","MT3x2.2"]
	American_AISC_MT_shapes_MT4x3_1 = ["American","AISC","MT shapes","MT4x3.1"]
	American_AISC_MT_shapes_MT4x3_25 = ["American","AISC","MT shapes","MT4x3.25"]
	American_AISC_MT_shapes_MT5x3_75 = ["American","AISC","MT shapes","MT5x3.75"]
	American_AISC_MT_shapes_MT5x4 = ["American","AISC","MT shapes","MT5x4"]
	American_AISC_MT_shapes_MT5x4_5 = ["American","AISC","MT shapes","MT5x4.5"]
	American_AISC_MT_shapes_MT6_25x5_8 = ["American","AISC","MT shapes","MT6.25x5.8"]
	American_AISC_MT_shapes_MT6_25x6_2 = ["American","AISC","MT shapes","MT6.25x6.2"]
	American_AISC_MT_shapes_MT6x5 = ["American","AISC","MT shapes","MT6x5"]
	American_AISC_MT_shapes_MT6x5_4 = ["American","AISC","MT shapes","MT6x5.4"]
	American_AISC_MT_shapes_MT6x5_9 = ["American","AISC","MT shapes","MT6x5.9"]
	American_AISC_Pipes_obsolete_P0_5x0_109 = ["American","AISC","Pipes (obsolete)","P0.5x0.109"]
	American_AISC_Pipes_obsolete_P0_5x0_147 = ["American","AISC","Pipes (obsolete)","P0.5x0.147"]
	American_AISC_Pipes_obsolete_P0_75x0_113 = ["American","AISC","Pipes (obsolete)","P0.75x0.113"]
	American_AISC_Pipes_obsolete_P0_75x0_154 = ["American","AISC","Pipes (obsolete)","P0.75x0.154"]
	American_AISC_Pipes_obsolete_P1_5x0_2 = ["American","AISC","Pipes (obsolete)","P1.5x0.2"]
	American_AISC_Pipes_obsolete_P1_5x0_145 = ["American","AISC","Pipes (obsolete)","P1.5x0.145"]
	American_AISC_Pipes_obsolete_P1_25x0_14 = ["American","AISC","Pipes (obsolete)","P1.25x0.14"]
	American_AISC_Pipes_obsolete_P1_25x0_191 = ["American","AISC","Pipes (obsolete)","P1.25x0.191"]
	American_AISC_Pipes_obsolete_P1x0_133 = ["American","AISC","Pipes (obsolete)","P1x0.133"]
	American_AISC_Pipes_obsolete_P1x0_179 = ["American","AISC","Pipes (obsolete)","P1x0.179"]
	American_AISC_Pipes_obsolete_P2_5x0_203 = ["American","AISC","Pipes (obsolete)","P2.5x0.203"]
	American_AISC_Pipes_obsolete_P2_5x0_276 = ["American","AISC","Pipes (obsolete)","P2.5x0.276"]
	American_AISC_Pipes_obsolete_P2_5x0_552 = ["American","AISC","Pipes (obsolete)","P2.5x0.552"]
	American_AISC_Pipes_obsolete_P2x0_154 = ["American","AISC","Pipes (obsolete)","P2x0.154"]
	American_AISC_Pipes_obsolete_P2x0_218 = ["American","AISC","Pipes (obsolete)","P2x0.218"]
	American_AISC_Pipes_obsolete_P2x0_436 = ["American","AISC","Pipes (obsolete)","P2x0.436"]
	American_AISC_Pipes_obsolete_P3_5x0_226 = ["American","AISC","Pipes (obsolete)","P3.5x0.226"]
	American_AISC_Pipes_obsolete_P3_5x0_318 = ["American","AISC","Pipes (obsolete)","P3.5x0.318"]
	American_AISC_Pipes_obsolete_P3x0_3 = ["American","AISC","Pipes (obsolete)","P3x0.3"]
	American_AISC_Pipes_obsolete_P3x0_6 = ["American","AISC","Pipes (obsolete)","P3x0.6"]
	American_AISC_Pipes_obsolete_P3x0_216 = ["American","AISC","Pipes (obsolete)","P3x0.216"]
	American_AISC_Pipes_obsolete_P4x0_237 = ["American","AISC","Pipes (obsolete)","P4x0.237"]
	American_AISC_Pipes_obsolete_P4x0_337 = ["American","AISC","Pipes (obsolete)","P4x0.337"]
	American_AISC_Pipes_obsolete_P4x0_674 = ["American","AISC","Pipes (obsolete)","P4x0.674"]
	American_AISC_Pipes_obsolete_P5x0_75 = ["American","AISC","Pipes (obsolete)","P5x0.75"]
	American_AISC_Pipes_obsolete_P5x0_258 = ["American","AISC","Pipes (obsolete)","P5x0.258"]
	American_AISC_Pipes_obsolete_P5x0_375 = ["American","AISC","Pipes (obsolete)","P5x0.375"]
	American_AISC_Pipes_obsolete_P6x0_28 = ["American","AISC","Pipes (obsolete)","P6x0.28"]
	American_AISC_Pipes_obsolete_P6x0_432 = ["American","AISC","Pipes (obsolete)","P6x0.432"]
	American_AISC_Pipes_obsolete_P6x0_864 = ["American","AISC","Pipes (obsolete)","P6x0.864"]
	American_AISC_Pipes_obsolete_P8x0_5 = ["American","AISC","Pipes (obsolete)","P8x0.5"]
	American_AISC_Pipes_obsolete_P8x0_322 = ["American","AISC","Pipes (obsolete)","P8x0.322"]
	American_AISC_Pipes_obsolete_P8x0_875 = ["American","AISC","Pipes (obsolete)","P8x0.875"]
	American_AISC_Pipes_obsolete_P10x0_5 = ["American","AISC","Pipes (obsolete)","P10x0.5"]
	American_AISC_Pipes_obsolete_P10x0_365 = ["American","AISC","Pipes (obsolete)","P10x0.365"]
	American_AISC_Pipes_obsolete_P12x0_5 = ["American","AISC","Pipes (obsolete)","P12x0.5"]
	American_AISC_Pipes_obsolete_P12x0_375 = ["American","AISC","Pipes (obsolete)","P12x0.375"]
	American_AISC_Rectangular_HSS_HSS2_12x1_12x14 = ["American","AISC","Rectangular HSS","HSS2-1/2x1-1/2x1/4"]
	American_AISC_Rectangular_HSS_HSS2_12x1_12x18 = ["American","AISC","Rectangular HSS","HSS2-1/2x1-1/2x1/8"]
	American_AISC_Rectangular_HSS_HSS2_12x1_12x316 = ["American","AISC","Rectangular HSS","HSS2-1/2x1-1/2x3/16"]
	American_AISC_Rectangular_HSS_HSS2_12x1x18 = ["American","AISC","Rectangular HSS","HSS2-1/2x1x1/8"]
	American_AISC_Rectangular_HSS_HSS2_12x1x316 = ["American","AISC","Rectangular HSS","HSS2-1/2x1x3/16"]
	American_AISC_Rectangular_HSS_HSS2_12x2x14 = ["American","AISC","Rectangular HSS","HSS2-1/2x2x1/4"]
	American_AISC_Rectangular_HSS_HSS2_12x2x18 = ["American","AISC","Rectangular HSS","HSS2-1/2x2x1/8"]
	American_AISC_Rectangular_HSS_HSS2_12x2x316 = ["American","AISC","Rectangular HSS","HSS2-1/2x2x3/16"]
	American_AISC_Rectangular_HSS_HSS2_14x2x18 = ["American","AISC","Rectangular HSS","HSS2-1/4x2x1/8"]
	American_AISC_Rectangular_HSS_HSS2_14x2x316 = ["American","AISC","Rectangular HSS","HSS2-1/4x2x3/16"]
	American_AISC_Rectangular_HSS_HSS2x1_12x18 = ["American","AISC","Rectangular HSS","HSS2x1-1/2x1/8"]
	American_AISC_Rectangular_HSS_HSS2x1_12x316 = ["American","AISC","Rectangular HSS","HSS2x1-1/2x3/16"]
	American_AISC_Rectangular_HSS_HSS2x1x18 = ["American","AISC","Rectangular HSS","HSS2x1x1/8"]
	American_AISC_Rectangular_HSS_HSS2x1x316 = ["American","AISC","Rectangular HSS","HSS2x1x3/16"]
	American_AISC_Rectangular_HSS_HSS3_12x1_12x14 = ["American","AISC","Rectangular HSS","HSS3-1/2x1-1/2x1/4"]
	American_AISC_Rectangular_HSS_HSS3_12x1_12x18 = ["American","AISC","Rectangular HSS","HSS3-1/2x1-1/2x1/8"]
	American_AISC_Rectangular_HSS_HSS3_12x1_12x316 = ["American","AISC","Rectangular HSS","HSS3-1/2x1-1/2x3/16"]
	American_AISC_Rectangular_HSS_HSS3_12x2_12x14 = ["American","AISC","Rectangular HSS","HSS3-1/2x2-1/2x1/4"]
	American_AISC_Rectangular_HSS_HSS3_12x2_12x18 = ["American","AISC","Rectangular HSS","HSS3-1/2x2-1/2x1/8"]
	American_AISC_Rectangular_HSS_HSS3_12x2_12x38 = ["American","AISC","Rectangular HSS","HSS3-1/2x2-1/2x3/8"]
	American_AISC_Rectangular_HSS_HSS3_12x2_12x316 = ["American","AISC","Rectangular HSS","HSS3-1/2x2-1/2x3/16"]
	American_AISC_Rectangular_HSS_HSS3_12x2_12x516 = ["American","AISC","Rectangular HSS","HSS3-1/2x2-1/2x5/16"]
	American_AISC_Rectangular_HSS_HSS3_12x2x14 = ["American","AISC","Rectangular HSS","HSS3-1/2x2x1/4"]
	American_AISC_Rectangular_HSS_HSS3_12x2x18 = ["American","AISC","Rectangular HSS","HSS3-1/2x2x1/8"]
	American_AISC_Rectangular_HSS_HSS3_12x2x316 = ["American","AISC","Rectangular HSS","HSS3-1/2x2x3/16"]
	American_AISC_Rectangular_HSS_HSS3x1_12x14 = ["American","AISC","Rectangular HSS","HSS3x1-1/2x1/4"]
	American_AISC_Rectangular_HSS_HSS3x1_12x18 = ["American","AISC","Rectangular HSS","HSS3x1-1/2x1/8"]
	American_AISC_Rectangular_HSS_HSS3x1_12x316 = ["American","AISC","Rectangular HSS","HSS3x1-1/2x3/16"]
	American_AISC_Rectangular_HSS_HSS3x1x18 = ["American","AISC","Rectangular HSS","HSS3x1x1/8"]
	American_AISC_Rectangular_HSS_HSS3x1x316 = ["American","AISC","Rectangular HSS","HSS3x1x3/16"]
	American_AISC_Rectangular_HSS_HSS3x2_12x14 = ["American","AISC","Rectangular HSS","HSS3x2-1/2x1/4"]
	American_AISC_Rectangular_HSS_HSS3x2_12x18 = ["American","AISC","Rectangular HSS","HSS3x2-1/2x1/8"]
	American_AISC_Rectangular_HSS_HSS3x2_12x316 = ["American","AISC","Rectangular HSS","HSS3x2-1/2x3/16"]
	American_AISC_Rectangular_HSS_HSS3x2_12x516 = ["American","AISC","Rectangular HSS","HSS3x2-1/2x5/16"]
	American_AISC_Rectangular_HSS_HSS3x2x14 = ["American","AISC","Rectangular HSS","HSS3x2x1/4"]
	American_AISC_Rectangular_HSS_HSS3x2x18 = ["American","AISC","Rectangular HSS","HSS3x2x1/8"]
	American_AISC_Rectangular_HSS_HSS3x2x316 = ["American","AISC","Rectangular HSS","HSS3x2x3/16"]
	American_AISC_Rectangular_HSS_HSS3x2x516 = ["American","AISC","Rectangular HSS","HSS3x2x5/16"]
	American_AISC_Rectangular_HSS_HSS4x2_12x14 = ["American","AISC","Rectangular HSS","HSS4x2-1/2x1/4"]
	American_AISC_Rectangular_HSS_HSS4x2_12x18 = ["American","AISC","Rectangular HSS","HSS4x2-1/2x1/8"]
	American_AISC_Rectangular_HSS_HSS4x2_12x38 = ["American","AISC","Rectangular HSS","HSS4x2-1/2x3/8"]
	American_AISC_Rectangular_HSS_HSS4x2_12x316 = ["American","AISC","Rectangular HSS","HSS4x2-1/2x3/16"]
	American_AISC_Rectangular_HSS_HSS4x2_12x516 = ["American","AISC","Rectangular HSS","HSS4x2-1/2x5/16"]
	American_AISC_Rectangular_HSS_HSS4x2x14 = ["American","AISC","Rectangular HSS","HSS4x2x1/4"]
	American_AISC_Rectangular_HSS_HSS4x2x18 = ["American","AISC","Rectangular HSS","HSS4x2x1/8"]
	American_AISC_Rectangular_HSS_HSS4x2x38 = ["American","AISC","Rectangular HSS","HSS4x2x3/8"]
	American_AISC_Rectangular_HSS_HSS4x2x316 = ["American","AISC","Rectangular HSS","HSS4x2x3/16"]
	American_AISC_Rectangular_HSS_HSS4x2x516 = ["American","AISC","Rectangular HSS","HSS4x2x5/16"]
	American_AISC_Rectangular_HSS_HSS4x3x14 = ["American","AISC","Rectangular HSS","HSS4x3x1/4"]
	American_AISC_Rectangular_HSS_HSS4x3x18 = ["American","AISC","Rectangular HSS","HSS4x3x1/8"]
	American_AISC_Rectangular_HSS_HSS4x3x38 = ["American","AISC","Rectangular HSS","HSS4x3x3/8"]
	American_AISC_Rectangular_HSS_HSS4x3x316 = ["American","AISC","Rectangular HSS","HSS4x3x3/16"]
	American_AISC_Rectangular_HSS_HSS4x3x516 = ["American","AISC","Rectangular HSS","HSS4x3x5/16"]
	American_AISC_Rectangular_HSS_HSS5x2_12x14 = ["American","AISC","Rectangular HSS","HSS5x2-1/2x1/4"]
	American_AISC_Rectangular_HSS_HSS5x2_12x18 = ["American","AISC","Rectangular HSS","HSS5x2-1/2x1/8"]
	American_AISC_Rectangular_HSS_HSS5x2_12x316 = ["American","AISC","Rectangular HSS","HSS5x2-1/2x3/16"]
	American_AISC_Rectangular_HSS_HSS5x2x14 = ["American","AISC","Rectangular HSS","HSS5x2x1/4"]
	American_AISC_Rectangular_HSS_HSS5x2x18 = ["American","AISC","Rectangular HSS","HSS5x2x1/8"]
	American_AISC_Rectangular_HSS_HSS5x2x38 = ["American","AISC","Rectangular HSS","HSS5x2x3/8"]
	American_AISC_Rectangular_HSS_HSS5x2x316 = ["American","AISC","Rectangular HSS","HSS5x2x3/16"]
	American_AISC_Rectangular_HSS_HSS5x2x516 = ["American","AISC","Rectangular HSS","HSS5x2x5/16"]
	American_AISC_Rectangular_HSS_HSS5x3x12 = ["American","AISC","Rectangular HSS","HSS5x3x1/2"]
	American_AISC_Rectangular_HSS_HSS5x3x14 = ["American","AISC","Rectangular HSS","HSS5x3x1/4"]
	American_AISC_Rectangular_HSS_HSS5x3x18 = ["American","AISC","Rectangular HSS","HSS5x3x1/8"]
	American_AISC_Rectangular_HSS_HSS5x3x38 = ["American","AISC","Rectangular HSS","HSS5x3x3/8"]
	American_AISC_Rectangular_HSS_HSS5x3x316 = ["American","AISC","Rectangular HSS","HSS5x3x3/16"]
	American_AISC_Rectangular_HSS_HSS5x3x516 = ["American","AISC","Rectangular HSS","HSS5x3x5/16"]
	American_AISC_Rectangular_HSS_HSS5x4x12 = ["American","AISC","Rectangular HSS","HSS5x4x1/2"]
	American_AISC_Rectangular_HSS_HSS5x4x14 = ["American","AISC","Rectangular HSS","HSS5x4x1/4"]
	American_AISC_Rectangular_HSS_HSS5x4x18 = ["American","AISC","Rectangular HSS","HSS5x4x1/8"]
	American_AISC_Rectangular_HSS_HSS5x4x38 = ["American","AISC","Rectangular HSS","HSS5x4x3/8"]
	American_AISC_Rectangular_HSS_HSS5x4x316 = ["American","AISC","Rectangular HSS","HSS5x4x3/16"]
	American_AISC_Rectangular_HSS_HSS5x4x516 = ["American","AISC","Rectangular HSS","HSS5x4x5/16"]
	American_AISC_Rectangular_HSS_HSS6x2x14 = ["American","AISC","Rectangular HSS","HSS6x2x1/4"]
	American_AISC_Rectangular_HSS_HSS6x2x18 = ["American","AISC","Rectangular HSS","HSS6x2x1/8"]
	American_AISC_Rectangular_HSS_HSS6x2x38 = ["American","AISC","Rectangular HSS","HSS6x2x3/8"]
	American_AISC_Rectangular_HSS_HSS6x2x316 = ["American","AISC","Rectangular HSS","HSS6x2x3/16"]
	American_AISC_Rectangular_HSS_HSS6x2x516 = ["American","AISC","Rectangular HSS","HSS6x2x5/16"]
	American_AISC_Rectangular_HSS_HSS6x3x12 = ["American","AISC","Rectangular HSS","HSS6x3x1/2"]
	American_AISC_Rectangular_HSS_HSS6x3x14 = ["American","AISC","Rectangular HSS","HSS6x3x1/4"]
	American_AISC_Rectangular_HSS_HSS6x3x18 = ["American","AISC","Rectangular HSS","HSS6x3x1/8"]
	American_AISC_Rectangular_HSS_HSS6x3x38 = ["American","AISC","Rectangular HSS","HSS6x3x3/8"]
	American_AISC_Rectangular_HSS_HSS6x3x316 = ["American","AISC","Rectangular HSS","HSS6x3x3/16"]
	American_AISC_Rectangular_HSS_HSS6x3x516 = ["American","AISC","Rectangular HSS","HSS6x3x5/16"]
	American_AISC_Rectangular_HSS_HSS6x4x12 = ["American","AISC","Rectangular HSS","HSS6x4x1/2"]
	American_AISC_Rectangular_HSS_HSS6x4x14 = ["American","AISC","Rectangular HSS","HSS6x4x1/4"]
	American_AISC_Rectangular_HSS_HSS6x4x18 = ["American","AISC","Rectangular HSS","HSS6x4x1/8"]
	American_AISC_Rectangular_HSS_HSS6x4x38 = ["American","AISC","Rectangular HSS","HSS6x4x3/8"]
	American_AISC_Rectangular_HSS_HSS6x4x316 = ["American","AISC","Rectangular HSS","HSS6x4x3/16"]
	American_AISC_Rectangular_HSS_HSS6x4x516 = ["American","AISC","Rectangular HSS","HSS6x4x5/16"]
	American_AISC_Rectangular_HSS_HSS6x5x12 = ["American","AISC","Rectangular HSS","HSS6x5x1/2"]
	American_AISC_Rectangular_HSS_HSS6x5x14 = ["American","AISC","Rectangular HSS","HSS6x5x1/4"]
	American_AISC_Rectangular_HSS_HSS6x5x18 = ["American","AISC","Rectangular HSS","HSS6x5x1/8"]
	American_AISC_Rectangular_HSS_HSS6x5x38 = ["American","AISC","Rectangular HSS","HSS6x5x3/8"]
	American_AISC_Rectangular_HSS_HSS6x5x316 = ["American","AISC","Rectangular HSS","HSS6x5x3/16"]
	American_AISC_Rectangular_HSS_HSS6x5x516 = ["American","AISC","Rectangular HSS","HSS6x5x5/16"]
	American_AISC_Rectangular_HSS_HSS7x2x14 = ["American","AISC","Rectangular HSS","HSS7x2x1/4"]
	American_AISC_Rectangular_HSS_HSS7x2x18 = ["American","AISC","Rectangular HSS","HSS7x2x1/8"]
	American_AISC_Rectangular_HSS_HSS7x2x316 = ["American","AISC","Rectangular HSS","HSS7x2x3/16"]
	American_AISC_Rectangular_HSS_HSS7x3x12 = ["American","AISC","Rectangular HSS","HSS7x3x1/2"]
	American_AISC_Rectangular_HSS_HSS7x3x14 = ["American","AISC","Rectangular HSS","HSS7x3x1/4"]
	American_AISC_Rectangular_HSS_HSS7x3x18 = ["American","AISC","Rectangular HSS","HSS7x3x1/8"]
	American_AISC_Rectangular_HSS_HSS7x3x38 = ["American","AISC","Rectangular HSS","HSS7x3x3/8"]
	American_AISC_Rectangular_HSS_HSS7x3x316 = ["American","AISC","Rectangular HSS","HSS7x3x3/16"]
	American_AISC_Rectangular_HSS_HSS7x3x516 = ["American","AISC","Rectangular HSS","HSS7x3x5/16"]
	American_AISC_Rectangular_HSS_HSS7x4x12 = ["American","AISC","Rectangular HSS","HSS7x4x1/2"]
	American_AISC_Rectangular_HSS_HSS7x4x14 = ["American","AISC","Rectangular HSS","HSS7x4x1/4"]
	American_AISC_Rectangular_HSS_HSS7x4x18 = ["American","AISC","Rectangular HSS","HSS7x4x1/8"]
	American_AISC_Rectangular_HSS_HSS7x4x38 = ["American","AISC","Rectangular HSS","HSS7x4x3/8"]
	American_AISC_Rectangular_HSS_HSS7x4x316 = ["American","AISC","Rectangular HSS","HSS7x4x3/16"]
	American_AISC_Rectangular_HSS_HSS7x4x516 = ["American","AISC","Rectangular HSS","HSS7x4x5/16"]
	American_AISC_Rectangular_HSS_HSS7x5x12 = ["American","AISC","Rectangular HSS","HSS7x5x1/2"]
	American_AISC_Rectangular_HSS_HSS7x5x14 = ["American","AISC","Rectangular HSS","HSS7x5x1/4"]
	American_AISC_Rectangular_HSS_HSS7x5x18 = ["American","AISC","Rectangular HSS","HSS7x5x1/8"]
	American_AISC_Rectangular_HSS_HSS7x5x38 = ["American","AISC","Rectangular HSS","HSS7x5x3/8"]
	American_AISC_Rectangular_HSS_HSS7x5x316 = ["American","AISC","Rectangular HSS","HSS7x5x3/16"]
	American_AISC_Rectangular_HSS_HSS7x5x516 = ["American","AISC","Rectangular HSS","HSS7x5x5/16"]
	American_AISC_Rectangular_HSS_HSS8x2x14 = ["American","AISC","Rectangular HSS","HSS8x2x1/4"]
	American_AISC_Rectangular_HSS_HSS8x2x18 = ["American","AISC","Rectangular HSS","HSS8x2x1/8"]
	American_AISC_Rectangular_HSS_HSS8x2x38 = ["American","AISC","Rectangular HSS","HSS8x2x3/8"]
	American_AISC_Rectangular_HSS_HSS8x2x316 = ["American","AISC","Rectangular HSS","HSS8x2x3/16"]
	American_AISC_Rectangular_HSS_HSS8x2x516 = ["American","AISC","Rectangular HSS","HSS8x2x5/16"]
	American_AISC_Rectangular_HSS_HSS8x3x12 = ["American","AISC","Rectangular HSS","HSS8x3x1/2"]
	American_AISC_Rectangular_HSS_HSS8x3x14 = ["American","AISC","Rectangular HSS","HSS8x3x1/4"]
	American_AISC_Rectangular_HSS_HSS8x3x18 = ["American","AISC","Rectangular HSS","HSS8x3x1/8"]
	American_AISC_Rectangular_HSS_HSS8x3x38 = ["American","AISC","Rectangular HSS","HSS8x3x3/8"]
	American_AISC_Rectangular_HSS_HSS8x3x316 = ["American","AISC","Rectangular HSS","HSS8x3x3/16"]
	American_AISC_Rectangular_HSS_HSS8x3x516 = ["American","AISC","Rectangular HSS","HSS8x3x5/16"]
	American_AISC_Rectangular_HSS_HSS8x4x12 = ["American","AISC","Rectangular HSS","HSS8x4x1/2"]
	American_AISC_Rectangular_HSS_HSS8x4x14 = ["American","AISC","Rectangular HSS","HSS8x4x1/4"]
	American_AISC_Rectangular_HSS_HSS8x4x18 = ["American","AISC","Rectangular HSS","HSS8x4x1/8"]
	American_AISC_Rectangular_HSS_HSS8x4x38 = ["American","AISC","Rectangular HSS","HSS8x4x3/8"]
	American_AISC_Rectangular_HSS_HSS8x4x316 = ["American","AISC","Rectangular HSS","HSS8x4x3/16"]
	American_AISC_Rectangular_HSS_HSS8x4x58 = ["American","AISC","Rectangular HSS","HSS8x4x5/8"]
	American_AISC_Rectangular_HSS_HSS8x4x516 = ["American","AISC","Rectangular HSS","HSS8x4x5/16"]
	American_AISC_Rectangular_HSS_HSS8x6x12 = ["American","AISC","Rectangular HSS","HSS8x6x1/2"]
	American_AISC_Rectangular_HSS_HSS8x6x14 = ["American","AISC","Rectangular HSS","HSS8x6x1/4"]
	American_AISC_Rectangular_HSS_HSS8x6x38 = ["American","AISC","Rectangular HSS","HSS8x6x3/8"]
	American_AISC_Rectangular_HSS_HSS8x6x316 = ["American","AISC","Rectangular HSS","HSS8x6x3/16"]
	American_AISC_Rectangular_HSS_HSS8x6x58 = ["American","AISC","Rectangular HSS","HSS8x6x5/8"]
	American_AISC_Rectangular_HSS_HSS8x6x516 = ["American","AISC","Rectangular HSS","HSS8x6x5/16"]
	American_AISC_Rectangular_HSS_HSS9x3x12 = ["American","AISC","Rectangular HSS","HSS9x3x1/2"]
	American_AISC_Rectangular_HSS_HSS9x3x14 = ["American","AISC","Rectangular HSS","HSS9x3x1/4"]
	American_AISC_Rectangular_HSS_HSS9x3x38 = ["American","AISC","Rectangular HSS","HSS9x3x3/8"]
	American_AISC_Rectangular_HSS_HSS9x3x316 = ["American","AISC","Rectangular HSS","HSS9x3x3/16"]
	American_AISC_Rectangular_HSS_HSS9x3x516 = ["American","AISC","Rectangular HSS","HSS9x3x5/16"]
	American_AISC_Rectangular_HSS_HSS9x5x12 = ["American","AISC","Rectangular HSS","HSS9x5x1/2"]
	American_AISC_Rectangular_HSS_HSS9x5x14 = ["American","AISC","Rectangular HSS","HSS9x5x1/4"]
	American_AISC_Rectangular_HSS_HSS9x5x38 = ["American","AISC","Rectangular HSS","HSS9x5x3/8"]
	American_AISC_Rectangular_HSS_HSS9x5x316 = ["American","AISC","Rectangular HSS","HSS9x5x3/16"]
	American_AISC_Rectangular_HSS_HSS9x5x58 = ["American","AISC","Rectangular HSS","HSS9x5x5/8"]
	American_AISC_Rectangular_HSS_HSS9x5x516 = ["American","AISC","Rectangular HSS","HSS9x5x5/16"]
	American_AISC_Rectangular_HSS_HSS9x7x12 = ["American","AISC","Rectangular HSS","HSS9x7x1/2"]
	American_AISC_Rectangular_HSS_HSS9x7x14 = ["American","AISC","Rectangular HSS","HSS9x7x1/4"]
	American_AISC_Rectangular_HSS_HSS9x7x38 = ["American","AISC","Rectangular HSS","HSS9x7x3/8"]
	American_AISC_Rectangular_HSS_HSS9x7x316 = ["American","AISC","Rectangular HSS","HSS9x7x3/16"]
	American_AISC_Rectangular_HSS_HSS9x7x58 = ["American","AISC","Rectangular HSS","HSS9x7x5/8"]
	American_AISC_Rectangular_HSS_HSS9x7x516 = ["American","AISC","Rectangular HSS","HSS9x7x5/16"]
	American_AISC_Rectangular_HSS_HSS10x2x14 = ["American","AISC","Rectangular HSS","HSS10x2x1/4"]
	American_AISC_Rectangular_HSS_HSS10x2x18 = ["American","AISC","Rectangular HSS","HSS10x2x1/8"]
	American_AISC_Rectangular_HSS_HSS10x2x38 = ["American","AISC","Rectangular HSS","HSS10x2x3/8"]
	American_AISC_Rectangular_HSS_HSS10x2x316 = ["American","AISC","Rectangular HSS","HSS10x2x3/16"]
	American_AISC_Rectangular_HSS_HSS10x2x516 = ["American","AISC","Rectangular HSS","HSS10x2x5/16"]
	American_AISC_Rectangular_HSS_HSS10x3_12x12 = ["American","AISC","Rectangular HSS","HSS10x3-1/2x1/2"]
	American_AISC_Rectangular_HSS_HSS10x3_12x14 = ["American","AISC","Rectangular HSS","HSS10x3-1/2x1/4"]
	American_AISC_Rectangular_HSS_HSS10x3_12x18 = ["American","AISC","Rectangular HSS","HSS10x3-1/2x1/8"]
	American_AISC_Rectangular_HSS_HSS10x3_12x38 = ["American","AISC","Rectangular HSS","HSS10x3-1/2x3/8"]
	American_AISC_Rectangular_HSS_HSS10x3_12x316 = ["American","AISC","Rectangular HSS","HSS10x3-1/2x3/16"]
	American_AISC_Rectangular_HSS_HSS10x3_12x516 = ["American","AISC","Rectangular HSS","HSS10x3-1/2x5/16"]
	American_AISC_Rectangular_HSS_HSS10x3x14 = ["American","AISC","Rectangular HSS","HSS10x3x1/4"]
	American_AISC_Rectangular_HSS_HSS10x3x18 = ["American","AISC","Rectangular HSS","HSS10x3x1/8"]
	American_AISC_Rectangular_HSS_HSS10x3x38 = ["American","AISC","Rectangular HSS","HSS10x3x3/8"]
	American_AISC_Rectangular_HSS_HSS10x3x316 = ["American","AISC","Rectangular HSS","HSS10x3x3/16"]
	American_AISC_Rectangular_HSS_HSS10x3x516 = ["American","AISC","Rectangular HSS","HSS10x3x5/16"]
	American_AISC_Rectangular_HSS_HSS10x4x12 = ["American","AISC","Rectangular HSS","HSS10x4x1/2"]
	American_AISC_Rectangular_HSS_HSS10x4x14 = ["American","AISC","Rectangular HSS","HSS10x4x1/4"]
	American_AISC_Rectangular_HSS_HSS10x4x18 = ["American","AISC","Rectangular HSS","HSS10x4x1/8"]
	American_AISC_Rectangular_HSS_HSS10x4x38 = ["American","AISC","Rectangular HSS","HSS10x4x3/8"]
	American_AISC_Rectangular_HSS_HSS10x4x316 = ["American","AISC","Rectangular HSS","HSS10x4x3/16"]
	American_AISC_Rectangular_HSS_HSS10x4x58 = ["American","AISC","Rectangular HSS","HSS10x4x5/8"]
	American_AISC_Rectangular_HSS_HSS10x4x516 = ["American","AISC","Rectangular HSS","HSS10x4x5/16"]
	American_AISC_Rectangular_HSS_HSS10x5x14 = ["American","AISC","Rectangular HSS","HSS10x5x1/4"]
	American_AISC_Rectangular_HSS_HSS10x5x38 = ["American","AISC","Rectangular HSS","HSS10x5x3/8"]
	American_AISC_Rectangular_HSS_HSS10x5x316 = ["American","AISC","Rectangular HSS","HSS10x5x3/16"]
	American_AISC_Rectangular_HSS_HSS10x5x516 = ["American","AISC","Rectangular HSS","HSS10x5x5/16"]
	American_AISC_Rectangular_HSS_HSS10x6x12 = ["American","AISC","Rectangular HSS","HSS10x6x1/2"]
	American_AISC_Rectangular_HSS_HSS10x6x14 = ["American","AISC","Rectangular HSS","HSS10x6x1/4"]
	American_AISC_Rectangular_HSS_HSS10x6x38 = ["American","AISC","Rectangular HSS","HSS10x6x3/8"]
	American_AISC_Rectangular_HSS_HSS10x6x316 = ["American","AISC","Rectangular HSS","HSS10x6x3/16"]
	American_AISC_Rectangular_HSS_HSS10x6x58 = ["American","AISC","Rectangular HSS","HSS10x6x5/8"]
	American_AISC_Rectangular_HSS_HSS10x6x516 = ["American","AISC","Rectangular HSS","HSS10x6x5/16"]
	American_AISC_Rectangular_HSS_HSS10x8x12 = ["American","AISC","Rectangular HSS","HSS10x8x1/2"]
	American_AISC_Rectangular_HSS_HSS10x8x14 = ["American","AISC","Rectangular HSS","HSS10x8x1/4"]
	American_AISC_Rectangular_HSS_HSS10x8x38 = ["American","AISC","Rectangular HSS","HSS10x8x3/8"]
	American_AISC_Rectangular_HSS_HSS10x8x316 = ["American","AISC","Rectangular HSS","HSS10x8x3/16"]
	American_AISC_Rectangular_HSS_HSS10x8x58 = ["American","AISC","Rectangular HSS","HSS10x8x5/8"]
	American_AISC_Rectangular_HSS_HSS10x8x516 = ["American","AISC","Rectangular HSS","HSS10x8x5/16"]
	American_AISC_Rectangular_HSS_HSS12x2x14 = ["American","AISC","Rectangular HSS","HSS12x2x1/4"]
	American_AISC_Rectangular_HSS_HSS12x2x316 = ["American","AISC","Rectangular HSS","HSS12x2x3/16"]
	American_AISC_Rectangular_HSS_HSS12x2x516 = ["American","AISC","Rectangular HSS","HSS12x2x5/16"]
	American_AISC_Rectangular_HSS_HSS12x3_12x38 = ["American","AISC","Rectangular HSS","HSS12x3-1/2x3/8"]
	American_AISC_Rectangular_HSS_HSS12x3_12x516 = ["American","AISC","Rectangular HSS","HSS12x3-1/2x5/16"]
	American_AISC_Rectangular_HSS_HSS12x3x14 = ["American","AISC","Rectangular HSS","HSS12x3x1/4"]
	American_AISC_Rectangular_HSS_HSS12x3x316 = ["American","AISC","Rectangular HSS","HSS12x3x3/16"]
	American_AISC_Rectangular_HSS_HSS12x3x516 = ["American","AISC","Rectangular HSS","HSS12x3x5/16"]
	American_AISC_Rectangular_HSS_HSS12x4x12 = ["American","AISC","Rectangular HSS","HSS12x4x1/2"]
	American_AISC_Rectangular_HSS_HSS12x4x14 = ["American","AISC","Rectangular HSS","HSS12x4x1/4"]
	American_AISC_Rectangular_HSS_HSS12x4x38 = ["American","AISC","Rectangular HSS","HSS12x4x3/8"]
	American_AISC_Rectangular_HSS_HSS12x4x316 = ["American","AISC","Rectangular HSS","HSS12x4x3/16"]
	American_AISC_Rectangular_HSS_HSS12x4x58 = ["American","AISC","Rectangular HSS","HSS12x4x5/8"]
	American_AISC_Rectangular_HSS_HSS12x4x516 = ["American","AISC","Rectangular HSS","HSS12x4x5/16"]
	American_AISC_Rectangular_HSS_HSS12x6x12 = ["American","AISC","Rectangular HSS","HSS12x6x1/2"]
	American_AISC_Rectangular_HSS_HSS12x6x14 = ["American","AISC","Rectangular HSS","HSS12x6x1/4"]
	American_AISC_Rectangular_HSS_HSS12x6x38 = ["American","AISC","Rectangular HSS","HSS12x6x3/8"]
	American_AISC_Rectangular_HSS_HSS12x6x316 = ["American","AISC","Rectangular HSS","HSS12x6x3/16"]
	American_AISC_Rectangular_HSS_HSS12x6x58 = ["American","AISC","Rectangular HSS","HSS12x6x5/8"]
	American_AISC_Rectangular_HSS_HSS12x6x516 = ["American","AISC","Rectangular HSS","HSS12x6x5/16"]
	American_AISC_Rectangular_HSS_HSS12x8x12 = ["American","AISC","Rectangular HSS","HSS12x8x1/2"]
	American_AISC_Rectangular_HSS_HSS12x8x14 = ["American","AISC","Rectangular HSS","HSS12x8x1/4"]
	American_AISC_Rectangular_HSS_HSS12x8x38 = ["American","AISC","Rectangular HSS","HSS12x8x3/8"]
	American_AISC_Rectangular_HSS_HSS12x8x316 = ["American","AISC","Rectangular HSS","HSS12x8x3/16"]
	American_AISC_Rectangular_HSS_HSS12x8x58 = ["American","AISC","Rectangular HSS","HSS12x8x5/8"]
	American_AISC_Rectangular_HSS_HSS12x8x516 = ["American","AISC","Rectangular HSS","HSS12x8x5/16"]
	American_AISC_Rectangular_HSS_HSS12x10x12 = ["American","AISC","Rectangular HSS","HSS12x10x1/2"]
	American_AISC_Rectangular_HSS_HSS12x10x14 = ["American","AISC","Rectangular HSS","HSS12x10x1/4"]
	American_AISC_Rectangular_HSS_HSS12x10x38 = ["American","AISC","Rectangular HSS","HSS12x10x3/8"]
	American_AISC_Rectangular_HSS_HSS12x10x516 = ["American","AISC","Rectangular HSS","HSS12x10x5/16"]
	American_AISC_Rectangular_HSS_HSS14x4x12 = ["American","AISC","Rectangular HSS","HSS14x4x1/2"]
	American_AISC_Rectangular_HSS_HSS14x4x14 = ["American","AISC","Rectangular HSS","HSS14x4x1/4"]
	American_AISC_Rectangular_HSS_HSS14x4x38 = ["American","AISC","Rectangular HSS","HSS14x4x3/8"]
	American_AISC_Rectangular_HSS_HSS14x4x316 = ["American","AISC","Rectangular HSS","HSS14x4x3/16"]
	American_AISC_Rectangular_HSS_HSS14x4x58 = ["American","AISC","Rectangular HSS","HSS14x4x5/8"]
	American_AISC_Rectangular_HSS_HSS14x4x516 = ["American","AISC","Rectangular HSS","HSS14x4x5/16"]
	American_AISC_Rectangular_HSS_HSS14x6x12 = ["American","AISC","Rectangular HSS","HSS14x6x1/2"]
	American_AISC_Rectangular_HSS_HSS14x6x14 = ["American","AISC","Rectangular HSS","HSS14x6x1/4"]
	American_AISC_Rectangular_HSS_HSS14x6x38 = ["American","AISC","Rectangular HSS","HSS14x6x3/8"]
	American_AISC_Rectangular_HSS_HSS14x6x316 = ["American","AISC","Rectangular HSS","HSS14x6x3/16"]
	American_AISC_Rectangular_HSS_HSS14x6x58 = ["American","AISC","Rectangular HSS","HSS14x6x5/8"]
	American_AISC_Rectangular_HSS_HSS14x6x516 = ["American","AISC","Rectangular HSS","HSS14x6x5/16"]
	American_AISC_Rectangular_HSS_HSS14x10x12 = ["American","AISC","Rectangular HSS","HSS14x10x1/2"]
	American_AISC_Rectangular_HSS_HSS14x10x14 = ["American","AISC","Rectangular HSS","HSS14x10x1/4"]
	American_AISC_Rectangular_HSS_HSS14x10x38 = ["American","AISC","Rectangular HSS","HSS14x10x3/8"]
	American_AISC_Rectangular_HSS_HSS14x10x58 = ["American","AISC","Rectangular HSS","HSS14x10x5/8"]
	American_AISC_Rectangular_HSS_HSS14x10x516 = ["American","AISC","Rectangular HSS","HSS14x10x5/16"]
	American_AISC_Rectangular_HSS_HSS16x4x12 = ["American","AISC","Rectangular HSS","HSS16x4x1/2"]
	American_AISC_Rectangular_HSS_HSS16x4x14 = ["American","AISC","Rectangular HSS","HSS16x4x1/4"]
	American_AISC_Rectangular_HSS_HSS16x4x38 = ["American","AISC","Rectangular HSS","HSS16x4x3/8"]
	American_AISC_Rectangular_HSS_HSS16x4x316 = ["American","AISC","Rectangular HSS","HSS16x4x3/16"]
	American_AISC_Rectangular_HSS_HSS16x4x58 = ["American","AISC","Rectangular HSS","HSS16x4x5/8"]
	American_AISC_Rectangular_HSS_HSS16x4x516 = ["American","AISC","Rectangular HSS","HSS16x4x5/16"]
	American_AISC_Rectangular_HSS_HSS16x8x12 = ["American","AISC","Rectangular HSS","HSS16x8x1/2"]
	American_AISC_Rectangular_HSS_HSS16x8x14 = ["American","AISC","Rectangular HSS","HSS16x8x1/4"]
	American_AISC_Rectangular_HSS_HSS16x8x38 = ["American","AISC","Rectangular HSS","HSS16x8x3/8"]
	American_AISC_Rectangular_HSS_HSS16x8x58 = ["American","AISC","Rectangular HSS","HSS16x8x5/8"]
	American_AISC_Rectangular_HSS_HSS16x8x516 = ["American","AISC","Rectangular HSS","HSS16x8x5/16"]
	American_AISC_Rectangular_HSS_HSS16x12x12 = ["American","AISC","Rectangular HSS","HSS16x12x1/2"]
	American_AISC_Rectangular_HSS_HSS16x12x38 = ["American","AISC","Rectangular HSS","HSS16x12x3/8"]
	American_AISC_Rectangular_HSS_HSS16x12x58 = ["American","AISC","Rectangular HSS","HSS16x12x5/8"]
	American_AISC_Rectangular_HSS_HSS16x12x516 = ["American","AISC","Rectangular HSS","HSS16x12x5/16"]
	American_AISC_Rectangular_HSS_HSS18x6x12 = ["American","AISC","Rectangular HSS","HSS18x6x1/2"]
	American_AISC_Rectangular_HSS_HSS18x6x14 = ["American","AISC","Rectangular HSS","HSS18x6x1/4"]
	American_AISC_Rectangular_HSS_HSS18x6x38 = ["American","AISC","Rectangular HSS","HSS18x6x3/8"]
	American_AISC_Rectangular_HSS_HSS18x6x58 = ["American","AISC","Rectangular HSS","HSS18x6x5/8"]
	American_AISC_Rectangular_HSS_HSS18x6x516 = ["American","AISC","Rectangular HSS","HSS18x6x5/16"]
	American_AISC_Rectangular_HSS_HSS20x4x12 = ["American","AISC","Rectangular HSS","HSS20x4x1/2"]
	American_AISC_Rectangular_HSS_HSS20x4x14 = ["American","AISC","Rectangular HSS","HSS20x4x1/4"]
	American_AISC_Rectangular_HSS_HSS20x4x38 = ["American","AISC","Rectangular HSS","HSS20x4x3/8"]
	American_AISC_Rectangular_HSS_HSS20x4x516 = ["American","AISC","Rectangular HSS","HSS20x4x5/16"]
	American_AISC_Rectangular_HSS_HSS20x8x12 = ["American","AISC","Rectangular HSS","HSS20x8x1/2"]
	American_AISC_Rectangular_HSS_HSS20x8x38 = ["American","AISC","Rectangular HSS","HSS20x8x3/8"]
	American_AISC_Rectangular_HSS_HSS20x8x58 = ["American","AISC","Rectangular HSS","HSS20x8x5/8"]
	American_AISC_Rectangular_HSS_HSS20x8x516 = ["American","AISC","Rectangular HSS","HSS20x8x5/16"]
	American_AISC_Rectangular_HSS_HSS20x12x12 = ["American","AISC","Rectangular HSS","HSS20x12x1/2"]
	American_AISC_Rectangular_HSS_HSS20x12x38 = ["American","AISC","Rectangular HSS","HSS20x12x3/8"]
	American_AISC_Rectangular_HSS_HSS20x12x58 = ["American","AISC","Rectangular HSS","HSS20x12x5/8"]
	American_AISC_Rectangular_HSS_HSS20x12x516 = ["American","AISC","Rectangular HSS","HSS20x12x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS2_5x1_5x14 = ["American","AISC","Rectangular tubes (obsolete)","TS2.5x1.5x1/4"]
	American_AISC_Rectangular_tubes_obsolete_TS2_5x1_5x316 = ["American","AISC","Rectangular tubes (obsolete)","TS2.5x1.5x3/16"]
	American_AISC_Rectangular_tubes_obsolete_TS3x2x14 = ["American","AISC","Rectangular tubes (obsolete)","TS3x2x1/4"]
	American_AISC_Rectangular_tubes_obsolete_TS3x2x18 = ["American","AISC","Rectangular tubes (obsolete)","TS3x2x1/8"]
	American_AISC_Rectangular_tubes_obsolete_TS3x2x316 = ["American","AISC","Rectangular tubes (obsolete)","TS3x2x3/16"]
	American_AISC_Rectangular_tubes_obsolete_TS3x2x516 = ["American","AISC","Rectangular tubes (obsolete)","TS3x2x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS4x2x14 = ["American","AISC","Rectangular tubes (obsolete)","TS4x2x1/4"]
	American_AISC_Rectangular_tubes_obsolete_TS4x2x18 = ["American","AISC","Rectangular tubes (obsolete)","TS4x2x1/8"]
	American_AISC_Rectangular_tubes_obsolete_TS4x2x38 = ["American","AISC","Rectangular tubes (obsolete)","TS4x2x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS4x2x316 = ["American","AISC","Rectangular tubes (obsolete)","TS4x2x3/16"]
	American_AISC_Rectangular_tubes_obsolete_TS4x2x516 = ["American","AISC","Rectangular tubes (obsolete)","TS4x2x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS4x3x14 = ["American","AISC","Rectangular tubes (obsolete)","TS4x3x1/4"]
	American_AISC_Rectangular_tubes_obsolete_TS4x3x18 = ["American","AISC","Rectangular tubes (obsolete)","TS4x3x1/8"]
	American_AISC_Rectangular_tubes_obsolete_TS4x3x316 = ["American","AISC","Rectangular tubes (obsolete)","TS4x3x3/16"]
	American_AISC_Rectangular_tubes_obsolete_TS4x3x516 = ["American","AISC","Rectangular tubes (obsolete)","TS4x3x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS5x2x14 = ["American","AISC","Rectangular tubes (obsolete)","TS5x2x1/4"]
	American_AISC_Rectangular_tubes_obsolete_TS5x2x18 = ["American","AISC","Rectangular tubes (obsolete)","TS5x2x1/8"]
	American_AISC_Rectangular_tubes_obsolete_TS5x2x316 = ["American","AISC","Rectangular tubes (obsolete)","TS5x2x3/16"]
	American_AISC_Rectangular_tubes_obsolete_TS5x2x516 = ["American","AISC","Rectangular tubes (obsolete)","TS5x2x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS5x3x12 = ["American","AISC","Rectangular tubes (obsolete)","TS5x3x1/2"]
	American_AISC_Rectangular_tubes_obsolete_TS5x3x14 = ["American","AISC","Rectangular tubes (obsolete)","TS5x3x1/4"]
	American_AISC_Rectangular_tubes_obsolete_TS5x3x18 = ["American","AISC","Rectangular tubes (obsolete)","TS5x3x1/8"]
	American_AISC_Rectangular_tubes_obsolete_TS5x3x38 = ["American","AISC","Rectangular tubes (obsolete)","TS5x3x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS5x3x316 = ["American","AISC","Rectangular tubes (obsolete)","TS5x3x3/16"]
	American_AISC_Rectangular_tubes_obsolete_TS5x3x516 = ["American","AISC","Rectangular tubes (obsolete)","TS5x3x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS5x4x14 = ["American","AISC","Rectangular tubes (obsolete)","TS5x4x1/4"]
	American_AISC_Rectangular_tubes_obsolete_TS5x4x38 = ["American","AISC","Rectangular tubes (obsolete)","TS5x4x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS5x4x316 = ["American","AISC","Rectangular tubes (obsolete)","TS5x4x3/16"]
	American_AISC_Rectangular_tubes_obsolete_TS5x4x516 = ["American","AISC","Rectangular tubes (obsolete)","TS5x4x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS6x2x14 = ["American","AISC","Rectangular tubes (obsolete)","TS6x2x1/4"]
	American_AISC_Rectangular_tubes_obsolete_TS6x2x18 = ["American","AISC","Rectangular tubes (obsolete)","TS6x2x1/8"]
	American_AISC_Rectangular_tubes_obsolete_TS6x2x38 = ["American","AISC","Rectangular tubes (obsolete)","TS6x2x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS6x2x316 = ["American","AISC","Rectangular tubes (obsolete)","TS6x2x3/16"]
	American_AISC_Rectangular_tubes_obsolete_TS6x2x516 = ["American","AISC","Rectangular tubes (obsolete)","TS6x2x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS6x3x12 = ["American","AISC","Rectangular tubes (obsolete)","TS6x3x1/2"]
	American_AISC_Rectangular_tubes_obsolete_TS6x3x14 = ["American","AISC","Rectangular tubes (obsolete)","TS6x3x1/4"]
	American_AISC_Rectangular_tubes_obsolete_TS6x3x18 = ["American","AISC","Rectangular tubes (obsolete)","TS6x3x1/8"]
	American_AISC_Rectangular_tubes_obsolete_TS6x3x38 = ["American","AISC","Rectangular tubes (obsolete)","TS6x3x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS6x3x316 = ["American","AISC","Rectangular tubes (obsolete)","TS6x3x3/16"]
	American_AISC_Rectangular_tubes_obsolete_TS6x3x516 = ["American","AISC","Rectangular tubes (obsolete)","TS6x3x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS6x4x12 = ["American","AISC","Rectangular tubes (obsolete)","TS6x4x1/2"]
	American_AISC_Rectangular_tubes_obsolete_TS6x4x14 = ["American","AISC","Rectangular tubes (obsolete)","TS6x4x1/4"]
	American_AISC_Rectangular_tubes_obsolete_TS6x4x18 = ["American","AISC","Rectangular tubes (obsolete)","TS6x4x1/8"]
	American_AISC_Rectangular_tubes_obsolete_TS6x4x38 = ["American","AISC","Rectangular tubes (obsolete)","TS6x4x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS6x4x316 = ["American","AISC","Rectangular tubes (obsolete)","TS6x4x3/16"]
	American_AISC_Rectangular_tubes_obsolete_TS6x4x516 = ["American","AISC","Rectangular tubes (obsolete)","TS6x4x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS7x3x14 = ["American","AISC","Rectangular tubes (obsolete)","TS7x3x1/4"]
	American_AISC_Rectangular_tubes_obsolete_TS7x3x18 = ["American","AISC","Rectangular tubes (obsolete)","TS7x3x1/8"]
	American_AISC_Rectangular_tubes_obsolete_TS7x3x38 = ["American","AISC","Rectangular tubes (obsolete)","TS7x3x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS7x3x316 = ["American","AISC","Rectangular tubes (obsolete)","TS7x3x3/16"]
	American_AISC_Rectangular_tubes_obsolete_TS7x3x516 = ["American","AISC","Rectangular tubes (obsolete)","TS7x3x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS7x4x14 = ["American","AISC","Rectangular tubes (obsolete)","TS7x4x1/4"]
	American_AISC_Rectangular_tubes_obsolete_TS7x4x18 = ["American","AISC","Rectangular tubes (obsolete)","TS7x4x1/8"]
	American_AISC_Rectangular_tubes_obsolete_TS7x4x38 = ["American","AISC","Rectangular tubes (obsolete)","TS7x4x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS7x4x316 = ["American","AISC","Rectangular tubes (obsolete)","TS7x4x3/16"]
	American_AISC_Rectangular_tubes_obsolete_TS7x4x516 = ["American","AISC","Rectangular tubes (obsolete)","TS7x4x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS7x5x12 = ["American","AISC","Rectangular tubes (obsolete)","TS7x5x1/2"]
	American_AISC_Rectangular_tubes_obsolete_TS7x5x14 = ["American","AISC","Rectangular tubes (obsolete)","TS7x5x1/4"]
	American_AISC_Rectangular_tubes_obsolete_TS7x5x18 = ["American","AISC","Rectangular tubes (obsolete)","TS7x5x1/8"]
	American_AISC_Rectangular_tubes_obsolete_TS7x5x38 = ["American","AISC","Rectangular tubes (obsolete)","TS7x5x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS7x5x316 = ["American","AISC","Rectangular tubes (obsolete)","TS7x5x3/16"]
	American_AISC_Rectangular_tubes_obsolete_TS7x5x516 = ["American","AISC","Rectangular tubes (obsolete)","TS7x5x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS8x2x14 = ["American","AISC","Rectangular tubes (obsolete)","TS8x2x1/4"]
	American_AISC_Rectangular_tubes_obsolete_TS8x2x18 = ["American","AISC","Rectangular tubes (obsolete)","TS8x2x1/8"]
	American_AISC_Rectangular_tubes_obsolete_TS8x2x38 = ["American","AISC","Rectangular tubes (obsolete)","TS8x2x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS8x2x316 = ["American","AISC","Rectangular tubes (obsolete)","TS8x2x3/16"]
	American_AISC_Rectangular_tubes_obsolete_TS8x2x516 = ["American","AISC","Rectangular tubes (obsolete)","TS8x2x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS8x3x12 = ["American","AISC","Rectangular tubes (obsolete)","TS8x3x1/2"]
	American_AISC_Rectangular_tubes_obsolete_TS8x3x14 = ["American","AISC","Rectangular tubes (obsolete)","TS8x3x1/4"]
	American_AISC_Rectangular_tubes_obsolete_TS8x3x18 = ["American","AISC","Rectangular tubes (obsolete)","TS8x3x1/8"]
	American_AISC_Rectangular_tubes_obsolete_TS8x3x38 = ["American","AISC","Rectangular tubes (obsolete)","TS8x3x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS8x3x316 = ["American","AISC","Rectangular tubes (obsolete)","TS8x3x3/16"]
	American_AISC_Rectangular_tubes_obsolete_TS8x3x516 = ["American","AISC","Rectangular tubes (obsolete)","TS8x3x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS8x4x12 = ["American","AISC","Rectangular tubes (obsolete)","TS8x4x1/2"]
	American_AISC_Rectangular_tubes_obsolete_TS8x4x14 = ["American","AISC","Rectangular tubes (obsolete)","TS8x4x1/4"]
	American_AISC_Rectangular_tubes_obsolete_TS8x4x18 = ["American","AISC","Rectangular tubes (obsolete)","TS8x4x1/8"]
	American_AISC_Rectangular_tubes_obsolete_TS8x4x38 = ["American","AISC","Rectangular tubes (obsolete)","TS8x4x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS8x4x316 = ["American","AISC","Rectangular tubes (obsolete)","TS8x4x3/16"]
	American_AISC_Rectangular_tubes_obsolete_TS8x4x58 = ["American","AISC","Rectangular tubes (obsolete)","TS8x4x5/8"]
	American_AISC_Rectangular_tubes_obsolete_TS8x4x516 = ["American","AISC","Rectangular tubes (obsolete)","TS8x4x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS8x6x12 = ["American","AISC","Rectangular tubes (obsolete)","TS8x6x1/2"]
	American_AISC_Rectangular_tubes_obsolete_TS8x6x14 = ["American","AISC","Rectangular tubes (obsolete)","TS8x6x1/4"]
	American_AISC_Rectangular_tubes_obsolete_TS8x6x38 = ["American","AISC","Rectangular tubes (obsolete)","TS8x6x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS8x6x316 = ["American","AISC","Rectangular tubes (obsolete)","TS8x6x3/16"]
	American_AISC_Rectangular_tubes_obsolete_TS8x6x516 = ["American","AISC","Rectangular tubes (obsolete)","TS8x6x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS10x2x14 = ["American","AISC","Rectangular tubes (obsolete)","TS10x2x1/4"]
	American_AISC_Rectangular_tubes_obsolete_TS10x2x38 = ["American","AISC","Rectangular tubes (obsolete)","TS10x2x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS10x2x316 = ["American","AISC","Rectangular tubes (obsolete)","TS10x2x3/16"]
	American_AISC_Rectangular_tubes_obsolete_TS10x2x516 = ["American","AISC","Rectangular tubes (obsolete)","TS10x2x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS10x3x14 = ["American","AISC","Rectangular tubes (obsolete)","TS10x3x1/4"]
	American_AISC_Rectangular_tubes_obsolete_TS10x3x38 = ["American","AISC","Rectangular tubes (obsolete)","TS10x3x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS10x3x316 = ["American","AISC","Rectangular tubes (obsolete)","TS10x3x3/16"]
	American_AISC_Rectangular_tubes_obsolete_TS10x3x516 = ["American","AISC","Rectangular tubes (obsolete)","TS10x3x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS10x4x12 = ["American","AISC","Rectangular tubes (obsolete)","TS10x4x1/2"]
	American_AISC_Rectangular_tubes_obsolete_TS10x4x14 = ["American","AISC","Rectangular tubes (obsolete)","TS10x4x1/4"]
	American_AISC_Rectangular_tubes_obsolete_TS10x4x38 = ["American","AISC","Rectangular tubes (obsolete)","TS10x4x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS10x4x316 = ["American","AISC","Rectangular tubes (obsolete)","TS10x4x3/16"]
	American_AISC_Rectangular_tubes_obsolete_TS10x4x516 = ["American","AISC","Rectangular tubes (obsolete)","TS10x4x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS10x5x14 = ["American","AISC","Rectangular tubes (obsolete)","TS10x5x1/4"]
	American_AISC_Rectangular_tubes_obsolete_TS10x5x38 = ["American","AISC","Rectangular tubes (obsolete)","TS10x5x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS10x5x316 = ["American","AISC","Rectangular tubes (obsolete)","TS10x5x3/16"]
	American_AISC_Rectangular_tubes_obsolete_TS10x5x516 = ["American","AISC","Rectangular tubes (obsolete)","TS10x5x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS10x6x12 = ["American","AISC","Rectangular tubes (obsolete)","TS10x6x1/2"]
	American_AISC_Rectangular_tubes_obsolete_TS10x6x14 = ["American","AISC","Rectangular tubes (obsolete)","TS10x6x1/4"]
	American_AISC_Rectangular_tubes_obsolete_TS10x6x38 = ["American","AISC","Rectangular tubes (obsolete)","TS10x6x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS10x6x316 = ["American","AISC","Rectangular tubes (obsolete)","TS10x6x3/16"]
	American_AISC_Rectangular_tubes_obsolete_TS10x6x516 = ["American","AISC","Rectangular tubes (obsolete)","TS10x6x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS10x8x12 = ["American","AISC","Rectangular tubes (obsolete)","TS10x8x1/2"]
	American_AISC_Rectangular_tubes_obsolete_TS10x8x14 = ["American","AISC","Rectangular tubes (obsolete)","TS10x8x1/4"]
	American_AISC_Rectangular_tubes_obsolete_TS10x8x38 = ["American","AISC","Rectangular tubes (obsolete)","TS10x8x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS10x8x316 = ["American","AISC","Rectangular tubes (obsolete)","TS10x8x3/16"]
	American_AISC_Rectangular_tubes_obsolete_TS10x8x516 = ["American","AISC","Rectangular tubes (obsolete)","TS10x8x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS12x2x14 = ["American","AISC","Rectangular tubes (obsolete)","TS12x2x1/4"]
	American_AISC_Rectangular_tubes_obsolete_TS12x2x316 = ["American","AISC","Rectangular tubes (obsolete)","TS12x2x3/16"]
	American_AISC_Rectangular_tubes_obsolete_TS12x3x14 = ["American","AISC","Rectangular tubes (obsolete)","TS12x3x1/4"]
	American_AISC_Rectangular_tubes_obsolete_TS12x3x316 = ["American","AISC","Rectangular tubes (obsolete)","TS12x3x3/16"]
	American_AISC_Rectangular_tubes_obsolete_TS12x3x516 = ["American","AISC","Rectangular tubes (obsolete)","TS12x3x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS12x4x12 = ["American","AISC","Rectangular tubes (obsolete)","TS12x4x1/2"]
	American_AISC_Rectangular_tubes_obsolete_TS12x4x14 = ["American","AISC","Rectangular tubes (obsolete)","TS12x4x1/4"]
	American_AISC_Rectangular_tubes_obsolete_TS12x4x38 = ["American","AISC","Rectangular tubes (obsolete)","TS12x4x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS12x4x316 = ["American","AISC","Rectangular tubes (obsolete)","TS12x4x3/16"]
	American_AISC_Rectangular_tubes_obsolete_TS12x4x58 = ["American","AISC","Rectangular tubes (obsolete)","TS12x4x5/8"]
	American_AISC_Rectangular_tubes_obsolete_TS12x4x516 = ["American","AISC","Rectangular tubes (obsolete)","TS12x4x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS12x6x12 = ["American","AISC","Rectangular tubes (obsolete)","TS12x6x1/2"]
	American_AISC_Rectangular_tubes_obsolete_TS12x6x14 = ["American","AISC","Rectangular tubes (obsolete)","TS12x6x1/4"]
	American_AISC_Rectangular_tubes_obsolete_TS12x6x38 = ["American","AISC","Rectangular tubes (obsolete)","TS12x6x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS12x6x316 = ["American","AISC","Rectangular tubes (obsolete)","TS12x6x3/16"]
	American_AISC_Rectangular_tubes_obsolete_TS12x6x58 = ["American","AISC","Rectangular tubes (obsolete)","TS12x6x5/8"]
	American_AISC_Rectangular_tubes_obsolete_TS12x6x516 = ["American","AISC","Rectangular tubes (obsolete)","TS12x6x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS12x8x12 = ["American","AISC","Rectangular tubes (obsolete)","TS12x8x1/2"]
	American_AISC_Rectangular_tubes_obsolete_TS12x8x14 = ["American","AISC","Rectangular tubes (obsolete)","TS12x8x1/4"]
	American_AISC_Rectangular_tubes_obsolete_TS12x8x38 = ["American","AISC","Rectangular tubes (obsolete)","TS12x8x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS12x8x316 = ["American","AISC","Rectangular tubes (obsolete)","TS12x8x3/16"]
	American_AISC_Rectangular_tubes_obsolete_TS12x8x58 = ["American","AISC","Rectangular tubes (obsolete)","TS12x8x5/8"]
	American_AISC_Rectangular_tubes_obsolete_TS12x8x516 = ["American","AISC","Rectangular tubes (obsolete)","TS12x8x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS12x10x12 = ["American","AISC","Rectangular tubes (obsolete)","TS12x10x1/2"]
	American_AISC_Rectangular_tubes_obsolete_TS12x10x14 = ["American","AISC","Rectangular tubes (obsolete)","TS12x10x1/4"]
	American_AISC_Rectangular_tubes_obsolete_TS12x10x38 = ["American","AISC","Rectangular tubes (obsolete)","TS12x10x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS12x10x516 = ["American","AISC","Rectangular tubes (obsolete)","TS12x10x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS14x4x12 = ["American","AISC","Rectangular tubes (obsolete)","TS14x4x1/2"]
	American_AISC_Rectangular_tubes_obsolete_TS14x4x14 = ["American","AISC","Rectangular tubes (obsolete)","TS14x4x1/4"]
	American_AISC_Rectangular_tubes_obsolete_TS14x4x38 = ["American","AISC","Rectangular tubes (obsolete)","TS14x4x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS14x4x316 = ["American","AISC","Rectangular tubes (obsolete)","TS14x4x3/16"]
	American_AISC_Rectangular_tubes_obsolete_TS14x4x58 = ["American","AISC","Rectangular tubes (obsolete)","TS14x4x5/8"]
	American_AISC_Rectangular_tubes_obsolete_TS14x4x516 = ["American","AISC","Rectangular tubes (obsolete)","TS14x4x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS14x6x12 = ["American","AISC","Rectangular tubes (obsolete)","TS14x6x1/2"]
	American_AISC_Rectangular_tubes_obsolete_TS14x6x14 = ["American","AISC","Rectangular tubes (obsolete)","TS14x6x1/4"]
	American_AISC_Rectangular_tubes_obsolete_TS14x6x38 = ["American","AISC","Rectangular tubes (obsolete)","TS14x6x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS14x6x58 = ["American","AISC","Rectangular tubes (obsolete)","TS14x6x5/8"]
	American_AISC_Rectangular_tubes_obsolete_TS14x6x516 = ["American","AISC","Rectangular tubes (obsolete)","TS14x6x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS14x10x12 = ["American","AISC","Rectangular tubes (obsolete)","TS14x10x1/2"]
	American_AISC_Rectangular_tubes_obsolete_TS14x10x38 = ["American","AISC","Rectangular tubes (obsolete)","TS14x10x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS14x10x516 = ["American","AISC","Rectangular tubes (obsolete)","TS14x10x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS14x12x12 = ["American","AISC","Rectangular tubes (obsolete)","TS14x12x1/2"]
	American_AISC_Rectangular_tubes_obsolete_TS14x12x38 = ["American","AISC","Rectangular tubes (obsolete)","TS14x12x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS16x4x12 = ["American","AISC","Rectangular tubes (obsolete)","TS16x4x1/2"]
	American_AISC_Rectangular_tubes_obsolete_TS16x4x38 = ["American","AISC","Rectangular tubes (obsolete)","TS16x4x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS16x4x516 = ["American","AISC","Rectangular tubes (obsolete)","TS16x4x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS16x8x12 = ["American","AISC","Rectangular tubes (obsolete)","TS16x8x1/2"]
	American_AISC_Rectangular_tubes_obsolete_TS16x8x38 = ["American","AISC","Rectangular tubes (obsolete)","TS16x8x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS16x8x516 = ["American","AISC","Rectangular tubes (obsolete)","TS16x8x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS16x12x12 = ["American","AISC","Rectangular tubes (obsolete)","TS16x12x1/2"]
	American_AISC_Rectangular_tubes_obsolete_TS16x12x38 = ["American","AISC","Rectangular tubes (obsolete)","TS16x12x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS16x12x516 = ["American","AISC","Rectangular tubes (obsolete)","TS16x12x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS18x6x12 = ["American","AISC","Rectangular tubes (obsolete)","TS18x6x1/2"]
	American_AISC_Rectangular_tubes_obsolete_TS18x6x14 = ["American","AISC","Rectangular tubes (obsolete)","TS18x6x1/4"]
	American_AISC_Rectangular_tubes_obsolete_TS18x6x38 = ["American","AISC","Rectangular tubes (obsolete)","TS18x6x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS18x6x516 = ["American","AISC","Rectangular tubes (obsolete)","TS18x6x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS18x12x12 = ["American","AISC","Rectangular tubes (obsolete)","TS18x12x1/2"]
	American_AISC_Rectangular_tubes_obsolete_TS18x12x38 = ["American","AISC","Rectangular tubes (obsolete)","TS18x12x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS18x12x516 = ["American","AISC","Rectangular tubes (obsolete)","TS18x12x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS20x4x12 = ["American","AISC","Rectangular tubes (obsolete)","TS20x4x1/2"]
	American_AISC_Rectangular_tubes_obsolete_TS20x4x38 = ["American","AISC","Rectangular tubes (obsolete)","TS20x4x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS20x4x516 = ["American","AISC","Rectangular tubes (obsolete)","TS20x4x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS20x8x12 = ["American","AISC","Rectangular tubes (obsolete)","TS20x8x1/2"]
	American_AISC_Rectangular_tubes_obsolete_TS20x8x38 = ["American","AISC","Rectangular tubes (obsolete)","TS20x8x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS20x8x516 = ["American","AISC","Rectangular tubes (obsolete)","TS20x8x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS20x12x12 = ["American","AISC","Rectangular tubes (obsolete)","TS20x12x1/2"]
	American_AISC_Rectangular_tubes_obsolete_TS20x12x38 = ["American","AISC","Rectangular tubes (obsolete)","TS20x12x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS20x12x516 = ["American","AISC","Rectangular tubes (obsolete)","TS20x12x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS20x18x12 = ["American","AISC","Rectangular tubes (obsolete)","TS20x18x1/2"]
	American_AISC_Rectangular_tubes_obsolete_TS20x18x38 = ["American","AISC","Rectangular tubes (obsolete)","TS20x18x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS20x18x516 = ["American","AISC","Rectangular tubes (obsolete)","TS20x18x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS22x20x12 = ["American","AISC","Rectangular tubes (obsolete)","TS22x20x1/2"]
	American_AISC_Rectangular_tubes_obsolete_TS22x20x38 = ["American","AISC","Rectangular tubes (obsolete)","TS22x20x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS22x20x516 = ["American","AISC","Rectangular tubes (obsolete)","TS22x20x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS24x22x12 = ["American","AISC","Rectangular tubes (obsolete)","TS24x22x1/2"]
	American_AISC_Rectangular_tubes_obsolete_TS24x22x38 = ["American","AISC","Rectangular tubes (obsolete)","TS24x22x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS24x22x516 = ["American","AISC","Rectangular tubes (obsolete)","TS24x22x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS26x24x12 = ["American","AISC","Rectangular tubes (obsolete)","TS26x24x1/2"]
	American_AISC_Rectangular_tubes_obsolete_TS26x24x38 = ["American","AISC","Rectangular tubes (obsolete)","TS26x24x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS26x24x516 = ["American","AISC","Rectangular tubes (obsolete)","TS26x24x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS28x24x12 = ["American","AISC","Rectangular tubes (obsolete)","TS28x24x1/2"]
	American_AISC_Rectangular_tubes_obsolete_TS28x24x38 = ["American","AISC","Rectangular tubes (obsolete)","TS28x24x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS28x24x516 = ["American","AISC","Rectangular tubes (obsolete)","TS28x24x5/16"]
	American_AISC_Rectangular_tubes_obsolete_TS30x24x12 = ["American","AISC","Rectangular tubes (obsolete)","TS30x24x1/2"]
	American_AISC_Rectangular_tubes_obsolete_TS30x24x38 = ["American","AISC","Rectangular tubes (obsolete)","TS30x24x3/8"]
	American_AISC_Rectangular_tubes_obsolete_TS30x24x516 = ["American","AISC","Rectangular tubes (obsolete)","TS30x24x5/16"]
	American_AISC_Round_HSS_HSS1_660x0_140 = ["American","AISC","Round HSS","HSS1.660x0.140"]
	American_AISC_Round_HSS_HSS1_900x0_120 = ["American","AISC","Round HSS","HSS1.900x0.120"]
	American_AISC_Round_HSS_HSS1_900x0_145 = ["American","AISC","Round HSS","HSS1.900x0.145"]
	American_AISC_Round_HSS_HSS1_900x0_188 = ["American","AISC","Round HSS","HSS1.900x0.188"]
	American_AISC_Round_HSS_HSS2_375x0_125 = ["American","AISC","Round HSS","HSS2.375x0.125"]
	American_AISC_Round_HSS_HSS2_375x0_154 = ["American","AISC","Round HSS","HSS2.375x0.154"]
	American_AISC_Round_HSS_HSS2_375x0_188 = ["American","AISC","Round HSS","HSS2.375x0.188"]
	American_AISC_Round_HSS_HSS2_375x0_218 = ["American","AISC","Round HSS","HSS2.375x0.218"]
	American_AISC_Round_HSS_HSS2_375x0_250 = ["American","AISC","Round HSS","HSS2.375x0.250"]
	American_AISC_Round_HSS_HSS2_500x0_125 = ["American","AISC","Round HSS","HSS2.500x0.125"]
	American_AISC_Round_HSS_HSS2_500x0_188 = ["American","AISC","Round HSS","HSS2.500x0.188"]
	American_AISC_Round_HSS_HSS2_500x0_250 = ["American","AISC","Round HSS","HSS2.500x0.250"]
	American_AISC_Round_HSS_HSS2_875x0_125 = ["American","AISC","Round HSS","HSS2.875x0.125"]
	American_AISC_Round_HSS_HSS2_875x0_188 = ["American","AISC","Round HSS","HSS2.875x0.188"]
	American_AISC_Round_HSS_HSS2_875x0_203 = ["American","AISC","Round HSS","HSS2.875x0.203"]
	American_AISC_Round_HSS_HSS2_875x0_250 = ["American","AISC","Round HSS","HSS2.875x0.250"]
	American_AISC_Round_HSS_HSS3_500x0_125 = ["American","AISC","Round HSS","HSS3.500x0.125"]
	American_AISC_Round_HSS_HSS3_500x0_188 = ["American","AISC","Round HSS","HSS3.500x0.188"]
	American_AISC_Round_HSS_HSS3_500x0_203 = ["American","AISC","Round HSS","HSS3.500x0.203"]
	American_AISC_Round_HSS_HSS3_500x0_216 = ["American","AISC","Round HSS","HSS3.500x0.216"]
	American_AISC_Round_HSS_HSS3_500x0_250 = ["American","AISC","Round HSS","HSS3.500x0.250"]
	American_AISC_Round_HSS_HSS3_500x0_300 = ["American","AISC","Round HSS","HSS3.500x0.300"]
	American_AISC_Round_HSS_HSS3_500x0_313 = ["American","AISC","Round HSS","HSS3.500x0.313"]
	American_AISC_Round_HSS_HSS3x0_125 = ["American","AISC","Round HSS","HSS3x0.125"]
	American_AISC_Round_HSS_HSS3x0_134 = ["American","AISC","Round HSS","HSS3x0.134"]
	American_AISC_Round_HSS_HSS3x0_152 = ["American","AISC","Round HSS","HSS3x0.152"]
	American_AISC_Round_HSS_HSS3x0_188 = ["American","AISC","Round HSS","HSS3x0.188"]
	American_AISC_Round_HSS_HSS3x0_203 = ["American","AISC","Round HSS","HSS3x0.203"]
	American_AISC_Round_HSS_HSS3x0_216 = ["American","AISC","Round HSS","HSS3x0.216"]
	American_AISC_Round_HSS_HSS3x0_250 = ["American","AISC","Round HSS","HSS3x0.250"]
	American_AISC_Round_HSS_HSS4_500x0_125 = ["American","AISC","Round HSS","HSS4.500x0.125"]
	American_AISC_Round_HSS_HSS4_500x0_188 = ["American","AISC","Round HSS","HSS4.500x0.188"]
	American_AISC_Round_HSS_HSS4_500x0_237 = ["American","AISC","Round HSS","HSS4.500x0.237"]
	American_AISC_Round_HSS_HSS4_500x0_337 = ["American","AISC","Round HSS","HSS4.500x0.337"]
	American_AISC_Round_HSS_HSS4_500x0_375 = ["American","AISC","Round HSS","HSS4.500x0.375"]
	American_AISC_Round_HSS_HSS4x0_125 = ["American","AISC","Round HSS","HSS4x0.125"]
	American_AISC_Round_HSS_HSS4x0_188 = ["American","AISC","Round HSS","HSS4x0.188"]
	American_AISC_Round_HSS_HSS4x0_220 = ["American","AISC","Round HSS","HSS4x0.220"]
	American_AISC_Round_HSS_HSS4x0_226 = ["American","AISC","Round HSS","HSS4x0.226"]
	American_AISC_Round_HSS_HSS4x0_237 = ["American","AISC","Round HSS","HSS4x0.237"]
	American_AISC_Round_HSS_HSS4x0_250 = ["American","AISC","Round HSS","HSS4x0.250"]
	American_AISC_Round_HSS_HSS4x0_313 = ["American","AISC","Round HSS","HSS4x0.313"]
	American_AISC_Round_HSS_HSS5_500x0_258 = ["American","AISC","Round HSS","HSS5.500x0.258"]
	American_AISC_Round_HSS_HSS5_500x0_375 = ["American","AISC","Round HSS","HSS5.500x0.375"]
	American_AISC_Round_HSS_HSS5_500x0_500 = ["American","AISC","Round HSS","HSS5.500x0.500"]
	American_AISC_Round_HSS_HSS5_563x0_134 = ["American","AISC","Round HSS","HSS5.563x0.134"]
	American_AISC_Round_HSS_HSS5_563x0_188 = ["American","AISC","Round HSS","HSS5.563x0.188"]
	American_AISC_Round_HSS_HSS5_563x0_258 = ["American","AISC","Round HSS","HSS5.563x0.258"]
	American_AISC_Round_HSS_HSS5_563x0_375 = ["American","AISC","Round HSS","HSS5.563x0.375"]
	American_AISC_Round_HSS_HSS5_563x0_500 = ["American","AISC","Round HSS","HSS5.563x0.500"]
	American_AISC_Round_HSS_HSS5x0_125 = ["American","AISC","Round HSS","HSS5x0.125"]
	American_AISC_Round_HSS_HSS5x0_188 = ["American","AISC","Round HSS","HSS5x0.188"]
	American_AISC_Round_HSS_HSS5x0_250 = ["American","AISC","Round HSS","HSS5x0.250"]
	American_AISC_Round_HSS_HSS5x0_258 = ["American","AISC","Round HSS","HSS5x0.258"]
	American_AISC_Round_HSS_HSS5x0_312 = ["American","AISC","Round HSS","HSS5x0.312"]
	American_AISC_Round_HSS_HSS5x0_375 = ["American","AISC","Round HSS","HSS5x0.375"]
	American_AISC_Round_HSS_HSS5x0_500 = ["American","AISC","Round HSS","HSS5x0.500"]
	American_AISC_Round_HSS_HSS6_625x0_125 = ["American","AISC","Round HSS","HSS6.625x0.125"]
	American_AISC_Round_HSS_HSS6_625x0_188 = ["American","AISC","Round HSS","HSS6.625x0.188"]
	American_AISC_Round_HSS_HSS6_625x0_250 = ["American","AISC","Round HSS","HSS6.625x0.250"]
	American_AISC_Round_HSS_HSS6_625x0_280 = ["American","AISC","Round HSS","HSS6.625x0.280"]
	American_AISC_Round_HSS_HSS6_625x0_312 = ["American","AISC","Round HSS","HSS6.625x0.312"]
	American_AISC_Round_HSS_HSS6_625x0_375 = ["American","AISC","Round HSS","HSS6.625x0.375"]
	American_AISC_Round_HSS_HSS6_625x0_432 = ["American","AISC","Round HSS","HSS6.625x0.432"]
	American_AISC_Round_HSS_HSS6_625x0_500 = ["American","AISC","Round HSS","HSS6.625x0.500"]
	American_AISC_Round_HSS_HSS6_875x0_188 = ["American","AISC","Round HSS","HSS6.875x0.188"]
	American_AISC_Round_HSS_HSS6_875x0_250 = ["American","AISC","Round HSS","HSS6.875x0.250"]
	American_AISC_Round_HSS_HSS6_875x0_312 = ["American","AISC","Round HSS","HSS6.875x0.312"]
	American_AISC_Round_HSS_HSS6_875x0_375 = ["American","AISC","Round HSS","HSS6.875x0.375"]
	American_AISC_Round_HSS_HSS6_875x0_500 = ["American","AISC","Round HSS","HSS6.875x0.500"]
	American_AISC_Round_HSS_HSS6x0_125 = ["American","AISC","Round HSS","HSS6x0.125"]
	American_AISC_Round_HSS_HSS6x0_188 = ["American","AISC","Round HSS","HSS6x0.188"]
	American_AISC_Round_HSS_HSS6x0_250 = ["American","AISC","Round HSS","HSS6x0.250"]
	American_AISC_Round_HSS_HSS6x0_280 = ["American","AISC","Round HSS","HSS6x0.280"]
	American_AISC_Round_HSS_HSS6x0_312 = ["American","AISC","Round HSS","HSS6x0.312"]
	American_AISC_Round_HSS_HSS6x0_375 = ["American","AISC","Round HSS","HSS6x0.375"]
	American_AISC_Round_HSS_HSS6x0_500 = ["American","AISC","Round HSS","HSS6x0.500"]
	American_AISC_Round_HSS_HSS7_500x0_188 = ["American","AISC","Round HSS","HSS7.500x0.188"]
	American_AISC_Round_HSS_HSS7_500x0_250 = ["American","AISC","Round HSS","HSS7.500x0.250"]
	American_AISC_Round_HSS_HSS7_500x0_312 = ["American","AISC","Round HSS","HSS7.500x0.312"]
	American_AISC_Round_HSS_HSS7_500x0_375 = ["American","AISC","Round HSS","HSS7.500x0.375"]
	American_AISC_Round_HSS_HSS7_500x0_500 = ["American","AISC","Round HSS","HSS7.500x0.500"]
	American_AISC_Round_HSS_HSS7_625x0_328 = ["American","AISC","Round HSS","HSS7.625x0.328"]
	American_AISC_Round_HSS_HSS7_625x0_375 = ["American","AISC","Round HSS","HSS7.625x0.375"]
	American_AISC_Round_HSS_HSS7x0_125 = ["American","AISC","Round HSS","HSS7x0.125"]
	American_AISC_Round_HSS_HSS7x0_188 = ["American","AISC","Round HSS","HSS7x0.188"]
	American_AISC_Round_HSS_HSS7x0_250 = ["American","AISC","Round HSS","HSS7x0.250"]
	American_AISC_Round_HSS_HSS7x0_312 = ["American","AISC","Round HSS","HSS7x0.312"]
	American_AISC_Round_HSS_HSS7x0_375 = ["American","AISC","Round HSS","HSS7x0.375"]
	American_AISC_Round_HSS_HSS7x0_500 = ["American","AISC","Round HSS","HSS7x0.500"]
	American_AISC_Round_HSS_HSS8_625x0_188 = ["American","AISC","Round HSS","HSS8.625x0.188"]
	American_AISC_Round_HSS_HSS8_625x0_250 = ["American","AISC","Round HSS","HSS8.625x0.250"]
	American_AISC_Round_HSS_HSS8_625x0_322 = ["American","AISC","Round HSS","HSS8.625x0.322"]
	American_AISC_Round_HSS_HSS8_625x0_375 = ["American","AISC","Round HSS","HSS8.625x0.375"]
	American_AISC_Round_HSS_HSS8_625x0_500 = ["American","AISC","Round HSS","HSS8.625x0.500"]
	American_AISC_Round_HSS_HSS8_625x0_625 = ["American","AISC","Round HSS","HSS8.625x0.625"]
	American_AISC_Round_HSS_HSS9_625x0_188 = ["American","AISC","Round HSS","HSS9.625x0.188"]
	American_AISC_Round_HSS_HSS9_625x0_250 = ["American","AISC","Round HSS","HSS9.625x0.250"]
	American_AISC_Round_HSS_HSS9_625x0_312 = ["American","AISC","Round HSS","HSS9.625x0.312"]
	American_AISC_Round_HSS_HSS9_625x0_375 = ["American","AISC","Round HSS","HSS9.625x0.375"]
	American_AISC_Round_HSS_HSS9_625x0_500 = ["American","AISC","Round HSS","HSS9.625x0.500"]
	American_AISC_Round_HSS_HSS10_750x0_250 = ["American","AISC","Round HSS","HSS10.750x0.250"]
	American_AISC_Round_HSS_HSS10_750x0_375 = ["American","AISC","Round HSS","HSS10.750x0.375"]
	American_AISC_Round_HSS_HSS10_750x0_500 = ["American","AISC","Round HSS","HSS10.750x0.500"]
	American_AISC_Round_HSS_HSS10x0_188 = ["American","AISC","Round HSS","HSS10x0.188"]
	American_AISC_Round_HSS_HSS10x0_250 = ["American","AISC","Round HSS","HSS10x0.250"]
	American_AISC_Round_HSS_HSS10x0_312 = ["American","AISC","Round HSS","HSS10x0.312"]
	American_AISC_Round_HSS_HSS10x0_375 = ["American","AISC","Round HSS","HSS10x0.375"]
	American_AISC_Round_HSS_HSS10x0_500 = ["American","AISC","Round HSS","HSS10x0.500"]
	American_AISC_Round_HSS_HSS10x0_625 = ["American","AISC","Round HSS","HSS10x0.625"]
	American_AISC_Round_HSS_HSS12_750x0_250 = ["American","AISC","Round HSS","HSS12.750x0.250"]
	American_AISC_Round_HSS_HSS12_750x0_375 = ["American","AISC","Round HSS","HSS12.750x0.375"]
	American_AISC_Round_HSS_HSS12_750x0_500 = ["American","AISC","Round HSS","HSS12.750x0.500"]
	American_AISC_Round_HSS_HSS14x0_250 = ["American","AISC","Round HSS","HSS14x0.250"]
	American_AISC_Round_HSS_HSS14x0_312 = ["American","AISC","Round HSS","HSS14x0.312"]
	American_AISC_Round_HSS_HSS14x0_375 = ["American","AISC","Round HSS","HSS14x0.375"]
	American_AISC_Round_HSS_HSS14x0_500 = ["American","AISC","Round HSS","HSS14x0.500"]
	American_AISC_Round_HSS_HSS14x0_625 = ["American","AISC","Round HSS","HSS14x0.625"]
	American_AISC_Round_HSS_HSS16x0_250 = ["American","AISC","Round HSS","HSS16x0.250"]
	American_AISC_Round_HSS_HSS16x0_312 = ["American","AISC","Round HSS","HSS16x0.312"]
	American_AISC_Round_HSS_HSS16x0_375 = ["American","AISC","Round HSS","HSS16x0.375"]
	American_AISC_Round_HSS_HSS16x0_438 = ["American","AISC","Round HSS","HSS16x0.438"]
	American_AISC_Round_HSS_HSS16x0_500 = ["American","AISC","Round HSS","HSS16x0.500"]
	American_AISC_Round_HSS_HSS16x0_625 = ["American","AISC","Round HSS","HSS16x0.625"]
	American_AISC_Round_HSS_HSS18x0_375 = ["American","AISC","Round HSS","HSS18x0.375"]
	American_AISC_Round_HSS_HSS18x0_500 = ["American","AISC","Round HSS","HSS18x0.500"]
	American_AISC_Round_HSS_HSS20x0_375 = ["American","AISC","Round HSS","HSS20x0.375"]
	American_AISC_Round_HSS_HSS20x0_500 = ["American","AISC","Round HSS","HSS20x0.500"]
	American_AISC_Round_HSS_PIPE1_12STD = ["American","AISC","Round HSS","PIPE1-1/2STD"]
	American_AISC_Round_HSS_PIPE1_12xS = ["American","AISC","Round HSS","PIPE1-1/2xS"]
	American_AISC_Round_HSS_PIPE1_14STD = ["American","AISC","Round HSS","PIPE1-1/4STD"]
	American_AISC_Round_HSS_PIPE1_14xS = ["American","AISC","Round HSS","PIPE1-1/4xS"]
	American_AISC_Round_HSS_PIPE12STD = ["American","AISC","Round HSS","PIPE12STD"]
	American_AISC_Round_HSS_PIPE12xS = ["American","AISC","Round HSS","PIPE12xS"]
	American_AISC_Round_HSS_PIPE1STD = ["American","AISC","Round HSS","PIPE1STD"]
	American_AISC_Round_HSS_PIPE1xS = ["American","AISC","Round HSS","PIPE1xS"]
	American_AISC_Round_HSS_PIPE2_12STD = ["American","AISC","Round HSS","PIPE2-1/2STD"]
	American_AISC_Round_HSS_PIPE2_12xS = ["American","AISC","Round HSS","PIPE2-1/2xS"]
	American_AISC_Round_HSS_PIPE2_12xxS = ["American","AISC","Round HSS","PIPE2-1/2xxS"]
	American_AISC_Round_HSS_PIPE2STD = ["American","AISC","Round HSS","PIPE2STD"]
	American_AISC_Round_HSS_PIPE2xS = ["American","AISC","Round HSS","PIPE2xS"]
	American_AISC_Round_HSS_PIPE2xxS = ["American","AISC","Round HSS","PIPE2xxS"]
	American_AISC_Round_HSS_PIPE3_12STD = ["American","AISC","Round HSS","PIPE3-1/2STD"]
	American_AISC_Round_HSS_PIPE3_12xS = ["American","AISC","Round HSS","PIPE3-1/2xS"]
	American_AISC_Round_HSS_PIPE34STD = ["American","AISC","Round HSS","PIPE3/4STD"]
	American_AISC_Round_HSS_PIPE34xS = ["American","AISC","Round HSS","PIPE3/4xS"]
	American_AISC_Round_HSS_PIPE3STD = ["American","AISC","Round HSS","PIPE3STD"]
	American_AISC_Round_HSS_PIPE3xS = ["American","AISC","Round HSS","PIPE3xS"]
	American_AISC_Round_HSS_PIPE3xxS = ["American","AISC","Round HSS","PIPE3xxS"]
	American_AISC_Round_HSS_PIPE4STD = ["American","AISC","Round HSS","PIPE4STD"]
	American_AISC_Round_HSS_PIPE4xS = ["American","AISC","Round HSS","PIPE4xS"]
	American_AISC_Round_HSS_PIPE4xxS = ["American","AISC","Round HSS","PIPE4xxS"]
	American_AISC_Round_HSS_PIPE5STD = ["American","AISC","Round HSS","PIPE5STD"]
	American_AISC_Round_HSS_PIPE5xS = ["American","AISC","Round HSS","PIPE5xS"]
	American_AISC_Round_HSS_PIPE5xxS = ["American","AISC","Round HSS","PIPE5xxS"]
	American_AISC_Round_HSS_PIPE6STD = ["American","AISC","Round HSS","PIPE6STD"]
	American_AISC_Round_HSS_PIPE6xS = ["American","AISC","Round HSS","PIPE6xS"]
	American_AISC_Round_HSS_PIPE6xxS = ["American","AISC","Round HSS","PIPE6xxS"]
	American_AISC_Round_HSS_PIPE8STD = ["American","AISC","Round HSS","PIPE8STD"]
	American_AISC_Round_HSS_PIPE8xS = ["American","AISC","Round HSS","PIPE8xS"]
	American_AISC_Round_HSS_PIPE8xxS = ["American","AISC","Round HSS","PIPE8xxS"]
	American_AISC_Round_HSS_PIPE10STD = ["American","AISC","Round HSS","PIPE10STD"]
	American_AISC_Round_HSS_PIPE10xS = ["American","AISC","Round HSS","PIPE10xS"]
	American_AISC_S_shapes_S3x5_7 = ["American","AISC","S shapes","S3x5.7"]
	American_AISC_S_shapes_S3x7_5 = ["American","AISC","S shapes","S3x7.5"]
	American_AISC_S_shapes_S4x7_7 = ["American","AISC","S shapes","S4x7.7"]
	American_AISC_S_shapes_S4x9_5 = ["American","AISC","S shapes","S4x9.5"]
	American_AISC_S_shapes_S5x10 = ["American","AISC","S shapes","S5x10"]
	American_AISC_S_shapes_S6x12_5 = ["American","AISC","S shapes","S6x12.5"]
	American_AISC_S_shapes_S6x17_25 = ["American","AISC","S shapes","S6x17.25"]
	American_AISC_S_shapes_S8x18_4 = ["American","AISC","S shapes","S8x18.4"]
	American_AISC_S_shapes_S8x23 = ["American","AISC","S shapes","S8x23"]
	American_AISC_S_shapes_S10x25_4 = ["American","AISC","S shapes","S10x25.4"]
	American_AISC_S_shapes_S10x35 = ["American","AISC","S shapes","S10x35"]
	American_AISC_S_shapes_S12x31_8 = ["American","AISC","S shapes","S12x31.8"]
	American_AISC_S_shapes_S12x35 = ["American","AISC","S shapes","S12x35"]
	American_AISC_S_shapes_S12x40_8 = ["American","AISC","S shapes","S12x40.8"]
	American_AISC_S_shapes_S12x50 = ["American","AISC","S shapes","S12x50"]
	American_AISC_S_shapes_S15x42_9 = ["American","AISC","S shapes","S15x42.9"]
	American_AISC_S_shapes_S15x50 = ["American","AISC","S shapes","S15x50"]
	American_AISC_S_shapes_S18x54_7 = ["American","AISC","S shapes","S18x54.7"]
	American_AISC_S_shapes_S18x70 = ["American","AISC","S shapes","S18x70"]
	American_AISC_S_shapes_S20x66 = ["American","AISC","S shapes","S20x66"]
	American_AISC_S_shapes_S20x75 = ["American","AISC","S shapes","S20x75"]
	American_AISC_S_shapes_S20x86 = ["American","AISC","S shapes","S20x86"]
	American_AISC_S_shapes_S20x96 = ["American","AISC","S shapes","S20x96"]
	American_AISC_S_shapes_S24x80 = ["American","AISC","S shapes","S24x80"]
	American_AISC_S_shapes_S24x90 = ["American","AISC","S shapes","S24x90"]
	American_AISC_S_shapes_S24x100 = ["American","AISC","S shapes","S24x100"]
	American_AISC_S_shapes_S24x106 = ["American","AISC","S shapes","S24x106"]
	American_AISC_S_shapes_S24x121 = ["American","AISC","S shapes","S24x121"]
	American_AISC_Square_HSS_HSS2_12x2_12x14 = ["American","AISC","Square HSS","HSS2-1/2x2-1/2x1/4"]
	American_AISC_Square_HSS_HSS2_12x2_12x18 = ["American","AISC","Square HSS","HSS2-1/2x2-1/2x1/8"]
	American_AISC_Square_HSS_HSS2_12x2_12x316 = ["American","AISC","Square HSS","HSS2-1/2x2-1/2x3/16"]
	American_AISC_Square_HSS_HSS2_12x2_12x516 = ["American","AISC","Square HSS","HSS2-1/2x2-1/2x5/16"]
	American_AISC_Square_HSS_HSS2_14x2_14x14 = ["American","AISC","Square HSS","HSS2-1/4x2-1/4x1/4"]
	American_AISC_Square_HSS_HSS2_14x2_14x18 = ["American","AISC","Square HSS","HSS2-1/4x2-1/4x1/8"]
	American_AISC_Square_HSS_HSS2_14x2_14x316 = ["American","AISC","Square HSS","HSS2-1/4x2-1/4x3/16"]
	American_AISC_Square_HSS_HSS2x2x14 = ["American","AISC","Square HSS","HSS2x2x1/4"]
	American_AISC_Square_HSS_HSS2x2x18 = ["American","AISC","Square HSS","HSS2x2x1/8"]
	American_AISC_Square_HSS_HSS2x2x316 = ["American","AISC","Square HSS","HSS2x2x3/16"]
	American_AISC_Square_HSS_HSS3_12x3_12x14 = ["American","AISC","Square HSS","HSS3-1/2x3-1/2x1/4"]
	American_AISC_Square_HSS_HSS3_12x3_12x18 = ["American","AISC","Square HSS","HSS3-1/2x3-1/2x1/8"]
	American_AISC_Square_HSS_HSS3_12x3_12x38 = ["American","AISC","Square HSS","HSS3-1/2x3-1/2x3/8"]
	American_AISC_Square_HSS_HSS3_12x3_12x316 = ["American","AISC","Square HSS","HSS3-1/2x3-1/2x3/16"]
	American_AISC_Square_HSS_HSS3_12x3_12x516 = ["American","AISC","Square HSS","HSS3-1/2x3-1/2x5/16"]
	American_AISC_Square_HSS_HSS3x3x14 = ["American","AISC","Square HSS","HSS3x3x1/4"]
	American_AISC_Square_HSS_HSS3x3x18 = ["American","AISC","Square HSS","HSS3x3x1/8"]
	American_AISC_Square_HSS_HSS3x3x38 = ["American","AISC","Square HSS","HSS3x3x3/8"]
	American_AISC_Square_HSS_HSS3x3x316 = ["American","AISC","Square HSS","HSS3x3x3/16"]
	American_AISC_Square_HSS_HSS3x3x516 = ["American","AISC","Square HSS","HSS3x3x5/16"]
	American_AISC_Square_HSS_HSS4_12x4_12x12 = ["American","AISC","Square HSS","HSS4-1/2x4-1/2x1/2"]
	American_AISC_Square_HSS_HSS4_12x4_12x14 = ["American","AISC","Square HSS","HSS4-1/2x4-1/2x1/4"]
	American_AISC_Square_HSS_HSS4_12x4_12x18 = ["American","AISC","Square HSS","HSS4-1/2x4-1/2x1/8"]
	American_AISC_Square_HSS_HSS4_12x4_12x38 = ["American","AISC","Square HSS","HSS4-1/2x4-1/2x3/8"]
	American_AISC_Square_HSS_HSS4_12x4_12x316 = ["American","AISC","Square HSS","HSS4-1/2x4-1/2x3/16"]
	American_AISC_Square_HSS_HSS4_12x4_12x516 = ["American","AISC","Square HSS","HSS4-1/2x4-1/2x5/16"]
	American_AISC_Square_HSS_HSS4x4x12 = ["American","AISC","Square HSS","HSS4x4x1/2"]
	American_AISC_Square_HSS_HSS4x4x14 = ["American","AISC","Square HSS","HSS4x4x1/4"]
	American_AISC_Square_HSS_HSS4x4x18 = ["American","AISC","Square HSS","HSS4x4x1/8"]
	American_AISC_Square_HSS_HSS4x4x38 = ["American","AISC","Square HSS","HSS4x4x3/8"]
	American_AISC_Square_HSS_HSS4x4x316 = ["American","AISC","Square HSS","HSS4x4x3/16"]
	American_AISC_Square_HSS_HSS4x4x516 = ["American","AISC","Square HSS","HSS4x4x5/16"]
	American_AISC_Square_HSS_HSS5_12x5_12x14 = ["American","AISC","Square HSS","HSS5-1/2x5-1/2x1/4"]
	American_AISC_Square_HSS_HSS5_12x5_12x18 = ["American","AISC","Square HSS","HSS5-1/2x5-1/2x1/8"]
	American_AISC_Square_HSS_HSS5_12x5_12x38 = ["American","AISC","Square HSS","HSS5-1/2x5-1/2x3/8"]
	American_AISC_Square_HSS_HSS5_12x5_12x316 = ["American","AISC","Square HSS","HSS5-1/2x5-1/2x3/16"]
	American_AISC_Square_HSS_HSS5_12x5_12x516 = ["American","AISC","Square HSS","HSS5-1/2x5-1/2x5/16"]
	American_AISC_Square_HSS_HSS5x5x12 = ["American","AISC","Square HSS","HSS5x5x1/2"]
	American_AISC_Square_HSS_HSS5x5x14 = ["American","AISC","Square HSS","HSS5x5x1/4"]
	American_AISC_Square_HSS_HSS5x5x18 = ["American","AISC","Square HSS","HSS5x5x1/8"]
	American_AISC_Square_HSS_HSS5x5x38 = ["American","AISC","Square HSS","HSS5x5x3/8"]
	American_AISC_Square_HSS_HSS5x5x316 = ["American","AISC","Square HSS","HSS5x5x3/16"]
	American_AISC_Square_HSS_HSS5x5x516 = ["American","AISC","Square HSS","HSS5x5x5/16"]
	American_AISC_Square_HSS_HSS6x6x12 = ["American","AISC","Square HSS","HSS6x6x1/2"]
	American_AISC_Square_HSS_HSS6x6x14 = ["American","AISC","Square HSS","HSS6x6x1/4"]
	American_AISC_Square_HSS_HSS6x6x18 = ["American","AISC","Square HSS","HSS6x6x1/8"]
	American_AISC_Square_HSS_HSS6x6x38 = ["American","AISC","Square HSS","HSS6x6x3/8"]
	American_AISC_Square_HSS_HSS6x6x316 = ["American","AISC","Square HSS","HSS6x6x3/16"]
	American_AISC_Square_HSS_HSS6x6x58 = ["American","AISC","Square HSS","HSS6x6x5/8"]
	American_AISC_Square_HSS_HSS6x6x516 = ["American","AISC","Square HSS","HSS6x6x5/16"]
	American_AISC_Square_HSS_HSS7x7x12 = ["American","AISC","Square HSS","HSS7x7x1/2"]
	American_AISC_Square_HSS_HSS7x7x14 = ["American","AISC","Square HSS","HSS7x7x1/4"]
	American_AISC_Square_HSS_HSS7x7x18 = ["American","AISC","Square HSS","HSS7x7x1/8"]
	American_AISC_Square_HSS_HSS7x7x38 = ["American","AISC","Square HSS","HSS7x7x3/8"]
	American_AISC_Square_HSS_HSS7x7x316 = ["American","AISC","Square HSS","HSS7x7x3/16"]
	American_AISC_Square_HSS_HSS7x7x58 = ["American","AISC","Square HSS","HSS7x7x5/8"]
	American_AISC_Square_HSS_HSS7x7x516 = ["American","AISC","Square HSS","HSS7x7x5/16"]
	American_AISC_Square_HSS_HSS8x8x12 = ["American","AISC","Square HSS","HSS8x8x1/2"]
	American_AISC_Square_HSS_HSS8x8x14 = ["American","AISC","Square HSS","HSS8x8x1/4"]
	American_AISC_Square_HSS_HSS8x8x18 = ["American","AISC","Square HSS","HSS8x8x1/8"]
	American_AISC_Square_HSS_HSS8x8x38 = ["American","AISC","Square HSS","HSS8x8x3/8"]
	American_AISC_Square_HSS_HSS8x8x316 = ["American","AISC","Square HSS","HSS8x8x3/16"]
	American_AISC_Square_HSS_HSS8x8x58 = ["American","AISC","Square HSS","HSS8x8x5/8"]
	American_AISC_Square_HSS_HSS8x8x516 = ["American","AISC","Square HSS","HSS8x8x5/16"]
	American_AISC_Square_HSS_HSS9x9x12 = ["American","AISC","Square HSS","HSS9x9x1/2"]
	American_AISC_Square_HSS_HSS9x9x14 = ["American","AISC","Square HSS","HSS9x9x1/4"]
	American_AISC_Square_HSS_HSS9x9x18 = ["American","AISC","Square HSS","HSS9x9x1/8"]
	American_AISC_Square_HSS_HSS9x9x38 = ["American","AISC","Square HSS","HSS9x9x3/8"]
	American_AISC_Square_HSS_HSS9x9x316 = ["American","AISC","Square HSS","HSS9x9x3/16"]
	American_AISC_Square_HSS_HSS9x9x58 = ["American","AISC","Square HSS","HSS9x9x5/8"]
	American_AISC_Square_HSS_HSS9x9x516 = ["American","AISC","Square HSS","HSS9x9x5/16"]
	American_AISC_Square_HSS_HSS10x10x12 = ["American","AISC","Square HSS","HSS10x10x1/2"]
	American_AISC_Square_HSS_HSS10x10x14 = ["American","AISC","Square HSS","HSS10x10x1/4"]
	American_AISC_Square_HSS_HSS10x10x38 = ["American","AISC","Square HSS","HSS10x10x3/8"]
	American_AISC_Square_HSS_HSS10x10x316 = ["American","AISC","Square HSS","HSS10x10x3/16"]
	American_AISC_Square_HSS_HSS10x10x58 = ["American","AISC","Square HSS","HSS10x10x5/8"]
	American_AISC_Square_HSS_HSS10x10x516 = ["American","AISC","Square HSS","HSS10x10x5/16"]
	American_AISC_Square_HSS_HSS12x12x12 = ["American","AISC","Square HSS","HSS12x12x1/2"]
	American_AISC_Square_HSS_HSS12x12x14 = ["American","AISC","Square HSS","HSS12x12x1/4"]
	American_AISC_Square_HSS_HSS12x12x38 = ["American","AISC","Square HSS","HSS12x12x3/8"]
	American_AISC_Square_HSS_HSS12x12x316 = ["American","AISC","Square HSS","HSS12x12x3/16"]
	American_AISC_Square_HSS_HSS12x12x58 = ["American","AISC","Square HSS","HSS12x12x5/8"]
	American_AISC_Square_HSS_HSS12x12x516 = ["American","AISC","Square HSS","HSS12x12x5/16"]
	American_AISC_Square_HSS_HSS14x14x12 = ["American","AISC","Square HSS","HSS14x14x1/2"]
	American_AISC_Square_HSS_HSS14x14x38 = ["American","AISC","Square HSS","HSS14x14x3/8"]
	American_AISC_Square_HSS_HSS14x14x58 = ["American","AISC","Square HSS","HSS14x14x5/8"]
	American_AISC_Square_HSS_HSS14x14x516 = ["American","AISC","Square HSS","HSS14x14x5/16"]
	American_AISC_Square_HSS_HSS16x16x12 = ["American","AISC","Square HSS","HSS16x16x1/2"]
	American_AISC_Square_HSS_HSS16x16x38 = ["American","AISC","Square HSS","HSS16x16x3/8"]
	American_AISC_Square_HSS_HSS16x16x58 = ["American","AISC","Square HSS","HSS16x16x5/8"]
	American_AISC_Square_HSS_HSS16x16x516 = ["American","AISC","Square HSS","HSS16x16x5/16"]
	American_AISC_Square_tubes_obsolete_TS1_5x1_5x316 = ["American","AISC","Square tubes (obsolete)","TS1.5x1.5x3/16"]
	American_AISC_Square_tubes_obsolete_TS2_5x2_5x14 = ["American","AISC","Square tubes (obsolete)","TS2.5x2.5x1/4"]
	American_AISC_Square_tubes_obsolete_TS2_5x2_5x18 = ["American","AISC","Square tubes (obsolete)","TS2.5x2.5x1/8"]
	American_AISC_Square_tubes_obsolete_TS2_5x2_5x316 = ["American","AISC","Square tubes (obsolete)","TS2.5x2.5x3/16"]
	American_AISC_Square_tubes_obsolete_TS2_5x2_5x516 = ["American","AISC","Square tubes (obsolete)","TS2.5x2.5x5/16"]
	American_AISC_Square_tubes_obsolete_TS2x2x14 = ["American","AISC","Square tubes (obsolete)","TS2x2x1/4"]
	American_AISC_Square_tubes_obsolete_TS2x2x18 = ["American","AISC","Square tubes (obsolete)","TS2x2x1/8"]
	American_AISC_Square_tubes_obsolete_TS2x2x316 = ["American","AISC","Square tubes (obsolete)","TS2x2x3/16"]
	American_AISC_Square_tubes_obsolete_TS2x2x516 = ["American","AISC","Square tubes (obsolete)","TS2x2x5/16"]
	American_AISC_Square_tubes_obsolete_TS3_5x3_5x14 = ["American","AISC","Square tubes (obsolete)","TS3.5x3.5x1/4"]
	American_AISC_Square_tubes_obsolete_TS3_5x3_5x18 = ["American","AISC","Square tubes (obsolete)","TS3.5x3.5x1/8"]
	American_AISC_Square_tubes_obsolete_TS3_5x3_5x316 = ["American","AISC","Square tubes (obsolete)","TS3.5x3.5x3/16"]
	American_AISC_Square_tubes_obsolete_TS3_5x3_5x516 = ["American","AISC","Square tubes (obsolete)","TS3.5x3.5x5/16"]
	American_AISC_Square_tubes_obsolete_TS3x3x14 = ["American","AISC","Square tubes (obsolete)","TS3x3x1/4"]
	American_AISC_Square_tubes_obsolete_TS3x3x18 = ["American","AISC","Square tubes (obsolete)","TS3x3x1/8"]
	American_AISC_Square_tubes_obsolete_TS3x3x316 = ["American","AISC","Square tubes (obsolete)","TS3x3x3/16"]
	American_AISC_Square_tubes_obsolete_TS3x3x516 = ["American","AISC","Square tubes (obsolete)","TS3x3x5/16"]
	American_AISC_Square_tubes_obsolete_TS4_5x4_5x14 = ["American","AISC","Square tubes (obsolete)","TS4.5x4.5x1/4"]
	American_AISC_Square_tubes_obsolete_TS4_5x4_5x18 = ["American","AISC","Square tubes (obsolete)","TS4.5x4.5x1/8"]
	American_AISC_Square_tubes_obsolete_TS4_5x4_5x38 = ["American","AISC","Square tubes (obsolete)","TS4.5x4.5x3/8"]
	American_AISC_Square_tubes_obsolete_TS4_5x4_5x316 = ["American","AISC","Square tubes (obsolete)","TS4.5x4.5x3/16"]
	American_AISC_Square_tubes_obsolete_TS4_5x4_5x516 = ["American","AISC","Square tubes (obsolete)","TS4.5x4.5x5/16"]
	American_AISC_Square_tubes_obsolete_TS4x4x12 = ["American","AISC","Square tubes (obsolete)","TS4x4x1/2"]
	American_AISC_Square_tubes_obsolete_TS4x4x14 = ["American","AISC","Square tubes (obsolete)","TS4x4x1/4"]
	American_AISC_Square_tubes_obsolete_TS4x4x18 = ["American","AISC","Square tubes (obsolete)","TS4x4x1/8"]
	American_AISC_Square_tubes_obsolete_TS4x4x38 = ["American","AISC","Square tubes (obsolete)","TS4x4x3/8"]
	American_AISC_Square_tubes_obsolete_TS4x4x316 = ["American","AISC","Square tubes (obsolete)","TS4x4x3/16"]
	American_AISC_Square_tubes_obsolete_TS4x4x516 = ["American","AISC","Square tubes (obsolete)","TS4x4x5/16"]
	American_AISC_Square_tubes_obsolete_TS5_5x5_5x14 = ["American","AISC","Square tubes (obsolete)","TS5.5x5.5x1/4"]
	American_AISC_Square_tubes_obsolete_TS5_5x5_5x18 = ["American","AISC","Square tubes (obsolete)","TS5.5x5.5x1/8"]
	American_AISC_Square_tubes_obsolete_TS5_5x5_5x38 = ["American","AISC","Square tubes (obsolete)","TS5.5x5.5x3/8"]
	American_AISC_Square_tubes_obsolete_TS5_5x5_5x316 = ["American","AISC","Square tubes (obsolete)","TS5.5x5.5x3/16"]
	American_AISC_Square_tubes_obsolete_TS5_5x5_5x516 = ["American","AISC","Square tubes (obsolete)","TS5.5x5.5x5/16"]
	American_AISC_Square_tubes_obsolete_TS5x5x12 = ["American","AISC","Square tubes (obsolete)","TS5x5x1/2"]
	American_AISC_Square_tubes_obsolete_TS5x5x14 = ["American","AISC","Square tubes (obsolete)","TS5x5x1/4"]
	American_AISC_Square_tubes_obsolete_TS5x5x18 = ["American","AISC","Square tubes (obsolete)","TS5x5x1/8"]
	American_AISC_Square_tubes_obsolete_TS5x5x38 = ["American","AISC","Square tubes (obsolete)","TS5x5x3/8"]
	American_AISC_Square_tubes_obsolete_TS5x5x316 = ["American","AISC","Square tubes (obsolete)","TS5x5x3/16"]
	American_AISC_Square_tubes_obsolete_TS5x5x516 = ["American","AISC","Square tubes (obsolete)","TS5x5x5/16"]
	American_AISC_Square_tubes_obsolete_TS6x6x12 = ["American","AISC","Square tubes (obsolete)","TS6x6x1/2"]
	American_AISC_Square_tubes_obsolete_TS6x6x14 = ["American","AISC","Square tubes (obsolete)","TS6x6x1/4"]
	American_AISC_Square_tubes_obsolete_TS6x6x18 = ["American","AISC","Square tubes (obsolete)","TS6x6x1/8"]
	American_AISC_Square_tubes_obsolete_TS6x6x38 = ["American","AISC","Square tubes (obsolete)","TS6x6x3/8"]
	American_AISC_Square_tubes_obsolete_TS6x6x316 = ["American","AISC","Square tubes (obsolete)","TS6x6x3/16"]
	American_AISC_Square_tubes_obsolete_TS6x6x58 = ["American","AISC","Square tubes (obsolete)","TS6x6x5/8"]
	American_AISC_Square_tubes_obsolete_TS6x6x516 = ["American","AISC","Square tubes (obsolete)","TS6x6x5/16"]
	American_AISC_Square_tubes_obsolete_TS7x7x12 = ["American","AISC","Square tubes (obsolete)","TS7x7x1/2"]
	American_AISC_Square_tubes_obsolete_TS7x7x14 = ["American","AISC","Square tubes (obsolete)","TS7x7x1/4"]
	American_AISC_Square_tubes_obsolete_TS7x7x38 = ["American","AISC","Square tubes (obsolete)","TS7x7x3/8"]
	American_AISC_Square_tubes_obsolete_TS7x7x316 = ["American","AISC","Square tubes (obsolete)","TS7x7x3/16"]
	American_AISC_Square_tubes_obsolete_TS7x7x58 = ["American","AISC","Square tubes (obsolete)","TS7x7x5/8"]
	American_AISC_Square_tubes_obsolete_TS7x7x516 = ["American","AISC","Square tubes (obsolete)","TS7x7x5/16"]
	American_AISC_Square_tubes_obsolete_TS8x8x12 = ["American","AISC","Square tubes (obsolete)","TS8x8x1/2"]
	American_AISC_Square_tubes_obsolete_TS8x8x14 = ["American","AISC","Square tubes (obsolete)","TS8x8x1/4"]
	American_AISC_Square_tubes_obsolete_TS8x8x38 = ["American","AISC","Square tubes (obsolete)","TS8x8x3/8"]
	American_AISC_Square_tubes_obsolete_TS8x8x316 = ["American","AISC","Square tubes (obsolete)","TS8x8x3/16"]
	American_AISC_Square_tubes_obsolete_TS8x8x58 = ["American","AISC","Square tubes (obsolete)","TS8x8x5/8"]
	American_AISC_Square_tubes_obsolete_TS8x8x516 = ["American","AISC","Square tubes (obsolete)","TS8x8x5/16"]
	American_AISC_Square_tubes_obsolete_TS10x10x12 = ["American","AISC","Square tubes (obsolete)","TS10x10x1/2"]
	American_AISC_Square_tubes_obsolete_TS10x10x14 = ["American","AISC","Square tubes (obsolete)","TS10x10x1/4"]
	American_AISC_Square_tubes_obsolete_TS10x10x38 = ["American","AISC","Square tubes (obsolete)","TS10x10x3/8"]
	American_AISC_Square_tubes_obsolete_TS10x10x316 = ["American","AISC","Square tubes (obsolete)","TS10x10x3/16"]
	American_AISC_Square_tubes_obsolete_TS10x10x58 = ["American","AISC","Square tubes (obsolete)","TS10x10x5/8"]
	American_AISC_Square_tubes_obsolete_TS10x10x516 = ["American","AISC","Square tubes (obsolete)","TS10x10x5/16"]
	American_AISC_Square_tubes_obsolete_TS12x12x12 = ["American","AISC","Square tubes (obsolete)","TS12x12x1/2"]
	American_AISC_Square_tubes_obsolete_TS12x12x14 = ["American","AISC","Square tubes (obsolete)","TS12x12x1/4"]
	American_AISC_Square_tubes_obsolete_TS12x12x38 = ["American","AISC","Square tubes (obsolete)","TS12x12x3/8"]
	American_AISC_Square_tubes_obsolete_TS12x12x58 = ["American","AISC","Square tubes (obsolete)","TS12x12x5/8"]
	American_AISC_Square_tubes_obsolete_TS12x12x516 = ["American","AISC","Square tubes (obsolete)","TS12x12x5/16"]
	American_AISC_Square_tubes_obsolete_TS14x14x12 = ["American","AISC","Square tubes (obsolete)","TS14x14x1/2"]
	American_AISC_Square_tubes_obsolete_TS14x14x38 = ["American","AISC","Square tubes (obsolete)","TS14x14x3/8"]
	American_AISC_Square_tubes_obsolete_TS14x14x58 = ["American","AISC","Square tubes (obsolete)","TS14x14x5/8"]
	American_AISC_Square_tubes_obsolete_TS14x14x516 = ["American","AISC","Square tubes (obsolete)","TS14x14x5/16"]
	American_AISC_Square_tubes_obsolete_TS16x16x12 = ["American","AISC","Square tubes (obsolete)","TS16x16x1/2"]
	American_AISC_Square_tubes_obsolete_TS16x16x38 = ["American","AISC","Square tubes (obsolete)","TS16x16x3/8"]
	American_AISC_Square_tubes_obsolete_TS16x16x58 = ["American","AISC","Square tubes (obsolete)","TS16x16x5/8"]
	American_AISC_Square_tubes_obsolete_TS16x16x516 = ["American","AISC","Square tubes (obsolete)","TS16x16x5/16"]
	American_AISC_Square_tubes_obsolete_TS18x18x12 = ["American","AISC","Square tubes (obsolete)","TS18x18x1/2"]
	American_AISC_Square_tubes_obsolete_TS18x18x38 = ["American","AISC","Square tubes (obsolete)","TS18x18x3/8"]
	American_AISC_Square_tubes_obsolete_TS18x18x58 = ["American","AISC","Square tubes (obsolete)","TS18x18x5/8"]
	American_AISC_Square_tubes_obsolete_TS20x20x12 = ["American","AISC","Square tubes (obsolete)","TS20x20x1/2"]
	American_AISC_Square_tubes_obsolete_TS20x20x38 = ["American","AISC","Square tubes (obsolete)","TS20x20x3/8"]
	American_AISC_Square_tubes_obsolete_TS20x20x58 = ["American","AISC","Square tubes (obsolete)","TS20x20x5/8"]
	American_AISC_Square_tubes_obsolete_TS22x22x12 = ["American","AISC","Square tubes (obsolete)","TS22x22x1/2"]
	American_AISC_Square_tubes_obsolete_TS22x22x38 = ["American","AISC","Square tubes (obsolete)","TS22x22x3/8"]
	American_AISC_Square_tubes_obsolete_TS22x22x58 = ["American","AISC","Square tubes (obsolete)","TS22x22x5/8"]
	American_AISC_Square_tubes_obsolete_TS24x24x12 = ["American","AISC","Square tubes (obsolete)","TS24x24x1/2"]
	American_AISC_Square_tubes_obsolete_TS24x24x38 = ["American","AISC","Square tubes (obsolete)","TS24x24x3/8"]
	American_AISC_Square_tubes_obsolete_TS24x24x58 = ["American","AISC","Square tubes (obsolete)","TS24x24x5/8"]
	American_AISC_Square_tubes_obsolete_TS26x26x58 = ["American","AISC","Square tubes (obsolete)","TS26x26x5/8"]
	American_AISC_Square_tubes_obsolete_TS28x28x58 = ["American","AISC","Square tubes (obsolete)","TS28x28x5/8"]
	American_AISC_Square_tubes_obsolete_TS30x30x58 = ["American","AISC","Square tubes (obsolete)","TS30x30x5/8"]
	American_AISC_ST_shapes_ST4x11_5 = ["American","AISC","ST shapes","ST4x11.5"]
	American_AISC_ST_shapes_ST5x12_7 = ["American","AISC","ST shapes","ST5x12.7"]
	American_AISC_ST_shapes_ST5x17_5 = ["American","AISC","ST shapes","ST5x17.5"]
	American_AISC_ST_shapes_ST6x15_9 = ["American","AISC","ST shapes","ST6x15.9"]
	American_AISC_ST_shapes_ST6x17_5 = ["American","AISC","ST shapes","ST6x17.5"]
	American_AISC_ST_shapes_ST6x20_4 = ["American","AISC","ST shapes","ST6x20.4"]
	American_AISC_ST_shapes_ST6x25 = ["American","AISC","ST shapes","ST6x25"]
	American_AISC_ST_shapes_ST7_5x21_45 = ["American","AISC","ST shapes","ST7.5x21.45"]
	American_AISC_ST_shapes_ST7_5x25 = ["American","AISC","ST shapes","ST7.5x25"]
	American_AISC_ST_shapes_ST9x27_35 = ["American","AISC","ST shapes","ST9x27.35"]
	American_AISC_ST_shapes_ST9x35 = ["American","AISC","ST shapes","ST9x35"]
	American_AISC_ST_shapes_ST10x33 = ["American","AISC","ST shapes","ST10x33"]
	American_AISC_ST_shapes_ST10x37_5 = ["American","AISC","ST shapes","ST10x37.5"]
	American_AISC_ST_shapes_ST10x43 = ["American","AISC","ST shapes","ST10x43"]
	American_AISC_ST_shapes_ST10x48 = ["American","AISC","ST shapes","ST10x48"]
	American_AISC_ST_shapes_ST12x40 = ["American","AISC","ST shapes","ST12x40"]
	American_AISC_ST_shapes_ST12x45 = ["American","AISC","ST shapes","ST12x45"]
	American_AISC_ST_shapes_ST12x50 = ["American","AISC","ST shapes","ST12x50"]
	American_AISC_ST_shapes_ST12x53 = ["American","AISC","ST shapes","ST12x53"]
	American_AISC_ST_shapes_ST12x60_5 = ["American","AISC","ST shapes","ST12x60.5"]
	American_AISC_Unequal_angles_L2_5x1_5x14 = ["American","AISC","Unequal angles","L2.5x1.5x1/4"]
	American_AISC_Unequal_angles_L2_5x1_5x316 = ["American","AISC","Unequal angles","L2.5x1.5x3/16"]
	American_AISC_Unequal_angles_L2_5x2x14 = ["American","AISC","Unequal angles","L2.5x2x1/4"]
	American_AISC_Unequal_angles_L2_5x2x38 = ["American","AISC","Unequal angles","L2.5x2x3/8"]
	American_AISC_Unequal_angles_L2_5x2x316 = ["American","AISC","Unequal angles","L2.5x2x3/16"]
	American_AISC_Unequal_angles_L2_5x2x516 = ["American","AISC","Unequal angles","L2.5x2x5/16"]
	American_AISC_Unequal_angles_L3_5x2_5x12 = ["American","AISC","Unequal angles","L3.5x2.5x1/2"]
	American_AISC_Unequal_angles_L3_5x2_5x14 = ["American","AISC","Unequal angles","L3.5x2.5x1/4"]
	American_AISC_Unequal_angles_L3_5x2_5x38 = ["American","AISC","Unequal angles","L3.5x2.5x3/8"]
	American_AISC_Unequal_angles_L3_5x2_5x516 = ["American","AISC","Unequal angles","L3.5x2.5x5/16"]
	American_AISC_Unequal_angles_L3_5x3x12 = ["American","AISC","Unequal angles","L3.5x3x1/2"]
	American_AISC_Unequal_angles_L3_5x3x14 = ["American","AISC","Unequal angles","L3.5x3x1/4"]
	American_AISC_Unequal_angles_L3_5x3x38 = ["American","AISC","Unequal angles","L3.5x3x3/8"]
	American_AISC_Unequal_angles_L3_5x3x516 = ["American","AISC","Unequal angles","L3.5x3x5/16"]
	American_AISC_Unequal_angles_L3_5x3x716 = ["American","AISC","Unequal angles","L3.5x3x7/16"]
	American_AISC_Unequal_angles_L3x2_5x12 = ["American","AISC","Unequal angles","L3x2.5x1/2"]
	American_AISC_Unequal_angles_L3x2_5x14 = ["American","AISC","Unequal angles","L3x2.5x1/4"]
	American_AISC_Unequal_angles_L3x2_5x38 = ["American","AISC","Unequal angles","L3x2.5x3/8"]
	American_AISC_Unequal_angles_L3x2_5x316 = ["American","AISC","Unequal angles","L3x2.5x3/16"]
	American_AISC_Unequal_angles_L3x2_5x516 = ["American","AISC","Unequal angles","L3x2.5x5/16"]
	American_AISC_Unequal_angles_L3x2_5x716 = ["American","AISC","Unequal angles","L3x2.5x7/16"]
	American_AISC_Unequal_angles_L3x2x12 = ["American","AISC","Unequal angles","L3x2x1/2"]
	American_AISC_Unequal_angles_L3x2x14 = ["American","AISC","Unequal angles","L3x2x1/4"]
	American_AISC_Unequal_angles_L3x2x38 = ["American","AISC","Unequal angles","L3x2x3/8"]
	American_AISC_Unequal_angles_L3x2x316 = ["American","AISC","Unequal angles","L3x2x3/16"]
	American_AISC_Unequal_angles_L3x2x516 = ["American","AISC","Unequal angles","L3x2x5/16"]
	American_AISC_Unequal_angles_L4x3_5x12 = ["American","AISC","Unequal angles","L4x3.5x1/2"]
	American_AISC_Unequal_angles_L4x3_5x14 = ["American","AISC","Unequal angles","L4x3.5x1/4"]
	American_AISC_Unequal_angles_L4x3_5x38 = ["American","AISC","Unequal angles","L4x3.5x3/8"]
	American_AISC_Unequal_angles_L4x3_5x516 = ["American","AISC","Unequal angles","L4x3.5x5/16"]
	American_AISC_Unequal_angles_L4x3x12 = ["American","AISC","Unequal angles","L4x3x1/2"]
	American_AISC_Unequal_angles_L4x3x14 = ["American","AISC","Unequal angles","L4x3x1/4"]
	American_AISC_Unequal_angles_L4x3x38 = ["American","AISC","Unequal angles","L4x3x3/8"]
	American_AISC_Unequal_angles_L4x3x58 = ["American","AISC","Unequal angles","L4x3x5/8"]
	American_AISC_Unequal_angles_L4x3x516 = ["American","AISC","Unequal angles","L4x3x5/16"]
	American_AISC_Unequal_angles_L4x3x716 = ["American","AISC","Unequal angles","L4x3x7/16"]
	American_AISC_Unequal_angles_L5x3_5x12 = ["American","AISC","Unequal angles","L5x3.5x1/2"]
	American_AISC_Unequal_angles_L5x3_5x14 = ["American","AISC","Unequal angles","L5x3.5x1/4"]
	American_AISC_Unequal_angles_L5x3_5x34 = ["American","AISC","Unequal angles","L5x3.5x3/4"]
	American_AISC_Unequal_angles_L5x3_5x38 = ["American","AISC","Unequal angles","L5x3.5x3/8"]
	American_AISC_Unequal_angles_L5x3_5x58 = ["American","AISC","Unequal angles","L5x3.5x5/8"]
	American_AISC_Unequal_angles_L5x3_5x516 = ["American","AISC","Unequal angles","L5x3.5x5/16"]
	American_AISC_Unequal_angles_L5x3x12 = ["American","AISC","Unequal angles","L5x3x1/2"]
	American_AISC_Unequal_angles_L5x3x14 = ["American","AISC","Unequal angles","L5x3x1/4"]
	American_AISC_Unequal_angles_L5x3x38 = ["American","AISC","Unequal angles","L5x3x3/8"]
	American_AISC_Unequal_angles_L5x3x516 = ["American","AISC","Unequal angles","L5x3x5/16"]
	American_AISC_Unequal_angles_L5x3x716 = ["American","AISC","Unequal angles","L5x3x7/16"]
	American_AISC_Unequal_angles_L6x3_5x12 = ["American","AISC","Unequal angles","L6x3.5x1/2"]
	American_AISC_Unequal_angles_L6x3_5x38 = ["American","AISC","Unequal angles","L6x3.5x3/8"]
	American_AISC_Unequal_angles_L6x3_5x516 = ["American","AISC","Unequal angles","L6x3.5x5/16"]
	American_AISC_Unequal_angles_L6x4x12 = ["American","AISC","Unequal angles","L6x4x1/2"]
	American_AISC_Unequal_angles_L6x4x34 = ["American","AISC","Unequal angles","L6x4x3/4"]
	American_AISC_Unequal_angles_L6x4x38 = ["American","AISC","Unequal angles","L6x4x3/8"]
	American_AISC_Unequal_angles_L6x4x58 = ["American","AISC","Unequal angles","L6x4x5/8"]
	American_AISC_Unequal_angles_L6x4x516 = ["American","AISC","Unequal angles","L6x4x5/16"]
	American_AISC_Unequal_angles_L6x4x78 = ["American","AISC","Unequal angles","L6x4x7/8"]
	American_AISC_Unequal_angles_L6x4x716 = ["American","AISC","Unequal angles","L6x4x7/16"]
	American_AISC_Unequal_angles_L6x4x916 = ["American","AISC","Unequal angles","L6x4x9/16"]
	American_AISC_Unequal_angles_L7x4x12 = ["American","AISC","Unequal angles","L7x4x1/2"]
	American_AISC_Unequal_angles_L7x4x34 = ["American","AISC","Unequal angles","L7x4x3/4"]
	American_AISC_Unequal_angles_L7x4x38 = ["American","AISC","Unequal angles","L7x4x3/8"]
	American_AISC_Unequal_angles_L7x4x58 = ["American","AISC","Unequal angles","L7x4x5/8"]
	American_AISC_Unequal_angles_L7x4x716 = ["American","AISC","Unequal angles","L7x4x7/16"]
	American_AISC_Unequal_angles_L8x4x1 = ["American","AISC","Unequal angles","L8x4x1"]
	American_AISC_Unequal_angles_L8x4x12 = ["American","AISC","Unequal angles","L8x4x1/2"]
	American_AISC_Unequal_angles_L8x4x34 = ["American","AISC","Unequal angles","L8x4x3/4"]
	American_AISC_Unequal_angles_L8x4x58 = ["American","AISC","Unequal angles","L8x4x5/8"]
	American_AISC_Unequal_angles_L8x4x78 = ["American","AISC","Unequal angles","L8x4x7/8"]
	American_AISC_Unequal_angles_L8x4x716 = ["American","AISC","Unequal angles","L8x4x7/16"]
	American_AISC_Unequal_angles_L8x4x916 = ["American","AISC","Unequal angles","L8x4x9/16"]
	American_AISC_Unequal_angles_L8x6x1 = ["American","AISC","Unequal angles","L8x6x1"]
	American_AISC_Unequal_angles_L8x6x12 = ["American","AISC","Unequal angles","L8x6x1/2"]
	American_AISC_Unequal_angles_L8x6x34 = ["American","AISC","Unequal angles","L8x6x3/4"]
	American_AISC_Unequal_angles_L8x6x58 = ["American","AISC","Unequal angles","L8x6x5/8"]
	American_AISC_Unequal_angles_L8x6x78 = ["American","AISC","Unequal angles","L8x6x7/8"]
	American_AISC_Unequal_angles_L8x6x716 = ["American","AISC","Unequal angles","L8x6x7/16"]
	American_AISC_Unequal_angles_L8x6x916 = ["American","AISC","Unequal angles","L8x6x9/16"]
	American_AISC_W_shapes_W4x13 = ["American","AISC","W shapes","W4x13"]
	American_AISC_W_shapes_W5x16 = ["American","AISC","W shapes","W5x16"]
	American_AISC_W_shapes_W5x19 = ["American","AISC","W shapes","W5x19"]
	American_AISC_W_shapes_W6x8_5 = ["American","AISC","W shapes","W6x8.5"]
	American_AISC_W_shapes_W6x9 = ["American","AISC","W shapes","W6x9"]
	American_AISC_W_shapes_W6x12 = ["American","AISC","W shapes","W6x12"]
	American_AISC_W_shapes_W6x15 = ["American","AISC","W shapes","W6x15"]
	American_AISC_W_shapes_W6x16 = ["American","AISC","W shapes","W6x16"]
	American_AISC_W_shapes_W6x20 = ["American","AISC","W shapes","W6x20"]
	American_AISC_W_shapes_W6x25 = ["American","AISC","W shapes","W6x25"]
	American_AISC_W_shapes_W8x10 = ["American","AISC","W shapes","W8x10"]
	American_AISC_W_shapes_W8x13 = ["American","AISC","W shapes","W8x13"]
	American_AISC_W_shapes_W8x15 = ["American","AISC","W shapes","W8x15"]
	American_AISC_W_shapes_W8x18 = ["American","AISC","W shapes","W8x18"]
	American_AISC_W_shapes_W8x21 = ["American","AISC","W shapes","W8x21"]
	American_AISC_W_shapes_W8x24 = ["American","AISC","W shapes","W8x24"]
	American_AISC_W_shapes_W8x28 = ["American","AISC","W shapes","W8x28"]
	American_AISC_W_shapes_W8x31 = ["American","AISC","W shapes","W8x31"]
	American_AISC_W_shapes_W8x35 = ["American","AISC","W shapes","W8x35"]
	American_AISC_W_shapes_W8x40 = ["American","AISC","W shapes","W8x40"]
	American_AISC_W_shapes_W8x48 = ["American","AISC","W shapes","W8x48"]
	American_AISC_W_shapes_W8x58 = ["American","AISC","W shapes","W8x58"]
	American_AISC_W_shapes_W8x67 = ["American","AISC","W shapes","W8x67"]
	American_AISC_W_shapes_W10x12 = ["American","AISC","W shapes","W10x12"]
	American_AISC_W_shapes_W10x15 = ["American","AISC","W shapes","W10x15"]
	American_AISC_W_shapes_W10x17 = ["American","AISC","W shapes","W10x17"]
	American_AISC_W_shapes_W10x19 = ["American","AISC","W shapes","W10x19"]
	American_AISC_W_shapes_W10x22 = ["American","AISC","W shapes","W10x22"]
	American_AISC_W_shapes_W10x26 = ["American","AISC","W shapes","W10x26"]
	American_AISC_W_shapes_W10x30 = ["American","AISC","W shapes","W10x30"]
	American_AISC_W_shapes_W10x33 = ["American","AISC","W shapes","W10x33"]
	American_AISC_W_shapes_W10x39 = ["American","AISC","W shapes","W10x39"]
	American_AISC_W_shapes_W10x45 = ["American","AISC","W shapes","W10x45"]
	American_AISC_W_shapes_W10x49 = ["American","AISC","W shapes","W10x49"]
	American_AISC_W_shapes_W10x54 = ["American","AISC","W shapes","W10x54"]
	American_AISC_W_shapes_W10x60 = ["American","AISC","W shapes","W10x60"]
	American_AISC_W_shapes_W10x68 = ["American","AISC","W shapes","W10x68"]
	American_AISC_W_shapes_W10x77 = ["American","AISC","W shapes","W10x77"]
	American_AISC_W_shapes_W10x88 = ["American","AISC","W shapes","W10x88"]
	American_AISC_W_shapes_W10x100 = ["American","AISC","W shapes","W10x100"]
	American_AISC_W_shapes_W10x112 = ["American","AISC","W shapes","W10x112"]
	American_AISC_W_shapes_W12x14 = ["American","AISC","W shapes","W12x14"]
	American_AISC_W_shapes_W12x16 = ["American","AISC","W shapes","W12x16"]
	American_AISC_W_shapes_W12x19 = ["American","AISC","W shapes","W12x19"]
	American_AISC_W_shapes_W12x22 = ["American","AISC","W shapes","W12x22"]
	American_AISC_W_shapes_W12x26 = ["American","AISC","W shapes","W12x26"]
	American_AISC_W_shapes_W12x30 = ["American","AISC","W shapes","W12x30"]
	American_AISC_W_shapes_W12x35 = ["American","AISC","W shapes","W12x35"]
	American_AISC_W_shapes_W12x40 = ["American","AISC","W shapes","W12x40"]
	American_AISC_W_shapes_W12x45 = ["American","AISC","W shapes","W12x45"]
	American_AISC_W_shapes_W12x50 = ["American","AISC","W shapes","W12x50"]
	American_AISC_W_shapes_W12x53 = ["American","AISC","W shapes","W12x53"]
	American_AISC_W_shapes_W12x58 = ["American","AISC","W shapes","W12x58"]
	American_AISC_W_shapes_W12x65 = ["American","AISC","W shapes","W12x65"]
	American_AISC_W_shapes_W12x72 = ["American","AISC","W shapes","W12x72"]
	American_AISC_W_shapes_W12x79 = ["American","AISC","W shapes","W12x79"]
	American_AISC_W_shapes_W12x87 = ["American","AISC","W shapes","W12x87"]
	American_AISC_W_shapes_W12x96 = ["American","AISC","W shapes","W12x96"]
	American_AISC_W_shapes_W12x106 = ["American","AISC","W shapes","W12x106"]
	American_AISC_W_shapes_W12x120 = ["American","AISC","W shapes","W12x120"]
	American_AISC_W_shapes_W12x136 = ["American","AISC","W shapes","W12x136"]
	American_AISC_W_shapes_W12x152 = ["American","AISC","W shapes","W12x152"]
	American_AISC_W_shapes_W12x170 = ["American","AISC","W shapes","W12x170"]
	American_AISC_W_shapes_W12x190 = ["American","AISC","W shapes","W12x190"]
	American_AISC_W_shapes_W12x210 = ["American","AISC","W shapes","W12x210"]
	American_AISC_W_shapes_W12x230 = ["American","AISC","W shapes","W12x230"]
	American_AISC_W_shapes_W12x252 = ["American","AISC","W shapes","W12x252"]
	American_AISC_W_shapes_W12x279 = ["American","AISC","W shapes","W12x279"]
	American_AISC_W_shapes_W12x305 = ["American","AISC","W shapes","W12x305"]
	American_AISC_W_shapes_W12x336 = ["American","AISC","W shapes","W12x336"]
	American_AISC_W_shapes_W14x22 = ["American","AISC","W shapes","W14x22"]
	American_AISC_W_shapes_W14x26 = ["American","AISC","W shapes","W14x26"]
	American_AISC_W_shapes_W14x30 = ["American","AISC","W shapes","W14x30"]
	American_AISC_W_shapes_W14x34 = ["American","AISC","W shapes","W14x34"]
	American_AISC_W_shapes_W14x38 = ["American","AISC","W shapes","W14x38"]
	American_AISC_W_shapes_W14x43 = ["American","AISC","W shapes","W14x43"]
	American_AISC_W_shapes_W14x48 = ["American","AISC","W shapes","W14x48"]
	American_AISC_W_shapes_W14x53 = ["American","AISC","W shapes","W14x53"]
	American_AISC_W_shapes_W14x61 = ["American","AISC","W shapes","W14x61"]
	American_AISC_W_shapes_W14x68 = ["American","AISC","W shapes","W14x68"]
	American_AISC_W_shapes_W14x74 = ["American","AISC","W shapes","W14x74"]
	American_AISC_W_shapes_W14x82 = ["American","AISC","W shapes","W14x82"]
	American_AISC_W_shapes_W14x90 = ["American","AISC","W shapes","W14x90"]
	American_AISC_W_shapes_W14x99 = ["American","AISC","W shapes","W14x99"]
	American_AISC_W_shapes_W14x109 = ["American","AISC","W shapes","W14x109"]
	American_AISC_W_shapes_W14x120 = ["American","AISC","W shapes","W14x120"]
	American_AISC_W_shapes_W14x132 = ["American","AISC","W shapes","W14x132"]
	American_AISC_W_shapes_W14x145 = ["American","AISC","W shapes","W14x145"]
	American_AISC_W_shapes_W14x159 = ["American","AISC","W shapes","W14x159"]
	American_AISC_W_shapes_W14x176 = ["American","AISC","W shapes","W14x176"]
	American_AISC_W_shapes_W14x193 = ["American","AISC","W shapes","W14x193"]
	American_AISC_W_shapes_W14x211 = ["American","AISC","W shapes","W14x211"]
	American_AISC_W_shapes_W14x233 = ["American","AISC","W shapes","W14x233"]
	American_AISC_W_shapes_W14x257 = ["American","AISC","W shapes","W14x257"]
	American_AISC_W_shapes_W14x283 = ["American","AISC","W shapes","W14x283"]
	American_AISC_W_shapes_W14x311 = ["American","AISC","W shapes","W14x311"]
	American_AISC_W_shapes_W14x342 = ["American","AISC","W shapes","W14x342"]
	American_AISC_W_shapes_W14x370 = ["American","AISC","W shapes","W14x370"]
	American_AISC_W_shapes_W14x398 = ["American","AISC","W shapes","W14x398"]
	American_AISC_W_shapes_W14x426 = ["American","AISC","W shapes","W14x426"]
	American_AISC_W_shapes_W14x455 = ["American","AISC","W shapes","W14x455"]
	American_AISC_W_shapes_W14x500 = ["American","AISC","W shapes","W14x500"]
	American_AISC_W_shapes_W14x550 = ["American","AISC","W shapes","W14x550"]
	American_AISC_W_shapes_W14x605 = ["American","AISC","W shapes","W14x605"]
	American_AISC_W_shapes_W14x665 = ["American","AISC","W shapes","W14x665"]
	American_AISC_W_shapes_W14x730 = ["American","AISC","W shapes","W14x730"]
	American_AISC_W_shapes_W14x808 = ["American","AISC","W shapes","W14x808"]
	American_AISC_W_shapes_W16x26 = ["American","AISC","W shapes","W16x26"]
	American_AISC_W_shapes_W16x31 = ["American","AISC","W shapes","W16x31"]
	American_AISC_W_shapes_W16x36 = ["American","AISC","W shapes","W16x36"]
	American_AISC_W_shapes_W16x40 = ["American","AISC","W shapes","W16x40"]
	American_AISC_W_shapes_W16x45 = ["American","AISC","W shapes","W16x45"]
	American_AISC_W_shapes_W16x50 = ["American","AISC","W shapes","W16x50"]
	American_AISC_W_shapes_W16x57 = ["American","AISC","W shapes","W16x57"]
	American_AISC_W_shapes_W16x67 = ["American","AISC","W shapes","W16x67"]
	American_AISC_W_shapes_W16x77 = ["American","AISC","W shapes","W16x77"]
	American_AISC_W_shapes_W16x89 = ["American","AISC","W shapes","W16x89"]
	American_AISC_W_shapes_W16x100 = ["American","AISC","W shapes","W16x100"]
	American_AISC_W_shapes_W18x35 = ["American","AISC","W shapes","W18x35"]
	American_AISC_W_shapes_W18x40 = ["American","AISC","W shapes","W18x40"]
	American_AISC_W_shapes_W18x46 = ["American","AISC","W shapes","W18x46"]
	American_AISC_W_shapes_W18x50 = ["American","AISC","W shapes","W18x50"]
	American_AISC_W_shapes_W18x55 = ["American","AISC","W shapes","W18x55"]
	American_AISC_W_shapes_W18x60 = ["American","AISC","W shapes","W18x60"]
	American_AISC_W_shapes_W18x65 = ["American","AISC","W shapes","W18x65"]
	American_AISC_W_shapes_W18x71 = ["American","AISC","W shapes","W18x71"]
	American_AISC_W_shapes_W18x76 = ["American","AISC","W shapes","W18x76"]
	American_AISC_W_shapes_W18x86 = ["American","AISC","W shapes","W18x86"]
	American_AISC_W_shapes_W18x97 = ["American","AISC","W shapes","W18x97"]
	American_AISC_W_shapes_W18x106 = ["American","AISC","W shapes","W18x106"]
	American_AISC_W_shapes_W18x119 = ["American","AISC","W shapes","W18x119"]
	American_AISC_W_shapes_W18x130 = ["American","AISC","W shapes","W18x130"]
	American_AISC_W_shapes_W18x143 = ["American","AISC","W shapes","W18x143"]
	American_AISC_W_shapes_W18x158 = ["American","AISC","W shapes","W18x158"]
	American_AISC_W_shapes_W18x175 = ["American","AISC","W shapes","W18x175"]
	American_AISC_W_shapes_W18x192 = ["American","AISC","W shapes","W18x192"]
	American_AISC_W_shapes_W18x211 = ["American","AISC","W shapes","W18x211"]
	American_AISC_W_shapes_W18x234 = ["American","AISC","W shapes","W18x234"]
	American_AISC_W_shapes_W18x258 = ["American","AISC","W shapes","W18x258"]
	American_AISC_W_shapes_W18x283 = ["American","AISC","W shapes","W18x283"]
	American_AISC_W_shapes_W18x311 = ["American","AISC","W shapes","W18x311"]
	American_AISC_W_shapes_W21x44 = ["American","AISC","W shapes","W21x44"]
	American_AISC_W_shapes_W21x48 = ["American","AISC","W shapes","W21x48"]
	American_AISC_W_shapes_W21x50 = ["American","AISC","W shapes","W21x50"]
	American_AISC_W_shapes_W21x55 = ["American","AISC","W shapes","W21x55"]
	American_AISC_W_shapes_W21x57 = ["American","AISC","W shapes","W21x57"]
	American_AISC_W_shapes_W21x62 = ["American","AISC","W shapes","W21x62"]
	American_AISC_W_shapes_W21x68 = ["American","AISC","W shapes","W21x68"]
	American_AISC_W_shapes_W21x73 = ["American","AISC","W shapes","W21x73"]
	American_AISC_W_shapes_W21x83 = ["American","AISC","W shapes","W21x83"]
	American_AISC_W_shapes_W21x93 = ["American","AISC","W shapes","W21x93"]
	American_AISC_W_shapes_W21x101 = ["American","AISC","W shapes","W21x101"]
	American_AISC_W_shapes_W21x111 = ["American","AISC","W shapes","W21x111"]
	American_AISC_W_shapes_W21x122 = ["American","AISC","W shapes","W21x122"]
	American_AISC_W_shapes_W21x132 = ["American","AISC","W shapes","W21x132"]
	American_AISC_W_shapes_W21x147 = ["American","AISC","W shapes","W21x147"]
	American_AISC_W_shapes_W21x166 = ["American","AISC","W shapes","W21x166"]
	American_AISC_W_shapes_W21x182 = ["American","AISC","W shapes","W21x182"]
	American_AISC_W_shapes_W21x201 = ["American","AISC","W shapes","W21x201"]
	American_AISC_W_shapes_W24x55 = ["American","AISC","W shapes","W24x55"]
	American_AISC_W_shapes_W24x62 = ["American","AISC","W shapes","W24x62"]
	American_AISC_W_shapes_W24x68 = ["American","AISC","W shapes","W24x68"]
	American_AISC_W_shapes_W24x76 = ["American","AISC","W shapes","W24x76"]
	American_AISC_W_shapes_W24x84 = ["American","AISC","W shapes","W24x84"]
	American_AISC_W_shapes_W24x94 = ["American","AISC","W shapes","W24x94"]
	American_AISC_W_shapes_W24x103 = ["American","AISC","W shapes","W24x103"]
	American_AISC_W_shapes_W24x104 = ["American","AISC","W shapes","W24x104"]
	American_AISC_W_shapes_W24x117 = ["American","AISC","W shapes","W24x117"]
	American_AISC_W_shapes_W24x131 = ["American","AISC","W shapes","W24x131"]
	American_AISC_W_shapes_W24x146 = ["American","AISC","W shapes","W24x146"]
	American_AISC_W_shapes_W24x162 = ["American","AISC","W shapes","W24x162"]
	American_AISC_W_shapes_W24x176 = ["American","AISC","W shapes","W24x176"]
	American_AISC_W_shapes_W24x192 = ["American","AISC","W shapes","W24x192"]
	American_AISC_W_shapes_W24x207 = ["American","AISC","W shapes","W24x207"]
	American_AISC_W_shapes_W24x229 = ["American","AISC","W shapes","W24x229"]
	American_AISC_W_shapes_W24x250 = ["American","AISC","W shapes","W24x250"]
	American_AISC_W_shapes_W24x279 = ["American","AISC","W shapes","W24x279"]
	American_AISC_W_shapes_W24x306 = ["American","AISC","W shapes","W24x306"]
	American_AISC_W_shapes_W24x335 = ["American","AISC","W shapes","W24x335"]
	American_AISC_W_shapes_W24x370 = ["American","AISC","W shapes","W24x370"]
	American_AISC_W_shapes_W24x408 = ["American","AISC","W shapes","W24x408"]
	American_AISC_W_shapes_W24x492 = ["American","AISC","W shapes","W24x492"]
	American_AISC_W_shapes_W27x84 = ["American","AISC","W shapes","W27x84"]
	American_AISC_W_shapes_W27x94 = ["American","AISC","W shapes","W27x94"]
	American_AISC_W_shapes_W27x102 = ["American","AISC","W shapes","W27x102"]
	American_AISC_W_shapes_W27x114 = ["American","AISC","W shapes","W27x114"]
	American_AISC_W_shapes_W27x129 = ["American","AISC","W shapes","W27x129"]
	American_AISC_W_shapes_W27x146 = ["American","AISC","W shapes","W27x146"]
	American_AISC_W_shapes_W27x161 = ["American","AISC","W shapes","W27x161"]
	American_AISC_W_shapes_W27x178 = ["American","AISC","W shapes","W27x178"]
	American_AISC_W_shapes_W27x194 = ["American","AISC","W shapes","W27x194"]
	American_AISC_W_shapes_W27x217 = ["American","AISC","W shapes","W27x217"]
	American_AISC_W_shapes_W27x235 = ["American","AISC","W shapes","W27x235"]
	American_AISC_W_shapes_W27x258 = ["American","AISC","W shapes","W27x258"]
	American_AISC_W_shapes_W27x281 = ["American","AISC","W shapes","W27x281"]
	American_AISC_W_shapes_W27x307 = ["American","AISC","W shapes","W27x307"]
	American_AISC_W_shapes_W27x336 = ["American","AISC","W shapes","W27x336"]
	American_AISC_W_shapes_W27x368 = ["American","AISC","W shapes","W27x368"]
	American_AISC_W_shapes_W27x448 = ["American","AISC","W shapes","W27x448"]
	American_AISC_W_shapes_W27x539 = ["American","AISC","W shapes","W27x539"]
	American_AISC_W_shapes_W30x90 = ["American","AISC","W shapes","W30x90"]
	American_AISC_W_shapes_W30x99 = ["American","AISC","W shapes","W30x99"]
	American_AISC_W_shapes_W30x108 = ["American","AISC","W shapes","W30x108"]
	American_AISC_W_shapes_W30x116 = ["American","AISC","W shapes","W30x116"]
	American_AISC_W_shapes_W30x124 = ["American","AISC","W shapes","W30x124"]
	American_AISC_W_shapes_W30x132 = ["American","AISC","W shapes","W30x132"]
	American_AISC_W_shapes_W30x148 = ["American","AISC","W shapes","W30x148"]
	American_AISC_W_shapes_W30x173 = ["American","AISC","W shapes","W30x173"]
	American_AISC_W_shapes_W30x191 = ["American","AISC","W shapes","W30x191"]
	American_AISC_W_shapes_W30x211 = ["American","AISC","W shapes","W30x211"]
	American_AISC_W_shapes_W30x235 = ["American","AISC","W shapes","W30x235"]
	American_AISC_W_shapes_W30x261 = ["American","AISC","W shapes","W30x261"]
	American_AISC_W_shapes_W30x292 = ["American","AISC","W shapes","W30x292"]
	American_AISC_W_shapes_W30x326 = ["American","AISC","W shapes","W30x326"]
	American_AISC_W_shapes_W30x357 = ["American","AISC","W shapes","W30x357"]
	American_AISC_W_shapes_W30x391 = ["American","AISC","W shapes","W30x391"]
	American_AISC_W_shapes_W30x477 = ["American","AISC","W shapes","W30x477"]
	American_AISC_W_shapes_W33x118 = ["American","AISC","W shapes","W33x118"]
	American_AISC_W_shapes_W33x130 = ["American","AISC","W shapes","W33x130"]
	American_AISC_W_shapes_W33x141 = ["American","AISC","W shapes","W33x141"]
	American_AISC_W_shapes_W33x152 = ["American","AISC","W shapes","W33x152"]
	American_AISC_W_shapes_W33x169 = ["American","AISC","W shapes","W33x169"]
	American_AISC_W_shapes_W33x201 = ["American","AISC","W shapes","W33x201"]
	American_AISC_W_shapes_W33x221 = ["American","AISC","W shapes","W33x221"]
	American_AISC_W_shapes_W33x241 = ["American","AISC","W shapes","W33x241"]
	American_AISC_W_shapes_W33x263 = ["American","AISC","W shapes","W33x263"]
	American_AISC_W_shapes_W33x291 = ["American","AISC","W shapes","W33x291"]
	American_AISC_W_shapes_W33x318 = ["American","AISC","W shapes","W33x318"]
	American_AISC_W_shapes_W33x354 = ["American","AISC","W shapes","W33x354"]
	American_AISC_W_shapes_W33x387 = ["American","AISC","W shapes","W33x387"]
	American_AISC_W_shapes_W36x135 = ["American","AISC","W shapes","W36x135"]
	American_AISC_W_shapes_W36x150 = ["American","AISC","W shapes","W36x150"]
	American_AISC_W_shapes_W36x160 = ["American","AISC","W shapes","W36x160"]
	American_AISC_W_shapes_W36x170 = ["American","AISC","W shapes","W36x170"]
	American_AISC_W_shapes_W36x182 = ["American","AISC","W shapes","W36x182"]
	American_AISC_W_shapes_W36x194 = ["American","AISC","W shapes","W36x194"]
	American_AISC_W_shapes_W36x210 = ["American","AISC","W shapes","W36x210"]
	American_AISC_W_shapes_W36x230 = ["American","AISC","W shapes","W36x230"]
	American_AISC_W_shapes_W36x231 = ["American","AISC","W shapes","W36x231"]
	American_AISC_W_shapes_W36x232 = ["American","AISC","W shapes","W36x232"]
	American_AISC_W_shapes_W36x245 = ["American","AISC","W shapes","W36x245"]
	American_AISC_W_shapes_W36x247 = ["American","AISC","W shapes","W36x247"]
	American_AISC_W_shapes_W36x256 = ["American","AISC","W shapes","W36x256"]
	American_AISC_W_shapes_W36x260 = ["American","AISC","W shapes","W36x260"]
	American_AISC_W_shapes_W36x262 = ["American","AISC","W shapes","W36x262"]
	American_AISC_W_shapes_W36x280 = ["American","AISC","W shapes","W36x280"]
	American_AISC_W_shapes_W36x282 = ["American","AISC","W shapes","W36x282"]
	American_AISC_W_shapes_W36x300 = ["American","AISC","W shapes","W36x300"]
	American_AISC_W_shapes_W36x302 = ["American","AISC","W shapes","W36x302"]
	American_AISC_W_shapes_W36x328 = ["American","AISC","W shapes","W36x328"]
	American_AISC_W_shapes_W36x330 = ["American","AISC","W shapes","W36x330"]
	American_AISC_W_shapes_W36x359 = ["American","AISC","W shapes","W36x359"]
	American_AISC_W_shapes_W36x361 = ["American","AISC","W shapes","W36x361"]
	American_AISC_W_shapes_W36x393 = ["American","AISC","W shapes","W36x393"]
	American_AISC_W_shapes_W36x395 = ["American","AISC","W shapes","W36x395"]
	American_AISC_W_shapes_W36x439 = ["American","AISC","W shapes","W36x439"]
	American_AISC_W_shapes_W36x441 = ["American","AISC","W shapes","W36x441"]
	American_AISC_W_shapes_W36x487 = ["American","AISC","W shapes","W36x487"]
	American_AISC_W_shapes_W36x527 = ["American","AISC","W shapes","W36x527"]
	American_AISC_W_shapes_W36x529 = ["American","AISC","W shapes","W36x529"]
	American_AISC_W_shapes_W36x650 = ["American","AISC","W shapes","W36x650"]
	American_AISC_W_shapes_W36x652 = ["American","AISC","W shapes","W36x652"]
	American_AISC_W_shapes_W36x798 = ["American","AISC","W shapes","W36x798"]
	American_AISC_W_shapes_W36x848 = ["American","AISC","W shapes","W36x848"]
	American_AISC_W_shapes_W40x149 = ["American","AISC","W shapes","W40x149"]
	American_AISC_W_shapes_W40x167 = ["American","AISC","W shapes","W40x167"]
	American_AISC_W_shapes_W40x174 = ["American","AISC","W shapes","W40x174"]
	American_AISC_W_shapes_W40x183 = ["American","AISC","W shapes","W40x183"]
	American_AISC_W_shapes_W40x199 = ["American","AISC","W shapes","W40x199"]
	American_AISC_W_shapes_W40x211 = ["American","AISC","W shapes","W40x211"]
	American_AISC_W_shapes_W40x215 = ["American","AISC","W shapes","W40x215"]
	American_AISC_W_shapes_W40x235 = ["American","AISC","W shapes","W40x235"]
	American_AISC_W_shapes_W40x249 = ["American","AISC","W shapes","W40x249"]
	American_AISC_W_shapes_W40x264 = ["American","AISC","W shapes","W40x264"]
	American_AISC_W_shapes_W40x277 = ["American","AISC","W shapes","W40x277"]
	American_AISC_W_shapes_W40x278 = ["American","AISC","W shapes","W40x278"]
	American_AISC_W_shapes_W40x294 = ["American","AISC","W shapes","W40x294"]
	American_AISC_W_shapes_W40x297 = ["American","AISC","W shapes","W40x297"]
	American_AISC_W_shapes_W40x321 = ["American","AISC","W shapes","W40x321"]
	American_AISC_W_shapes_W40x327 = ["American","AISC","W shapes","W40x327"]
	American_AISC_W_shapes_W40x331 = ["American","AISC","W shapes","W40x331"]
	American_AISC_W_shapes_W40x362 = ["American","AISC","W shapes","W40x362"]
	American_AISC_W_shapes_W40x372 = ["American","AISC","W shapes","W40x372"]
	American_AISC_W_shapes_W40x392 = ["American","AISC","W shapes","W40x392"]
	American_AISC_W_shapes_W40x397 = ["American","AISC","W shapes","W40x397"]
	American_AISC_W_shapes_W40x431 = ["American","AISC","W shapes","W40x431"]
	American_AISC_W_shapes_W40x466 = ["American","AISC","W shapes","W40x466"]
	American_AISC_W_shapes_W40x503 = ["American","AISC","W shapes","W40x503"]
	American_AISC_W_shapes_W40x593 = ["American","AISC","W shapes","W40x593"]
	American_AISC_W_shapes_W44x230 = ["American","AISC","W shapes","W44x230"]
	American_AISC_W_shapes_W44x262 = ["American","AISC","W shapes","W44x262"]
	American_AISC_W_shapes_W44x290 = ["American","AISC","W shapes","W44x290"]
	American_AISC_W_shapes_W44x335 = ["American","AISC","W shapes","W44x335"]
	American_AISC_WT_shapes_WT4x5 = ["American","AISC","WT shapes","WT4x5"]
	American_AISC_WT_shapes_WT4x6_5 = ["American","AISC","WT shapes","WT4x6.5"]
	American_AISC_WT_shapes_WT4x7_5 = ["American","AISC","WT shapes","WT4x7.5"]
	American_AISC_WT_shapes_WT5x6 = ["American","AISC","WT shapes","WT5x6"]
	American_AISC_WT_shapes_WT5x7_5 = ["American","AISC","WT shapes","WT5x7.5"]
	American_AISC_WT_shapes_WT5x8_5 = ["American","AISC","WT shapes","WT5x8.5"]
	American_AISC_WT_shapes_WT5x9_5 = ["American","AISC","WT shapes","WT5x9.5"]
	American_AISC_WT_shapes_WT5x11 = ["American","AISC","WT shapes","WT5x11"]
	American_AISC_WT_shapes_WT5x13 = ["American","AISC","WT shapes","WT5x13"]
	American_AISC_WT_shapes_WT5x15 = ["American","AISC","WT shapes","WT5x15"]
	American_AISC_WT_shapes_WT6x7 = ["American","AISC","WT shapes","WT6x7"]
	American_AISC_WT_shapes_WT6x8 = ["American","AISC","WT shapes","WT6x8"]
	American_AISC_WT_shapes_WT6x9_5 = ["American","AISC","WT shapes","WT6x9.5"]
	American_AISC_WT_shapes_WT6x11 = ["American","AISC","WT shapes","WT6x11"]
	American_AISC_WT_shapes_WT6x13 = ["American","AISC","WT shapes","WT6x13"]
	American_AISC_WT_shapes_WT6x15 = ["American","AISC","WT shapes","WT6x15"]
	American_AISC_WT_shapes_WT6x17_5 = ["American","AISC","WT shapes","WT6x17.5"]
	American_AISC_WT_shapes_WT7x11 = ["American","AISC","WT shapes","WT7x11"]
	American_AISC_WT_shapes_WT7x13 = ["American","AISC","WT shapes","WT7x13"]
	American_AISC_WT_shapes_WT7x15 = ["American","AISC","WT shapes","WT7x15"]
	American_AISC_WT_shapes_WT7x17 = ["American","AISC","WT shapes","WT7x17"]
	American_AISC_WT_shapes_WT7x19 = ["American","AISC","WT shapes","WT7x19"]
	American_AISC_WT_shapes_WT8x13 = ["American","AISC","WT shapes","WT8x13"]
	American_AISC_WT_shapes_WT8x15_5 = ["American","AISC","WT shapes","WT8x15.5"]
	American_AISC_WT_shapes_WT8x18 = ["American","AISC","WT shapes","WT8x18"]
	American_AISC_WT_shapes_WT8x20 = ["American","AISC","WT shapes","WT8x20"]
	American_AISC_WT_shapes_WT8x22_5 = ["American","AISC","WT shapes","WT8x22.5"]
	American_AISC_WT_shapes_WT8x25 = ["American","AISC","WT shapes","WT8x25"]
	American_AISC_WT_shapes_WT8x28_5 = ["American","AISC","WT shapes","WT8x28.5"]
	American_AISC_WT_shapes_WT9x17_5 = ["American","AISC","WT shapes","WT9x17.5"]
	American_AISC_WT_shapes_WT9x20 = ["American","AISC","WT shapes","WT9x20"]
	American_AISC_WT_shapes_WT9x23 = ["American","AISC","WT shapes","WT9x23"]
	American_AISC_WT_shapes_WT9x25 = ["American","AISC","WT shapes","WT9x25"]
	American_AISC_WT_shapes_WT9x27_5 = ["American","AISC","WT shapes","WT9x27.5"]
	American_AISC_WT_shapes_WT9x30 = ["American","AISC","WT shapes","WT9x30"]
	American_AISC_WT_shapes_WT9x32_5 = ["American","AISC","WT shapes","WT9x32.5"]
	American_AISC_WT_shapes_WT9x35_5 = ["American","AISC","WT shapes","WT9x35.5"]
	American_AISC_WT_shapes_WT10_5x22 = ["American","AISC","WT shapes","WT10.5x22"]
	American_AISC_WT_shapes_WT10_5x25 = ["American","AISC","WT shapes","WT10.5x25"]
	American_AISC_WT_shapes_WT10_5x27_5 = ["American","AISC","WT shapes","WT10.5x27.5"]
	American_AISC_WT_shapes_WT10_5x28_5 = ["American","AISC","WT shapes","WT10.5x28.5"]
	American_AISC_WT_shapes_WT10_5x31 = ["American","AISC","WT shapes","WT10.5x31"]
	American_AISC_WT_shapes_WT10_5x34 = ["American","AISC","WT shapes","WT10.5x34"]
	American_AISC_WT_shapes_WT10_5x36_5 = ["American","AISC","WT shapes","WT10.5x36.5"]
	American_AISC_WT_shapes_WT10_5x41_5 = ["American","AISC","WT shapes","WT10.5x41.5"]
	American_AISC_WT_shapes_WT10_5x46_5 = ["American","AISC","WT shapes","WT10.5x46.5"]
	American_AISC_WT_shapes_WT10_5x50_5 = ["American","AISC","WT shapes","WT10.5x50.5"]
	American_AISC_WT_shapes_WT10_5x55_5 = ["American","AISC","WT shapes","WT10.5x55.5"]
	American_AISC_WT_shapes_WT10_5x61 = ["American","AISC","WT shapes","WT10.5x61"]
	American_AISC_WT_shapes_WT10_5x66 = ["American","AISC","WT shapes","WT10.5x66"]
	American_AISC_WT_shapes_WT10_5x73_5 = ["American","AISC","WT shapes","WT10.5x73.5"]
	American_AISC_WT_shapes_WT10_5x83 = ["American","AISC","WT shapes","WT10.5x83"]
	American_AISC_WT_shapes_WT10_5x91 = ["American","AISC","WT shapes","WT10.5x91"]
	American_AISC_WT_shapes_WT10_5x100_5 = ["American","AISC","WT shapes","WT10.5x100.5"]
	American_AISC_WT_shapes_WT12x27_5 = ["American","AISC","WT shapes","WT12x27.5"]
	American_AISC_WT_shapes_WT12x31 = ["American","AISC","WT shapes","WT12x31"]
	American_AISC_WT_shapes_WT12x34 = ["American","AISC","WT shapes","WT12x34"]
	American_AISC_WT_shapes_WT12x38 = ["American","AISC","WT shapes","WT12x38"]
	American_AISC_WT_shapes_WT12x42 = ["American","AISC","WT shapes","WT12x42"]
	American_AISC_WT_shapes_WT12x47 = ["American","AISC","WT shapes","WT12x47"]
	American_AISC_WT_shapes_WT12x51_5 = ["American","AISC","WT shapes","WT12x51.5"]
	American_AISC_WT_shapes_WT12x52 = ["American","AISC","WT shapes","WT12x52"]
	American_AISC_WT_shapes_WT12x58_5 = ["American","AISC","WT shapes","WT12x58.5"]
	American_AISC_WT_shapes_WT12x65_5 = ["American","AISC","WT shapes","WT12x65.5"]
	American_AISC_WT_shapes_WT12x73 = ["American","AISC","WT shapes","WT12x73"]
	American_AISC_WT_shapes_WT12x81 = ["American","AISC","WT shapes","WT12x81"]
	American_AISC_WT_shapes_WT12x88 = ["American","AISC","WT shapes","WT12x88"]
	American_AISC_WT_shapes_WT12x96 = ["American","AISC","WT shapes","WT12x96"]
	American_AISC_WT_shapes_WT12x103_5 = ["American","AISC","WT shapes","WT12x103.5"]
	American_AISC_WT_shapes_WT12x114_5 = ["American","AISC","WT shapes","WT12x114.5"]
	American_AISC_WT_shapes_WT12x125 = ["American","AISC","WT shapes","WT12x125"]
	American_AISC_WT_shapes_WT12x139_5 = ["American","AISC","WT shapes","WT12x139.5"]
	American_AISC_WT_shapes_WT12x153 = ["American","AISC","WT shapes","WT12x153"]
	American_AISC_WT_shapes_WT12x167_5 = ["American","AISC","WT shapes","WT12x167.5"]
	American_AISC_WT_shapes_WT12x185 = ["American","AISC","WT shapes","WT12x185"]
	American_AISC_WT_shapes_WT12x204 = ["American","AISC","WT shapes","WT12x204"]
	American_AISC_WT_shapes_WT12x246 = ["American","AISC","WT shapes","WT12x246"]
	American_AISC_WT_shapes_WT13_5x42 = ["American","AISC","WT shapes","WT13.5x42"]
	American_AISC_WT_shapes_WT13_5x47 = ["American","AISC","WT shapes","WT13.5x47"]
	American_AISC_WT_shapes_WT13_5x51 = ["American","AISC","WT shapes","WT13.5x51"]
	American_AISC_WT_shapes_WT13_5x57 = ["American","AISC","WT shapes","WT13.5x57"]
	American_AISC_WT_shapes_WT13_5x64_5 = ["American","AISC","WT shapes","WT13.5x64.5"]
	American_AISC_WT_shapes_WT13_5x73 = ["American","AISC","WT shapes","WT13.5x73"]
	American_AISC_WT_shapes_WT13_5x80_5 = ["American","AISC","WT shapes","WT13.5x80.5"]
	American_AISC_WT_shapes_WT13_5x89 = ["American","AISC","WT shapes","WT13.5x89"]
	American_AISC_WT_shapes_WT13_5x97 = ["American","AISC","WT shapes","WT13.5x97"]
	American_AISC_WT_shapes_WT13_5x108_5 = ["American","AISC","WT shapes","WT13.5x108.5"]
	American_AISC_WT_shapes_WT13_5x117_5 = ["American","AISC","WT shapes","WT13.5x117.5"]
	American_AISC_WT_shapes_WT13_5x129 = ["American","AISC","WT shapes","WT13.5x129"]
	American_AISC_WT_shapes_WT13_5x140_5 = ["American","AISC","WT shapes","WT13.5x140.5"]
	American_AISC_WT_shapes_WT13_5x153_5 = ["American","AISC","WT shapes","WT13.5x153.5"]
	American_AISC_WT_shapes_WT13_5x168 = ["American","AISC","WT shapes","WT13.5x168"]
	American_AISC_WT_shapes_WT13_5x184 = ["American","AISC","WT shapes","WT13.5x184"]
	American_AISC_WT_shapes_WT13_5x224 = ["American","AISC","WT shapes","WT13.5x224"]
	American_AISC_WT_shapes_WT13_5x269_5 = ["American","AISC","WT shapes","WT13.5x269.5"]
	American_AISC_WT_shapes_WT15x45 = ["American","AISC","WT shapes","WT15x45"]
	American_AISC_WT_shapes_WT15x49_5 = ["American","AISC","WT shapes","WT15x49.5"]
	American_AISC_WT_shapes_WT15x54 = ["American","AISC","WT shapes","WT15x54"]
	American_AISC_WT_shapes_WT15x58 = ["American","AISC","WT shapes","WT15x58"]
	American_AISC_WT_shapes_WT15x62 = ["American","AISC","WT shapes","WT15x62"]
	American_AISC_WT_shapes_WT15x66 = ["American","AISC","WT shapes","WT15x66"]
	American_AISC_WT_shapes_WT15x74 = ["American","AISC","WT shapes","WT15x74"]
	American_AISC_WT_shapes_WT15x86_5 = ["American","AISC","WT shapes","WT15x86.5"]
	American_AISC_WT_shapes_WT15x95_5 = ["American","AISC","WT shapes","WT15x95.5"]
	American_AISC_WT_shapes_WT15x105_5 = ["American","AISC","WT shapes","WT15x105.5"]
	American_AISC_WT_shapes_WT15x117_5 = ["American","AISC","WT shapes","WT15x117.5"]
	American_AISC_WT_shapes_WT15x130_5 = ["American","AISC","WT shapes","WT15x130.5"]
	American_AISC_WT_shapes_WT15x146 = ["American","AISC","WT shapes","WT15x146"]
	American_AISC_WT_shapes_WT15x163 = ["American","AISC","WT shapes","WT15x163"]
	American_AISC_WT_shapes_WT15x178_5 = ["American","AISC","WT shapes","WT15x178.5"]
	American_AISC_WT_shapes_WT15x195_5 = ["American","AISC","WT shapes","WT15x195.5"]
	American_AISC_WT_shapes_WT15x238_5 = ["American","AISC","WT shapes","WT15x238.5"]
	American_AISC_WT_shapes_WT16_5x59 = ["American","AISC","WT shapes","WT16.5x59"]
	American_AISC_WT_shapes_WT16_5x65 = ["American","AISC","WT shapes","WT16.5x65"]
	American_AISC_WT_shapes_WT16_5x70_5 = ["American","AISC","WT shapes","WT16.5x70.5"]
	American_AISC_WT_shapes_WT16_5x76 = ["American","AISC","WT shapes","WT16.5x76"]
	American_AISC_WT_shapes_WT16_5x84_5 = ["American","AISC","WT shapes","WT16.5x84.5"]
	American_AISC_WT_shapes_WT16_5x100_5 = ["American","AISC","WT shapes","WT16.5x100.5"]
	American_AISC_WT_shapes_WT16_5x110_5 = ["American","AISC","WT shapes","WT16.5x110.5"]
	American_AISC_WT_shapes_WT16_5x120_5 = ["American","AISC","WT shapes","WT16.5x120.5"]
	American_AISC_WT_shapes_WT16_5x131_5 = ["American","AISC","WT shapes","WT16.5x131.5"]
	American_AISC_WT_shapes_WT16_5x145_5 = ["American","AISC","WT shapes","WT16.5x145.5"]
	American_AISC_WT_shapes_WT16_5x159 = ["American","AISC","WT shapes","WT16.5x159"]
	American_AISC_WT_shapes_WT16_5x177 = ["American","AISC","WT shapes","WT16.5x177"]
	American_AISC_WT_shapes_WT16_5x193_5 = ["American","AISC","WT shapes","WT16.5x193.5"]
	American_AISC_WT_shapes_WT18x67_5 = ["American","AISC","WT shapes","WT18x67.5"]
	American_AISC_WT_shapes_WT18x75 = ["American","AISC","WT shapes","WT18x75"]
	American_AISC_WT_shapes_WT18x80 = ["American","AISC","WT shapes","WT18x80"]
	American_AISC_WT_shapes_WT18x85 = ["American","AISC","WT shapes","WT18x85"]
	American_AISC_WT_shapes_WT18x91 = ["American","AISC","WT shapes","WT18x91"]
	American_AISC_WT_shapes_WT18x97 = ["American","AISC","WT shapes","WT18x97"]
	American_AISC_WT_shapes_WT18x105 = ["American","AISC","WT shapes","WT18x105"]
	American_AISC_WT_shapes_WT18x115 = ["American","AISC","WT shapes","WT18x115"]
	American_AISC_WT_shapes_WT18x115_5 = ["American","AISC","WT shapes","WT18x115.5"]
	American_AISC_WT_shapes_WT18x116 = ["American","AISC","WT shapes","WT18x116"]
	American_AISC_WT_shapes_WT18x122_5 = ["American","AISC","WT shapes","WT18x122.5"]
	American_AISC_WT_shapes_WT18x123_5 = ["American","AISC","WT shapes","WT18x123.5"]
	American_AISC_WT_shapes_WT18x128 = ["American","AISC","WT shapes","WT18x128"]
	American_AISC_WT_shapes_WT18x130 = ["American","AISC","WT shapes","WT18x130"]
	American_AISC_WT_shapes_WT18x131 = ["American","AISC","WT shapes","WT18x131"]
	American_AISC_WT_shapes_WT18x140 = ["American","AISC","WT shapes","WT18x140"]
	American_AISC_WT_shapes_WT18x141 = ["American","AISC","WT shapes","WT18x141"]
	American_AISC_WT_shapes_WT18x150 = ["American","AISC","WT shapes","WT18x150"]
	American_AISC_WT_shapes_WT18x151 = ["American","AISC","WT shapes","WT18x151"]
	American_AISC_WT_shapes_WT18x164 = ["American","AISC","WT shapes","WT18x164"]
	American_AISC_WT_shapes_WT18x165 = ["American","AISC","WT shapes","WT18x165"]
	American_AISC_WT_shapes_WT18x179_5 = ["American","AISC","WT shapes","WT18x179.5"]
	American_AISC_WT_shapes_WT18x180_5 = ["American","AISC","WT shapes","WT18x180.5"]
	American_AISC_WT_shapes_WT18x196_5 = ["American","AISC","WT shapes","WT18x196.5"]
	American_AISC_WT_shapes_WT18x197_5 = ["American","AISC","WT shapes","WT18x197.5"]
	American_AISC_WT_shapes_WT18x219_5 = ["American","AISC","WT shapes","WT18x219.5"]
	American_AISC_WT_shapes_WT18x220_5 = ["American","AISC","WT shapes","WT18x220.5"]
	American_AISC_WT_shapes_WT18x243_5 = ["American","AISC","WT shapes","WT18x243.5"]
	American_AISC_WT_shapes_WT18x263_5 = ["American","AISC","WT shapes","WT18x263.5"]
	American_AISC_WT_shapes_WT18x264_5 = ["American","AISC","WT shapes","WT18x264.5"]
	American_AISC_WT_shapes_WT18x325 = ["American","AISC","WT shapes","WT18x325"]
	American_AISC_WT_shapes_WT18x326 = ["American","AISC","WT shapes","WT18x326"]
	American_AISC_WT_shapes_WT18x399 = ["American","AISC","WT shapes","WT18x399"]
	American_AISC_WT_shapes_WT18x424 = ["American","AISC","WT shapes","WT18x424"]
	American_AISC_WT_shapes_WT20x74_5 = ["American","AISC","WT shapes","WT20x74.5"]
	American_AISC_WT_shapes_WT20x83_5 = ["American","AISC","WT shapes","WT20x83.5"]
	American_AISC_WT_shapes_WT20x87 = ["American","AISC","WT shapes","WT20x87"]
	American_AISC_WT_shapes_WT20x91_5 = ["American","AISC","WT shapes","WT20x91.5"]
	American_AISC_WT_shapes_WT20x99_5 = ["American","AISC","WT shapes","WT20x99.5"]
	American_AISC_WT_shapes_WT20x105_5 = ["American","AISC","WT shapes","WT20x105.5"]
	American_AISC_WT_shapes_WT20x107_5 = ["American","AISC","WT shapes","WT20x107.5"]
	American_AISC_WT_shapes_WT20x117_5 = ["American","AISC","WT shapes","WT20x117.5"]
	American_AISC_WT_shapes_WT20x124_5 = ["American","AISC","WT shapes","WT20x124.5"]
	American_AISC_WT_shapes_WT20x132 = ["American","AISC","WT shapes","WT20x132"]
	American_AISC_WT_shapes_WT20x138_5 = ["American","AISC","WT shapes","WT20x138.5"]
	American_AISC_WT_shapes_WT20x139 = ["American","AISC","WT shapes","WT20x139"]
	American_AISC_WT_shapes_WT20x147 = ["American","AISC","WT shapes","WT20x147"]
	American_AISC_WT_shapes_WT20x148_5 = ["American","AISC","WT shapes","WT20x148.5"]
	American_AISC_WT_shapes_WT20x160_5 = ["American","AISC","WT shapes","WT20x160.5"]
	American_AISC_WT_shapes_WT20x162 = ["American","AISC","WT shapes","WT20x162"]
	American_AISC_WT_shapes_WT20x163_5 = ["American","AISC","WT shapes","WT20x163.5"]
	American_AISC_WT_shapes_WT20x165_5 = ["American","AISC","WT shapes","WT20x165.5"]
	American_AISC_WT_shapes_WT20x181 = ["American","AISC","WT shapes","WT20x181"]
	American_AISC_WT_shapes_WT20x186 = ["American","AISC","WT shapes","WT20x186"]
	American_AISC_WT_shapes_WT20x196 = ["American","AISC","WT shapes","WT20x196"]
	American_AISC_WT_shapes_WT20x198_5 = ["American","AISC","WT shapes","WT20x198.5"]
	American_AISC_WT_shapes_WT20x215_5 = ["American","AISC","WT shapes","WT20x215.5"]
	American_AISC_WT_shapes_WT20x233 = ["American","AISC","WT shapes","WT20x233"]
	American_AISC_WT_shapes_WT20x251_5 = ["American","AISC","WT shapes","WT20x251.5"]
	American_AISC_WT_shapes_WT20x296_5 = ["American","AISC","WT shapes","WT20x296.5"]
	American_AISC_WT_shapes_WT22x115 = ["American","AISC","WT shapes","WT22x115"]
	American_AISC_WT_shapes_WT22x131 = ["American","AISC","WT shapes","WT22x131"]
	American_AISC_WT_shapes_WT22x145 = ["American","AISC","WT shapes","WT22x145"]
	American_AISC_WT_shapes_WT22x167_5 = ["American","AISC","WT shapes","WT22x167.5"]
	American_AISI_C_Sections_W_Lips_I_1_4CS2_5x059 = ["American","AISI","C-Sections W Lips (I-1)","4CS2.5x059"]
	American_AISI_C_Sections_W_Lips_I_1_4CS2_5x065 = ["American","AISI","C-Sections W Lips (I-1)","4CS2.5x065"]
	American_AISI_C_Sections_W_Lips_I_1_4CS2_5x070 = ["American","AISI","C-Sections W Lips (I-1)","4CS2.5x070"]
	American_AISI_C_Sections_W_Lips_I_1_4CS2_5x085 = ["American","AISI","C-Sections W Lips (I-1)","4CS2.5x085"]
	American_AISI_C_Sections_W_Lips_I_1_4CS2_5x105 = ["American","AISI","C-Sections W Lips (I-1)","4CS2.5x105"]
	American_AISI_C_Sections_W_Lips_I_1_4CS2x059 = ["American","AISI","C-Sections W Lips (I-1)","4CS2x059"]
	American_AISI_C_Sections_W_Lips_I_1_4CS2x065 = ["American","AISI","C-Sections W Lips (I-1)","4CS2x065"]
	American_AISI_C_Sections_W_Lips_I_1_4CS2x070 = ["American","AISI","C-Sections W Lips (I-1)","4CS2x070"]
	American_AISI_C_Sections_W_Lips_I_1_4CS2x085 = ["American","AISI","C-Sections W Lips (I-1)","4CS2x085"]
	American_AISI_C_Sections_W_Lips_I_1_4CS2x105 = ["American","AISI","C-Sections W Lips (I-1)","4CS2x105"]
	American_AISI_C_Sections_W_Lips_I_1_4CS4x059 = ["American","AISI","C-Sections W Lips (I-1)","4CS4x059"]
	American_AISI_C_Sections_W_Lips_I_1_4CS4x065 = ["American","AISI","C-Sections W Lips (I-1)","4CS4x065"]
	American_AISI_C_Sections_W_Lips_I_1_4CS4x070 = ["American","AISI","C-Sections W Lips (I-1)","4CS4x070"]
	American_AISI_C_Sections_W_Lips_I_1_4CS4x085 = ["American","AISI","C-Sections W Lips (I-1)","4CS4x085"]
	American_AISI_C_Sections_W_Lips_I_1_4CS4x105 = ["American","AISI","C-Sections W Lips (I-1)","4CS4x105"]
	American_AISI_C_Sections_W_Lips_I_1_6CS2_5x059 = ["American","AISI","C-Sections W Lips (I-1)","6CS2.5x059"]
	American_AISI_C_Sections_W_Lips_I_1_6CS2_5x065 = ["American","AISI","C-Sections W Lips (I-1)","6CS2.5x065"]
	American_AISI_C_Sections_W_Lips_I_1_6CS2_5x070 = ["American","AISI","C-Sections W Lips (I-1)","6CS2.5x070"]
	American_AISI_C_Sections_W_Lips_I_1_6CS2_5x085 = ["American","AISI","C-Sections W Lips (I-1)","6CS2.5x085"]
	American_AISI_C_Sections_W_Lips_I_1_6CS2_5x105 = ["American","AISI","C-Sections W Lips (I-1)","6CS2.5x105"]
	American_AISI_C_Sections_W_Lips_I_1_6CS4x059 = ["American","AISI","C-Sections W Lips (I-1)","6CS4x059"]
	American_AISI_C_Sections_W_Lips_I_1_6CS4x065 = ["American","AISI","C-Sections W Lips (I-1)","6CS4x065"]
	American_AISI_C_Sections_W_Lips_I_1_6CS4x070 = ["American","AISI","C-Sections W Lips (I-1)","6CS4x070"]
	American_AISI_C_Sections_W_Lips_I_1_6CS4x085 = ["American","AISI","C-Sections W Lips (I-1)","6CS4x085"]
	American_AISI_C_Sections_W_Lips_I_1_6CS4x105 = ["American","AISI","C-Sections W Lips (I-1)","6CS4x105"]
	American_AISI_C_Sections_W_Lips_I_1_7CS2_5x059 = ["American","AISI","C-Sections W Lips (I-1)","7CS2.5x059"]
	American_AISI_C_Sections_W_Lips_I_1_7CS2_5x065 = ["American","AISI","C-Sections W Lips (I-1)","7CS2.5x065"]
	American_AISI_C_Sections_W_Lips_I_1_7CS2_5x070 = ["American","AISI","C-Sections W Lips (I-1)","7CS2.5x070"]
	American_AISI_C_Sections_W_Lips_I_1_7CS2_5x085 = ["American","AISI","C-Sections W Lips (I-1)","7CS2.5x085"]
	American_AISI_C_Sections_W_Lips_I_1_7CS2_5x105 = ["American","AISI","C-Sections W Lips (I-1)","7CS2.5x105"]
	American_AISI_C_Sections_W_Lips_I_1_7CS4x059 = ["American","AISI","C-Sections W Lips (I-1)","7CS4x059"]
	American_AISI_C_Sections_W_Lips_I_1_7CS4x065 = ["American","AISI","C-Sections W Lips (I-1)","7CS4x065"]
	American_AISI_C_Sections_W_Lips_I_1_7CS4x070 = ["American","AISI","C-Sections W Lips (I-1)","7CS4x070"]
	American_AISI_C_Sections_W_Lips_I_1_7CS4x085 = ["American","AISI","C-Sections W Lips (I-1)","7CS4x085"]
	American_AISI_C_Sections_W_Lips_I_1_7CS4x105 = ["American","AISI","C-Sections W Lips (I-1)","7CS4x105"]
	American_AISI_C_Sections_W_Lips_I_1_8CS2_5x059 = ["American","AISI","C-Sections W Lips (I-1)","8CS2.5x059"]
	American_AISI_C_Sections_W_Lips_I_1_8CS2_5x065 = ["American","AISI","C-Sections W Lips (I-1)","8CS2.5x065"]
	American_AISI_C_Sections_W_Lips_I_1_8CS2_5x070 = ["American","AISI","C-Sections W Lips (I-1)","8CS2.5x070"]
	American_AISI_C_Sections_W_Lips_I_1_8CS2_5x085 = ["American","AISI","C-Sections W Lips (I-1)","8CS2.5x085"]
	American_AISI_C_Sections_W_Lips_I_1_8CS2_5x105 = ["American","AISI","C-Sections W Lips (I-1)","8CS2.5x105"]
	American_AISI_C_Sections_W_Lips_I_1_8CS2x059 = ["American","AISI","C-Sections W Lips (I-1)","8CS2x059"]
	American_AISI_C_Sections_W_Lips_I_1_8CS2x065 = ["American","AISI","C-Sections W Lips (I-1)","8CS2x065"]
	American_AISI_C_Sections_W_Lips_I_1_8CS2x070 = ["American","AISI","C-Sections W Lips (I-1)","8CS2x070"]
	American_AISI_C_Sections_W_Lips_I_1_8CS2x085 = ["American","AISI","C-Sections W Lips (I-1)","8CS2x085"]
	American_AISI_C_Sections_W_Lips_I_1_8CS2x105 = ["American","AISI","C-Sections W Lips (I-1)","8CS2x105"]
	American_AISI_C_Sections_W_Lips_I_1_8CS3_5x059 = ["American","AISI","C-Sections W Lips (I-1)","8CS3.5x059"]
	American_AISI_C_Sections_W_Lips_I_1_8CS3_5x065 = ["American","AISI","C-Sections W Lips (I-1)","8CS3.5x065"]
	American_AISI_C_Sections_W_Lips_I_1_8CS3_5x070 = ["American","AISI","C-Sections W Lips (I-1)","8CS3.5x070"]
	American_AISI_C_Sections_W_Lips_I_1_8CS3_5x085 = ["American","AISI","C-Sections W Lips (I-1)","8CS3.5x085"]
	American_AISI_C_Sections_W_Lips_I_1_8CS3_5x105 = ["American","AISI","C-Sections W Lips (I-1)","8CS3.5x105"]
	American_AISI_C_Sections_W_Lips_I_1_8CS4x059 = ["American","AISI","C-Sections W Lips (I-1)","8CS4x059"]
	American_AISI_C_Sections_W_Lips_I_1_8CS4x065 = ["American","AISI","C-Sections W Lips (I-1)","8CS4x065"]
	American_AISI_C_Sections_W_Lips_I_1_8CS4x070 = ["American","AISI","C-Sections W Lips (I-1)","8CS4x070"]
	American_AISI_C_Sections_W_Lips_I_1_8CS4x085 = ["American","AISI","C-Sections W Lips (I-1)","8CS4x085"]
	American_AISI_C_Sections_W_Lips_I_1_8CS4x105 = ["American","AISI","C-Sections W Lips (I-1)","8CS4x105"]
	American_AISI_C_Sections_W_Lips_I_1_9CS2_5x059 = ["American","AISI","C-Sections W Lips (I-1)","9CS2.5x059"]
	American_AISI_C_Sections_W_Lips_I_1_9CS2_5x065 = ["American","AISI","C-Sections W Lips (I-1)","9CS2.5x065"]
	American_AISI_C_Sections_W_Lips_I_1_9CS2_5x070 = ["American","AISI","C-Sections W Lips (I-1)","9CS2.5x070"]
	American_AISI_C_Sections_W_Lips_I_1_9CS2_5x085 = ["American","AISI","C-Sections W Lips (I-1)","9CS2.5x085"]
	American_AISI_C_Sections_W_Lips_I_1_9CS2_5x105 = ["American","AISI","C-Sections W Lips (I-1)","9CS2.5x105"]
	American_AISI_C_Sections_W_Lips_I_1_10CS2_5x065 = ["American","AISI","C-Sections W Lips (I-1)","10CS2.5x065"]
	American_AISI_C_Sections_W_Lips_I_1_10CS2_5x070 = ["American","AISI","C-Sections W Lips (I-1)","10CS2.5x070"]
	American_AISI_C_Sections_W_Lips_I_1_10CS2_5x085 = ["American","AISI","C-Sections W Lips (I-1)","10CS2.5x085"]
	American_AISI_C_Sections_W_Lips_I_1_10CS2_5x105 = ["American","AISI","C-Sections W Lips (I-1)","10CS2.5x105"]
	American_AISI_C_Sections_W_Lips_I_1_10CS2x065 = ["American","AISI","C-Sections W Lips (I-1)","10CS2x065"]
	American_AISI_C_Sections_W_Lips_I_1_10CS2x070 = ["American","AISI","C-Sections W Lips (I-1)","10CS2x070"]
	American_AISI_C_Sections_W_Lips_I_1_10CS2x085 = ["American","AISI","C-Sections W Lips (I-1)","10CS2x085"]
	American_AISI_C_Sections_W_Lips_I_1_10CS2x105 = ["American","AISI","C-Sections W Lips (I-1)","10CS2x105"]
	American_AISI_C_Sections_W_Lips_I_1_10CS3_5x065 = ["American","AISI","C-Sections W Lips (I-1)","10CS3.5x065"]
	American_AISI_C_Sections_W_Lips_I_1_10CS3_5x070 = ["American","AISI","C-Sections W Lips (I-1)","10CS3.5x070"]
	American_AISI_C_Sections_W_Lips_I_1_10CS3_5x085 = ["American","AISI","C-Sections W Lips (I-1)","10CS3.5x085"]
	American_AISI_C_Sections_W_Lips_I_1_10CS3_5x105 = ["American","AISI","C-Sections W Lips (I-1)","10CS3.5x105"]
	American_AISI_C_Sections_W_Lips_I_1_10CS4x065 = ["American","AISI","C-Sections W Lips (I-1)","10CS4x065"]
	American_AISI_C_Sections_W_Lips_I_1_10CS4x070 = ["American","AISI","C-Sections W Lips (I-1)","10CS4x070"]
	American_AISI_C_Sections_W_Lips_I_1_10CS4x085 = ["American","AISI","C-Sections W Lips (I-1)","10CS4x085"]
	American_AISI_C_Sections_W_Lips_I_1_10CS4x105 = ["American","AISI","C-Sections W Lips (I-1)","10CS4x105"]
	American_AISI_C_Sections_W_Lips_I_1_12CS2_5x070 = ["American","AISI","C-Sections W Lips (I-1)","12CS2.5x070"]
	American_AISI_C_Sections_W_Lips_I_1_12CS2_5x085 = ["American","AISI","C-Sections W Lips (I-1)","12CS2.5x085"]
	American_AISI_C_Sections_W_Lips_I_1_12CS2_5x105 = ["American","AISI","C-Sections W Lips (I-1)","12CS2.5x105"]
	American_AISI_C_Sections_W_Lips_I_1_12CS3_5x070 = ["American","AISI","C-Sections W Lips (I-1)","12CS3.5x070"]
	American_AISI_C_Sections_W_Lips_I_1_12CS3_5x085 = ["American","AISI","C-Sections W Lips (I-1)","12CS3.5x085"]
	American_AISI_C_Sections_W_Lips_I_1_12CS3_5x105 = ["American","AISI","C-Sections W Lips (I-1)","12CS3.5x105"]
	American_AISI_C_Sections_W_Lips_I_1_12CS4x070 = ["American","AISI","C-Sections W Lips (I-1)","12CS4x070"]
	American_AISI_C_Sections_W_Lips_I_1_12CS4x085 = ["American","AISI","C-Sections W Lips (I-1)","12CS4x085"]
	American_AISI_C_Sections_W_Lips_I_1_12CS4x105 = ["American","AISI","C-Sections W Lips (I-1)","12CS4x105"]
	American_AISI_C_Sections_W_Lips_I_2_250S137_33 = ["American","AISI","C-Sections W Lips (I-2)","250S137-33"]
	American_AISI_C_Sections_W_Lips_I_2_250S137_43 = ["American","AISI","C-Sections W Lips (I-2)","250S137-43"]
	American_AISI_C_Sections_W_Lips_I_2_250S137_54 = ["American","AISI","C-Sections W Lips (I-2)","250S137-54"]
	American_AISI_C_Sections_W_Lips_I_2_250S137_68 = ["American","AISI","C-Sections W Lips (I-2)","250S137-68"]
	American_AISI_C_Sections_W_Lips_I_2_250S162_33 = ["American","AISI","C-Sections W Lips (I-2)","250S162-33"]
	American_AISI_C_Sections_W_Lips_I_2_250S162_43 = ["American","AISI","C-Sections W Lips (I-2)","250S162-43"]
	American_AISI_C_Sections_W_Lips_I_2_250S162_54 = ["American","AISI","C-Sections W Lips (I-2)","250S162-54"]
	American_AISI_C_Sections_W_Lips_I_2_250S162_68 = ["American","AISI","C-Sections W Lips (I-2)","250S162-68"]
	American_AISI_C_Sections_W_Lips_I_2_350S162_33 = ["American","AISI","C-Sections W Lips (I-2)","350S162-33"]
	American_AISI_C_Sections_W_Lips_I_2_350S162_43 = ["American","AISI","C-Sections W Lips (I-2)","350S162-43"]
	American_AISI_C_Sections_W_Lips_I_2_350S162_54 = ["American","AISI","C-Sections W Lips (I-2)","350S162-54"]
	American_AISI_C_Sections_W_Lips_I_2_350S162_68 = ["American","AISI","C-Sections W Lips (I-2)","350S162-68"]
	American_AISI_C_Sections_W_Lips_I_2_362S137_33 = ["American","AISI","C-Sections W Lips (I-2)","362S137-33"]
	American_AISI_C_Sections_W_Lips_I_2_362S137_43 = ["American","AISI","C-Sections W Lips (I-2)","362S137-43"]
	American_AISI_C_Sections_W_Lips_I_2_362S137_54 = ["American","AISI","C-Sections W Lips (I-2)","362S137-54"]
	American_AISI_C_Sections_W_Lips_I_2_362S137_68 = ["American","AISI","C-Sections W Lips (I-2)","362S137-68"]
	American_AISI_C_Sections_W_Lips_I_2_362S162_33 = ["American","AISI","C-Sections W Lips (I-2)","362S162-33"]
	American_AISI_C_Sections_W_Lips_I_2_362S162_43 = ["American","AISI","C-Sections W Lips (I-2)","362S162-43"]
	American_AISI_C_Sections_W_Lips_I_2_362S162_54 = ["American","AISI","C-Sections W Lips (I-2)","362S162-54"]
	American_AISI_C_Sections_W_Lips_I_2_362S162_68 = ["American","AISI","C-Sections W Lips (I-2)","362S162-68"]
	American_AISI_C_Sections_W_Lips_I_2_362S200_33 = ["American","AISI","C-Sections W Lips (I-2)","362S200-33"]
	American_AISI_C_Sections_W_Lips_I_2_362S200_43 = ["American","AISI","C-Sections W Lips (I-2)","362S200-43"]
	American_AISI_C_Sections_W_Lips_I_2_362S200_54 = ["American","AISI","C-Sections W Lips (I-2)","362S200-54"]
	American_AISI_C_Sections_W_Lips_I_2_362S200_68 = ["American","AISI","C-Sections W Lips (I-2)","362S200-68"]
	American_AISI_C_Sections_W_Lips_I_2_400S137_33 = ["American","AISI","C-Sections W Lips (I-2)","400S137-33"]
	American_AISI_C_Sections_W_Lips_I_2_400S137_43 = ["American","AISI","C-Sections W Lips (I-2)","400S137-43"]
	American_AISI_C_Sections_W_Lips_I_2_400S137_54 = ["American","AISI","C-Sections W Lips (I-2)","400S137-54"]
	American_AISI_C_Sections_W_Lips_I_2_400S137_68 = ["American","AISI","C-Sections W Lips (I-2)","400S137-68"]
	American_AISI_C_Sections_W_Lips_I_2_400S162_33 = ["American","AISI","C-Sections W Lips (I-2)","400S162-33"]
	American_AISI_C_Sections_W_Lips_I_2_400S162_43 = ["American","AISI","C-Sections W Lips (I-2)","400S162-43"]
	American_AISI_C_Sections_W_Lips_I_2_400S162_54 = ["American","AISI","C-Sections W Lips (I-2)","400S162-54"]
	American_AISI_C_Sections_W_Lips_I_2_400S162_68 = ["American","AISI","C-Sections W Lips (I-2)","400S162-68"]
	American_AISI_C_Sections_W_Lips_I_2_400S200_33 = ["American","AISI","C-Sections W Lips (I-2)","400S200-33"]
	American_AISI_C_Sections_W_Lips_I_2_400S200_43 = ["American","AISI","C-Sections W Lips (I-2)","400S200-43"]
	American_AISI_C_Sections_W_Lips_I_2_400S200_54 = ["American","AISI","C-Sections W Lips (I-2)","400S200-54"]
	American_AISI_C_Sections_W_Lips_I_2_400S200_68 = ["American","AISI","C-Sections W Lips (I-2)","400S200-68"]
	American_AISI_C_Sections_W_Lips_I_2_550S162_33 = ["American","AISI","C-Sections W Lips (I-2)","550S162-33"]
	American_AISI_C_Sections_W_Lips_I_2_550S162_43 = ["American","AISI","C-Sections W Lips (I-2)","550S162-43"]
	American_AISI_C_Sections_W_Lips_I_2_550S162_54 = ["American","AISI","C-Sections W Lips (I-2)","550S162-54"]
	American_AISI_C_Sections_W_Lips_I_2_550S162_68 = ["American","AISI","C-Sections W Lips (I-2)","550S162-68"]
	American_AISI_C_Sections_W_Lips_I_2_600S137_33 = ["American","AISI","C-Sections W Lips (I-2)","600S137-33"]
	American_AISI_C_Sections_W_Lips_I_2_600S137_43 = ["American","AISI","C-Sections W Lips (I-2)","600S137-43"]
	American_AISI_C_Sections_W_Lips_I_2_600S137_54 = ["American","AISI","C-Sections W Lips (I-2)","600S137-54"]
	American_AISI_C_Sections_W_Lips_I_2_600S137_68 = ["American","AISI","C-Sections W Lips (I-2)","600S137-68"]
	American_AISI_C_Sections_W_Lips_I_2_600S137_97 = ["American","AISI","C-Sections W Lips (I-2)","600S137-97"]
	American_AISI_C_Sections_W_Lips_I_2_600S162_33 = ["American","AISI","C-Sections W Lips (I-2)","600S162-33"]
	American_AISI_C_Sections_W_Lips_I_2_600S162_43 = ["American","AISI","C-Sections W Lips (I-2)","600S162-43"]
	American_AISI_C_Sections_W_Lips_I_2_600S162_54 = ["American","AISI","C-Sections W Lips (I-2)","600S162-54"]
	American_AISI_C_Sections_W_Lips_I_2_600S162_68 = ["American","AISI","C-Sections W Lips (I-2)","600S162-68"]
	American_AISI_C_Sections_W_Lips_I_2_600S162_97 = ["American","AISI","C-Sections W Lips (I-2)","600S162-97"]
	American_AISI_C_Sections_W_Lips_I_2_600S200_33 = ["American","AISI","C-Sections W Lips (I-2)","600S200-33"]
	American_AISI_C_Sections_W_Lips_I_2_600S200_43 = ["American","AISI","C-Sections W Lips (I-2)","600S200-43"]
	American_AISI_C_Sections_W_Lips_I_2_600S200_54 = ["American","AISI","C-Sections W Lips (I-2)","600S200-54"]
	American_AISI_C_Sections_W_Lips_I_2_600S200_68 = ["American","AISI","C-Sections W Lips (I-2)","600S200-68"]
	American_AISI_C_Sections_W_Lips_I_2_600S200_97 = ["American","AISI","C-Sections W Lips (I-2)","600S200-97"]
	American_AISI_C_Sections_W_Lips_I_2_600S250_43 = ["American","AISI","C-Sections W Lips (I-2)","600S250-43"]
	American_AISI_C_Sections_W_Lips_I_2_600S250_54 = ["American","AISI","C-Sections W Lips (I-2)","600S250-54"]
	American_AISI_C_Sections_W_Lips_I_2_600S250_68 = ["American","AISI","C-Sections W Lips (I-2)","600S250-68"]
	American_AISI_C_Sections_W_Lips_I_2_600S250_97 = ["American","AISI","C-Sections W Lips (I-2)","600S250-97"]
	American_AISI_C_Sections_W_Lips_I_2_800S137_33 = ["American","AISI","C-Sections W Lips (I-2)","800S137-33*"]
	American_AISI_C_Sections_W_Lips_I_2_800S137_43 = ["American","AISI","C-Sections W Lips (I-2)","800S137-43"]
	American_AISI_C_Sections_W_Lips_I_2_800S137_54 = ["American","AISI","C-Sections W Lips (I-2)","800S137-54"]
	American_AISI_C_Sections_W_Lips_I_2_800S137_68 = ["American","AISI","C-Sections W Lips (I-2)","800S137-68"]
	American_AISI_C_Sections_W_Lips_I_2_800S137_97 = ["American","AISI","C-Sections W Lips (I-2)","800S137-97"]
	American_AISI_C_Sections_W_Lips_I_2_800S162_33 = ["American","AISI","C-Sections W Lips (I-2)","800S162-33*"]
	American_AISI_C_Sections_W_Lips_I_2_800S162_43 = ["American","AISI","C-Sections W Lips (I-2)","800S162-43"]
	American_AISI_C_Sections_W_Lips_I_2_800S162_54 = ["American","AISI","C-Sections W Lips (I-2)","800S162-54"]
	American_AISI_C_Sections_W_Lips_I_2_800S162_68 = ["American","AISI","C-Sections W Lips (I-2)","800S162-68"]
	American_AISI_C_Sections_W_Lips_I_2_800S162_97 = ["American","AISI","C-Sections W Lips (I-2)","800S162-97"]
	American_AISI_C_Sections_W_Lips_I_2_800S200_33 = ["American","AISI","C-Sections W Lips (I-2)","800S200-33*"]
	American_AISI_C_Sections_W_Lips_I_2_800S200_43 = ["American","AISI","C-Sections W Lips (I-2)","800S200-43"]
	American_AISI_C_Sections_W_Lips_I_2_800S200_54 = ["American","AISI","C-Sections W Lips (I-2)","800S200-54"]
	American_AISI_C_Sections_W_Lips_I_2_800S200_68 = ["American","AISI","C-Sections W Lips (I-2)","800S200-68"]
	American_AISI_C_Sections_W_Lips_I_2_800S200_97 = ["American","AISI","C-Sections W Lips (I-2)","800S200-97"]
	American_AISI_C_Sections_W_Lips_I_2_800S250_43 = ["American","AISI","C-Sections W Lips (I-2)","800S250-43"]
	American_AISI_C_Sections_W_Lips_I_2_800S250_54 = ["American","AISI","C-Sections W Lips (I-2)","800S250-54"]
	American_AISI_C_Sections_W_Lips_I_2_800S250_68 = ["American","AISI","C-Sections W Lips (I-2)","800S250-68"]
	American_AISI_C_Sections_W_Lips_I_2_800S250_97 = ["American","AISI","C-Sections W Lips (I-2)","800S250-97"]
	American_AISI_C_Sections_W_Lips_I_2_1000S162_43 = ["American","AISI","C-Sections W Lips (I-2)","1000S162-43*"]
	American_AISI_C_Sections_W_Lips_I_2_1000S162_54 = ["American","AISI","C-Sections W Lips (I-2)","1000S162-54"]
	American_AISI_C_Sections_W_Lips_I_2_1000S162_68 = ["American","AISI","C-Sections W Lips (I-2)","1000S162-68"]
	American_AISI_C_Sections_W_Lips_I_2_1000S162_97 = ["American","AISI","C-Sections W Lips (I-2)","1000S162-97"]
	American_AISI_C_Sections_W_Lips_I_2_1000S200_43 = ["American","AISI","C-Sections W Lips (I-2)","1000S200-43*"]
	American_AISI_C_Sections_W_Lips_I_2_1000S200_54 = ["American","AISI","C-Sections W Lips (I-2)","1000S200-54"]
	American_AISI_C_Sections_W_Lips_I_2_1000S200_68 = ["American","AISI","C-Sections W Lips (I-2)","1000S200-68"]
	American_AISI_C_Sections_W_Lips_I_2_1000S200_97 = ["American","AISI","C-Sections W Lips (I-2)","1000S200-97"]
	American_AISI_C_Sections_W_Lips_I_2_1000S250_43 = ["American","AISI","C-Sections W Lips (I-2)","1000S250-43*"]
	American_AISI_C_Sections_W_Lips_I_2_1000S250_54 = ["American","AISI","C-Sections W Lips (I-2)","1000S250-54"]
	American_AISI_C_Sections_W_Lips_I_2_1000S250_68 = ["American","AISI","C-Sections W Lips (I-2)","1000S250-68"]
	American_AISI_C_Sections_W_Lips_I_2_1000S250_97 = ["American","AISI","C-Sections W Lips (I-2)","1000S250-97"]
	American_AISI_C_Sections_W_Lips_I_2_1200S162_54 = ["American","AISI","C-Sections W Lips (I-2)","1200S162-54*"]
	American_AISI_C_Sections_W_Lips_I_2_1200S162_68 = ["American","AISI","C-Sections W Lips (I-2)","1200S162-68"]
	American_AISI_C_Sections_W_Lips_I_2_1200S162_97 = ["American","AISI","C-Sections W Lips (I-2)","1200S162-97"]
	American_AISI_C_Sections_W_Lips_I_2_1200S200_54 = ["American","AISI","C-Sections W Lips (I-2)","1200S200-54*"]
	American_AISI_C_Sections_W_Lips_I_2_1200S200_68 = ["American","AISI","C-Sections W Lips (I-2)","1200S200-68"]
	American_AISI_C_Sections_W_Lips_I_2_1200S200_97 = ["American","AISI","C-Sections W Lips (I-2)","1200S200-97"]
	American_AISI_C_Sections_W_Lips_I_2_1200S250_54 = ["American","AISI","C-Sections W Lips (I-2)","1200S250-54*"]
	American_AISI_C_Sections_W_Lips_I_2_1200S250_68 = ["American","AISI","C-Sections W Lips (I-2)","1200S250-68"]
	American_AISI_C_Sections_W_Lips_I_2_1200S250_97 = ["American","AISI","C-Sections W Lips (I-2)","1200S250-97"]
	American_AISI_C_Sections_WO_Lips_I_3_162T125_18 = ["American","AISI","C-Sections WO Lips (I-3)","162T125-18"]
	American_AISI_C_Sections_WO_Lips_I_3_162T125_27 = ["American","AISI","C-Sections WO Lips (I-3)","162T125-27"]
	American_AISI_C_Sections_WO_Lips_I_3_162T125_30 = ["American","AISI","C-Sections WO Lips (I-3)","162T125-30"]
	American_AISI_C_Sections_WO_Lips_I_3_162T125_33 = ["American","AISI","C-Sections WO Lips (I-3)","162T125-33"]
	American_AISI_C_Sections_WO_Lips_I_3_250T125_18 = ["American","AISI","C-Sections WO Lips (I-3)","250T125-18"]
	American_AISI_C_Sections_WO_Lips_I_3_250T125_27 = ["American","AISI","C-Sections WO Lips (I-3)","250T125-27"]
	American_AISI_C_Sections_WO_Lips_I_3_250T125_30 = ["American","AISI","C-Sections WO Lips (I-3)","250T125-30"]
	American_AISI_C_Sections_WO_Lips_I_3_250T125_33 = ["American","AISI","C-Sections WO Lips (I-3)","250T125-33"]
	American_AISI_C_Sections_WO_Lips_I_3_250T125_43 = ["American","AISI","C-Sections WO Lips (I-3)","250T125-43"]
	American_AISI_C_Sections_WO_Lips_I_3_250T125_54 = ["American","AISI","C-Sections WO Lips (I-3)","250T125-54"]
	American_AISI_C_Sections_WO_Lips_I_3_250T125_68 = ["American","AISI","C-Sections WO Lips (I-3)","250T125-68"]
	American_AISI_C_Sections_WO_Lips_I_3_250T150_27 = ["American","AISI","C-Sections WO Lips (I-3)","250T150-27"]
	American_AISI_C_Sections_WO_Lips_I_3_250T150_30 = ["American","AISI","C-Sections WO Lips (I-3)","250T150-30"]
	American_AISI_C_Sections_WO_Lips_I_3_250T150_33 = ["American","AISI","C-Sections WO Lips (I-3)","250T150-33"]
	American_AISI_C_Sections_WO_Lips_I_3_250T150_43 = ["American","AISI","C-Sections WO Lips (I-3)","250T150-43"]
	American_AISI_C_Sections_WO_Lips_I_3_250T150_54 = ["American","AISI","C-Sections WO Lips (I-3)","250T150-54"]
	American_AISI_C_Sections_WO_Lips_I_3_250T150_68 = ["American","AISI","C-Sections WO Lips (I-3)","250T150-68"]
	American_AISI_C_Sections_WO_Lips_I_3_250T200_33 = ["American","AISI","C-Sections WO Lips (I-3)","250T200-33"]
	American_AISI_C_Sections_WO_Lips_I_3_250T200_43 = ["American","AISI","C-Sections WO Lips (I-3)","250T200-43"]
	American_AISI_C_Sections_WO_Lips_I_3_250T200_54 = ["American","AISI","C-Sections WO Lips (I-3)","250T200-54"]
	American_AISI_C_Sections_WO_Lips_I_3_250T200_68 = ["American","AISI","C-Sections WO Lips (I-3)","250T200-68"]
	American_AISI_C_Sections_WO_Lips_I_3_350T125_18 = ["American","AISI","C-Sections WO Lips (I-3)","350T125-18"]
	American_AISI_C_Sections_WO_Lips_I_3_350T125_27 = ["American","AISI","C-Sections WO Lips (I-3)","350T125-27"]
	American_AISI_C_Sections_WO_Lips_I_3_350T125_30 = ["American","AISI","C-Sections WO Lips (I-3)","350T125-30"]
	American_AISI_C_Sections_WO_Lips_I_3_350T125_33 = ["American","AISI","C-Sections WO Lips (I-3)","350T125-33"]
	American_AISI_C_Sections_WO_Lips_I_3_350T125_43 = ["American","AISI","C-Sections WO Lips (I-3)","350T125-43"]
	American_AISI_C_Sections_WO_Lips_I_3_350T125_54 = ["American","AISI","C-Sections WO Lips (I-3)","350T125-54"]
	American_AISI_C_Sections_WO_Lips_I_3_350T125_68 = ["American","AISI","C-Sections WO Lips (I-3)","350T125-68"]
	American_AISI_C_Sections_WO_Lips_I_3_350T150_27 = ["American","AISI","C-Sections WO Lips (I-3)","350T150-27"]
	American_AISI_C_Sections_WO_Lips_I_3_350T150_30 = ["American","AISI","C-Sections WO Lips (I-3)","350T150-30"]
	American_AISI_C_Sections_WO_Lips_I_3_350T150_33 = ["American","AISI","C-Sections WO Lips (I-3)","350T150-33"]
	American_AISI_C_Sections_WO_Lips_I_3_350T150_43 = ["American","AISI","C-Sections WO Lips (I-3)","350T150-43"]
	American_AISI_C_Sections_WO_Lips_I_3_350T150_54 = ["American","AISI","C-Sections WO Lips (I-3)","350T150-54"]
	American_AISI_C_Sections_WO_Lips_I_3_350T150_68 = ["American","AISI","C-Sections WO Lips (I-3)","350T150-68"]
	American_AISI_C_Sections_WO_Lips_I_3_350T200_33 = ["American","AISI","C-Sections WO Lips (I-3)","350T200-33"]
	American_AISI_C_Sections_WO_Lips_I_3_350T200_43 = ["American","AISI","C-Sections WO Lips (I-3)","350T200-43"]
	American_AISI_C_Sections_WO_Lips_I_3_350T200_54 = ["American","AISI","C-Sections WO Lips (I-3)","350T200-54"]
	American_AISI_C_Sections_WO_Lips_I_3_350T200_68 = ["American","AISI","C-Sections WO Lips (I-3)","350T200-68"]
	American_AISI_C_Sections_WO_Lips_I_3_362T125_18 = ["American","AISI","C-Sections WO Lips (I-3)","362T125-18"]
	American_AISI_C_Sections_WO_Lips_I_3_362T125_27 = ["American","AISI","C-Sections WO Lips (I-3)","362T125-27"]
	American_AISI_C_Sections_WO_Lips_I_3_362T125_30 = ["American","AISI","C-Sections WO Lips (I-3)","362T125-30"]
	American_AISI_C_Sections_WO_Lips_I_3_362T125_33 = ["American","AISI","C-Sections WO Lips (I-3)","362T125-33"]
	American_AISI_C_Sections_WO_Lips_I_3_362T125_43 = ["American","AISI","C-Sections WO Lips (I-3)","362T125-43"]
	American_AISI_C_Sections_WO_Lips_I_3_362T125_54 = ["American","AISI","C-Sections WO Lips (I-3)","362T125-54"]
	American_AISI_C_Sections_WO_Lips_I_3_362T125_68 = ["American","AISI","C-Sections WO Lips (I-3)","362T125-68"]
	American_AISI_C_Sections_WO_Lips_I_3_362T150_27 = ["American","AISI","C-Sections WO Lips (I-3)","362T150-27"]
	American_AISI_C_Sections_WO_Lips_I_3_362T150_30 = ["American","AISI","C-Sections WO Lips (I-3)","362T150-30"]
	American_AISI_C_Sections_WO_Lips_I_3_362T150_33 = ["American","AISI","C-Sections WO Lips (I-3)","362T150-33"]
	American_AISI_C_Sections_WO_Lips_I_3_362T150_43 = ["American","AISI","C-Sections WO Lips (I-3)","362T150-43"]
	American_AISI_C_Sections_WO_Lips_I_3_362T150_54 = ["American","AISI","C-Sections WO Lips (I-3)","362T150-54"]
	American_AISI_C_Sections_WO_Lips_I_3_362T150_68 = ["American","AISI","C-Sections WO Lips (I-3)","362T150-68"]
	American_AISI_C_Sections_WO_Lips_I_3_362T200_33 = ["American","AISI","C-Sections WO Lips (I-3)","362T200-33"]
	American_AISI_C_Sections_WO_Lips_I_3_362T200_43 = ["American","AISI","C-Sections WO Lips (I-3)","362T200-43"]
	American_AISI_C_Sections_WO_Lips_I_3_362T200_54 = ["American","AISI","C-Sections WO Lips (I-3)","362T200-54"]
	American_AISI_C_Sections_WO_Lips_I_3_362T200_68 = ["American","AISI","C-Sections WO Lips (I-3)","362T200-68"]
	American_AISI_C_Sections_WO_Lips_I_3_400T125_18 = ["American","AISI","C-Sections WO Lips (I-3)","400T125-18*"]
	American_AISI_C_Sections_WO_Lips_I_3_400T125_27 = ["American","AISI","C-Sections WO Lips (I-3)","400T125-27"]
	American_AISI_C_Sections_WO_Lips_I_3_400T125_30 = ["American","AISI","C-Sections WO Lips (I-3)","400T125-30"]
	American_AISI_C_Sections_WO_Lips_I_3_400T125_33 = ["American","AISI","C-Sections WO Lips (I-3)","400T125-33"]
	American_AISI_C_Sections_WO_Lips_I_3_400T125_43 = ["American","AISI","C-Sections WO Lips (I-3)","400T125-43"]
	American_AISI_C_Sections_WO_Lips_I_3_400T125_54 = ["American","AISI","C-Sections WO Lips (I-3)","400T125-54"]
	American_AISI_C_Sections_WO_Lips_I_3_400T125_68 = ["American","AISI","C-Sections WO Lips (I-3)","400T125-68"]
	American_AISI_C_Sections_WO_Lips_I_3_400T150_27 = ["American","AISI","C-Sections WO Lips (I-3)","400T150-27"]
	American_AISI_C_Sections_WO_Lips_I_3_400T150_30 = ["American","AISI","C-Sections WO Lips (I-3)","400T150-30"]
	American_AISI_C_Sections_WO_Lips_I_3_400T150_33 = ["American","AISI","C-Sections WO Lips (I-3)","400T150-33"]
	American_AISI_C_Sections_WO_Lips_I_3_400T150_43 = ["American","AISI","C-Sections WO Lips (I-3)","400T150-43"]
	American_AISI_C_Sections_WO_Lips_I_3_400T150_54 = ["American","AISI","C-Sections WO Lips (I-3)","400T150-54"]
	American_AISI_C_Sections_WO_Lips_I_3_400T150_68 = ["American","AISI","C-Sections WO Lips (I-3)","400T150-68"]
	American_AISI_C_Sections_WO_Lips_I_3_400T200_33 = ["American","AISI","C-Sections WO Lips (I-3)","400T200-33"]
	American_AISI_C_Sections_WO_Lips_I_3_400T200_43 = ["American","AISI","C-Sections WO Lips (I-3)","400T200-43"]
	American_AISI_C_Sections_WO_Lips_I_3_400T200_54 = ["American","AISI","C-Sections WO Lips (I-3)","400T200-54"]
	American_AISI_C_Sections_WO_Lips_I_3_400T200_68 = ["American","AISI","C-Sections WO Lips (I-3)","400T200-68"]
	American_AISI_C_Sections_WO_Lips_I_3_550T125_27 = ["American","AISI","C-Sections WO Lips (I-3)","550T125-27"]
	American_AISI_C_Sections_WO_Lips_I_3_550T125_30 = ["American","AISI","C-Sections WO Lips (I-3)","550T125-30"]
	American_AISI_C_Sections_WO_Lips_I_3_550T125_33 = ["American","AISI","C-Sections WO Lips (I-3)","550T125-33"]
	American_AISI_C_Sections_WO_Lips_I_3_550T125_43 = ["American","AISI","C-Sections WO Lips (I-3)","550T125-43"]
	American_AISI_C_Sections_WO_Lips_I_3_550T125_54 = ["American","AISI","C-Sections WO Lips (I-3)","550T125-54"]
	American_AISI_C_Sections_WO_Lips_I_3_550T125_68 = ["American","AISI","C-Sections WO Lips (I-3)","550T125-68"]
	American_AISI_C_Sections_WO_Lips_I_3_550T150_27 = ["American","AISI","C-Sections WO Lips (I-3)","550T150-27"]
	American_AISI_C_Sections_WO_Lips_I_3_550T150_30 = ["American","AISI","C-Sections WO Lips (I-3)","550T150-30"]
	American_AISI_C_Sections_WO_Lips_I_3_550T150_33 = ["American","AISI","C-Sections WO Lips (I-3)","550T150-33"]
	American_AISI_C_Sections_WO_Lips_I_3_550T150_43 = ["American","AISI","C-Sections WO Lips (I-3)","550T150-43"]
	American_AISI_C_Sections_WO_Lips_I_3_550T150_54 = ["American","AISI","C-Sections WO Lips (I-3)","550T150-54"]
	American_AISI_C_Sections_WO_Lips_I_3_550T150_68 = ["American","AISI","C-Sections WO Lips (I-3)","550T150-68"]
	American_AISI_C_Sections_WO_Lips_I_3_550T200_33 = ["American","AISI","C-Sections WO Lips (I-3)","550T200-33"]
	American_AISI_C_Sections_WO_Lips_I_3_550T200_43 = ["American","AISI","C-Sections WO Lips (I-3)","550T200-43"]
	American_AISI_C_Sections_WO_Lips_I_3_550T200_54 = ["American","AISI","C-Sections WO Lips (I-3)","550T200-54"]
	American_AISI_C_Sections_WO_Lips_I_3_550T200_68 = ["American","AISI","C-Sections WO Lips (I-3)","550T200-68"]
	American_AISI_C_Sections_WO_Lips_I_3_600T125_27 = ["American","AISI","C-Sections WO Lips (I-3)","600T125-27*"]
	American_AISI_C_Sections_WO_Lips_I_3_600T125_30 = ["American","AISI","C-Sections WO Lips (I-3)","600T125-30"]
	American_AISI_C_Sections_WO_Lips_I_3_600T125_33 = ["American","AISI","C-Sections WO Lips (I-3)","600T125-33"]
	American_AISI_C_Sections_WO_Lips_I_3_600T125_43 = ["American","AISI","C-Sections WO Lips (I-3)","600T125-43"]
	American_AISI_C_Sections_WO_Lips_I_3_600T125_54 = ["American","AISI","C-Sections WO Lips (I-3)","600T125-54"]
	American_AISI_C_Sections_WO_Lips_I_3_600T125_68 = ["American","AISI","C-Sections WO Lips (I-3)","600T125-68"]
	American_AISI_C_Sections_WO_Lips_I_3_600T125_97 = ["American","AISI","C-Sections WO Lips (I-3)","600T125-97"]
	American_AISI_C_Sections_WO_Lips_I_3_600T150_27 = ["American","AISI","C-Sections WO Lips (I-3)","600T150-27*"]
	American_AISI_C_Sections_WO_Lips_I_3_600T150_30 = ["American","AISI","C-Sections WO Lips (I-3)","600T150-30"]
	American_AISI_C_Sections_WO_Lips_I_3_600T150_33 = ["American","AISI","C-Sections WO Lips (I-3)","600T150-33"]
	American_AISI_C_Sections_WO_Lips_I_3_600T150_43 = ["American","AISI","C-Sections WO Lips (I-3)","600T150-43"]
	American_AISI_C_Sections_WO_Lips_I_3_600T150_54 = ["American","AISI","C-Sections WO Lips (I-3)","600T150-54"]
	American_AISI_C_Sections_WO_Lips_I_3_600T150_68 = ["American","AISI","C-Sections WO Lips (I-3)","600T150-68"]
	American_AISI_C_Sections_WO_Lips_I_3_600T150_97 = ["American","AISI","C-Sections WO Lips (I-3)","600T150-97"]
	American_AISI_C_Sections_WO_Lips_I_3_600T200_33 = ["American","AISI","C-Sections WO Lips (I-3)","600T200-33"]
	American_AISI_C_Sections_WO_Lips_I_3_600T200_43 = ["American","AISI","C-Sections WO Lips (I-3)","600T200-43"]
	American_AISI_C_Sections_WO_Lips_I_3_600T200_54 = ["American","AISI","C-Sections WO Lips (I-3)","600T200-54"]
	American_AISI_C_Sections_WO_Lips_I_3_600T200_68 = ["American","AISI","C-Sections WO Lips (I-3)","600T200-68"]
	American_AISI_C_Sections_WO_Lips_I_3_600T200_97 = ["American","AISI","C-Sections WO Lips (I-3)","600T200-97"]
	American_AISI_C_Sections_WO_Lips_I_3_800T125_33 = ["American","AISI","C-Sections WO Lips (I-3)","800T125-33*"]
	American_AISI_C_Sections_WO_Lips_I_3_800T125_43 = ["American","AISI","C-Sections WO Lips (I-3)","800T125-43"]
	American_AISI_C_Sections_WO_Lips_I_3_800T125_54 = ["American","AISI","C-Sections WO Lips (I-3)","800T125-54"]
	American_AISI_C_Sections_WO_Lips_I_3_800T125_68 = ["American","AISI","C-Sections WO Lips (I-3)","800T125-68"]
	American_AISI_C_Sections_WO_Lips_I_3_800T125_97 = ["American","AISI","C-Sections WO Lips (I-3)","800T125-97"]
	American_AISI_C_Sections_WO_Lips_I_3_800T150_33 = ["American","AISI","C-Sections WO Lips (I-3)","800T150-33*"]
	American_AISI_C_Sections_WO_Lips_I_3_800T150_43 = ["American","AISI","C-Sections WO Lips (I-3)","800T150-43"]
	American_AISI_C_Sections_WO_Lips_I_3_800T150_54 = ["American","AISI","C-Sections WO Lips (I-3)","800T150-54"]
	American_AISI_C_Sections_WO_Lips_I_3_800T150_68 = ["American","AISI","C-Sections WO Lips (I-3)","800T150-68"]
	American_AISI_C_Sections_WO_Lips_I_3_800T150_97 = ["American","AISI","C-Sections WO Lips (I-3)","800T150-97"]
	American_AISI_C_Sections_WO_Lips_I_3_800T200_33 = ["American","AISI","C-Sections WO Lips (I-3)","800T200-33*"]
	American_AISI_C_Sections_WO_Lips_I_3_800T200_43 = ["American","AISI","C-Sections WO Lips (I-3)","800T200-43"]
	American_AISI_C_Sections_WO_Lips_I_3_800T200_54 = ["American","AISI","C-Sections WO Lips (I-3)","800T200-54"]
	American_AISI_C_Sections_WO_Lips_I_3_800T200_68 = ["American","AISI","C-Sections WO Lips (I-3)","800T200-68"]
	American_AISI_C_Sections_WO_Lips_I_3_800T200_97 = ["American","AISI","C-Sections WO Lips (I-3)","800T200-97"]
	American_AISI_C_Sections_WO_Lips_I_3_1000T125_43 = ["American","AISI","C-Sections WO Lips (I-3)","1000T125-43*"]
	American_AISI_C_Sections_WO_Lips_I_3_1000T125_54 = ["American","AISI","C-Sections WO Lips (I-3)","1000T125-54"]
	American_AISI_C_Sections_WO_Lips_I_3_1000T125_68 = ["American","AISI","C-Sections WO Lips (I-3)","1000T125-68"]
	American_AISI_C_Sections_WO_Lips_I_3_1000T125_97 = ["American","AISI","C-Sections WO Lips (I-3)","1000T125-97"]
	American_AISI_C_Sections_WO_Lips_I_3_1000T150_43 = ["American","AISI","C-Sections WO Lips (I-3)","1000T150-43*"]
	American_AISI_C_Sections_WO_Lips_I_3_1000T150_54 = ["American","AISI","C-Sections WO Lips (I-3)","1000T150-54"]
	American_AISI_C_Sections_WO_Lips_I_3_1000T150_68 = ["American","AISI","C-Sections WO Lips (I-3)","1000T150-68"]
	American_AISI_C_Sections_WO_Lips_I_3_1000T150_97 = ["American","AISI","C-Sections WO Lips (I-3)","1000T150-97"]
	American_AISI_C_Sections_WO_Lips_I_3_1000T200_43 = ["American","AISI","C-Sections WO Lips (I-3)","1000T200-43*"]
	American_AISI_C_Sections_WO_Lips_I_3_1000T200_54 = ["American","AISI","C-Sections WO Lips (I-3)","1000T200-54"]
	American_AISI_C_Sections_WO_Lips_I_3_1000T200_68 = ["American","AISI","C-Sections WO Lips (I-3)","1000T200-68"]
	American_AISI_C_Sections_WO_Lips_I_3_1000T200_97 = ["American","AISI","C-Sections WO Lips (I-3)","1000T200-97"]
	American_AISI_C_Sections_WO_Lips_I_3_1200T125_54 = ["American","AISI","C-Sections WO Lips (I-3)","1200T125-54*"]
	American_AISI_C_Sections_WO_Lips_I_3_1200T125_68 = ["American","AISI","C-Sections WO Lips (I-3)","1200T125-68"]
	American_AISI_C_Sections_WO_Lips_I_3_1200T125_97 = ["American","AISI","C-Sections WO Lips (I-3)","1200T125-97"]
	American_AISI_C_Sections_WO_Lips_I_3_1200T150_54 = ["American","AISI","C-Sections WO Lips (I-3)","1200T150-54*"]
	American_AISI_C_Sections_WO_Lips_I_3_1200T150_68 = ["American","AISI","C-Sections WO Lips (I-3)","1200T150-68"]
	American_AISI_C_Sections_WO_Lips_I_3_1200T150_97 = ["American","AISI","C-Sections WO Lips (I-3)","1200T150-97"]
	American_AISI_C_Sections_WO_Lips_I_3_1200T200_54 = ["American","AISI","C-Sections WO Lips (I-3)","1200T200-54*"]
	American_AISI_C_Sections_WO_Lips_I_3_1200T200_68 = ["American","AISI","C-Sections WO Lips (I-3)","1200T200-68"]
	American_AISI_C_Sections_WO_Lips_I_3_1200T200_97 = ["American","AISI","C-Sections WO Lips (I-3)","1200T200-97"]
	American_AISI_Z_Sections_W_Lips_I_4_3_5ZS1_5x059 = ["American","AISI","Z-Sections W Lips (I-4)","3.5ZS1.5x059"]
	American_AISI_Z_Sections_W_Lips_I_4_3_5ZS1_5x065 = ["American","AISI","Z-Sections W Lips (I-4)","3.5ZS1.5x065"]
	American_AISI_Z_Sections_W_Lips_I_4_3_5ZS1_5x070 = ["American","AISI","Z-Sections W Lips (I-4)","3.5ZS1.5x070"]
	American_AISI_Z_Sections_W_Lips_I_4_4ZS2_25x059 = ["American","AISI","Z-Sections W Lips (I-4)","4ZS2.25x059"]
	American_AISI_Z_Sections_W_Lips_I_4_4ZS2_25x065 = ["American","AISI","Z-Sections W Lips (I-4)","4ZS2.25x065"]
	American_AISI_Z_Sections_W_Lips_I_4_4ZS2_25x070 = ["American","AISI","Z-Sections W Lips (I-4)","4ZS2.25x070"]
	American_AISI_Z_Sections_W_Lips_I_4_6ZS2_25x059 = ["American","AISI","Z-Sections W Lips (I-4)","6ZS2.25x059"]
	American_AISI_Z_Sections_W_Lips_I_4_6ZS2_25x065 = ["American","AISI","Z-Sections W Lips (I-4)","6ZS2.25x065"]
	American_AISI_Z_Sections_W_Lips_I_4_6ZS2_25x070 = ["American","AISI","Z-Sections W Lips (I-4)","6ZS2.25x070"]
	American_AISI_Z_Sections_W_Lips_I_4_6ZS2_25x085 = ["American","AISI","Z-Sections W Lips (I-4)","6ZS2.25x085"]
	American_AISI_Z_Sections_W_Lips_I_4_6ZS2_25x105 = ["American","AISI","Z-Sections W Lips (I-4)","6ZS2.25x105"]
	American_AISI_Z_Sections_W_Lips_I_4_7ZS2_25x059 = ["American","AISI","Z-Sections W Lips (I-4)","7ZS2.25x059"]
	American_AISI_Z_Sections_W_Lips_I_4_7ZS2_25x065 = ["American","AISI","Z-Sections W Lips (I-4)","7ZS2.25x065"]
	American_AISI_Z_Sections_W_Lips_I_4_7ZS2_25x070 = ["American","AISI","Z-Sections W Lips (I-4)","7ZS2.25x070"]
	American_AISI_Z_Sections_W_Lips_I_4_7ZS2_25x085 = ["American","AISI","Z-Sections W Lips (I-4)","7ZS2.25x085"]
	American_AISI_Z_Sections_W_Lips_I_4_7ZS2_25x105 = ["American","AISI","Z-Sections W Lips (I-4)","7ZS2.25x105"]
	American_AISI_Z_Sections_W_Lips_I_4_8ZS2_25x059 = ["American","AISI","Z-Sections W Lips (I-4)","8ZS2.25x059"]
	American_AISI_Z_Sections_W_Lips_I_4_8ZS2_25x065 = ["American","AISI","Z-Sections W Lips (I-4)","8ZS2.25x065"]
	American_AISI_Z_Sections_W_Lips_I_4_8ZS2_25x070 = ["American","AISI","Z-Sections W Lips (I-4)","8ZS2.25x070"]
	American_AISI_Z_Sections_W_Lips_I_4_8ZS2_25x085 = ["American","AISI","Z-Sections W Lips (I-4)","8ZS2.25x085"]
	American_AISI_Z_Sections_W_Lips_I_4_8ZS2_25x105 = ["American","AISI","Z-Sections W Lips (I-4)","8ZS2.25x105"]
	American_AISI_Z_Sections_W_Lips_I_4_8ZS2_75x059 = ["American","AISI","Z-Sections W Lips (I-4)","8ZS2.75x059"]
	American_AISI_Z_Sections_W_Lips_I_4_8ZS2_75x065 = ["American","AISI","Z-Sections W Lips (I-4)","8ZS2.75x065"]
	American_AISI_Z_Sections_W_Lips_I_4_8ZS2_75x070 = ["American","AISI","Z-Sections W Lips (I-4)","8ZS2.75x070"]
	American_AISI_Z_Sections_W_Lips_I_4_8ZS2_75x085 = ["American","AISI","Z-Sections W Lips (I-4)","8ZS2.75x085"]
	American_AISI_Z_Sections_W_Lips_I_4_8ZS2_75x105 = ["American","AISI","Z-Sections W Lips (I-4)","8ZS2.75x105"]
	American_AISI_Z_Sections_W_Lips_I_4_8ZS3_25x059 = ["American","AISI","Z-Sections W Lips (I-4)","8ZS3.25x059"]
	American_AISI_Z_Sections_W_Lips_I_4_8ZS3_25x065 = ["American","AISI","Z-Sections W Lips (I-4)","8ZS3.25x065"]
	American_AISI_Z_Sections_W_Lips_I_4_8ZS3_25x070 = ["American","AISI","Z-Sections W Lips (I-4)","8ZS3.25x070"]
	American_AISI_Z_Sections_W_Lips_I_4_8ZS3_25x085 = ["American","AISI","Z-Sections W Lips (I-4)","8ZS3.25x085"]
	American_AISI_Z_Sections_W_Lips_I_4_8ZS3_25x105 = ["American","AISI","Z-Sections W Lips (I-4)","8ZS3.25x105"]
	American_AISI_Z_Sections_W_Lips_I_4_9ZS2_25x059 = ["American","AISI","Z-Sections W Lips (I-4)","9ZS2.25x059"]
	American_AISI_Z_Sections_W_Lips_I_4_9ZS2_25x065 = ["American","AISI","Z-Sections W Lips (I-4)","9ZS2.25x065"]
	American_AISI_Z_Sections_W_Lips_I_4_9ZS2_25x070 = ["American","AISI","Z-Sections W Lips (I-4)","9ZS2.25x070"]
	American_AISI_Z_Sections_W_Lips_I_4_9ZS2_25x085 = ["American","AISI","Z-Sections W Lips (I-4)","9ZS2.25x085"]
	American_AISI_Z_Sections_W_Lips_I_4_9ZS2_25x105 = ["American","AISI","Z-Sections W Lips (I-4)","9ZS2.25x105"]
	American_AISI_Z_Sections_W_Lips_I_4_10ZS2_25x059 = ["American","AISI","Z-Sections W Lips (I-4)","10ZS2.25x059"]
	American_AISI_Z_Sections_W_Lips_I_4_10ZS2_25x065 = ["American","AISI","Z-Sections W Lips (I-4)","10ZS2.25x065"]
	American_AISI_Z_Sections_W_Lips_I_4_10ZS2_25x070 = ["American","AISI","Z-Sections W Lips (I-4)","10ZS2.25x070"]
	American_AISI_Z_Sections_W_Lips_I_4_10ZS2_25x085 = ["American","AISI","Z-Sections W Lips (I-4)","10ZS2.25x085"]
	American_AISI_Z_Sections_W_Lips_I_4_10ZS2_25x105 = ["American","AISI","Z-Sections W Lips (I-4)","10ZS2.25x105"]
	American_AISI_Z_Sections_W_Lips_I_4_10ZS2_75x059 = ["American","AISI","Z-Sections W Lips (I-4)","10ZS2.75x059"]
	American_AISI_Z_Sections_W_Lips_I_4_10ZS2_75x065 = ["American","AISI","Z-Sections W Lips (I-4)","10ZS2.75x065"]
	American_AISI_Z_Sections_W_Lips_I_4_10ZS2_75x070 = ["American","AISI","Z-Sections W Lips (I-4)","10ZS2.75x070"]
	American_AISI_Z_Sections_W_Lips_I_4_10ZS2_75x085 = ["American","AISI","Z-Sections W Lips (I-4)","10ZS2.75x085"]
	American_AISI_Z_Sections_W_Lips_I_4_10ZS2_75x105 = ["American","AISI","Z-Sections W Lips (I-4)","10ZS2.75x105"]
	American_AISI_Z_Sections_W_Lips_I_4_10ZS3_25x059 = ["American","AISI","Z-Sections W Lips (I-4)","10ZS3.25x059"]
	American_AISI_Z_Sections_W_Lips_I_4_10ZS3_25x065 = ["American","AISI","Z-Sections W Lips (I-4)","10ZS3.25x065"]
	American_AISI_Z_Sections_W_Lips_I_4_10ZS3_25x070 = ["American","AISI","Z-Sections W Lips (I-4)","10ZS3.25x070"]
	American_AISI_Z_Sections_W_Lips_I_4_10ZS3_25x085 = ["American","AISI","Z-Sections W Lips (I-4)","10ZS3.25x085"]
	American_AISI_Z_Sections_W_Lips_I_4_10ZS3_25x105 = ["American","AISI","Z-Sections W Lips (I-4)","10ZS3.25x105"]
	American_AISI_Z_Sections_W_Lips_I_4_12ZS2_25x070 = ["American","AISI","Z-Sections W Lips (I-4)","12ZS2.25x070"]
	American_AISI_Z_Sections_W_Lips_I_4_12ZS2_25x085 = ["American","AISI","Z-Sections W Lips (I-4)","12ZS2.25x085"]
	American_AISI_Z_Sections_W_Lips_I_4_12ZS2_25x105 = ["American","AISI","Z-Sections W Lips (I-4)","12ZS2.25x105"]
	American_AISI_Z_Sections_W_Lips_I_4_12ZS2_75x070 = ["American","AISI","Z-Sections W Lips (I-4)","12ZS2.75x070"]
	American_AISI_Z_Sections_W_Lips_I_4_12ZS2_75x085 = ["American","AISI","Z-Sections W Lips (I-4)","12ZS2.75x085"]
	American_AISI_Z_Sections_W_Lips_I_4_12ZS2_75x105 = ["American","AISI","Z-Sections W Lips (I-4)","12ZS2.75x105"]
	American_AISI_Z_Sections_W_Lips_I_4_12ZS3_25x070 = ["American","AISI","Z-Sections W Lips (I-4)","12ZS3.25x070"]
	American_AISI_Z_Sections_W_Lips_I_4_12ZS3_25x085 = ["American","AISI","Z-Sections W Lips (I-4)","12ZS3.25x085"]
	American_AISI_Z_Sections_W_Lips_I_4_12ZS3_25x105 = ["American","AISI","Z-Sections W Lips (I-4)","12ZS3.25x105"]
	American_AISI_Z_Sections_WO_Lips_I_5_1_5ZU1_25x036 = ["American","AISI","Z-Sections WO Lips (I-5)","1.5ZU1.25x036"]
	American_AISI_Z_Sections_WO_Lips_I_5_1_5ZU1_25x048 = ["American","AISI","Z-Sections WO Lips (I-5)","1.5ZU1.25x048"]
	American_AISI_Z_Sections_WO_Lips_I_5_1_5ZU1_25x060 = ["American","AISI","Z-Sections WO Lips (I-5)","1.5ZU1.25x060"]
	American_AISI_Z_Sections_WO_Lips_I_5_1_5ZU1_25x075 = ["American","AISI","Z-Sections WO Lips (I-5)","1.5ZU1.25x075"]
	American_AISI_Z_Sections_WO_Lips_I_5_1_5ZU1_25x090 = ["American","AISI","Z-Sections WO Lips (I-5)","1.5ZU1.25x090"]
	American_AISI_Z_Sections_WO_Lips_I_5_2_5ZU1_25x036 = ["American","AISI","Z-Sections WO Lips (I-5)","2.5ZU1.25x036"]
	American_AISI_Z_Sections_WO_Lips_I_5_2_5ZU1_25x048 = ["American","AISI","Z-Sections WO Lips (I-5)","2.5ZU1.25x048"]
	American_AISI_Z_Sections_WO_Lips_I_5_2_5ZU1_25x060 = ["American","AISI","Z-Sections WO Lips (I-5)","2.5ZU1.25x060"]
	American_AISI_Z_Sections_WO_Lips_I_5_2_5ZU1_25x075 = ["American","AISI","Z-Sections WO Lips (I-5)","2.5ZU1.25x075"]
	American_AISI_Z_Sections_WO_Lips_I_5_2_5ZU1_25x090 = ["American","AISI","Z-Sections WO Lips (I-5)","2.5ZU1.25x090"]
	American_AISI_Z_Sections_WO_Lips_I_5_3_625ZU1_25x036 = ["American","AISI","Z-Sections WO Lips (I-5)","3.625ZU1.25x036"]
	American_AISI_Z_Sections_WO_Lips_I_5_3_625ZU1_25x048 = ["American","AISI","Z-Sections WO Lips (I-5)","3.625ZU1.25x048"]
	American_AISI_Z_Sections_WO_Lips_I_5_3_625ZU1_25x060 = ["American","AISI","Z-Sections WO Lips (I-5)","3.625ZU1.25x060"]
	American_AISI_Z_Sections_WO_Lips_I_5_3_625ZU1_25x075 = ["American","AISI","Z-Sections WO Lips (I-5)","3.625ZU1.25x075"]
	American_AISI_Z_Sections_WO_Lips_I_5_3_625ZU1_25x090 = ["American","AISI","Z-Sections WO Lips (I-5)","3.625ZU1.25x090"]
	American_AISI_Z_Sections_WO_Lips_I_5_4ZU1_25x036 = ["American","AISI","Z-Sections WO Lips (I-5)","4ZU1.25x036"]
	American_AISI_Z_Sections_WO_Lips_I_5_4ZU1_25x048 = ["American","AISI","Z-Sections WO Lips (I-5)","4ZU1.25x048"]
	American_AISI_Z_Sections_WO_Lips_I_5_4ZU1_25x060 = ["American","AISI","Z-Sections WO Lips (I-5)","4ZU1.25x060"]
	American_AISI_Z_Sections_WO_Lips_I_5_4ZU1_25x075 = ["American","AISI","Z-Sections WO Lips (I-5)","4ZU1.25x075"]
	American_AISI_Z_Sections_WO_Lips_I_5_4ZU1_25x090 = ["American","AISI","Z-Sections WO Lips (I-5)","4ZU1.25x090"]
	American_AISI_Z_Sections_WO_Lips_I_5_6ZU1_25x048 = ["American","AISI","Z-Sections WO Lips (I-5)","6ZU1.25x048"]
	American_AISI_Z_Sections_WO_Lips_I_5_6ZU1_25x060 = ["American","AISI","Z-Sections WO Lips (I-5)","6ZU1.25x060"]
	American_AISI_Z_Sections_WO_Lips_I_5_6ZU1_25x075 = ["American","AISI","Z-Sections WO Lips (I-5)","6ZU1.25x075"]
	American_AISI_Z_Sections_WO_Lips_I_5_6ZU1_25x090 = ["American","AISI","Z-Sections WO Lips (I-5)","6ZU1.25x090"]
	American_AISI_Z_Sections_WO_Lips_I_5_6ZU1_25x105 = ["American","AISI","Z-Sections WO Lips (I-5)","6ZU1.25x105"]
	American_AISI_Z_Sections_WO_Lips_I_5_8ZU1_25x048 = ["American","AISI","Z-Sections WO Lips (I-5)","8ZU1.25x048"]
	American_AISI_Z_Sections_WO_Lips_I_5_8ZU1_25x060 = ["American","AISI","Z-Sections WO Lips (I-5)","8ZU1.25x060"]
	American_AISI_Z_Sections_WO_Lips_I_5_8ZU1_25x075 = ["American","AISI","Z-Sections WO Lips (I-5)","8ZU1.25x075"]
	American_AISI_Z_Sections_WO_Lips_I_5_8ZU1_25x090 = ["American","AISI","Z-Sections WO Lips (I-5)","8ZU1.25x090"]
	American_AISI_Z_Sections_WO_Lips_I_5_8ZU1_25x105 = ["American","AISI","Z-Sections WO Lips (I-5)","8ZU1.25x105"]
	American_AISI_EL_Angles_W_Lips_I_6_2_5LS2_5x060 = ["American","AISI","EL Angles W Lips (I-6)","2.5LS2.5x060"]
	American_AISI_EL_Angles_W_Lips_I_6_2_5LS2_5x075 = ["American","AISI","EL Angles W Lips (I-6)","2.5LS2.5x075"]
	American_AISI_EL_Angles_W_Lips_I_6_2_5LS2_5x090 = ["American","AISI","EL Angles W Lips (I-6)","2.5LS2.5x090"]
	American_AISI_EL_Angles_W_Lips_I_6_2_5LS2_5x105 = ["American","AISI","EL Angles W Lips (I-6)","2.5LS2.5x105"]
	American_AISI_EL_Angles_W_Lips_I_6_2_5LS2_5x135 = ["American","AISI","EL Angles W Lips (I-6)","2.5LS2.5x135"]
	American_AISI_EL_Angles_W_Lips_I_6_2LS2x060 = ["American","AISI","EL Angles W Lips (I-6)","2LS2x060"]
	American_AISI_EL_Angles_W_Lips_I_6_2LS2x075 = ["American","AISI","EL Angles W Lips (I-6)","2LS2x075"]
	American_AISI_EL_Angles_W_Lips_I_6_2LS2x090 = ["American","AISI","EL Angles W Lips (I-6)","2LS2x090"]
	American_AISI_EL_Angles_W_Lips_I_6_2LS2x105 = ["American","AISI","EL Angles W Lips (I-6)","2LS2x105"]
	American_AISI_EL_Angles_W_Lips_I_6_2LS2x135 = ["American","AISI","EL Angles W Lips (I-6)","2LS2x135"]
	American_AISI_EL_Angles_W_Lips_I_6_3LS3x060 = ["American","AISI","EL Angles W Lips (I-6)","3LS3x060"]
	American_AISI_EL_Angles_W_Lips_I_6_3LS3x075 = ["American","AISI","EL Angles W Lips (I-6)","3LS3x075"]
	American_AISI_EL_Angles_W_Lips_I_6_3LS3x090 = ["American","AISI","EL Angles W Lips (I-6)","3LS3x090"]
	American_AISI_EL_Angles_W_Lips_I_6_3LS3x105 = ["American","AISI","EL Angles W Lips (I-6)","3LS3x105"]
	American_AISI_EL_Angles_W_Lips_I_6_3LS3x135 = ["American","AISI","EL Angles W Lips (I-6)","3LS3x135"]
	American_AISI_EL_Angles_W_Lips_I_6_4LS4x060 = ["American","AISI","EL Angles W Lips (I-6)","4LS4x060"]
	American_AISI_EL_Angles_W_Lips_I_6_4LS4x075 = ["American","AISI","EL Angles W Lips (I-6)","4LS4x075"]
	American_AISI_EL_Angles_W_Lips_I_6_4LS4x090 = ["American","AISI","EL Angles W Lips (I-6)","4LS4x090"]
	American_AISI_EL_Angles_W_Lips_I_6_4LS4x105 = ["American","AISI","EL Angles W Lips (I-6)","4LS4x105"]
	American_AISI_EL_Angles_W_Lips_I_6_4LS4x135 = ["American","AISI","EL Angles W Lips (I-6)","4LS4x135"]
	American_AISI_EL_Angles_WO_Lips_I_7_2_5LU2_5x060 = ["American","AISI","EL Angles WO Lips (I-7)","2.5LU2.5x060"]
	American_AISI_EL_Angles_WO_Lips_I_7_2_5LU2_5x075 = ["American","AISI","EL Angles WO Lips (I-7)","2.5LU2.5x075"]
	American_AISI_EL_Angles_WO_Lips_I_7_2_5LU2_5x090 = ["American","AISI","EL Angles WO Lips (I-7)","2.5LU2.5x090"]
	American_AISI_EL_Angles_WO_Lips_I_7_2_5LU2_5x105 = ["American","AISI","EL Angles WO Lips (I-7)","2.5LU2.5x105"]
	American_AISI_EL_Angles_WO_Lips_I_7_2_5LU2_5x135 = ["American","AISI","EL Angles WO Lips (I-7)","2.5LU2.5x135"]
	American_AISI_EL_Angles_WO_Lips_I_7_2LU2x060 = ["American","AISI","EL Angles WO Lips (I-7)","2LU2x060"]
	American_AISI_EL_Angles_WO_Lips_I_7_2LU2x075 = ["American","AISI","EL Angles WO Lips (I-7)","2LU2x075"]
	American_AISI_EL_Angles_WO_Lips_I_7_2LU2x090 = ["American","AISI","EL Angles WO Lips (I-7)","2LU2x090"]
	American_AISI_EL_Angles_WO_Lips_I_7_2LU2x105 = ["American","AISI","EL Angles WO Lips (I-7)","2LU2x105"]
	American_AISI_EL_Angles_WO_Lips_I_7_2LU2x135 = ["American","AISI","EL Angles WO Lips (I-7)","2LU2x135"]
	American_AISI_EL_Angles_WO_Lips_I_7_3LU3x060 = ["American","AISI","EL Angles WO Lips (I-7)","3LU3x060"]
	American_AISI_EL_Angles_WO_Lips_I_7_3LU3x075 = ["American","AISI","EL Angles WO Lips (I-7)","3LU3x075"]
	American_AISI_EL_Angles_WO_Lips_I_7_3LU3x090 = ["American","AISI","EL Angles WO Lips (I-7)","3LU3x090"]
	American_AISI_EL_Angles_WO_Lips_I_7_3LU3x105 = ["American","AISI","EL Angles WO Lips (I-7)","3LU3x105"]
	American_AISI_EL_Angles_WO_Lips_I_7_3LU3x135 = ["American","AISI","EL Angles WO Lips (I-7)","3LU3x135"]
	American_AISI_EL_Angles_WO_Lips_I_7_4LU4x060 = ["American","AISI","EL Angles WO Lips (I-7)","4LU4x060"]
	American_AISI_EL_Angles_WO_Lips_I_7_4LU4x075 = ["American","AISI","EL Angles WO Lips (I-7)","4LU4x075"]
	American_AISI_EL_Angles_WO_Lips_I_7_4LU4x090 = ["American","AISI","EL Angles WO Lips (I-7)","4LU4x090"]
	American_AISI_EL_Angles_WO_Lips_I_7_4LU4x105 = ["American","AISI","EL Angles WO Lips (I-7)","4LU4x105"]
	American_AISI_EL_Angles_WO_Lips_I_7_4LU4x135 = ["American","AISI","EL Angles WO Lips (I-7)","4LU4x135"]
	American_AISI_Hat_Sections_I_8_3HU3x075 = ["American","AISI","Hat Sections (I-8)","3HU3x075"]
	American_AISI_Hat_Sections_I_8_3HU3x105 = ["American","AISI","Hat Sections (I-8)","3HU3x105"]
	American_AISI_Hat_Sections_I_8_3HU4_5x105 = ["American","AISI","Hat Sections (I-8)","3HU4.5x105"]
	American_AISI_Hat_Sections_I_8_3HU4_5x135 = ["American","AISI","Hat Sections (I-8)","3HU4.5x135"]
	American_AISI_Hat_Sections_I_8_4HU2x048 = ["American","AISI","Hat Sections (I-8)","4HU2x048"]
	American_AISI_Hat_Sections_I_8_4HU2x060 = ["American","AISI","Hat Sections (I-8)","4HU2x060"]
	American_AISI_Hat_Sections_I_8_4HU2x075 = ["American","AISI","Hat Sections (I-8)","4HU2x075"]
	American_AISI_Hat_Sections_I_8_4HU4x075 = ["American","AISI","Hat Sections (I-8)","4HU4x075"]
	American_AISI_Hat_Sections_I_8_4HU4x105 = ["American","AISI","Hat Sections (I-8)","4HU4x105"]
	American_AISI_Hat_Sections_I_8_4HU6x105 = ["American","AISI","Hat Sections (I-8)","4HU6x105"]
	American_AISI_Hat_Sections_I_8_4HU6x135 = ["American","AISI","Hat Sections (I-8)","4HU6x135"]
	American_AISI_Hat_Sections_I_8_6HU3x048 = ["American","AISI","Hat Sections (I-8)","6HU3x048"]
	American_AISI_Hat_Sections_I_8_6HU3x060 = ["American","AISI","Hat Sections (I-8)","6HU3x060"]
	American_AISI_Hat_Sections_I_8_6HU3x075 = ["American","AISI","Hat Sections (I-8)","6HU3x075"]
	American_AISI_Hat_Sections_I_8_6HU6x075 = ["American","AISI","Hat Sections (I-8)","6HU6x075"]
	American_AISI_Hat_Sections_I_8_6HU6x105 = ["American","AISI","Hat Sections (I-8)","6HU6x105"]
	American_AISI_Hat_Sections_I_8_6HU9x105 = ["American","AISI","Hat Sections (I-8)","6HU9x105"]
	American_AISI_Hat_Sections_I_8_6HU9x135 = ["American","AISI","Hat Sections (I-8)","6HU9x135"]
	American_AISI_Hat_Sections_I_8_8HU4x060 = ["American","AISI","Hat Sections (I-8)","8HU4x060"]
	American_AISI_Hat_Sections_I_8_8HU4x075 = ["American","AISI","Hat Sections (I-8)","8HU4x075"]
	American_AISI_Hat_Sections_I_8_8HU8x075 = ["American","AISI","Hat Sections (I-8)","8HU8x075"]
	American_AISI_Hat_Sections_I_8_8HU8x105 = ["American","AISI","Hat Sections (I-8)","8HU8x105"]
	American_AISI_Hat_Sections_I_8_8HU12x105 = ["American","AISI","Hat Sections (I-8)","8HU12x105"]
	American_AISI_Hat_Sections_I_8_8HU12x135 = ["American","AISI","Hat Sections (I-8)","8HU12x135"]
	American_AISI_Hat_Sections_I_8_10HU5x075 = ["American","AISI","Hat Sections (I-8)","10HU5x075"]
	American_NDS_Sawn_Lumber_1_x_3 = ["American","NDS","Sawn Lumber","1 x 3"]
	American_NDS_Sawn_Lumber_1_x_4 = ["American","NDS","Sawn Lumber","1 x 4"]
	American_NDS_Sawn_Lumber_1_x_6 = ["American","NDS","Sawn Lumber","1 x 6"]
	American_NDS_Sawn_Lumber_1_x_8 = ["American","NDS","Sawn Lumber","1 x 8"]
	American_NDS_Sawn_Lumber_1_x_10 = ["American","NDS","Sawn Lumber","1 x 10"]
	American_NDS_Sawn_Lumber_1_x_12 = ["American","NDS","Sawn Lumber","1 x 12"]
	American_NDS_Sawn_Lumber_2_x_3 = ["American","NDS","Sawn Lumber","2 x 3"]
	American_NDS_Sawn_Lumber_2_x_4 = ["American","NDS","Sawn Lumber","2 x 4"]
	American_NDS_Sawn_Lumber_2_x_5 = ["American","NDS","Sawn Lumber","2 x 5"]
	American_NDS_Sawn_Lumber_2_x_6 = ["American","NDS","Sawn Lumber","2 x 6"]
	American_NDS_Sawn_Lumber_2_x_8 = ["American","NDS","Sawn Lumber","2 x 8"]
	American_NDS_Sawn_Lumber_2_x_10 = ["American","NDS","Sawn Lumber","2 x 10"]
	American_NDS_Sawn_Lumber_2_x_12 = ["American","NDS","Sawn Lumber","2 x 12"]
	American_NDS_Sawn_Lumber_2_x_14 = ["American","NDS","Sawn Lumber","2 x 14"]
	American_NDS_Sawn_Lumber_3_x_4 = ["American","NDS","Sawn Lumber","3 x 4"]
	American_NDS_Sawn_Lumber_3_x_5 = ["American","NDS","Sawn Lumber","3 x 5"]
	American_NDS_Sawn_Lumber_3_x_6 = ["American","NDS","Sawn Lumber","3 x 6"]
	American_NDS_Sawn_Lumber_3_x_8 = ["American","NDS","Sawn Lumber","3 x 8"]
	American_NDS_Sawn_Lumber_3_x_10 = ["American","NDS","Sawn Lumber","3 x 10"]
	American_NDS_Sawn_Lumber_3_x_12 = ["American","NDS","Sawn Lumber","3 x 12"]
	American_NDS_Sawn_Lumber_3_x_14 = ["American","NDS","Sawn Lumber","3 x 14"]
	American_NDS_Sawn_Lumber_3_x_16 = ["American","NDS","Sawn Lumber","3 x 16"]
	American_NDS_Sawn_Lumber_4_x_4 = ["American","NDS","Sawn Lumber","4 x 4"]
	American_NDS_Sawn_Lumber_4_x_5 = ["American","NDS","Sawn Lumber","4 x 5"]
	American_NDS_Sawn_Lumber_4_x_6 = ["American","NDS","Sawn Lumber","4 x 6"]
	American_NDS_Sawn_Lumber_4_x_8 = ["American","NDS","Sawn Lumber","4 x 8"]
	American_NDS_Sawn_Lumber_4_x_10 = ["American","NDS","Sawn Lumber","4 x 10"]
	American_NDS_Sawn_Lumber_4_x_12 = ["American","NDS","Sawn Lumber","4 x 12"]
	American_NDS_Sawn_Lumber_4_x_14 = ["American","NDS","Sawn Lumber","4 x 14"]
	American_NDS_Sawn_Lumber_4_x_16 = ["American","NDS","Sawn Lumber","4 x 16"]
	American_NDS_Sawn_Lumber_5_x_5 = ["American","NDS","Sawn Lumber","5 x 5"]
	American_NDS_Sawn_Lumber_6_x_6 = ["American","NDS","Sawn Lumber","6 x 6"]
	American_NDS_Sawn_Lumber_6_x_8 = ["American","NDS","Sawn Lumber","6 x 8"]
	American_NDS_Sawn_Lumber_6_x_10 = ["American","NDS","Sawn Lumber","6 x 10"]
	American_NDS_Sawn_Lumber_6_x_12 = ["American","NDS","Sawn Lumber","6 x 12"]
	American_NDS_Sawn_Lumber_6_x_14 = ["American","NDS","Sawn Lumber","6 x 14"]
	American_NDS_Sawn_Lumber_6_x_16 = ["American","NDS","Sawn Lumber","6 x 16"]
	American_NDS_Sawn_Lumber_6_x_18 = ["American","NDS","Sawn Lumber","6 x 18"]
	American_NDS_Sawn_Lumber_6_x_20 = ["American","NDS","Sawn Lumber","6 x 20"]
	American_NDS_Sawn_Lumber_6_x_22 = ["American","NDS","Sawn Lumber","6 x 22"]
	American_NDS_Sawn_Lumber_6_x_24 = ["American","NDS","Sawn Lumber","6 x 24"]
	American_NDS_Sawn_Lumber_8_x_8 = ["American","NDS","Sawn Lumber","8 x 8"]
	American_NDS_Sawn_Lumber_8_x_10 = ["American","NDS","Sawn Lumber","8 x 10"]
	American_NDS_Sawn_Lumber_8_x_12 = ["American","NDS","Sawn Lumber","8 x 12"]
	American_NDS_Sawn_Lumber_8_x_14 = ["American","NDS","Sawn Lumber","8 x 14"]
	American_NDS_Sawn_Lumber_8_x_16 = ["American","NDS","Sawn Lumber","8 x 16"]
	American_NDS_Sawn_Lumber_8_x_18 = ["American","NDS","Sawn Lumber","8 x 18"]
	American_NDS_Sawn_Lumber_8_x_20 = ["American","NDS","Sawn Lumber","8 x 20"]
	American_NDS_Sawn_Lumber_8_x_22 = ["American","NDS","Sawn Lumber","8 x 22"]
	American_NDS_Sawn_Lumber_8_x_24 = ["American","NDS","Sawn Lumber","8 x 24"]
	American_NDS_Sawn_Lumber_10_x_10 = ["American","NDS","Sawn Lumber","10 x 10"]
	American_NDS_Sawn_Lumber_10_x_12 = ["American","NDS","Sawn Lumber","10 x 12"]
	American_NDS_Sawn_Lumber_10_x_14 = ["American","NDS","Sawn Lumber","10 x 14"]
	American_NDS_Sawn_Lumber_10_x_16 = ["American","NDS","Sawn Lumber","10 x 16"]
	American_NDS_Sawn_Lumber_10_x_18 = ["American","NDS","Sawn Lumber","10 x 18"]
	American_NDS_Sawn_Lumber_10_x_20 = ["American","NDS","Sawn Lumber","10 x 20"]
	American_NDS_Sawn_Lumber_10_x_22 = ["American","NDS","Sawn Lumber","10 x 22"]
	American_NDS_Sawn_Lumber_10_x_24 = ["American","NDS","Sawn Lumber","10 x 24"]
	American_NDS_Sawn_Lumber_12_x_12 = ["American","NDS","Sawn Lumber","12 x 12"]
	American_NDS_Sawn_Lumber_12_x_14 = ["American","NDS","Sawn Lumber","12 x 14"]
	American_NDS_Sawn_Lumber_12_x_16 = ["American","NDS","Sawn Lumber","12 x 16"]
	American_NDS_Sawn_Lumber_12_x_18 = ["American","NDS","Sawn Lumber","12 x 18"]
	American_NDS_Sawn_Lumber_12_x_20 = ["American","NDS","Sawn Lumber","12 x 20"]
	American_NDS_Sawn_Lumber_12_x_22 = ["American","NDS","Sawn Lumber","12 x 22"]
	American_NDS_Sawn_Lumber_12_x_24 = ["American","NDS","Sawn Lumber","12 x 24"]
	American_NDS_Sawn_Lumber_14_x_14 = ["American","NDS","Sawn Lumber","14 x 14"]
	American_NDS_Sawn_Lumber_14_x_16 = ["American","NDS","Sawn Lumber","14 x 16"]
	American_NDS_Sawn_Lumber_14_x_18 = ["American","NDS","Sawn Lumber","14 x 18"]
	American_NDS_Sawn_Lumber_14_x_20 = ["American","NDS","Sawn Lumber","14 x 20"]
	American_NDS_Sawn_Lumber_14_x_22 = ["American","NDS","Sawn Lumber","14 x 22"]
	American_NDS_Sawn_Lumber_14_x_24 = ["American","NDS","Sawn Lumber","14 x 24"]
	American_NDS_Sawn_Lumber_16_x_16 = ["American","NDS","Sawn Lumber","16 x 16"]
	American_NDS_Sawn_Lumber_16_x_18 = ["American","NDS","Sawn Lumber","16 x 18"]
	American_NDS_Sawn_Lumber_16_x_20 = ["American","NDS","Sawn Lumber","16 x 20"]
	American_NDS_Sawn_Lumber_16_x_22 = ["American","NDS","Sawn Lumber","16 x 22"]
	American_NDS_Sawn_Lumber_16_x_24 = ["American","NDS","Sawn Lumber","16 x 24"]
	American_NDS_Sawn_Lumber_18_x_18 = ["American","NDS","Sawn Lumber","18 x 18"]
	American_NDS_Sawn_Lumber_18_x_20 = ["American","NDS","Sawn Lumber","18 x 20"]
	American_NDS_Sawn_Lumber_18_x_22 = ["American","NDS","Sawn Lumber","18 x 22"]
	American_NDS_Sawn_Lumber_18_x_24 = ["American","NDS","Sawn Lumber","18 x 24"]
	American_NDS_Sawn_Lumber_20_x_20 = ["American","NDS","Sawn Lumber","20 x 20"]
	American_NDS_Sawn_Lumber_20_x_22 = ["American","NDS","Sawn Lumber","20 x 22"]
	American_NDS_Sawn_Lumber_20_x_24 = ["American","NDS","Sawn Lumber","20 x 24"]
	American_NDS_Sawn_Lumber_22_x_22 = ["American","NDS","Sawn Lumber","22 x 22"]
	American_NDS_Sawn_Lumber_22_x_24 = ["American","NDS","Sawn Lumber","22 x 24"]
	American_NDS_Sawn_Lumber_24_x_24 = ["American","NDS","Sawn Lumber","24 x 24"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_2_12_x_6 = ["American","NDS","Western Species Structural Glued Laminated Timber","2-1/2 x 6"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_2_12_x_7_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","2-1/2 x 7-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_2_12_x_9 = ["American","NDS","Western Species Structural Glued Laminated Timber","2-1/2 x 9"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_2_12_x_10_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","2-1/2 x 10-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_2_12_x_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","2-1/2 x 12"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_2_12_x_13_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","2-1/2 x 13-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_2_12_x_15 = ["American","NDS","Western Species Structural Glued Laminated Timber","2-1/2 x 15"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_2_12_x_16_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","2-1/2 x 16-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_2_12_x_18 = ["American","NDS","Western Species Structural Glued Laminated Timber","2-1/2 x 18"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_2_12_x_19_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","2-1/2 x 19-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_2_12_x_21 = ["American","NDS","Western Species Structural Glued Laminated Timber","2-1/2 x 21"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_3_12_x_6 = ["American","NDS","Western Species Structural Glued Laminated Timber","3-1/2 x 6"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_3_12_x_7_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","3-1/2 x 7-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_3_12_x_9 = ["American","NDS","Western Species Structural Glued Laminated Timber","3-1/2 x 9"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_3_12_x_9_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","3-1/2 x 9-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_3_12_x_9_14 = ["American","NDS","Western Species Structural Glued Laminated Timber","3-1/2 x 9-1/4"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_3_12_x_10_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","3-1/2 x 10-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_3_12_x_11_14 = ["American","NDS","Western Species Structural Glued Laminated Timber","3-1/2 x 11-1/4"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_3_12_x_11_78 = ["American","NDS","Western Species Structural Glued Laminated Timber","3-1/2 x 11-7/8"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_3_12_x_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","3-1/2 x 12"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_3_12_x_13_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","3-1/2 x 13-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_3_12_x_14 = ["American","NDS","Western Species Structural Glued Laminated Timber","3-1/2 x 14"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_3_12_x_15 = ["American","NDS","Western Species Structural Glued Laminated Timber","3-1/2 x 15"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_3_12_x_16 = ["American","NDS","Western Species Structural Glued Laminated Timber","3-1/2 x 16"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_3_12_x_16_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","3-1/2 x 16-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_3_12_x_18 = ["American","NDS","Western Species Structural Glued Laminated Timber","3-1/2 x 18"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_3_12_x_19_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","3-1/2 x 19-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_3_12_x_20 = ["American","NDS","Western Species Structural Glued Laminated Timber","3-1/2 x 20"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_3_12_x_21 = ["American","NDS","Western Species Structural Glued Laminated Timber","3-1/2 x 21"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_3_12_x_22 = ["American","NDS","Western Species Structural Glued Laminated Timber","3-1/2 x 22"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_3_12_x_22_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","3-1/2 x 22-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_3_12_x_24 = ["American","NDS","Western Species Structural Glued Laminated Timber","3-1/2 x 24"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_3_18_x_6 = ["American","NDS","Western Species Structural Glued Laminated Timber","3-1/8 x 6"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_3_18_x_7_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","3-1/8 x 7-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_3_18_x_9 = ["American","NDS","Western Species Structural Glued Laminated Timber","3-1/8 x 9"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_3_18_x_10_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","3-1/8 x 10-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_3_18_x_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","3-1/8 x 12"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_3_18_x_13_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","3-1/8 x 13-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_3_18_x_15 = ["American","NDS","Western Species Structural Glued Laminated Timber","3-1/8 x 15"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_3_18_x_16_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","3-1/8 x 16-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_3_18_x_18 = ["American","NDS","Western Species Structural Glued Laminated Timber","3-1/8 x 18"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_3_18_x_19_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","3-1/8 x 19-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_3_18_x_21 = ["American","NDS","Western Species Structural Glued Laminated Timber","3-1/8 x 21"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_3_18_x_22_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","3-1/8 x 22-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_3_18_x_24 = ["American","NDS","Western Species Structural Glued Laminated Timber","3-1/8 x 24"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_5_12_x_6 = ["American","NDS","Western Species Structural Glued Laminated Timber","5-1/2 x 6"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_5_12_x_7_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","5-1/2 x 7-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_5_12_x_9 = ["American","NDS","Western Species Structural Glued Laminated Timber","5-1/2 x 9"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_5_12_x_9_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","5-1/2 x 9-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_5_12_x_9_14 = ["American","NDS","Western Species Structural Glued Laminated Timber","5-1/2 x 9-1/4"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_5_12_x_10_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","5-1/2 x 10-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_5_12_x_11_14 = ["American","NDS","Western Species Structural Glued Laminated Timber","5-1/2 x 11-1/4"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_5_12_x_11_78 = ["American","NDS","Western Species Structural Glued Laminated Timber","5-1/2 x 11-7/8"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_5_12_x_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","5-1/2 x 12"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_5_12_x_13_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","5-1/2 x 13-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_5_12_x_14 = ["American","NDS","Western Species Structural Glued Laminated Timber","5-1/2 x 14"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_5_12_x_15 = ["American","NDS","Western Species Structural Glued Laminated Timber","5-1/2 x 15"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_5_12_x_16 = ["American","NDS","Western Species Structural Glued Laminated Timber","5-1/2 x 16"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_5_12_x_16_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","5-1/2 x 16-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_5_12_x_18 = ["American","NDS","Western Species Structural Glued Laminated Timber","5-1/2 x 18"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_5_12_x_19_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","5-1/2 x 19-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_5_12_x_20 = ["American","NDS","Western Species Structural Glued Laminated Timber","5-1/2 x 20"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_5_12_x_21 = ["American","NDS","Western Species Structural Glued Laminated Timber","5-1/2 x 21"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_5_12_x_22 = ["American","NDS","Western Species Structural Glued Laminated Timber","5-1/2 x 22"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_5_12_x_22_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","5-1/2 x 22-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_5_12_x_24 = ["American","NDS","Western Species Structural Glued Laminated Timber","5-1/2 x 24"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_5_12_x_25_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","5-1/2 x 25-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_5_12_x_27 = ["American","NDS","Western Species Structural Glued Laminated Timber","5-1/2 x 27"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_5_12_x_28_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","5-1/2 x 28-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_5_12_x_30 = ["American","NDS","Western Species Structural Glued Laminated Timber","5-1/2 x 30"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_5_12_x_31_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","5-1/2 x 31-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_5_12_x_33 = ["American","NDS","Western Species Structural Glued Laminated Timber","5-1/2 x 33"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_5_12_x_34_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","5-1/2 x 34-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_5_12_x_36 = ["American","NDS","Western Species Structural Glued Laminated Timber","5-1/2 x 36"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_6_34_x_7_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","6-3/4 x 7-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_6_34_x_9 = ["American","NDS","Western Species Structural Glued Laminated Timber","6-3/4 x 9"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_6_34_x_10_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","6-3/4 x 10-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_6_34_x_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","6-3/4 x 12"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_6_34_x_13_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","6-3/4 x 13-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_6_34_x_15 = ["American","NDS","Western Species Structural Glued Laminated Timber","6-3/4 x 15"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_6_34_x_16_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","6-3/4 x 16-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_6_34_x_18 = ["American","NDS","Western Species Structural Glued Laminated Timber","6-3/4 x 18"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_6_34_x_19_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","6-3/4 x 19-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_6_34_x_21 = ["American","NDS","Western Species Structural Glued Laminated Timber","6-3/4 x 21"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_6_34_x_22_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","6-3/4 x 22-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_6_34_x_24 = ["American","NDS","Western Species Structural Glued Laminated Timber","6-3/4 x 24"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_6_34_x_25_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","6-3/4 x 25-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_6_34_x_27 = ["American","NDS","Western Species Structural Glued Laminated Timber","6-3/4 x 27"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_6_34_x_28_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","6-3/4 x 28-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_6_34_x_30 = ["American","NDS","Western Species Structural Glued Laminated Timber","6-3/4 x 30"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_6_34_x_31_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","6-3/4 x 31-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_6_34_x_33 = ["American","NDS","Western Species Structural Glued Laminated Timber","6-3/4 x 33"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_6_34_x_34_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","6-3/4 x 34-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_6_34_x_36 = ["American","NDS","Western Species Structural Glued Laminated Timber","6-3/4 x 36"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_6_34_x_37_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","6-3/4 x 37-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_6_34_x_39 = ["American","NDS","Western Species Structural Glued Laminated Timber","6-3/4 x 39"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_6_34_x_40_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","6-3/4 x 40-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_6_34_x_42 = ["American","NDS","Western Species Structural Glued Laminated Timber","6-3/4 x 42"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_6_34_x_43_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","6-3/4 x 43-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_6_34_x_45 = ["American","NDS","Western Species Structural Glued Laminated Timber","6-3/4 x 45"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_6_34_x_46_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","6-3/4 x 46-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_6_34_x_48 = ["American","NDS","Western Species Structural Glued Laminated Timber","6-3/4 x 48"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_6_34_x_49_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","6-3/4 x 49-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_6_34_x_51 = ["American","NDS","Western Species Structural Glued Laminated Timber","6-3/4 x 51"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_6_34_x_52_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","6-3/4 x 52-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_6_34_x_54 = ["American","NDS","Western Species Structural Glued Laminated Timber","6-3/4 x 54"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_6_34_x_55_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","6-3/4 x 55-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_6_34_x_57 = ["American","NDS","Western Species Structural Glued Laminated Timber","6-3/4 x 57"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_6_34_x_58_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","6-3/4 x 58-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_6_34_x_60 = ["American","NDS","Western Species Structural Glued Laminated Timber","6-3/4 x 60"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_10_34_x_9 = ["American","NDS","Western Species Structural Glued Laminated Timber","10-3/4 x 9"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_10_34_x_10_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","10-3/4 x 10-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_10_34_x_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","10-3/4 x 12"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_10_34_x_13_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","10-3/4 x 13-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_10_34_x_15 = ["American","NDS","Western Species Structural Glued Laminated Timber","10-3/4 x 15"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_10_34_x_16_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","10-3/4 x 16-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_10_34_x_18 = ["American","NDS","Western Species Structural Glued Laminated Timber","10-3/4 x 18"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_10_34_x_19_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","10-3/4 x 19-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_10_34_x_21 = ["American","NDS","Western Species Structural Glued Laminated Timber","10-3/4 x 21"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_10_34_x_22_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","10-3/4 x 22-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_10_34_x_24 = ["American","NDS","Western Species Structural Glued Laminated Timber","10-3/4 x 24"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_10_34_x_25_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","10-3/4 x 25-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_10_34_x_27 = ["American","NDS","Western Species Structural Glued Laminated Timber","10-3/4 x 27"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_10_34_x_28_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","10-3/4 x 28-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_10_34_x_30 = ["American","NDS","Western Species Structural Glued Laminated Timber","10-3/4 x 30"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_10_34_x_31_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","10-3/4 x 31-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_10_34_x_33 = ["American","NDS","Western Species Structural Glued Laminated Timber","10-3/4 x 33"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_10_34_x_34_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","10-3/4 x 34-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_10_34_x_36 = ["American","NDS","Western Species Structural Glued Laminated Timber","10-3/4 x 36"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_10_34_x_37_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","10-3/4 x 37-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_10_34_x_39 = ["American","NDS","Western Species Structural Glued Laminated Timber","10-3/4 x 39"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_10_34_x_40_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","10-3/4 x 40-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_10_34_x_42 = ["American","NDS","Western Species Structural Glued Laminated Timber","10-3/4 x 42"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_10_34_x_43_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","10-3/4 x 43-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_10_34_x_45 = ["American","NDS","Western Species Structural Glued Laminated Timber","10-3/4 x 45"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_10_34_x_46_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","10-3/4 x 46-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_10_34_x_48 = ["American","NDS","Western Species Structural Glued Laminated Timber","10-3/4 x 48"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_10_34_x_49_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","10-3/4 x 49-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_10_34_x_51 = ["American","NDS","Western Species Structural Glued Laminated Timber","10-3/4 x 51"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_10_34_x_52_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","10-3/4 x 52-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_10_34_x_54 = ["American","NDS","Western Species Structural Glued Laminated Timber","10-3/4 x 54"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_10_34_x_55_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","10-3/4 x 55-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_10_34_x_57 = ["American","NDS","Western Species Structural Glued Laminated Timber","10-3/4 x 57"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_10_34_x_58_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","10-3/4 x 58-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_10_34_x_60 = ["American","NDS","Western Species Structural Glued Laminated Timber","10-3/4 x 60"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_12_14_x_13_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","12-1/4 x 13-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_12_14_x_15 = ["American","NDS","Western Species Structural Glued Laminated Timber","12-1/4 x 15"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_12_14_x_16_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","12-1/4 x 16-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_12_14_x_18 = ["American","NDS","Western Species Structural Glued Laminated Timber","12-1/4 x 18"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_12_14_x_19_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","12-1/4 x 19-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_12_14_x_21 = ["American","NDS","Western Species Structural Glued Laminated Timber","12-1/4 x 21"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_12_14_x_22_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","12-1/4 x 22-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_12_14_x_24 = ["American","NDS","Western Species Structural Glued Laminated Timber","12-1/4 x 24"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_12_14_x_25_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","12-1/4 x 25-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_12_14_x_27 = ["American","NDS","Western Species Structural Glued Laminated Timber","12-1/4 x 27"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_12_14_x_28_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","12-1/4 x 28-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_12_14_x_30 = ["American","NDS","Western Species Structural Glued Laminated Timber","12-1/4 x 30"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_12_14_x_31_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","12-1/4 x 31-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_12_14_x_33 = ["American","NDS","Western Species Structural Glued Laminated Timber","12-1/4 x 33"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_12_14_x_34_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","12-1/4 x 34-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_12_14_x_36 = ["American","NDS","Western Species Structural Glued Laminated Timber","12-1/4 x 36"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_12_14_x_37_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","12-1/4 x 37-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_12_14_x_39 = ["American","NDS","Western Species Structural Glued Laminated Timber","12-1/4 x 39"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_12_14_x_40_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","12-1/4 x 40-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_12_14_x_42 = ["American","NDS","Western Species Structural Glued Laminated Timber","12-1/4 x 42"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_12_14_x_43_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","12-1/4 x 43-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_12_14_x_45 = ["American","NDS","Western Species Structural Glued Laminated Timber","12-1/4 x 45"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_12_14_x_46_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","12-1/4 x 46-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_12_14_x_48 = ["American","NDS","Western Species Structural Glued Laminated Timber","12-1/4 x 48"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_12_14_x_49_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","12-1/4 x 49-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_12_14_x_51 = ["American","NDS","Western Species Structural Glued Laminated Timber","12-1/4 x 51"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_12_14_x_52_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","12-1/4 x 52-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_12_14_x_54 = ["American","NDS","Western Species Structural Glued Laminated Timber","12-1/4 x 54"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_12_14_x_55_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","12-1/4 x 55-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_12_14_x_57 = ["American","NDS","Western Species Structural Glued Laminated Timber","12-1/4 x 57"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_12_14_x_58_12 = ["American","NDS","Western Species Structural Glued Laminated Timber","12-1/4 x 58-1/2"]
	American_NDS_Western_Species_Structural_Glued_Laminated_Timber_12_14_x_60 = ["American","NDS","Western Species Structural Glued Laminated Timber","12-1/4 x 60"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_2_12_x_5_12 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","2-1/2 x 5-1/2"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_2_12_x_6_78 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","2-1/2 x 6-7/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_2_12_x_8_14 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","2-1/2 x 8-1/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_2_12_x_9_58 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","2-1/2 x 9-5/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_2_12_x_11 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","2-1/2 x 11"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_2_12_x_12_38 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","2-1/2 x 12-3/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_2_12_x_13_34 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","2-1/2 x 13-3/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_2_12_x_15_18 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","2-1/2 x 15-1/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_2_12_x_16_12 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","2-1/2 x 16-1/2"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_2_12_x_17_78 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","2-1/2 x 17-7/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_2_12_x_19_14 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","2-1/2 x 19-1/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_2_12_x_20_58 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","2-1/2 x 20-5/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_2_12_x_22 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","2-1/2 x 22"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_2_12_x_23_38 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","2-1/2 x 23-3/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_x_5_12 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3 x 5-1/2"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_x_6_78 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3 x 6-7/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_x_8_14 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3 x 8-1/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_x_9_58 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3 x 9-5/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_x_11 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3 x 11"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_x_12_38 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3 x 12-3/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_x_13_34 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3 x 13-3/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_x_15_18 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3 x 15-1/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_x_16_12 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3 x 16-1/2"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_x_17_78 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3 x 17-7/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_x_19_14 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3 x 19-1/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_x_20_58 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3 x 20-5/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_x_22 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3 x 22"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_x_23_38 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3 x 23-3/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_12_x_5_12 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3-1/2 x 5-1/2"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_12_x_6_78 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3-1/2 x 6-7/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_12_x_8_14 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3-1/2 x 8-1/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_12_x_9_12 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3-1/2 x 9-1/2"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_12_x_9_14 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3-1/2 x 9-1/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_12_x_9_58 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3-1/2 x 9-5/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_12_x_11 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3-1/2 x 11"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_12_x_11_14 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3-1/2 x 11-1/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_12_x_11_78 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3-1/2 x 11-7/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_12_x_12_38 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3-1/2 x 12-3/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_12_x_13_34 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3-1/2 x 13-3/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_12_x_14 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3-1/2 x 14"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_12_x_15_18 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3-1/2 x 15-1/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_12_x_16 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3-1/2 x 16"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_12_x_16_12 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3-1/2 x 16-1/2"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_12_x_17_78 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3-1/2 x 17-7/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_12_x_18 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3-1/2 x 18"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_12_x_19_14 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3-1/2 x 19-1/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_12_x_20 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3-1/2 x 20"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_12_x_20_58 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3-1/2 x 20-5/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_12_x_22 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3-1/2 x 22"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_12_x_23_38 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3-1/2 x 23-3/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_12_x_24 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3-1/2 x 24"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_18_x_5_12 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3-1/8 x 5-1/2"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_18_x_6_78 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3-1/8 x 6-7/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_18_x_8_14 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3-1/8 x 8-1/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_18_x_9_58 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3-1/8 x 9-5/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_18_x_11 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3-1/8 x 11"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_18_x_12_38 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3-1/8 x 12-3/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_18_x_13_34 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3-1/8 x 13-3/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_18_x_15_18 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3-1/8 x 15-1/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_18_x_16_12 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3-1/8 x 16-1/2"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_18_x_17_78 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3-1/8 x 17-7/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_18_x_19_14 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3-1/8 x 19-1/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_18_x_20_58 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3-1/8 x 20-5/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_18_x_22 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3-1/8 x 22"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_3_18_x_23_38 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","3-1/8 x 23-3/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_x_6_78 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5 x 6-7/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_x_8_14 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5 x 8-1/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_x_9_58 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5 x 9-5/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_x_11 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5 x 11"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_x_12_38 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5 x 12-3/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_x_13_34 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5 x 13-3/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_x_15_18 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5 x 15-1/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_x_16_12 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5 x 16-1/2"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_x_17_78 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5 x 17-7/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_x_19_14 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5 x 19-1/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_x_20_58 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5 x 20-5/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_x_22 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5 x 22"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_x_23_38 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5 x 23-3/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_x_24_34 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5 x 24-3/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_x_26_18 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5 x 26-1/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_x_27_12 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5 x 27-1/2"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_x_28_78 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5 x 28-7/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_x_30_14 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5 x 30-1/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_x_31_58 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5 x 31-5/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_x_33 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5 x 33"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_x_34_38 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5 x 34-3/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_x_35_34 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5 x 35-3/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_12_x_6_78 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/2 x 6-7/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_12_x_8_14 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/2 x 8-1/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_12_x_9_12 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/2 x 9-1/2"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_12_x_9_14 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/2 x 9-1/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_12_x_9_58 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/2 x 9-5/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_12_x_11 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/2 x 11"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_12_x_11_14 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/2 x 11-1/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_12_x_11_78 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/2 x 11-7/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_12_x_12_38 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/2 x 12-3/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_12_x_13_34 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/2 x 13-3/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_12_x_14 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/2 x 14"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_12_x_15_18 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/2 x 15-1/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_12_x_16 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/2 x 16"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_12_x_16_12 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/2 x 16-1/2"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_12_x_17_78 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/2 x 17-7/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_12_x_18 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/2 x 18"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_12_x_19_14 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/2 x 19-1/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_12_x_20 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/2 x 20"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_12_x_20_58 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/2 x 20-5/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_12_x_22 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/2 x 22"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_12_x_23_38 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/2 x 23-3/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_12_x_24 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/2 x 24"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_12_x_24_34 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/2 x 24-3/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_12_x_26_18 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/2 x 26-1/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_12_x_27_12 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/2 x 27-1/2"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_12_x_28_78 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/2 x 28-7/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_12_x_30_14 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/2 x 30-1/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_12_x_31_58 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/2 x 31-5/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_12_x_33 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/2 x 33"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_12_x_34_38 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/2 x 34-3/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_12_x_35_34 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/2 x 35-3/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_18_x_6_78 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/8 x 6-7/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_18_x_8_14 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/8 x 8-1/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_18_x_9_58 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/8 x 9-5/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_18_x_11 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/8 x 11"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_18_x_12_38 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/8 x 12-3/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_18_x_13_34 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/8 x 13-3/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_18_x_15_18 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/8 x 15-1/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_18_x_16_12 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/8 x 16-1/2"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_18_x_17_78 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/8 x 17-7/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_18_x_19_14 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/8 x 19-1/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_18_x_20_58 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/8 x 20-5/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_18_x_22 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/8 x 22"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_18_x_23_38 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/8 x 23-3/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_18_x_24_34 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/8 x 24-3/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_18_x_26_18 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/8 x 26-1/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_18_x_27_12 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/8 x 27-1/2"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_18_x_28_78 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/8 x 28-7/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_18_x_30_14 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/8 x 30-1/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_18_x_31_58 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/8 x 31-5/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_18_x_33 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/8 x 33"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_18_x_34_38 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/8 x 34-3/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_5_18_x_35_34 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","5-1/8 x 35-3/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_6_78 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 6-7/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_8_14 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 8-1/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_9_58 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 9-5/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_11 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 11"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_12_38 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 12-3/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_13_34 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 13-3/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_15_18 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 15-1/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_16_12 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 16-1/2"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_17_78 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 17-7/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_19_14 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 19-1/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_20_58 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 20-5/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_22 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 22"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_23_38 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 23-3/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_24_34 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 24-3/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_26_18 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 26-1/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_27_12 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 27-1/2"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_28_78 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 28-7/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_30_14 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 30-1/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_31_58 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 31-5/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_33 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 33"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_34_38 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 34-3/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_35_34 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 35-3/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_37_18 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 37-1/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_38_12 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 38-1/2"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_39_78 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 39-7/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_41_14 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 41-1/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_42_58 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 42-5/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_44 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 44"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_45_38 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 45-3/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_46_34 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 46-3/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_48_18 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 48-1/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_49_12 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 49-1/2"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_50_78 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 50-7/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_52_14 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 52-1/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_53_58 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 53-5/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_55 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 55"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_56_38 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 56-3/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_57_34 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 57-3/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_59_18 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 59-1/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_6_34_x_60_12 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","6-3/4 x 60-1/2"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_8_12_x_9_58 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","8-1/2 x 9-5/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_8_12_x_11 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","8-1/2 x 11"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_8_12_x_12_38 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","8-1/2 x 12-3/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_8_12_x_13_34 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","8-1/2 x 13-3/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_8_12_x_15_18 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","8-1/2 x 15-1/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_8_12_x_16_12 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","8-1/2 x 16-1/2"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_8_12_x_17_78 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","8-1/2 x 17-7/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_8_12_x_19_14 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","8-1/2 x 19-1/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_8_12_x_20_58 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","8-1/2 x 20-5/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_8_12_x_22 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","8-1/2 x 22"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_8_12_x_23_38 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","8-1/2 x 23-3/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_8_12_x_24_34 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","8-1/2 x 24-3/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_8_12_x_26_18 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","8-1/2 x 26-1/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_8_12_x_27_12 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","8-1/2 x 27-1/2"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_8_12_x_28_78 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","8-1/2 x 28-7/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_8_12_x_30_14 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","8-1/2 x 30-1/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_8_12_x_31_58 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","8-1/2 x 31-5/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_8_12_x_33 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","8-1/2 x 33"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_8_12_x_34_38 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","8-1/2 x 34-3/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_8_12_x_35_34 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","8-1/2 x 35-3/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_8_12_x_37_18 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","8-1/2 x 37-1/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_8_12_x_38_12 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","8-1/2 x 38-1/2"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_8_12_x_39_78 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","8-1/2 x 39-7/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_8_12_x_41_14 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","8-1/2 x 41-1/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_8_12_x_42_58 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","8-1/2 x 42-5/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_8_12_x_44 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","8-1/2 x 44"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_8_12_x_45_38 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","8-1/2 x 45-3/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_8_12_x_46_34 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","8-1/2 x 46-3/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_8_12_x_48_18 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","8-1/2 x 48-1/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_8_12_x_49_12 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","8-1/2 x 49-1/2"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_8_12_x_50_78 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","8-1/2 x 50-7/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_8_12_x_52_14 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","8-1/2 x 52-1/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_8_12_x_53_58 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","8-1/2 x 53-5/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_8_12_x_55 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","8-1/2 x 55"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_8_12_x_56_38 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","8-1/2 x 56-3/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_8_12_x_57_34 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","8-1/2 x 57-3/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_8_12_x_59_18 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","8-1/2 x 59-1/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_8_12_x_60_12 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","8-1/2 x 60-1/2"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_10_12_x_11 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","10-1/2 x 11"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_10_12_x_12_38 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","10-1/2 x 12-3/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_10_12_x_13_34 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","10-1/2 x 13-3/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_10_12_x_15_18 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","10-1/2 x 15-1/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_10_12_x_16_12 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","10-1/2 x 16-1/2"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_10_12_x_17_78 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","10-1/2 x 17-7/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_10_12_x_19_14 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","10-1/2 x 19-1/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_10_12_x_20_58 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","10-1/2 x 20-5/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_10_12_x_22 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","10-1/2 x 22"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_10_12_x_23_38 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","10-1/2 x 23-3/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_10_12_x_24_34 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","10-1/2 x 24-3/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_10_12_x_26_18 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","10-1/2 x 26-1/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_10_12_x_27_12 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","10-1/2 x 27-1/2"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_10_12_x_28_78 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","10-1/2 x 28-7/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_10_12_x_30_14 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","10-1/2 x 30-1/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_10_12_x_31_58 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","10-1/2 x 31-5/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_10_12_x_33 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","10-1/2 x 33"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_10_12_x_34_38 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","10-1/2 x 34-3/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_10_12_x_35_34 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","10-1/2 x 35-3/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_10_12_x_37_18 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","10-1/2 x 37-1/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_10_12_x_38_12 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","10-1/2 x 38-1/2"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_10_12_x_39_78 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","10-1/2 x 39-7/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_10_12_x_41_14 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","10-1/2 x 41-1/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_10_12_x_42_58 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","10-1/2 x 42-5/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_10_12_x_44 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","10-1/2 x 44"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_10_12_x_45_38 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","10-1/2 x 45-3/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_10_12_x_46_34 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","10-1/2 x 46-3/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_10_12_x_48_18 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","10-1/2 x 48-1/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_10_12_x_49_12 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","10-1/2 x 49-1/2"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_10_12_x_50_78 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","10-1/2 x 50-7/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_10_12_x_52_14 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","10-1/2 x 52-1/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_10_12_x_53_58 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","10-1/2 x 53-5/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_10_12_x_55 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","10-1/2 x 55"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_10_12_x_56_38 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","10-1/2 x 56-3/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_10_12_x_57_34 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","10-1/2 x 57-3/4"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_10_12_x_59_18 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","10-1/2 x 59-1/8"]
	American_NDS_Southern_Pine_Structural_Glued_Laminated_Timber_10_12_x_60_12 = ["American","NDS","Southern Pine Structural Glued Laminated Timber","10-1/2 x 60-1/2"]
	American_SJI_Virtual_Joists_VJ10_1 = ["American","SJI","Virtual Joists","VJ10-1"]
	American_SJI_Virtual_Joists_VJ10_2 = ["American","SJI","Virtual Joists","VJ10-2"]
	American_SJI_Virtual_Joists_VJ10_3 = ["American","SJI","Virtual Joists","VJ10-3"]
	American_SJI_Virtual_Joists_VJ10_4 = ["American","SJI","Virtual Joists","VJ10-4"]
	American_SJI_Virtual_Joists_VJ10_5 = ["American","SJI","Virtual Joists","VJ10-5"]
	American_SJI_Virtual_Joists_VJ10_6 = ["American","SJI","Virtual Joists","VJ10-6"]
	American_SJI_Virtual_Joists_VJ10_7 = ["American","SJI","Virtual Joists","VJ10-7"]
	American_SJI_Virtual_Joists_VJ10_8 = ["American","SJI","Virtual Joists","VJ10-8"]
	American_SJI_Virtual_Joists_VJ10_9 = ["American","SJI","Virtual Joists","VJ10-9"]
	American_SJI_Virtual_Joists_VJ10_10 = ["American","SJI","Virtual Joists","VJ10-10"]
	American_SJI_Virtual_Joists_VJ10_11 = ["American","SJI","Virtual Joists","VJ10-11"]
	American_SJI_Virtual_Joists_VJ10_12 = ["American","SJI","Virtual Joists","VJ10-12"]
	American_SJI_Virtual_Joists_VJ10_13 = ["American","SJI","Virtual Joists","VJ10-13"]
	American_SJI_Virtual_Joists_VJ10_14 = ["American","SJI","Virtual Joists","VJ10-14"]
	American_SJI_Virtual_Joists_VJ10_15 = ["American","SJI","Virtual Joists","VJ10-15"]
	American_SJI_Virtual_Joists_VJ10_16 = ["American","SJI","Virtual Joists","VJ10-16"]
	American_SJI_Virtual_Joists_VJ10_17 = ["American","SJI","Virtual Joists","VJ10-17"]
	American_SJI_Virtual_Joists_VJ10_18 = ["American","SJI","Virtual Joists","VJ10-18"]
	American_SJI_Virtual_Joists_VJ10_19 = ["American","SJI","Virtual Joists","VJ10-19"]
	American_SJI_Virtual_Joists_VJ10_20 = ["American","SJI","Virtual Joists","VJ10-20"]
	American_SJI_Virtual_Joists_VJ10_21 = ["American","SJI","Virtual Joists","VJ10-21"]
	American_SJI_Virtual_Joists_VJ10_22 = ["American","SJI","Virtual Joists","VJ10-22"]
	American_SJI_Virtual_Joists_VJ10_23 = ["American","SJI","Virtual Joists","VJ10-23"]
	American_SJI_Virtual_Joists_VJ10_24 = ["American","SJI","Virtual Joists","VJ10-24"]
	American_SJI_Virtual_Joists_VJ10_25 = ["American","SJI","Virtual Joists","VJ10-25"]
	American_SJI_Virtual_Joists_VJ10_26 = ["American","SJI","Virtual Joists","VJ10-26"]
	American_SJI_Virtual_Joists_VJ10_27 = ["American","SJI","Virtual Joists","VJ10-27"]
	American_SJI_Virtual_Joists_VJ10_28 = ["American","SJI","Virtual Joists","VJ10-28"]
	American_SJI_Virtual_Joists_VJ10_29 = ["American","SJI","Virtual Joists","VJ10-29"]
	American_SJI_Virtual_Joists_VJ10_30 = ["American","SJI","Virtual Joists","VJ10-30"]
	American_SJI_Virtual_Joists_VJ10_31 = ["American","SJI","Virtual Joists","VJ10-31"]
	American_SJI_Virtual_Joists_VJ10_32 = ["American","SJI","Virtual Joists","VJ10-32"]
	American_SJI_Virtual_Joists_VJ12_1 = ["American","SJI","Virtual Joists","VJ12-1"]
	American_SJI_Virtual_Joists_VJ12_2 = ["American","SJI","Virtual Joists","VJ12-2"]
	American_SJI_Virtual_Joists_VJ12_3 = ["American","SJI","Virtual Joists","VJ12-3"]
	American_SJI_Virtual_Joists_VJ12_4 = ["American","SJI","Virtual Joists","VJ12-4"]
	American_SJI_Virtual_Joists_VJ12_5 = ["American","SJI","Virtual Joists","VJ12-5"]
	American_SJI_Virtual_Joists_VJ12_6 = ["American","SJI","Virtual Joists","VJ12-6"]
	American_SJI_Virtual_Joists_VJ12_7 = ["American","SJI","Virtual Joists","VJ12-7"]
	American_SJI_Virtual_Joists_VJ12_8 = ["American","SJI","Virtual Joists","VJ12-8"]
	American_SJI_Virtual_Joists_VJ12_9 = ["American","SJI","Virtual Joists","VJ12-9"]
	American_SJI_Virtual_Joists_VJ12_10 = ["American","SJI","Virtual Joists","VJ12-10"]
	American_SJI_Virtual_Joists_VJ12_11 = ["American","SJI","Virtual Joists","VJ12-11"]
	American_SJI_Virtual_Joists_VJ12_12 = ["American","SJI","Virtual Joists","VJ12-12"]
	American_SJI_Virtual_Joists_VJ12_13 = ["American","SJI","Virtual Joists","VJ12-13"]
	American_SJI_Virtual_Joists_VJ12_14 = ["American","SJI","Virtual Joists","VJ12-14"]
	American_SJI_Virtual_Joists_VJ12_15 = ["American","SJI","Virtual Joists","VJ12-15"]
	American_SJI_Virtual_Joists_VJ12_16 = ["American","SJI","Virtual Joists","VJ12-16"]
	American_SJI_Virtual_Joists_VJ12_17 = ["American","SJI","Virtual Joists","VJ12-17"]
	American_SJI_Virtual_Joists_VJ12_18 = ["American","SJI","Virtual Joists","VJ12-18"]
	American_SJI_Virtual_Joists_VJ12_19 = ["American","SJI","Virtual Joists","VJ12-19"]
	American_SJI_Virtual_Joists_VJ12_20 = ["American","SJI","Virtual Joists","VJ12-20"]
	American_SJI_Virtual_Joists_VJ12_21 = ["American","SJI","Virtual Joists","VJ12-21"]
	American_SJI_Virtual_Joists_VJ12_22 = ["American","SJI","Virtual Joists","VJ12-22"]
	American_SJI_Virtual_Joists_VJ12_23 = ["American","SJI","Virtual Joists","VJ12-23"]
	American_SJI_Virtual_Joists_VJ12_24 = ["American","SJI","Virtual Joists","VJ12-24"]
	American_SJI_Virtual_Joists_VJ12_25 = ["American","SJI","Virtual Joists","VJ12-25"]
	American_SJI_Virtual_Joists_VJ12_26 = ["American","SJI","Virtual Joists","VJ12-26"]
	American_SJI_Virtual_Joists_VJ12_27 = ["American","SJI","Virtual Joists","VJ12-27"]
	American_SJI_Virtual_Joists_VJ12_28 = ["American","SJI","Virtual Joists","VJ12-28"]
	American_SJI_Virtual_Joists_VJ12_29 = ["American","SJI","Virtual Joists","VJ12-29"]
	American_SJI_Virtual_Joists_VJ12_30 = ["American","SJI","Virtual Joists","VJ12-30"]
	American_SJI_Virtual_Joists_VJ12_31 = ["American","SJI","Virtual Joists","VJ12-31"]
	American_SJI_Virtual_Joists_VJ12_32 = ["American","SJI","Virtual Joists","VJ12-32"]
	American_SJI_Virtual_Joists_VJ14_1 = ["American","SJI","Virtual Joists","VJ14-1"]
	American_SJI_Virtual_Joists_VJ14_2 = ["American","SJI","Virtual Joists","VJ14-2"]
	American_SJI_Virtual_Joists_VJ14_3 = ["American","SJI","Virtual Joists","VJ14-3"]
	American_SJI_Virtual_Joists_VJ14_4 = ["American","SJI","Virtual Joists","VJ14-4"]
	American_SJI_Virtual_Joists_VJ14_5 = ["American","SJI","Virtual Joists","VJ14-5"]
	American_SJI_Virtual_Joists_VJ14_6 = ["American","SJI","Virtual Joists","VJ14-6"]
	American_SJI_Virtual_Joists_VJ14_7 = ["American","SJI","Virtual Joists","VJ14-7"]
	American_SJI_Virtual_Joists_VJ14_8 = ["American","SJI","Virtual Joists","VJ14-8"]
	American_SJI_Virtual_Joists_VJ14_9 = ["American","SJI","Virtual Joists","VJ14-9"]
	American_SJI_Virtual_Joists_VJ14_10 = ["American","SJI","Virtual Joists","VJ14-10"]
	American_SJI_Virtual_Joists_VJ14_11 = ["American","SJI","Virtual Joists","VJ14-11"]
	American_SJI_Virtual_Joists_VJ14_12 = ["American","SJI","Virtual Joists","VJ14-12"]
	American_SJI_Virtual_Joists_VJ14_13 = ["American","SJI","Virtual Joists","VJ14-13"]
	American_SJI_Virtual_Joists_VJ14_14 = ["American","SJI","Virtual Joists","VJ14-14"]
	American_SJI_Virtual_Joists_VJ14_15 = ["American","SJI","Virtual Joists","VJ14-15"]
	American_SJI_Virtual_Joists_VJ14_16 = ["American","SJI","Virtual Joists","VJ14-16"]
	American_SJI_Virtual_Joists_VJ14_17 = ["American","SJI","Virtual Joists","VJ14-17"]
	American_SJI_Virtual_Joists_VJ14_18 = ["American","SJI","Virtual Joists","VJ14-18"]
	American_SJI_Virtual_Joists_VJ14_19 = ["American","SJI","Virtual Joists","VJ14-19"]
	American_SJI_Virtual_Joists_VJ14_20 = ["American","SJI","Virtual Joists","VJ14-20"]
	American_SJI_Virtual_Joists_VJ14_21 = ["American","SJI","Virtual Joists","VJ14-21"]
	American_SJI_Virtual_Joists_VJ14_22 = ["American","SJI","Virtual Joists","VJ14-22"]
	American_SJI_Virtual_Joists_VJ14_23 = ["American","SJI","Virtual Joists","VJ14-23"]
	American_SJI_Virtual_Joists_VJ14_24 = ["American","SJI","Virtual Joists","VJ14-24"]
	American_SJI_Virtual_Joists_VJ14_25 = ["American","SJI","Virtual Joists","VJ14-25"]
	American_SJI_Virtual_Joists_VJ14_26 = ["American","SJI","Virtual Joists","VJ14-26"]
	American_SJI_Virtual_Joists_VJ14_27 = ["American","SJI","Virtual Joists","VJ14-27"]
	American_SJI_Virtual_Joists_VJ14_28 = ["American","SJI","Virtual Joists","VJ14-28"]
	American_SJI_Virtual_Joists_VJ14_29 = ["American","SJI","Virtual Joists","VJ14-29"]
	American_SJI_Virtual_Joists_VJ14_30 = ["American","SJI","Virtual Joists","VJ14-30"]
	American_SJI_Virtual_Joists_VJ14_31 = ["American","SJI","Virtual Joists","VJ14-31"]
	American_SJI_Virtual_Joists_VJ14_32 = ["American","SJI","Virtual Joists","VJ14-32"]
	American_SJI_Virtual_Joists_VJ16_1 = ["American","SJI","Virtual Joists","VJ16-1"]
	American_SJI_Virtual_Joists_VJ16_2 = ["American","SJI","Virtual Joists","VJ16-2"]
	American_SJI_Virtual_Joists_VJ16_3 = ["American","SJI","Virtual Joists","VJ16-3"]
	American_SJI_Virtual_Joists_VJ16_4 = ["American","SJI","Virtual Joists","VJ16-4"]
	American_SJI_Virtual_Joists_VJ16_5 = ["American","SJI","Virtual Joists","VJ16-5"]
	American_SJI_Virtual_Joists_VJ16_6 = ["American","SJI","Virtual Joists","VJ16-6"]
	American_SJI_Virtual_Joists_VJ16_7 = ["American","SJI","Virtual Joists","VJ16-7"]
	American_SJI_Virtual_Joists_VJ16_8 = ["American","SJI","Virtual Joists","VJ16-8"]
	American_SJI_Virtual_Joists_VJ16_9 = ["American","SJI","Virtual Joists","VJ16-9"]
	American_SJI_Virtual_Joists_VJ16_10 = ["American","SJI","Virtual Joists","VJ16-10"]
	American_SJI_Virtual_Joists_VJ16_11 = ["American","SJI","Virtual Joists","VJ16-11"]
	American_SJI_Virtual_Joists_VJ16_12 = ["American","SJI","Virtual Joists","VJ16-12"]
	American_SJI_Virtual_Joists_VJ16_13 = ["American","SJI","Virtual Joists","VJ16-13"]
	American_SJI_Virtual_Joists_VJ16_14 = ["American","SJI","Virtual Joists","VJ16-14"]
	American_SJI_Virtual_Joists_VJ16_15 = ["American","SJI","Virtual Joists","VJ16-15"]
	American_SJI_Virtual_Joists_VJ16_16 = ["American","SJI","Virtual Joists","VJ16-16"]
	American_SJI_Virtual_Joists_VJ16_17 = ["American","SJI","Virtual Joists","VJ16-17"]
	American_SJI_Virtual_Joists_VJ16_18 = ["American","SJI","Virtual Joists","VJ16-18"]
	American_SJI_Virtual_Joists_VJ16_19 = ["American","SJI","Virtual Joists","VJ16-19"]
	American_SJI_Virtual_Joists_VJ16_20 = ["American","SJI","Virtual Joists","VJ16-20"]
	American_SJI_Virtual_Joists_VJ16_21 = ["American","SJI","Virtual Joists","VJ16-21"]
	American_SJI_Virtual_Joists_VJ16_22 = ["American","SJI","Virtual Joists","VJ16-22"]
	American_SJI_Virtual_Joists_VJ16_23 = ["American","SJI","Virtual Joists","VJ16-23"]
	American_SJI_Virtual_Joists_VJ16_24 = ["American","SJI","Virtual Joists","VJ16-24"]
	American_SJI_Virtual_Joists_VJ16_25 = ["American","SJI","Virtual Joists","VJ16-25"]
	American_SJI_Virtual_Joists_VJ16_26 = ["American","SJI","Virtual Joists","VJ16-26"]
	American_SJI_Virtual_Joists_VJ16_27 = ["American","SJI","Virtual Joists","VJ16-27"]
	American_SJI_Virtual_Joists_VJ16_28 = ["American","SJI","Virtual Joists","VJ16-28"]
	American_SJI_Virtual_Joists_VJ16_29 = ["American","SJI","Virtual Joists","VJ16-29"]
	American_SJI_Virtual_Joists_VJ16_30 = ["American","SJI","Virtual Joists","VJ16-30"]
	American_SJI_Virtual_Joists_VJ16_31 = ["American","SJI","Virtual Joists","VJ16-31"]
	American_SJI_Virtual_Joists_VJ16_32 = ["American","SJI","Virtual Joists","VJ16-32"]
	American_SJI_Virtual_Joists_VJ16_33 = ["American","SJI","Virtual Joists","VJ16-33"]
	American_SJI_Virtual_Joists_VJ16_34 = ["American","SJI","Virtual Joists","VJ16-34"]
	American_SJI_Virtual_Joists_VJ16_35 = ["American","SJI","Virtual Joists","VJ16-35"]
	American_SJI_Virtual_Joists_VJ16_36 = ["American","SJI","Virtual Joists","VJ16-36"]
	American_SJI_Virtual_Joists_VJ16_37 = ["American","SJI","Virtual Joists","VJ16-37"]
	American_SJI_Virtual_Joists_VJ16_38 = ["American","SJI","Virtual Joists","VJ16-38"]
	American_SJI_Virtual_Joists_VJ16_39 = ["American","SJI","Virtual Joists","VJ16-39"]
	American_SJI_Virtual_Joists_VJ16_40 = ["American","SJI","Virtual Joists","VJ16-40"]
	American_SJI_Virtual_Joists_VJ16_41 = ["American","SJI","Virtual Joists","VJ16-41"]
	American_SJI_Virtual_Joists_VJ16_42 = ["American","SJI","Virtual Joists","VJ16-42"]
	American_SJI_Virtual_Joists_VJ16_43 = ["American","SJI","Virtual Joists","VJ16-43"]
	American_SJI_Virtual_Joists_VJ16_44 = ["American","SJI","Virtual Joists","VJ16-44"]
	American_SJI_Virtual_Joists_VJ16_45 = ["American","SJI","Virtual Joists","VJ16-45"]
	American_SJI_Virtual_Joists_VJ16_46 = ["American","SJI","Virtual Joists","VJ16-46"]
	American_SJI_Virtual_Joists_VJ16_47 = ["American","SJI","Virtual Joists","VJ16-47"]
	American_SJI_Virtual_Joists_VJ16_48 = ["American","SJI","Virtual Joists","VJ16-48"]
	American_SJI_Virtual_Joists_VJ16_49 = ["American","SJI","Virtual Joists","VJ16-49"]
	American_SJI_Virtual_Joists_VJ16_50 = ["American","SJI","Virtual Joists","VJ16-50"]
	American_SJI_Virtual_Joists_VJ16_51 = ["American","SJI","Virtual Joists","VJ16-51"]
	American_SJI_Virtual_Joists_VJ16_52 = ["American","SJI","Virtual Joists","VJ16-52"]
	American_SJI_Virtual_Joists_VJ16_53 = ["American","SJI","Virtual Joists","VJ16-53"]
	American_SJI_Virtual_Joists_VJ16_54 = ["American","SJI","Virtual Joists","VJ16-54"]
	American_SJI_Virtual_Joists_VJ18_1 = ["American","SJI","Virtual Joists","VJ18-1"]
	American_SJI_Virtual_Joists_VJ18_2 = ["American","SJI","Virtual Joists","VJ18-2"]
	American_SJI_Virtual_Joists_VJ18_3 = ["American","SJI","Virtual Joists","VJ18-3"]
	American_SJI_Virtual_Joists_VJ18_4 = ["American","SJI","Virtual Joists","VJ18-4"]
	American_SJI_Virtual_Joists_VJ18_5 = ["American","SJI","Virtual Joists","VJ18-5"]
	American_SJI_Virtual_Joists_VJ18_6 = ["American","SJI","Virtual Joists","VJ18-6"]
	American_SJI_Virtual_Joists_VJ18_7 = ["American","SJI","Virtual Joists","VJ18-7"]
	American_SJI_Virtual_Joists_VJ18_8 = ["American","SJI","Virtual Joists","VJ18-8"]
	American_SJI_Virtual_Joists_VJ18_9 = ["American","SJI","Virtual Joists","VJ18-9"]
	American_SJI_Virtual_Joists_VJ18_10 = ["American","SJI","Virtual Joists","VJ18-10"]
	American_SJI_Virtual_Joists_VJ18_11 = ["American","SJI","Virtual Joists","VJ18-11"]
	American_SJI_Virtual_Joists_VJ18_12 = ["American","SJI","Virtual Joists","VJ18-12"]
	American_SJI_Virtual_Joists_VJ18_13 = ["American","SJI","Virtual Joists","VJ18-13"]
	American_SJI_Virtual_Joists_VJ18_14 = ["American","SJI","Virtual Joists","VJ18-14"]
	American_SJI_Virtual_Joists_VJ18_15 = ["American","SJI","Virtual Joists","VJ18-15"]
	American_SJI_Virtual_Joists_VJ18_16 = ["American","SJI","Virtual Joists","VJ18-16"]
	American_SJI_Virtual_Joists_VJ18_17 = ["American","SJI","Virtual Joists","VJ18-17"]
	American_SJI_Virtual_Joists_VJ18_18 = ["American","SJI","Virtual Joists","VJ18-18"]
	American_SJI_Virtual_Joists_VJ18_19 = ["American","SJI","Virtual Joists","VJ18-19"]
	American_SJI_Virtual_Joists_VJ18_20 = ["American","SJI","Virtual Joists","VJ18-20"]
	American_SJI_Virtual_Joists_VJ18_21 = ["American","SJI","Virtual Joists","VJ18-21"]
	American_SJI_Virtual_Joists_VJ18_22 = ["American","SJI","Virtual Joists","VJ18-22"]
	American_SJI_Virtual_Joists_VJ18_23 = ["American","SJI","Virtual Joists","VJ18-23"]
	American_SJI_Virtual_Joists_VJ18_24 = ["American","SJI","Virtual Joists","VJ18-24"]
	American_SJI_Virtual_Joists_VJ18_25 = ["American","SJI","Virtual Joists","VJ18-25"]
	American_SJI_Virtual_Joists_VJ18_26 = ["American","SJI","Virtual Joists","VJ18-26"]
	American_SJI_Virtual_Joists_VJ18_27 = ["American","SJI","Virtual Joists","VJ18-27"]
	American_SJI_Virtual_Joists_VJ18_28 = ["American","SJI","Virtual Joists","VJ18-28"]
	American_SJI_Virtual_Joists_VJ18_29 = ["American","SJI","Virtual Joists","VJ18-29"]
	American_SJI_Virtual_Joists_VJ18_30 = ["American","SJI","Virtual Joists","VJ18-30"]
	American_SJI_Virtual_Joists_VJ18_31 = ["American","SJI","Virtual Joists","VJ18-31"]
	American_SJI_Virtual_Joists_VJ18_32 = ["American","SJI","Virtual Joists","VJ18-32"]
	American_SJI_Virtual_Joists_VJ18_33 = ["American","SJI","Virtual Joists","VJ18-33"]
	American_SJI_Virtual_Joists_VJ18_34 = ["American","SJI","Virtual Joists","VJ18-34"]
	American_SJI_Virtual_Joists_VJ18_35 = ["American","SJI","Virtual Joists","VJ18-35"]
	American_SJI_Virtual_Joists_VJ18_36 = ["American","SJI","Virtual Joists","VJ18-36"]
	American_SJI_Virtual_Joists_VJ18_37 = ["American","SJI","Virtual Joists","VJ18-37"]
	American_SJI_Virtual_Joists_VJ18_38 = ["American","SJI","Virtual Joists","VJ18-38"]
	American_SJI_Virtual_Joists_VJ18_39 = ["American","SJI","Virtual Joists","VJ18-39"]
	American_SJI_Virtual_Joists_VJ18_40 = ["American","SJI","Virtual Joists","VJ18-40"]
	American_SJI_Virtual_Joists_VJ18_41 = ["American","SJI","Virtual Joists","VJ18-41"]
	American_SJI_Virtual_Joists_VJ18_42 = ["American","SJI","Virtual Joists","VJ18-42"]
	American_SJI_Virtual_Joists_VJ18_43 = ["American","SJI","Virtual Joists","VJ18-43"]
	American_SJI_Virtual_Joists_VJ18_44 = ["American","SJI","Virtual Joists","VJ18-44"]
	American_SJI_Virtual_Joists_VJ18_45 = ["American","SJI","Virtual Joists","VJ18-45"]
	American_SJI_Virtual_Joists_VJ18_46 = ["American","SJI","Virtual Joists","VJ18-46"]
	American_SJI_Virtual_Joists_VJ18_47 = ["American","SJI","Virtual Joists","VJ18-47"]
	American_SJI_Virtual_Joists_VJ18_48 = ["American","SJI","Virtual Joists","VJ18-48"]
	American_SJI_Virtual_Joists_VJ18_49 = ["American","SJI","Virtual Joists","VJ18-49"]
	American_SJI_Virtual_Joists_VJ18_50 = ["American","SJI","Virtual Joists","VJ18-50"]
	American_SJI_Virtual_Joists_VJ18_51 = ["American","SJI","Virtual Joists","VJ18-51"]
	American_SJI_Virtual_Joists_VJ18_52 = ["American","SJI","Virtual Joists","VJ18-52"]
	American_SJI_Virtual_Joists_VJ18_53 = ["American","SJI","Virtual Joists","VJ18-53"]
	American_SJI_Virtual_Joists_VJ18_54 = ["American","SJI","Virtual Joists","VJ18-54"]
	American_SJI_Virtual_Joists_VJ18_55 = ["American","SJI","Virtual Joists","VJ18-55"]
	American_SJI_Virtual_Joists_VJ18_56 = ["American","SJI","Virtual Joists","VJ18-56"]
	American_SJI_Virtual_Joists_VJ18_57 = ["American","SJI","Virtual Joists","VJ18-57"]
	American_SJI_Virtual_Joists_VJ18_58 = ["American","SJI","Virtual Joists","VJ18-58"]
	American_SJI_Virtual_Joists_VJ18_59 = ["American","SJI","Virtual Joists","VJ18-59"]
	American_SJI_Virtual_Joists_VJ18_60 = ["American","SJI","Virtual Joists","VJ18-60"]
	American_SJI_Virtual_Joists_VJ20_1 = ["American","SJI","Virtual Joists","VJ20-1"]
	American_SJI_Virtual_Joists_VJ20_2 = ["American","SJI","Virtual Joists","VJ20-2"]
	American_SJI_Virtual_Joists_VJ20_3 = ["American","SJI","Virtual Joists","VJ20-3"]
	American_SJI_Virtual_Joists_VJ20_4 = ["American","SJI","Virtual Joists","VJ20-4"]
	American_SJI_Virtual_Joists_VJ20_5 = ["American","SJI","Virtual Joists","VJ20-5"]
	American_SJI_Virtual_Joists_VJ20_6 = ["American","SJI","Virtual Joists","VJ20-6"]
	American_SJI_Virtual_Joists_VJ20_7 = ["American","SJI","Virtual Joists","VJ20-7"]
	American_SJI_Virtual_Joists_VJ20_8 = ["American","SJI","Virtual Joists","VJ20-8"]
	American_SJI_Virtual_Joists_VJ20_9 = ["American","SJI","Virtual Joists","VJ20-9"]
	American_SJI_Virtual_Joists_VJ20_10 = ["American","SJI","Virtual Joists","VJ20-10"]
	American_SJI_Virtual_Joists_VJ20_11 = ["American","SJI","Virtual Joists","VJ20-11"]
	American_SJI_Virtual_Joists_VJ20_12 = ["American","SJI","Virtual Joists","VJ20-12"]
	American_SJI_Virtual_Joists_VJ20_13 = ["American","SJI","Virtual Joists","VJ20-13"]
	American_SJI_Virtual_Joists_VJ20_14 = ["American","SJI","Virtual Joists","VJ20-14"]
	American_SJI_Virtual_Joists_VJ20_15 = ["American","SJI","Virtual Joists","VJ20-15"]
	American_SJI_Virtual_Joists_VJ20_16 = ["American","SJI","Virtual Joists","VJ20-16"]
	American_SJI_Virtual_Joists_VJ20_17 = ["American","SJI","Virtual Joists","VJ20-17"]
	American_SJI_Virtual_Joists_VJ20_18 = ["American","SJI","Virtual Joists","VJ20-18"]
	American_SJI_Virtual_Joists_VJ20_19 = ["American","SJI","Virtual Joists","VJ20-19"]
	American_SJI_Virtual_Joists_VJ20_20 = ["American","SJI","Virtual Joists","VJ20-20"]
	American_SJI_Virtual_Joists_VJ20_21 = ["American","SJI","Virtual Joists","VJ20-21"]
	American_SJI_Virtual_Joists_VJ20_22 = ["American","SJI","Virtual Joists","VJ20-22"]
	American_SJI_Virtual_Joists_VJ20_23 = ["American","SJI","Virtual Joists","VJ20-23"]
	American_SJI_Virtual_Joists_VJ20_24 = ["American","SJI","Virtual Joists","VJ20-24"]
	American_SJI_Virtual_Joists_VJ20_25 = ["American","SJI","Virtual Joists","VJ20-25"]
	American_SJI_Virtual_Joists_VJ20_26 = ["American","SJI","Virtual Joists","VJ20-26"]
	American_SJI_Virtual_Joists_VJ20_27 = ["American","SJI","Virtual Joists","VJ20-27"]
	American_SJI_Virtual_Joists_VJ20_28 = ["American","SJI","Virtual Joists","VJ20-28"]
	American_SJI_Virtual_Joists_VJ20_29 = ["American","SJI","Virtual Joists","VJ20-29"]
	American_SJI_Virtual_Joists_VJ20_30 = ["American","SJI","Virtual Joists","VJ20-30"]
	American_SJI_Virtual_Joists_VJ20_31 = ["American","SJI","Virtual Joists","VJ20-31"]
	American_SJI_Virtual_Joists_VJ20_32 = ["American","SJI","Virtual Joists","VJ20-32"]
	American_SJI_Virtual_Joists_VJ20_33 = ["American","SJI","Virtual Joists","VJ20-33"]
	American_SJI_Virtual_Joists_VJ20_34 = ["American","SJI","Virtual Joists","VJ20-34"]
	American_SJI_Virtual_Joists_VJ20_35 = ["American","SJI","Virtual Joists","VJ20-35"]
	American_SJI_Virtual_Joists_VJ20_36 = ["American","SJI","Virtual Joists","VJ20-36"]
	American_SJI_Virtual_Joists_VJ20_37 = ["American","SJI","Virtual Joists","VJ20-37"]
	American_SJI_Virtual_Joists_VJ20_38 = ["American","SJI","Virtual Joists","VJ20-38"]
	American_SJI_Virtual_Joists_VJ20_39 = ["American","SJI","Virtual Joists","VJ20-39"]
	American_SJI_Virtual_Joists_VJ20_40 = ["American","SJI","Virtual Joists","VJ20-40"]
	American_SJI_Virtual_Joists_VJ20_41 = ["American","SJI","Virtual Joists","VJ20-41"]
	American_SJI_Virtual_Joists_VJ20_42 = ["American","SJI","Virtual Joists","VJ20-42"]
	American_SJI_Virtual_Joists_VJ20_43 = ["American","SJI","Virtual Joists","VJ20-43"]
	American_SJI_Virtual_Joists_VJ20_44 = ["American","SJI","Virtual Joists","VJ20-44"]
	American_SJI_Virtual_Joists_VJ20_45 = ["American","SJI","Virtual Joists","VJ20-45"]
	American_SJI_Virtual_Joists_VJ20_46 = ["American","SJI","Virtual Joists","VJ20-46"]
	American_SJI_Virtual_Joists_VJ20_47 = ["American","SJI","Virtual Joists","VJ20-47"]
	American_SJI_Virtual_Joists_VJ20_48 = ["American","SJI","Virtual Joists","VJ20-48"]
	American_SJI_Virtual_Joists_VJ20_49 = ["American","SJI","Virtual Joists","VJ20-49"]
	American_SJI_Virtual_Joists_VJ20_50 = ["American","SJI","Virtual Joists","VJ20-50"]
	American_SJI_Virtual_Joists_VJ20_51 = ["American","SJI","Virtual Joists","VJ20-51"]
	American_SJI_Virtual_Joists_VJ20_52 = ["American","SJI","Virtual Joists","VJ20-52"]
	American_SJI_Virtual_Joists_VJ20_53 = ["American","SJI","Virtual Joists","VJ20-53"]
	American_SJI_Virtual_Joists_VJ20_54 = ["American","SJI","Virtual Joists","VJ20-54"]
	American_SJI_Virtual_Joists_VJ20_55 = ["American","SJI","Virtual Joists","VJ20-55"]
	American_SJI_Virtual_Joists_VJ20_56 = ["American","SJI","Virtual Joists","VJ20-56"]
	American_SJI_Virtual_Joists_VJ20_57 = ["American","SJI","Virtual Joists","VJ20-57"]
	American_SJI_Virtual_Joists_VJ20_58 = ["American","SJI","Virtual Joists","VJ20-58"]
	American_SJI_Virtual_Joists_VJ20_59 = ["American","SJI","Virtual Joists","VJ20-59"]
	American_SJI_Virtual_Joists_VJ20_60 = ["American","SJI","Virtual Joists","VJ20-60"]
	American_SJI_Virtual_Joists_VJ22_1 = ["American","SJI","Virtual Joists","VJ22-1"]
	American_SJI_Virtual_Joists_VJ22_2 = ["American","SJI","Virtual Joists","VJ22-2"]
	American_SJI_Virtual_Joists_VJ22_3 = ["American","SJI","Virtual Joists","VJ22-3"]
	American_SJI_Virtual_Joists_VJ22_4 = ["American","SJI","Virtual Joists","VJ22-4"]
	American_SJI_Virtual_Joists_VJ22_5 = ["American","SJI","Virtual Joists","VJ22-5"]
	American_SJI_Virtual_Joists_VJ22_6 = ["American","SJI","Virtual Joists","VJ22-6"]
	American_SJI_Virtual_Joists_VJ22_7 = ["American","SJI","Virtual Joists","VJ22-7"]
	American_SJI_Virtual_Joists_VJ22_8 = ["American","SJI","Virtual Joists","VJ22-8"]
	American_SJI_Virtual_Joists_VJ22_9 = ["American","SJI","Virtual Joists","VJ22-9"]
	American_SJI_Virtual_Joists_VJ22_10 = ["American","SJI","Virtual Joists","VJ22-10"]
	American_SJI_Virtual_Joists_VJ22_11 = ["American","SJI","Virtual Joists","VJ22-11"]
	American_SJI_Virtual_Joists_VJ22_12 = ["American","SJI","Virtual Joists","VJ22-12"]
	American_SJI_Virtual_Joists_VJ22_13 = ["American","SJI","Virtual Joists","VJ22-13"]
	American_SJI_Virtual_Joists_VJ22_14 = ["American","SJI","Virtual Joists","VJ22-14"]
	American_SJI_Virtual_Joists_VJ22_15 = ["American","SJI","Virtual Joists","VJ22-15"]
	American_SJI_Virtual_Joists_VJ22_16 = ["American","SJI","Virtual Joists","VJ22-16"]
	American_SJI_Virtual_Joists_VJ22_17 = ["American","SJI","Virtual Joists","VJ22-17"]
	American_SJI_Virtual_Joists_VJ22_18 = ["American","SJI","Virtual Joists","VJ22-18"]
	American_SJI_Virtual_Joists_VJ22_19 = ["American","SJI","Virtual Joists","VJ22-19"]
	American_SJI_Virtual_Joists_VJ22_20 = ["American","SJI","Virtual Joists","VJ22-20"]
	American_SJI_Virtual_Joists_VJ22_21 = ["American","SJI","Virtual Joists","VJ22-21"]
	American_SJI_Virtual_Joists_VJ22_22 = ["American","SJI","Virtual Joists","VJ22-22"]
	American_SJI_Virtual_Joists_VJ22_23 = ["American","SJI","Virtual Joists","VJ22-23"]
	American_SJI_Virtual_Joists_VJ22_24 = ["American","SJI","Virtual Joists","VJ22-24"]
	American_SJI_Virtual_Joists_VJ22_25 = ["American","SJI","Virtual Joists","VJ22-25"]
	American_SJI_Virtual_Joists_VJ22_26 = ["American","SJI","Virtual Joists","VJ22-26"]
	American_SJI_Virtual_Joists_VJ22_27 = ["American","SJI","Virtual Joists","VJ22-27"]
	American_SJI_Virtual_Joists_VJ22_28 = ["American","SJI","Virtual Joists","VJ22-28"]
	American_SJI_Virtual_Joists_VJ22_29 = ["American","SJI","Virtual Joists","VJ22-29"]
	American_SJI_Virtual_Joists_VJ22_30 = ["American","SJI","Virtual Joists","VJ22-30"]
	American_SJI_Virtual_Joists_VJ22_31 = ["American","SJI","Virtual Joists","VJ22-31"]
	American_SJI_Virtual_Joists_VJ22_32 = ["American","SJI","Virtual Joists","VJ22-32"]
	American_SJI_Virtual_Joists_VJ22_33 = ["American","SJI","Virtual Joists","VJ22-33"]
	American_SJI_Virtual_Joists_VJ22_34 = ["American","SJI","Virtual Joists","VJ22-34"]
	American_SJI_Virtual_Joists_VJ22_35 = ["American","SJI","Virtual Joists","VJ22-35"]
	American_SJI_Virtual_Joists_VJ22_36 = ["American","SJI","Virtual Joists","VJ22-36"]
	American_SJI_Virtual_Joists_VJ22_37 = ["American","SJI","Virtual Joists","VJ22-37"]
	American_SJI_Virtual_Joists_VJ22_38 = ["American","SJI","Virtual Joists","VJ22-38"]
	American_SJI_Virtual_Joists_VJ22_39 = ["American","SJI","Virtual Joists","VJ22-39"]
	American_SJI_Virtual_Joists_VJ22_40 = ["American","SJI","Virtual Joists","VJ22-40"]
	American_SJI_Virtual_Joists_VJ22_41 = ["American","SJI","Virtual Joists","VJ22-41"]
	American_SJI_Virtual_Joists_VJ22_42 = ["American","SJI","Virtual Joists","VJ22-42"]
	American_SJI_Virtual_Joists_VJ22_43 = ["American","SJI","Virtual Joists","VJ22-43"]
	American_SJI_Virtual_Joists_VJ22_44 = ["American","SJI","Virtual Joists","VJ22-44"]
	American_SJI_Virtual_Joists_VJ22_45 = ["American","SJI","Virtual Joists","VJ22-45"]
	American_SJI_Virtual_Joists_VJ22_46 = ["American","SJI","Virtual Joists","VJ22-46"]
	American_SJI_Virtual_Joists_VJ22_47 = ["American","SJI","Virtual Joists","VJ22-47"]
	American_SJI_Virtual_Joists_VJ22_48 = ["American","SJI","Virtual Joists","VJ22-48"]
	American_SJI_Virtual_Joists_VJ22_49 = ["American","SJI","Virtual Joists","VJ22-49"]
	American_SJI_Virtual_Joists_VJ22_50 = ["American","SJI","Virtual Joists","VJ22-50"]
	American_SJI_Virtual_Joists_VJ22_51 = ["American","SJI","Virtual Joists","VJ22-51"]
	American_SJI_Virtual_Joists_VJ22_52 = ["American","SJI","Virtual Joists","VJ22-52"]
	American_SJI_Virtual_Joists_VJ22_53 = ["American","SJI","Virtual Joists","VJ22-53"]
	American_SJI_Virtual_Joists_VJ22_54 = ["American","SJI","Virtual Joists","VJ22-54"]
	American_SJI_Virtual_Joists_VJ22_55 = ["American","SJI","Virtual Joists","VJ22-55"]
	American_SJI_Virtual_Joists_VJ22_56 = ["American","SJI","Virtual Joists","VJ22-56"]
	American_SJI_Virtual_Joists_VJ22_57 = ["American","SJI","Virtual Joists","VJ22-57"]
	American_SJI_Virtual_Joists_VJ22_58 = ["American","SJI","Virtual Joists","VJ22-58"]
	American_SJI_Virtual_Joists_VJ22_59 = ["American","SJI","Virtual Joists","VJ22-59"]
	American_SJI_Virtual_Joists_VJ22_60 = ["American","SJI","Virtual Joists","VJ22-60"]
	American_SJI_Virtual_Joists_VJ24_1 = ["American","SJI","Virtual Joists","VJ24-1"]
	American_SJI_Virtual_Joists_VJ24_2 = ["American","SJI","Virtual Joists","VJ24-2"]
	American_SJI_Virtual_Joists_VJ24_3 = ["American","SJI","Virtual Joists","VJ24-3"]
	American_SJI_Virtual_Joists_VJ24_4 = ["American","SJI","Virtual Joists","VJ24-4"]
	American_SJI_Virtual_Joists_VJ24_5 = ["American","SJI","Virtual Joists","VJ24-5"]
	American_SJI_Virtual_Joists_VJ24_6 = ["American","SJI","Virtual Joists","VJ24-6"]
	American_SJI_Virtual_Joists_VJ24_7 = ["American","SJI","Virtual Joists","VJ24-7"]
	American_SJI_Virtual_Joists_VJ24_8 = ["American","SJI","Virtual Joists","VJ24-8"]
	American_SJI_Virtual_Joists_VJ24_9 = ["American","SJI","Virtual Joists","VJ24-9"]
	American_SJI_Virtual_Joists_VJ24_10 = ["American","SJI","Virtual Joists","VJ24-10"]
	American_SJI_Virtual_Joists_VJ24_11 = ["American","SJI","Virtual Joists","VJ24-11"]
	American_SJI_Virtual_Joists_VJ24_12 = ["American","SJI","Virtual Joists","VJ24-12"]
	American_SJI_Virtual_Joists_VJ24_13 = ["American","SJI","Virtual Joists","VJ24-13"]
	American_SJI_Virtual_Joists_VJ24_14 = ["American","SJI","Virtual Joists","VJ24-14"]
	American_SJI_Virtual_Joists_VJ24_15 = ["American","SJI","Virtual Joists","VJ24-15"]
	American_SJI_Virtual_Joists_VJ24_16 = ["American","SJI","Virtual Joists","VJ24-16"]
	American_SJI_Virtual_Joists_VJ24_17 = ["American","SJI","Virtual Joists","VJ24-17"]
	American_SJI_Virtual_Joists_VJ24_18 = ["American","SJI","Virtual Joists","VJ24-18"]
	American_SJI_Virtual_Joists_VJ24_19 = ["American","SJI","Virtual Joists","VJ24-19"]
	American_SJI_Virtual_Joists_VJ24_20 = ["American","SJI","Virtual Joists","VJ24-20"]
	American_SJI_Virtual_Joists_VJ24_21 = ["American","SJI","Virtual Joists","VJ24-21"]
	American_SJI_Virtual_Joists_VJ24_22 = ["American","SJI","Virtual Joists","VJ24-22"]
	American_SJI_Virtual_Joists_VJ24_23 = ["American","SJI","Virtual Joists","VJ24-23"]
	American_SJI_Virtual_Joists_VJ24_24 = ["American","SJI","Virtual Joists","VJ24-24"]
	American_SJI_Virtual_Joists_VJ24_25 = ["American","SJI","Virtual Joists","VJ24-25"]
	American_SJI_Virtual_Joists_VJ24_26 = ["American","SJI","Virtual Joists","VJ24-26"]
	American_SJI_Virtual_Joists_VJ24_27 = ["American","SJI","Virtual Joists","VJ24-27"]
	American_SJI_Virtual_Joists_VJ24_28 = ["American","SJI","Virtual Joists","VJ24-28"]
	American_SJI_Virtual_Joists_VJ24_29 = ["American","SJI","Virtual Joists","VJ24-29"]
	American_SJI_Virtual_Joists_VJ24_30 = ["American","SJI","Virtual Joists","VJ24-30"]
	American_SJI_Virtual_Joists_VJ24_31 = ["American","SJI","Virtual Joists","VJ24-31"]
	American_SJI_Virtual_Joists_VJ24_32 = ["American","SJI","Virtual Joists","VJ24-32"]
	American_SJI_Virtual_Joists_VJ24_33 = ["American","SJI","Virtual Joists","VJ24-33"]
	American_SJI_Virtual_Joists_VJ24_34 = ["American","SJI","Virtual Joists","VJ24-34"]
	American_SJI_Virtual_Joists_VJ24_35 = ["American","SJI","Virtual Joists","VJ24-35"]
	American_SJI_Virtual_Joists_VJ24_36 = ["American","SJI","Virtual Joists","VJ24-36"]
	American_SJI_Virtual_Joists_VJ24_37 = ["American","SJI","Virtual Joists","VJ24-37"]
	American_SJI_Virtual_Joists_VJ24_38 = ["American","SJI","Virtual Joists","VJ24-38"]
	American_SJI_Virtual_Joists_VJ24_39 = ["American","SJI","Virtual Joists","VJ24-39"]
	American_SJI_Virtual_Joists_VJ24_40 = ["American","SJI","Virtual Joists","VJ24-40"]
	American_SJI_Virtual_Joists_VJ24_41 = ["American","SJI","Virtual Joists","VJ24-41"]
	American_SJI_Virtual_Joists_VJ24_42 = ["American","SJI","Virtual Joists","VJ24-42"]
	American_SJI_Virtual_Joists_VJ24_43 = ["American","SJI","Virtual Joists","VJ24-43"]
	American_SJI_Virtual_Joists_VJ24_44 = ["American","SJI","Virtual Joists","VJ24-44"]
	American_SJI_Virtual_Joists_VJ24_45 = ["American","SJI","Virtual Joists","VJ24-45"]
	American_SJI_Virtual_Joists_VJ24_46 = ["American","SJI","Virtual Joists","VJ24-46"]
	American_SJI_Virtual_Joists_VJ24_47 = ["American","SJI","Virtual Joists","VJ24-47"]
	American_SJI_Virtual_Joists_VJ24_48 = ["American","SJI","Virtual Joists","VJ24-48"]
	American_SJI_Virtual_Joists_VJ24_49 = ["American","SJI","Virtual Joists","VJ24-49"]
	American_SJI_Virtual_Joists_VJ24_50 = ["American","SJI","Virtual Joists","VJ24-50"]
	American_SJI_Virtual_Joists_VJ24_51 = ["American","SJI","Virtual Joists","VJ24-51"]
	American_SJI_Virtual_Joists_VJ24_52 = ["American","SJI","Virtual Joists","VJ24-52"]
	American_SJI_Virtual_Joists_VJ24_53 = ["American","SJI","Virtual Joists","VJ24-53"]
	American_SJI_Virtual_Joists_VJ24_54 = ["American","SJI","Virtual Joists","VJ24-54"]
	American_SJI_Virtual_Joists_VJ24_55 = ["American","SJI","Virtual Joists","VJ24-55"]
	American_SJI_Virtual_Joists_VJ24_56 = ["American","SJI","Virtual Joists","VJ24-56"]
	American_SJI_Virtual_Joists_VJ24_57 = ["American","SJI","Virtual Joists","VJ24-57"]
	American_SJI_Virtual_Joists_VJ24_58 = ["American","SJI","Virtual Joists","VJ24-58"]
	American_SJI_Virtual_Joists_VJ24_59 = ["American","SJI","Virtual Joists","VJ24-59"]
	American_SJI_Virtual_Joists_VJ24_60 = ["American","SJI","Virtual Joists","VJ24-60"]
	American_SJI_Virtual_Joists_VJ24_61 = ["American","SJI","Virtual Joists","VJ24-61"]
	American_SJI_Virtual_Joists_VJ24_62 = ["American","SJI","Virtual Joists","VJ24-62"]
	American_SJI_Virtual_Joists_VJ24_63 = ["American","SJI","Virtual Joists","VJ24-63"]
	American_SJI_Virtual_Joists_VJ24_64 = ["American","SJI","Virtual Joists","VJ24-64"]
	American_SJI_Virtual_Joists_VJ24_65 = ["American","SJI","Virtual Joists","VJ24-65"]
	American_SJI_Virtual_Joists_VJ24_66 = ["American","SJI","Virtual Joists","VJ24-66"]
	American_SJI_Virtual_Joists_VJ26_1 = ["American","SJI","Virtual Joists","VJ26-1"]
	American_SJI_Virtual_Joists_VJ26_2 = ["American","SJI","Virtual Joists","VJ26-2"]
	American_SJI_Virtual_Joists_VJ26_3 = ["American","SJI","Virtual Joists","VJ26-3"]
	American_SJI_Virtual_Joists_VJ26_4 = ["American","SJI","Virtual Joists","VJ26-4"]
	American_SJI_Virtual_Joists_VJ26_5 = ["American","SJI","Virtual Joists","VJ26-5"]
	American_SJI_Virtual_Joists_VJ26_6 = ["American","SJI","Virtual Joists","VJ26-6"]
	American_SJI_Virtual_Joists_VJ26_7 = ["American","SJI","Virtual Joists","VJ26-7"]
	American_SJI_Virtual_Joists_VJ26_8 = ["American","SJI","Virtual Joists","VJ26-8"]
	American_SJI_Virtual_Joists_VJ26_9 = ["American","SJI","Virtual Joists","VJ26-9"]
	American_SJI_Virtual_Joists_VJ26_10 = ["American","SJI","Virtual Joists","VJ26-10"]
	American_SJI_Virtual_Joists_VJ26_11 = ["American","SJI","Virtual Joists","VJ26-11"]
	American_SJI_Virtual_Joists_VJ26_12 = ["American","SJI","Virtual Joists","VJ26-12"]
	American_SJI_Virtual_Joists_VJ26_13 = ["American","SJI","Virtual Joists","VJ26-13"]
	American_SJI_Virtual_Joists_VJ26_14 = ["American","SJI","Virtual Joists","VJ26-14"]
	American_SJI_Virtual_Joists_VJ26_15 = ["American","SJI","Virtual Joists","VJ26-15"]
	American_SJI_Virtual_Joists_VJ26_16 = ["American","SJI","Virtual Joists","VJ26-16"]
	American_SJI_Virtual_Joists_VJ26_17 = ["American","SJI","Virtual Joists","VJ26-17"]
	American_SJI_Virtual_Joists_VJ26_18 = ["American","SJI","Virtual Joists","VJ26-18"]
	American_SJI_Virtual_Joists_VJ26_19 = ["American","SJI","Virtual Joists","VJ26-19"]
	American_SJI_Virtual_Joists_VJ26_20 = ["American","SJI","Virtual Joists","VJ26-20"]
	American_SJI_Virtual_Joists_VJ26_21 = ["American","SJI","Virtual Joists","VJ26-21"]
	American_SJI_Virtual_Joists_VJ26_22 = ["American","SJI","Virtual Joists","VJ26-22"]
	American_SJI_Virtual_Joists_VJ26_23 = ["American","SJI","Virtual Joists","VJ26-23"]
	American_SJI_Virtual_Joists_VJ26_24 = ["American","SJI","Virtual Joists","VJ26-24"]
	American_SJI_Virtual_Joists_VJ26_25 = ["American","SJI","Virtual Joists","VJ26-25"]
	American_SJI_Virtual_Joists_VJ26_26 = ["American","SJI","Virtual Joists","VJ26-26"]
	American_SJI_Virtual_Joists_VJ26_27 = ["American","SJI","Virtual Joists","VJ26-27"]
	American_SJI_Virtual_Joists_VJ26_28 = ["American","SJI","Virtual Joists","VJ26-28"]
	American_SJI_Virtual_Joists_VJ26_29 = ["American","SJI","Virtual Joists","VJ26-29"]
	American_SJI_Virtual_Joists_VJ26_30 = ["American","SJI","Virtual Joists","VJ26-30"]
	American_SJI_Virtual_Joists_VJ26_31 = ["American","SJI","Virtual Joists","VJ26-31"]
	American_SJI_Virtual_Joists_VJ26_32 = ["American","SJI","Virtual Joists","VJ26-32"]
	American_SJI_Virtual_Joists_VJ26_33 = ["American","SJI","Virtual Joists","VJ26-33"]
	American_SJI_Virtual_Joists_VJ26_34 = ["American","SJI","Virtual Joists","VJ26-34"]
	American_SJI_Virtual_Joists_VJ26_35 = ["American","SJI","Virtual Joists","VJ26-35"]
	American_SJI_Virtual_Joists_VJ26_36 = ["American","SJI","Virtual Joists","VJ26-36"]
	American_SJI_Virtual_Joists_VJ26_37 = ["American","SJI","Virtual Joists","VJ26-37"]
	American_SJI_Virtual_Joists_VJ26_38 = ["American","SJI","Virtual Joists","VJ26-38"]
	American_SJI_Virtual_Joists_VJ26_39 = ["American","SJI","Virtual Joists","VJ26-39"]
	American_SJI_Virtual_Joists_VJ26_40 = ["American","SJI","Virtual Joists","VJ26-40"]
	American_SJI_Virtual_Joists_VJ26_41 = ["American","SJI","Virtual Joists","VJ26-41"]
	American_SJI_Virtual_Joists_VJ26_42 = ["American","SJI","Virtual Joists","VJ26-42"]
	American_SJI_Virtual_Joists_VJ26_43 = ["American","SJI","Virtual Joists","VJ26-43"]
	American_SJI_Virtual_Joists_VJ26_44 = ["American","SJI","Virtual Joists","VJ26-44"]
	American_SJI_Virtual_Joists_VJ26_45 = ["American","SJI","Virtual Joists","VJ26-45"]
	American_SJI_Virtual_Joists_VJ26_46 = ["American","SJI","Virtual Joists","VJ26-46"]
	American_SJI_Virtual_Joists_VJ26_47 = ["American","SJI","Virtual Joists","VJ26-47"]
	American_SJI_Virtual_Joists_VJ26_48 = ["American","SJI","Virtual Joists","VJ26-48"]
	American_SJI_Virtual_Joists_VJ26_49 = ["American","SJI","Virtual Joists","VJ26-49"]
	American_SJI_Virtual_Joists_VJ26_50 = ["American","SJI","Virtual Joists","VJ26-50"]
	American_SJI_Virtual_Joists_VJ26_51 = ["American","SJI","Virtual Joists","VJ26-51"]
	American_SJI_Virtual_Joists_VJ26_52 = ["American","SJI","Virtual Joists","VJ26-52"]
	American_SJI_Virtual_Joists_VJ26_53 = ["American","SJI","Virtual Joists","VJ26-53"]
	American_SJI_Virtual_Joists_VJ26_54 = ["American","SJI","Virtual Joists","VJ26-54"]
	American_SJI_Virtual_Joists_VJ26_55 = ["American","SJI","Virtual Joists","VJ26-55"]
	American_SJI_Virtual_Joists_VJ26_56 = ["American","SJI","Virtual Joists","VJ26-56"]
	American_SJI_Virtual_Joists_VJ26_57 = ["American","SJI","Virtual Joists","VJ26-57"]
	American_SJI_Virtual_Joists_VJ26_58 = ["American","SJI","Virtual Joists","VJ26-58"]
	American_SJI_Virtual_Joists_VJ26_59 = ["American","SJI","Virtual Joists","VJ26-59"]
	American_SJI_Virtual_Joists_VJ26_60 = ["American","SJI","Virtual Joists","VJ26-60"]
	American_SJI_Virtual_Joists_VJ26_61 = ["American","SJI","Virtual Joists","VJ26-61"]
	American_SJI_Virtual_Joists_VJ26_62 = ["American","SJI","Virtual Joists","VJ26-62"]
	American_SJI_Virtual_Joists_VJ26_63 = ["American","SJI","Virtual Joists","VJ26-63"]
	American_SJI_Virtual_Joists_VJ26_64 = ["American","SJI","Virtual Joists","VJ26-64"]
	American_SJI_Virtual_Joists_VJ26_65 = ["American","SJI","Virtual Joists","VJ26-65"]
	American_SJI_Virtual_Joists_VJ26_66 = ["American","SJI","Virtual Joists","VJ26-66"]
	American_SJI_Virtual_Joists_VJ28_1 = ["American","SJI","Virtual Joists","VJ28-1"]
	American_SJI_Virtual_Joists_VJ28_2 = ["American","SJI","Virtual Joists","VJ28-2"]
	American_SJI_Virtual_Joists_VJ28_3 = ["American","SJI","Virtual Joists","VJ28-3"]
	American_SJI_Virtual_Joists_VJ28_4 = ["American","SJI","Virtual Joists","VJ28-4"]
	American_SJI_Virtual_Joists_VJ28_5 = ["American","SJI","Virtual Joists","VJ28-5"]
	American_SJI_Virtual_Joists_VJ28_6 = ["American","SJI","Virtual Joists","VJ28-6"]
	American_SJI_Virtual_Joists_VJ28_7 = ["American","SJI","Virtual Joists","VJ28-7"]
	American_SJI_Virtual_Joists_VJ28_8 = ["American","SJI","Virtual Joists","VJ28-8"]
	American_SJI_Virtual_Joists_VJ28_9 = ["American","SJI","Virtual Joists","VJ28-9"]
	American_SJI_Virtual_Joists_VJ28_10 = ["American","SJI","Virtual Joists","VJ28-10"]
	American_SJI_Virtual_Joists_VJ28_11 = ["American","SJI","Virtual Joists","VJ28-11"]
	American_SJI_Virtual_Joists_VJ28_12 = ["American","SJI","Virtual Joists","VJ28-12"]
	American_SJI_Virtual_Joists_VJ28_13 = ["American","SJI","Virtual Joists","VJ28-13"]
	American_SJI_Virtual_Joists_VJ28_14 = ["American","SJI","Virtual Joists","VJ28-14"]
	American_SJI_Virtual_Joists_VJ28_15 = ["American","SJI","Virtual Joists","VJ28-15"]
	American_SJI_Virtual_Joists_VJ28_16 = ["American","SJI","Virtual Joists","VJ28-16"]
	American_SJI_Virtual_Joists_VJ28_17 = ["American","SJI","Virtual Joists","VJ28-17"]
	American_SJI_Virtual_Joists_VJ28_18 = ["American","SJI","Virtual Joists","VJ28-18"]
	American_SJI_Virtual_Joists_VJ28_19 = ["American","SJI","Virtual Joists","VJ28-19"]
	American_SJI_Virtual_Joists_VJ28_20 = ["American","SJI","Virtual Joists","VJ28-20"]
	American_SJI_Virtual_Joists_VJ28_21 = ["American","SJI","Virtual Joists","VJ28-21"]
	American_SJI_Virtual_Joists_VJ28_22 = ["American","SJI","Virtual Joists","VJ28-22"]
	American_SJI_Virtual_Joists_VJ28_23 = ["American","SJI","Virtual Joists","VJ28-23"]
	American_SJI_Virtual_Joists_VJ28_24 = ["American","SJI","Virtual Joists","VJ28-24"]
	American_SJI_Virtual_Joists_VJ28_25 = ["American","SJI","Virtual Joists","VJ28-25"]
	American_SJI_Virtual_Joists_VJ28_26 = ["American","SJI","Virtual Joists","VJ28-26"]
	American_SJI_Virtual_Joists_VJ28_27 = ["American","SJI","Virtual Joists","VJ28-27"]
	American_SJI_Virtual_Joists_VJ28_28 = ["American","SJI","Virtual Joists","VJ28-28"]
	American_SJI_Virtual_Joists_VJ28_29 = ["American","SJI","Virtual Joists","VJ28-29"]
	American_SJI_Virtual_Joists_VJ28_30 = ["American","SJI","Virtual Joists","VJ28-30"]
	American_SJI_Virtual_Joists_VJ28_31 = ["American","SJI","Virtual Joists","VJ28-31"]
	American_SJI_Virtual_Joists_VJ28_32 = ["American","SJI","Virtual Joists","VJ28-32"]
	American_SJI_Virtual_Joists_VJ28_33 = ["American","SJI","Virtual Joists","VJ28-33"]
	American_SJI_Virtual_Joists_VJ28_34 = ["American","SJI","Virtual Joists","VJ28-34"]
	American_SJI_Virtual_Joists_VJ28_35 = ["American","SJI","Virtual Joists","VJ28-35"]
	American_SJI_Virtual_Joists_VJ28_36 = ["American","SJI","Virtual Joists","VJ28-36"]
	American_SJI_Virtual_Joists_VJ28_37 = ["American","SJI","Virtual Joists","VJ28-37"]
	American_SJI_Virtual_Joists_VJ28_38 = ["American","SJI","Virtual Joists","VJ28-38"]
	American_SJI_Virtual_Joists_VJ28_39 = ["American","SJI","Virtual Joists","VJ28-39"]
	American_SJI_Virtual_Joists_VJ28_40 = ["American","SJI","Virtual Joists","VJ28-40"]
	American_SJI_Virtual_Joists_VJ28_41 = ["American","SJI","Virtual Joists","VJ28-41"]
	American_SJI_Virtual_Joists_VJ28_42 = ["American","SJI","Virtual Joists","VJ28-42"]
	American_SJI_Virtual_Joists_VJ28_43 = ["American","SJI","Virtual Joists","VJ28-43"]
	American_SJI_Virtual_Joists_VJ28_44 = ["American","SJI","Virtual Joists","VJ28-44"]
	American_SJI_Virtual_Joists_VJ28_45 = ["American","SJI","Virtual Joists","VJ28-45"]
	American_SJI_Virtual_Joists_VJ28_46 = ["American","SJI","Virtual Joists","VJ28-46"]
	American_SJI_Virtual_Joists_VJ28_47 = ["American","SJI","Virtual Joists","VJ28-47"]
	American_SJI_Virtual_Joists_VJ28_48 = ["American","SJI","Virtual Joists","VJ28-48"]
	American_SJI_Virtual_Joists_VJ28_49 = ["American","SJI","Virtual Joists","VJ28-49"]
	American_SJI_Virtual_Joists_VJ28_50 = ["American","SJI","Virtual Joists","VJ28-50"]
	American_SJI_Virtual_Joists_VJ28_51 = ["American","SJI","Virtual Joists","VJ28-51"]
	American_SJI_Virtual_Joists_VJ28_52 = ["American","SJI","Virtual Joists","VJ28-52"]
	American_SJI_Virtual_Joists_VJ28_53 = ["American","SJI","Virtual Joists","VJ28-53"]
	American_SJI_Virtual_Joists_VJ28_54 = ["American","SJI","Virtual Joists","VJ28-54"]
	American_SJI_Virtual_Joists_VJ28_55 = ["American","SJI","Virtual Joists","VJ28-55"]
	American_SJI_Virtual_Joists_VJ28_56 = ["American","SJI","Virtual Joists","VJ28-56"]
	American_SJI_Virtual_Joists_VJ28_57 = ["American","SJI","Virtual Joists","VJ28-57"]
	American_SJI_Virtual_Joists_VJ28_58 = ["American","SJI","Virtual Joists","VJ28-58"]
	American_SJI_Virtual_Joists_VJ28_59 = ["American","SJI","Virtual Joists","VJ28-59"]
	American_SJI_Virtual_Joists_VJ28_60 = ["American","SJI","Virtual Joists","VJ28-60"]
	American_SJI_Virtual_Joists_VJ28_61 = ["American","SJI","Virtual Joists","VJ28-61"]
	American_SJI_Virtual_Joists_VJ28_62 = ["American","SJI","Virtual Joists","VJ28-62"]
	American_SJI_Virtual_Joists_VJ28_63 = ["American","SJI","Virtual Joists","VJ28-63"]
	American_SJI_Virtual_Joists_VJ28_64 = ["American","SJI","Virtual Joists","VJ28-64"]
	American_SJI_Virtual_Joists_VJ28_65 = ["American","SJI","Virtual Joists","VJ28-65"]
	American_SJI_Virtual_Joists_VJ28_66 = ["American","SJI","Virtual Joists","VJ28-66"]
	American_SJI_Virtual_Joists_VJ28_67 = ["American","SJI","Virtual Joists","VJ28-67"]
	American_SJI_Virtual_Joists_VJ28_68 = ["American","SJI","Virtual Joists","VJ28-68"]
	American_SJI_Virtual_Joists_VJ28_69 = ["American","SJI","Virtual Joists","VJ28-69"]
	American_SJI_Virtual_Joists_VJ28_70 = ["American","SJI","Virtual Joists","VJ28-70"]
	American_SJI_Virtual_Joists_VJ28_71 = ["American","SJI","Virtual Joists","VJ28-71"]
	American_SJI_Virtual_Joists_VJ28_72 = ["American","SJI","Virtual Joists","VJ28-72"]
	American_SJI_Virtual_Joists_VJ30_1 = ["American","SJI","Virtual Joists","VJ30-1"]
	American_SJI_Virtual_Joists_VJ30_2 = ["American","SJI","Virtual Joists","VJ30-2"]
	American_SJI_Virtual_Joists_VJ30_3 = ["American","SJI","Virtual Joists","VJ30-3"]
	American_SJI_Virtual_Joists_VJ30_4 = ["American","SJI","Virtual Joists","VJ30-4"]
	American_SJI_Virtual_Joists_VJ30_5 = ["American","SJI","Virtual Joists","VJ30-5"]
	American_SJI_Virtual_Joists_VJ30_6 = ["American","SJI","Virtual Joists","VJ30-6"]
	American_SJI_Virtual_Joists_VJ30_7 = ["American","SJI","Virtual Joists","VJ30-7"]
	American_SJI_Virtual_Joists_VJ30_8 = ["American","SJI","Virtual Joists","VJ30-8"]
	American_SJI_Virtual_Joists_VJ30_9 = ["American","SJI","Virtual Joists","VJ30-9"]
	American_SJI_Virtual_Joists_VJ30_10 = ["American","SJI","Virtual Joists","VJ30-10"]
	American_SJI_Virtual_Joists_VJ30_11 = ["American","SJI","Virtual Joists","VJ30-11"]
	American_SJI_Virtual_Joists_VJ30_12 = ["American","SJI","Virtual Joists","VJ30-12"]
	American_SJI_Virtual_Joists_VJ30_13 = ["American","SJI","Virtual Joists","VJ30-13"]
	American_SJI_Virtual_Joists_VJ30_14 = ["American","SJI","Virtual Joists","VJ30-14"]
	American_SJI_Virtual_Joists_VJ30_15 = ["American","SJI","Virtual Joists","VJ30-15"]
	American_SJI_Virtual_Joists_VJ30_16 = ["American","SJI","Virtual Joists","VJ30-16"]
	American_SJI_Virtual_Joists_VJ30_17 = ["American","SJI","Virtual Joists","VJ30-17"]
	American_SJI_Virtual_Joists_VJ30_18 = ["American","SJI","Virtual Joists","VJ30-18"]
	American_SJI_Virtual_Joists_VJ30_19 = ["American","SJI","Virtual Joists","VJ30-19"]
	American_SJI_Virtual_Joists_VJ30_20 = ["American","SJI","Virtual Joists","VJ30-20"]
	American_SJI_Virtual_Joists_VJ30_21 = ["American","SJI","Virtual Joists","VJ30-21"]
	American_SJI_Virtual_Joists_VJ30_22 = ["American","SJI","Virtual Joists","VJ30-22"]
	American_SJI_Virtual_Joists_VJ30_23 = ["American","SJI","Virtual Joists","VJ30-23"]
	American_SJI_Virtual_Joists_VJ30_24 = ["American","SJI","Virtual Joists","VJ30-24"]
	American_SJI_Virtual_Joists_VJ30_25 = ["American","SJI","Virtual Joists","VJ30-25"]
	American_SJI_Virtual_Joists_VJ30_26 = ["American","SJI","Virtual Joists","VJ30-26"]
	American_SJI_Virtual_Joists_VJ30_27 = ["American","SJI","Virtual Joists","VJ30-27"]
	American_SJI_Virtual_Joists_VJ30_28 = ["American","SJI","Virtual Joists","VJ30-28"]
	American_SJI_Virtual_Joists_VJ30_29 = ["American","SJI","Virtual Joists","VJ30-29"]
	American_SJI_Virtual_Joists_VJ30_30 = ["American","SJI","Virtual Joists","VJ30-30"]
	American_SJI_Virtual_Joists_VJ30_31 = ["American","SJI","Virtual Joists","VJ30-31"]
	American_SJI_Virtual_Joists_VJ30_32 = ["American","SJI","Virtual Joists","VJ30-32"]
	American_SJI_Virtual_Joists_VJ30_33 = ["American","SJI","Virtual Joists","VJ30-33"]
	American_SJI_Virtual_Joists_VJ30_34 = ["American","SJI","Virtual Joists","VJ30-34"]
	American_SJI_Virtual_Joists_VJ30_35 = ["American","SJI","Virtual Joists","VJ30-35"]
	American_SJI_Virtual_Joists_VJ30_36 = ["American","SJI","Virtual Joists","VJ30-36"]
	American_SJI_Virtual_Joists_VJ30_37 = ["American","SJI","Virtual Joists","VJ30-37"]
	American_SJI_Virtual_Joists_VJ30_38 = ["American","SJI","Virtual Joists","VJ30-38"]
	American_SJI_Virtual_Joists_VJ30_39 = ["American","SJI","Virtual Joists","VJ30-39"]
	American_SJI_Virtual_Joists_VJ30_40 = ["American","SJI","Virtual Joists","VJ30-40"]
	American_SJI_Virtual_Joists_VJ30_41 = ["American","SJI","Virtual Joists","VJ30-41"]
	American_SJI_Virtual_Joists_VJ30_42 = ["American","SJI","Virtual Joists","VJ30-42"]
	American_SJI_Virtual_Joists_VJ30_43 = ["American","SJI","Virtual Joists","VJ30-43"]
	American_SJI_Virtual_Joists_VJ30_44 = ["American","SJI","Virtual Joists","VJ30-44"]
	American_SJI_Virtual_Joists_VJ30_45 = ["American","SJI","Virtual Joists","VJ30-45"]
	American_SJI_Virtual_Joists_VJ30_46 = ["American","SJI","Virtual Joists","VJ30-46"]
	American_SJI_Virtual_Joists_VJ30_47 = ["American","SJI","Virtual Joists","VJ30-47"]
	American_SJI_Virtual_Joists_VJ30_48 = ["American","SJI","Virtual Joists","VJ30-48"]
	American_SJI_Virtual_Joists_VJ30_49 = ["American","SJI","Virtual Joists","VJ30-49"]
	American_SJI_Virtual_Joists_VJ30_50 = ["American","SJI","Virtual Joists","VJ30-50"]
	American_SJI_Virtual_Joists_VJ30_51 = ["American","SJI","Virtual Joists","VJ30-51"]
	American_SJI_Virtual_Joists_VJ30_52 = ["American","SJI","Virtual Joists","VJ30-52"]
	American_SJI_Virtual_Joists_VJ30_53 = ["American","SJI","Virtual Joists","VJ30-53"]
	American_SJI_Virtual_Joists_VJ30_54 = ["American","SJI","Virtual Joists","VJ30-54"]
	American_SJI_Virtual_Joists_VJ30_55 = ["American","SJI","Virtual Joists","VJ30-55"]
	American_SJI_Virtual_Joists_VJ30_56 = ["American","SJI","Virtual Joists","VJ30-56"]
	American_SJI_Virtual_Joists_VJ30_57 = ["American","SJI","Virtual Joists","VJ30-57"]
	American_SJI_Virtual_Joists_VJ30_58 = ["American","SJI","Virtual Joists","VJ30-58"]
	American_SJI_Virtual_Joists_VJ30_59 = ["American","SJI","Virtual Joists","VJ30-59"]
	American_SJI_Virtual_Joists_VJ30_60 = ["American","SJI","Virtual Joists","VJ30-60"]
	American_SJI_Virtual_Joists_VJ30_61 = ["American","SJI","Virtual Joists","VJ30-61"]
	American_SJI_Virtual_Joists_VJ30_62 = ["American","SJI","Virtual Joists","VJ30-62"]
	American_SJI_Virtual_Joists_VJ30_63 = ["American","SJI","Virtual Joists","VJ30-63"]
	American_SJI_Virtual_Joists_VJ30_64 = ["American","SJI","Virtual Joists","VJ30-64"]
	American_SJI_Virtual_Joists_VJ30_65 = ["American","SJI","Virtual Joists","VJ30-65"]
	American_SJI_Virtual_Joists_VJ30_66 = ["American","SJI","Virtual Joists","VJ30-66"]
	American_SJI_Virtual_Joists_VJ30_67 = ["American","SJI","Virtual Joists","VJ30-67"]
	American_SJI_Virtual_Joists_VJ30_68 = ["American","SJI","Virtual Joists","VJ30-68"]
	American_SJI_Virtual_Joists_VJ30_69 = ["American","SJI","Virtual Joists","VJ30-69"]
	American_SJI_Virtual_Joists_VJ30_70 = ["American","SJI","Virtual Joists","VJ30-70"]
	American_SJI_Virtual_Joists_VJ30_71 = ["American","SJI","Virtual Joists","VJ30-71"]
	American_SJI_Virtual_Joists_VJ30_72 = ["American","SJI","Virtual Joists","VJ30-72"]
	American_SJI_Virtual_Joists_VJ32_1 = ["American","SJI","Virtual Joists","VJ32-1"]
	American_SJI_Virtual_Joists_VJ32_2 = ["American","SJI","Virtual Joists","VJ32-2"]
	American_SJI_Virtual_Joists_VJ32_3 = ["American","SJI","Virtual Joists","VJ32-3"]
	American_SJI_Virtual_Joists_VJ32_4 = ["American","SJI","Virtual Joists","VJ32-4"]
	American_SJI_Virtual_Joists_VJ32_5 = ["American","SJI","Virtual Joists","VJ32-5"]
	American_SJI_Virtual_Joists_VJ32_6 = ["American","SJI","Virtual Joists","VJ32-6"]
	American_SJI_Virtual_Joists_VJ32_7 = ["American","SJI","Virtual Joists","VJ32-7"]
	American_SJI_Virtual_Joists_VJ32_8 = ["American","SJI","Virtual Joists","VJ32-8"]
	American_SJI_Virtual_Joists_VJ32_9 = ["American","SJI","Virtual Joists","VJ32-9"]
	American_SJI_Virtual_Joists_VJ32_10 = ["American","SJI","Virtual Joists","VJ32-10"]
	American_SJI_Virtual_Joists_VJ32_11 = ["American","SJI","Virtual Joists","VJ32-11"]
	American_SJI_Virtual_Joists_VJ32_12 = ["American","SJI","Virtual Joists","VJ32-12"]
	American_SJI_Virtual_Joists_VJ32_13 = ["American","SJI","Virtual Joists","VJ32-13"]
	American_SJI_Virtual_Joists_VJ32_14 = ["American","SJI","Virtual Joists","VJ32-14"]
	American_SJI_Virtual_Joists_VJ32_15 = ["American","SJI","Virtual Joists","VJ32-15"]
	American_SJI_Virtual_Joists_VJ32_16 = ["American","SJI","Virtual Joists","VJ32-16"]
	American_SJI_Virtual_Joists_VJ32_17 = ["American","SJI","Virtual Joists","VJ32-17"]
	American_SJI_Virtual_Joists_VJ32_18 = ["American","SJI","Virtual Joists","VJ32-18"]
	American_SJI_Virtual_Joists_VJ32_19 = ["American","SJI","Virtual Joists","VJ32-19"]
	American_SJI_Virtual_Joists_VJ32_20 = ["American","SJI","Virtual Joists","VJ32-20"]
	American_SJI_Virtual_Joists_VJ32_21 = ["American","SJI","Virtual Joists","VJ32-21"]
	American_SJI_Virtual_Joists_VJ32_22 = ["American","SJI","Virtual Joists","VJ32-22"]
	American_SJI_Virtual_Joists_VJ32_23 = ["American","SJI","Virtual Joists","VJ32-23"]
	American_SJI_Virtual_Joists_VJ32_24 = ["American","SJI","Virtual Joists","VJ32-24"]
	American_SJI_Virtual_Joists_VJ32_25 = ["American","SJI","Virtual Joists","VJ32-25"]
	American_SJI_Virtual_Joists_VJ32_26 = ["American","SJI","Virtual Joists","VJ32-26"]
	American_SJI_Virtual_Joists_VJ32_27 = ["American","SJI","Virtual Joists","VJ32-27"]
	American_SJI_Virtual_Joists_VJ32_28 = ["American","SJI","Virtual Joists","VJ32-28"]
	American_SJI_Virtual_Joists_VJ32_29 = ["American","SJI","Virtual Joists","VJ32-29"]
	American_SJI_Virtual_Joists_VJ32_30 = ["American","SJI","Virtual Joists","VJ32-30"]
	American_SJI_Virtual_Joists_VJ32_31 = ["American","SJI","Virtual Joists","VJ32-31"]
	American_SJI_Virtual_Joists_VJ32_32 = ["American","SJI","Virtual Joists","VJ32-32"]
	American_SJI_Virtual_Joists_VJ32_33 = ["American","SJI","Virtual Joists","VJ32-33"]
	American_SJI_Virtual_Joists_VJ32_34 = ["American","SJI","Virtual Joists","VJ32-34"]
	American_SJI_Virtual_Joists_VJ32_35 = ["American","SJI","Virtual Joists","VJ32-35"]
	American_SJI_Virtual_Joists_VJ32_36 = ["American","SJI","Virtual Joists","VJ32-36"]
	American_SJI_Virtual_Joists_VJ32_37 = ["American","SJI","Virtual Joists","VJ32-37"]
	American_SJI_Virtual_Joists_VJ32_38 = ["American","SJI","Virtual Joists","VJ32-38"]
	American_SJI_Virtual_Joists_VJ32_39 = ["American","SJI","Virtual Joists","VJ32-39"]
	American_SJI_Virtual_Joists_VJ32_40 = ["American","SJI","Virtual Joists","VJ32-40"]
	American_SJI_Virtual_Joists_VJ32_41 = ["American","SJI","Virtual Joists","VJ32-41"]
	American_SJI_Virtual_Joists_VJ32_42 = ["American","SJI","Virtual Joists","VJ32-42"]
	American_SJI_Virtual_Joists_VJ32_43 = ["American","SJI","Virtual Joists","VJ32-43"]
	American_SJI_Virtual_Joists_VJ32_44 = ["American","SJI","Virtual Joists","VJ32-44"]
	American_SJI_Virtual_Joists_VJ32_45 = ["American","SJI","Virtual Joists","VJ32-45"]
	American_SJI_Virtual_Joists_VJ36_1 = ["American","SJI","Virtual Joists","VJ36-1"]
	American_SJI_Virtual_Joists_VJ36_2 = ["American","SJI","Virtual Joists","VJ36-2"]
	American_SJI_Virtual_Joists_VJ36_3 = ["American","SJI","Virtual Joists","VJ36-3"]
	American_SJI_Virtual_Joists_VJ36_4 = ["American","SJI","Virtual Joists","VJ36-4"]
	American_SJI_Virtual_Joists_VJ36_5 = ["American","SJI","Virtual Joists","VJ36-5"]
	American_SJI_Virtual_Joists_VJ36_6 = ["American","SJI","Virtual Joists","VJ36-6"]
	American_SJI_Virtual_Joists_VJ36_7 = ["American","SJI","Virtual Joists","VJ36-7"]
	American_SJI_Virtual_Joists_VJ36_8 = ["American","SJI","Virtual Joists","VJ36-8"]
	American_SJI_Virtual_Joists_VJ36_9 = ["American","SJI","Virtual Joists","VJ36-9"]
	American_SJI_Virtual_Joists_VJ36_10 = ["American","SJI","Virtual Joists","VJ36-10"]
	American_SJI_Virtual_Joists_VJ36_11 = ["American","SJI","Virtual Joists","VJ36-11"]
	American_SJI_Virtual_Joists_VJ36_12 = ["American","SJI","Virtual Joists","VJ36-12"]
	American_SJI_Virtual_Joists_VJ36_13 = ["American","SJI","Virtual Joists","VJ36-13"]
	American_SJI_Virtual_Joists_VJ36_14 = ["American","SJI","Virtual Joists","VJ36-14"]
	American_SJI_Virtual_Joists_VJ36_15 = ["American","SJI","Virtual Joists","VJ36-15"]
	American_SJI_Virtual_Joists_VJ36_16 = ["American","SJI","Virtual Joists","VJ36-16"]
	American_SJI_Virtual_Joists_VJ36_17 = ["American","SJI","Virtual Joists","VJ36-17"]
	American_SJI_Virtual_Joists_VJ36_18 = ["American","SJI","Virtual Joists","VJ36-18"]
	American_SJI_Virtual_Joists_VJ36_19 = ["American","SJI","Virtual Joists","VJ36-19"]
	American_SJI_Virtual_Joists_VJ36_20 = ["American","SJI","Virtual Joists","VJ36-20"]
	American_SJI_Virtual_Joists_VJ36_21 = ["American","SJI","Virtual Joists","VJ36-21"]
	American_SJI_Virtual_Joists_VJ36_22 = ["American","SJI","Virtual Joists","VJ36-22"]
	American_SJI_Virtual_Joists_VJ36_23 = ["American","SJI","Virtual Joists","VJ36-23"]
	American_SJI_Virtual_Joists_VJ36_24 = ["American","SJI","Virtual Joists","VJ36-24"]
	American_SJI_Virtual_Joists_VJ36_25 = ["American","SJI","Virtual Joists","VJ36-25"]
	American_SJI_Virtual_Joists_VJ36_26 = ["American","SJI","Virtual Joists","VJ36-26"]
	American_SJI_Virtual_Joists_VJ36_27 = ["American","SJI","Virtual Joists","VJ36-27"]
	American_SJI_Virtual_Joists_VJ36_28 = ["American","SJI","Virtual Joists","VJ36-28"]
	American_SJI_Virtual_Joists_VJ36_29 = ["American","SJI","Virtual Joists","VJ36-29"]
	American_SJI_Virtual_Joists_VJ36_30 = ["American","SJI","Virtual Joists","VJ36-30"]
	American_SJI_Virtual_Joists_VJ36_31 = ["American","SJI","Virtual Joists","VJ36-31"]
	American_SJI_Virtual_Joists_VJ36_32 = ["American","SJI","Virtual Joists","VJ36-32"]
	American_SJI_Virtual_Joists_VJ36_33 = ["American","SJI","Virtual Joists","VJ36-33"]
	American_SJI_Virtual_Joists_VJ36_34 = ["American","SJI","Virtual Joists","VJ36-34"]
	American_SJI_Virtual_Joists_VJ36_35 = ["American","SJI","Virtual Joists","VJ36-35"]
	American_SJI_Virtual_Joists_VJ36_36 = ["American","SJI","Virtual Joists","VJ36-36"]
	American_SJI_Virtual_Joists_VJ36_37 = ["American","SJI","Virtual Joists","VJ36-37"]
	American_SJI_Virtual_Joists_VJ36_38 = ["American","SJI","Virtual Joists","VJ36-38"]
	American_SJI_Virtual_Joists_VJ36_39 = ["American","SJI","Virtual Joists","VJ36-39"]
	American_SJI_Virtual_Joists_VJ36_40 = ["American","SJI","Virtual Joists","VJ36-40"]
	American_SJI_Virtual_Joists_VJ36_41 = ["American","SJI","Virtual Joists","VJ36-41"]
	American_SJI_Virtual_Joists_VJ36_42 = ["American","SJI","Virtual Joists","VJ36-42"]
	American_SJI_Virtual_Joists_VJ36_43 = ["American","SJI","Virtual Joists","VJ36-43"]
	American_SJI_Virtual_Joists_VJ36_44 = ["American","SJI","Virtual Joists","VJ36-44"]
	American_SJI_Virtual_Joists_VJ36_45 = ["American","SJI","Virtual Joists","VJ36-45"]
	American_SJI_Virtual_Joists_VJ40_1 = ["American","SJI","Virtual Joists","VJ40-1"]
	American_SJI_Virtual_Joists_VJ40_2 = ["American","SJI","Virtual Joists","VJ40-2"]
	American_SJI_Virtual_Joists_VJ40_3 = ["American","SJI","Virtual Joists","VJ40-3"]
	American_SJI_Virtual_Joists_VJ40_4 = ["American","SJI","Virtual Joists","VJ40-4"]
	American_SJI_Virtual_Joists_VJ40_5 = ["American","SJI","Virtual Joists","VJ40-5"]
	American_SJI_Virtual_Joists_VJ40_6 = ["American","SJI","Virtual Joists","VJ40-6"]
	American_SJI_Virtual_Joists_VJ40_7 = ["American","SJI","Virtual Joists","VJ40-7"]
	American_SJI_Virtual_Joists_VJ40_8 = ["American","SJI","Virtual Joists","VJ40-8"]
	American_SJI_Virtual_Joists_VJ40_9 = ["American","SJI","Virtual Joists","VJ40-9"]
	American_SJI_Virtual_Joists_VJ40_10 = ["American","SJI","Virtual Joists","VJ40-10"]
	American_SJI_Virtual_Joists_VJ40_11 = ["American","SJI","Virtual Joists","VJ40-11"]
	American_SJI_Virtual_Joists_VJ40_12 = ["American","SJI","Virtual Joists","VJ40-12"]
	American_SJI_Virtual_Joists_VJ40_13 = ["American","SJI","Virtual Joists","VJ40-13"]
	American_SJI_Virtual_Joists_VJ40_14 = ["American","SJI","Virtual Joists","VJ40-14"]
	American_SJI_Virtual_Joists_VJ40_15 = ["American","SJI","Virtual Joists","VJ40-15"]
	American_SJI_Virtual_Joists_VJ40_16 = ["American","SJI","Virtual Joists","VJ40-16"]
	American_SJI_Virtual_Joists_VJ40_17 = ["American","SJI","Virtual Joists","VJ40-17"]
	American_SJI_Virtual_Joists_VJ40_18 = ["American","SJI","Virtual Joists","VJ40-18"]
	American_SJI_Virtual_Joists_VJ40_19 = ["American","SJI","Virtual Joists","VJ40-19"]
	American_SJI_Virtual_Joists_VJ40_20 = ["American","SJI","Virtual Joists","VJ40-20"]
	American_SJI_Virtual_Joists_VJ40_21 = ["American","SJI","Virtual Joists","VJ40-21"]
	American_SJI_Virtual_Joists_VJ40_22 = ["American","SJI","Virtual Joists","VJ40-22"]
	American_SJI_Virtual_Joists_VJ40_23 = ["American","SJI","Virtual Joists","VJ40-23"]
	American_SJI_Virtual_Joists_VJ40_24 = ["American","SJI","Virtual Joists","VJ40-24"]
	American_SJI_Virtual_Joists_VJ40_25 = ["American","SJI","Virtual Joists","VJ40-25"]
	American_SJI_Virtual_Joists_VJ40_26 = ["American","SJI","Virtual Joists","VJ40-26"]
	American_SJI_Virtual_Joists_VJ40_27 = ["American","SJI","Virtual Joists","VJ40-27"]
	American_SJI_Virtual_Joists_VJ40_28 = ["American","SJI","Virtual Joists","VJ40-28"]
	American_SJI_Virtual_Joists_VJ40_29 = ["American","SJI","Virtual Joists","VJ40-29"]
	American_SJI_Virtual_Joists_VJ40_30 = ["American","SJI","Virtual Joists","VJ40-30"]
	American_SJI_Virtual_Joists_VJ40_31 = ["American","SJI","Virtual Joists","VJ40-31"]
	American_SJI_Virtual_Joists_VJ40_32 = ["American","SJI","Virtual Joists","VJ40-32"]
	American_SJI_Virtual_Joists_VJ40_33 = ["American","SJI","Virtual Joists","VJ40-33"]
	American_SJI_Virtual_Joists_VJ40_34 = ["American","SJI","Virtual Joists","VJ40-34"]
	American_SJI_Virtual_Joists_VJ40_35 = ["American","SJI","Virtual Joists","VJ40-35"]
	American_SJI_Virtual_Joists_VJ40_36 = ["American","SJI","Virtual Joists","VJ40-36"]
	American_SJI_Virtual_Joists_VJ40_37 = ["American","SJI","Virtual Joists","VJ40-37"]
	American_SJI_Virtual_Joists_VJ40_38 = ["American","SJI","Virtual Joists","VJ40-38"]
	American_SJI_Virtual_Joists_VJ40_39 = ["American","SJI","Virtual Joists","VJ40-39"]
	American_SJI_Virtual_Joists_VJ40_40 = ["American","SJI","Virtual Joists","VJ40-40"]
	American_SJI_Virtual_Joists_VJ40_41 = ["American","SJI","Virtual Joists","VJ40-41"]
	American_SJI_Virtual_Joists_VJ40_42 = ["American","SJI","Virtual Joists","VJ40-42"]
	American_SJI_Virtual_Joists_VJ44_1 = ["American","SJI","Virtual Joists","VJ44-1"]
	American_SJI_Virtual_Joists_VJ44_2 = ["American","SJI","Virtual Joists","VJ44-2"]
	American_SJI_Virtual_Joists_VJ44_3 = ["American","SJI","Virtual Joists","VJ44-3"]
	American_SJI_Virtual_Joists_VJ44_4 = ["American","SJI","Virtual Joists","VJ44-4"]
	American_SJI_Virtual_Joists_VJ44_5 = ["American","SJI","Virtual Joists","VJ44-5"]
	American_SJI_Virtual_Joists_VJ44_6 = ["American","SJI","Virtual Joists","VJ44-6"]
	American_SJI_Virtual_Joists_VJ44_7 = ["American","SJI","Virtual Joists","VJ44-7"]
	American_SJI_Virtual_Joists_VJ44_8 = ["American","SJI","Virtual Joists","VJ44-8"]
	American_SJI_Virtual_Joists_VJ44_9 = ["American","SJI","Virtual Joists","VJ44-9"]
	American_SJI_Virtual_Joists_VJ44_10 = ["American","SJI","Virtual Joists","VJ44-10"]
	American_SJI_Virtual_Joists_VJ44_11 = ["American","SJI","Virtual Joists","VJ44-11"]
	American_SJI_Virtual_Joists_VJ44_12 = ["American","SJI","Virtual Joists","VJ44-12"]
	American_SJI_Virtual_Joists_VJ44_13 = ["American","SJI","Virtual Joists","VJ44-13"]
	American_SJI_Virtual_Joists_VJ44_14 = ["American","SJI","Virtual Joists","VJ44-14"]
	American_SJI_Virtual_Joists_VJ44_15 = ["American","SJI","Virtual Joists","VJ44-15"]
	American_SJI_Virtual_Joists_VJ44_16 = ["American","SJI","Virtual Joists","VJ44-16"]
	American_SJI_Virtual_Joists_VJ44_17 = ["American","SJI","Virtual Joists","VJ44-17"]
	American_SJI_Virtual_Joists_VJ44_18 = ["American","SJI","Virtual Joists","VJ44-18"]
	American_SJI_Virtual_Joists_VJ44_19 = ["American","SJI","Virtual Joists","VJ44-19"]
	American_SJI_Virtual_Joists_VJ44_20 = ["American","SJI","Virtual Joists","VJ44-20"]
	American_SJI_Virtual_Joists_VJ44_21 = ["American","SJI","Virtual Joists","VJ44-21"]
	American_SJI_Virtual_Joists_VJ44_22 = ["American","SJI","Virtual Joists","VJ44-22"]
	American_SJI_Virtual_Joists_VJ44_23 = ["American","SJI","Virtual Joists","VJ44-23"]
	American_SJI_Virtual_Joists_VJ44_24 = ["American","SJI","Virtual Joists","VJ44-24"]
	American_SJI_Virtual_Joists_VJ44_25 = ["American","SJI","Virtual Joists","VJ44-25"]
	American_SJI_Virtual_Joists_VJ44_26 = ["American","SJI","Virtual Joists","VJ44-26"]
	American_SJI_Virtual_Joists_VJ44_27 = ["American","SJI","Virtual Joists","VJ44-27"]
	American_SJI_Virtual_Joists_VJ44_28 = ["American","SJI","Virtual Joists","VJ44-28"]
	American_SJI_Virtual_Joists_VJ44_29 = ["American","SJI","Virtual Joists","VJ44-29"]
	American_SJI_Virtual_Joists_VJ44_30 = ["American","SJI","Virtual Joists","VJ44-30"]
	American_SJI_Virtual_Joists_VJ44_31 = ["American","SJI","Virtual Joists","VJ44-31"]
	American_SJI_Virtual_Joists_VJ44_32 = ["American","SJI","Virtual Joists","VJ44-32"]
	American_SJI_Virtual_Joists_VJ44_33 = ["American","SJI","Virtual Joists","VJ44-33"]
	American_SJI_Virtual_Joists_VJ44_34 = ["American","SJI","Virtual Joists","VJ44-34"]
	American_SJI_Virtual_Joists_VJ44_35 = ["American","SJI","Virtual Joists","VJ44-35"]
	American_SJI_Virtual_Joists_VJ44_36 = ["American","SJI","Virtual Joists","VJ44-36"]
	American_SJI_Virtual_Joists_VJ44_37 = ["American","SJI","Virtual Joists","VJ44-37"]
	American_SJI_Virtual_Joists_VJ44_38 = ["American","SJI","Virtual Joists","VJ44-38"]
	American_SJI_Virtual_Joists_VJ44_39 = ["American","SJI","Virtual Joists","VJ44-39"]
	American_SJI_Virtual_Joists_VJ44_40 = ["American","SJI","Virtual Joists","VJ44-40"]
	American_SJI_Virtual_Joists_VJ44_41 = ["American","SJI","Virtual Joists","VJ44-41"]
	American_SJI_Virtual_Joists_VJ44_42 = ["American","SJI","Virtual Joists","VJ44-42"]
	American_SJI_Virtual_Joists_VJ48_1 = ["American","SJI","Virtual Joists","VJ48-1"]
	American_SJI_Virtual_Joists_VJ48_2 = ["American","SJI","Virtual Joists","VJ48-2"]
	American_SJI_Virtual_Joists_VJ48_3 = ["American","SJI","Virtual Joists","VJ48-3"]
	American_SJI_Virtual_Joists_VJ48_4 = ["American","SJI","Virtual Joists","VJ48-4"]
	American_SJI_Virtual_Joists_VJ48_5 = ["American","SJI","Virtual Joists","VJ48-5"]
	American_SJI_Virtual_Joists_VJ48_6 = ["American","SJI","Virtual Joists","VJ48-6"]
	American_SJI_Virtual_Joists_VJ48_7 = ["American","SJI","Virtual Joists","VJ48-7"]
	American_SJI_Virtual_Joists_VJ48_8 = ["American","SJI","Virtual Joists","VJ48-8"]
	American_SJI_Virtual_Joists_VJ48_9 = ["American","SJI","Virtual Joists","VJ48-9"]
	American_SJI_Virtual_Joists_VJ48_10 = ["American","SJI","Virtual Joists","VJ48-10"]
	American_SJI_Virtual_Joists_VJ48_11 = ["American","SJI","Virtual Joists","VJ48-11"]
	American_SJI_Virtual_Joists_VJ48_12 = ["American","SJI","Virtual Joists","VJ48-12"]
	American_SJI_Virtual_Joists_VJ48_13 = ["American","SJI","Virtual Joists","VJ48-13"]
	American_SJI_Virtual_Joists_VJ48_14 = ["American","SJI","Virtual Joists","VJ48-14"]
	American_SJI_Virtual_Joists_VJ48_15 = ["American","SJI","Virtual Joists","VJ48-15"]
	American_SJI_Virtual_Joists_VJ48_16 = ["American","SJI","Virtual Joists","VJ48-16"]
	American_SJI_Virtual_Joists_VJ48_17 = ["American","SJI","Virtual Joists","VJ48-17"]
	American_SJI_Virtual_Joists_VJ48_18 = ["American","SJI","Virtual Joists","VJ48-18"]
	American_SJI_Virtual_Joists_VJ48_19 = ["American","SJI","Virtual Joists","VJ48-19"]
	American_SJI_Virtual_Joists_VJ48_20 = ["American","SJI","Virtual Joists","VJ48-20"]
	American_SJI_Virtual_Joists_VJ48_21 = ["American","SJI","Virtual Joists","VJ48-21"]
	American_SJI_Virtual_Joists_VJ48_22 = ["American","SJI","Virtual Joists","VJ48-22"]
	American_SJI_Virtual_Joists_VJ48_23 = ["American","SJI","Virtual Joists","VJ48-23"]
	American_SJI_Virtual_Joists_VJ48_24 = ["American","SJI","Virtual Joists","VJ48-24"]
	American_SJI_Virtual_Joists_VJ48_25 = ["American","SJI","Virtual Joists","VJ48-25"]
	American_SJI_Virtual_Joists_VJ48_26 = ["American","SJI","Virtual Joists","VJ48-26"]
	American_SJI_Virtual_Joists_VJ48_27 = ["American","SJI","Virtual Joists","VJ48-27"]
	American_SJI_Virtual_Joists_VJ48_28 = ["American","SJI","Virtual Joists","VJ48-28"]
	American_SJI_Virtual_Joists_VJ48_29 = ["American","SJI","Virtual Joists","VJ48-29"]
	American_SJI_Virtual_Joists_VJ48_30 = ["American","SJI","Virtual Joists","VJ48-30"]
	American_SJI_Virtual_Joists_VJ48_31 = ["American","SJI","Virtual Joists","VJ48-31"]
	American_SJI_Virtual_Joists_VJ48_32 = ["American","SJI","Virtual Joists","VJ48-32"]
	American_SJI_Virtual_Joists_VJ48_33 = ["American","SJI","Virtual Joists","VJ48-33"]
	American_SJI_Virtual_Joists_VJ48_34 = ["American","SJI","Virtual Joists","VJ48-34"]
	American_SJI_Virtual_Joists_VJ48_35 = ["American","SJI","Virtual Joists","VJ48-35"]
	American_SJI_Virtual_Joists_VJ48_36 = ["American","SJI","Virtual Joists","VJ48-36"]
	American_SJI_Virtual_Joists_VJ48_37 = ["American","SJI","Virtual Joists","VJ48-37"]
	American_SJI_Virtual_Joists_VJ48_38 = ["American","SJI","Virtual Joists","VJ48-38"]
	American_SJI_Virtual_Joists_VJ48_39 = ["American","SJI","Virtual Joists","VJ48-39"]
	American_SJI_Virtual_Joists_VJ48_40 = ["American","SJI","Virtual Joists","VJ48-40"]
	American_SJI_Virtual_Joists_VJ48_41 = ["American","SJI","Virtual Joists","VJ48-41"]
	American_SJI_Virtual_Joists_VJ48_42 = ["American","SJI","Virtual Joists","VJ48-42"]
	American_SJI_Virtual_Joists_VJ52_1 = ["American","SJI","Virtual Joists","VJ52-1"]
	American_SJI_Virtual_Joists_VJ52_2 = ["American","SJI","Virtual Joists","VJ52-2"]
	American_SJI_Virtual_Joists_VJ52_3 = ["American","SJI","Virtual Joists","VJ52-3"]
	American_SJI_Virtual_Joists_VJ52_4 = ["American","SJI","Virtual Joists","VJ52-4"]
	American_SJI_Virtual_Joists_VJ52_5 = ["American","SJI","Virtual Joists","VJ52-5"]
	American_SJI_Virtual_Joists_VJ52_6 = ["American","SJI","Virtual Joists","VJ52-6"]
	American_SJI_Virtual_Joists_VJ52_7 = ["American","SJI","Virtual Joists","VJ52-7"]
	American_SJI_Virtual_Joists_VJ52_8 = ["American","SJI","Virtual Joists","VJ52-8"]
	American_SJI_Virtual_Joists_VJ52_9 = ["American","SJI","Virtual Joists","VJ52-9"]
	American_SJI_Virtual_Joists_VJ52_10 = ["American","SJI","Virtual Joists","VJ52-10"]
	American_SJI_Virtual_Joists_VJ52_11 = ["American","SJI","Virtual Joists","VJ52-11"]
	American_SJI_Virtual_Joists_VJ52_12 = ["American","SJI","Virtual Joists","VJ52-12"]
	American_SJI_Virtual_Joists_VJ52_13 = ["American","SJI","Virtual Joists","VJ52-13"]
	American_SJI_Virtual_Joists_VJ52_14 = ["American","SJI","Virtual Joists","VJ52-14"]
	American_SJI_Virtual_Joists_VJ52_15 = ["American","SJI","Virtual Joists","VJ52-15"]
	American_SJI_Virtual_Joists_VJ52_16 = ["American","SJI","Virtual Joists","VJ52-16"]
	American_SJI_Virtual_Joists_VJ52_17 = ["American","SJI","Virtual Joists","VJ52-17"]
	American_SJI_Virtual_Joists_VJ52_18 = ["American","SJI","Virtual Joists","VJ52-18"]
	American_SJI_Virtual_Joists_VJ52_19 = ["American","SJI","Virtual Joists","VJ52-19"]
	American_SJI_Virtual_Joists_VJ52_20 = ["American","SJI","Virtual Joists","VJ52-20"]
	American_SJI_Virtual_Joists_VJ52_21 = ["American","SJI","Virtual Joists","VJ52-21"]
	American_SJI_Virtual_Joists_VJ52_22 = ["American","SJI","Virtual Joists","VJ52-22"]
	American_SJI_Virtual_Joists_VJ52_23 = ["American","SJI","Virtual Joists","VJ52-23"]
	American_SJI_Virtual_Joists_VJ52_24 = ["American","SJI","Virtual Joists","VJ52-24"]
	American_SJI_Virtual_Joists_VJ52_25 = ["American","SJI","Virtual Joists","VJ52-25"]
	American_SJI_Virtual_Joists_VJ52_26 = ["American","SJI","Virtual Joists","VJ52-26"]
	American_SJI_Virtual_Joists_VJ52_27 = ["American","SJI","Virtual Joists","VJ52-27"]
	American_SJI_Virtual_Joists_VJ52_28 = ["American","SJI","Virtual Joists","VJ52-28"]
	American_SJI_Virtual_Joists_VJ52_29 = ["American","SJI","Virtual Joists","VJ52-29"]
	American_SJI_Virtual_Joists_VJ52_30 = ["American","SJI","Virtual Joists","VJ52-30"]
	American_SJI_Virtual_Joists_VJ52_31 = ["American","SJI","Virtual Joists","VJ52-31"]
	American_SJI_Virtual_Joists_VJ52_32 = ["American","SJI","Virtual Joists","VJ52-32"]
	American_SJI_Virtual_Joists_VJ52_33 = ["American","SJI","Virtual Joists","VJ52-33"]
	American_SJI_Virtual_Joists_VJ52_34 = ["American","SJI","Virtual Joists","VJ52-34"]
	American_SJI_Virtual_Joists_VJ52_35 = ["American","SJI","Virtual Joists","VJ52-35"]
	American_SJI_Virtual_Joists_VJ52_36 = ["American","SJI","Virtual Joists","VJ52-36"]
	American_SJI_Virtual_Joists_VJ52_37 = ["American","SJI","Virtual Joists","VJ52-37"]
	American_SJI_Virtual_Joists_VJ52_38 = ["American","SJI","Virtual Joists","VJ52-38"]
	American_SJI_Virtual_Joists_VJ52_39 = ["American","SJI","Virtual Joists","VJ52-39"]
	American_SJI_Virtual_Joists_VJ52_40 = ["American","SJI","Virtual Joists","VJ52-40"]
	American_SJI_Virtual_Joists_VJ52_41 = ["American","SJI","Virtual Joists","VJ52-41"]
	American_SJI_Virtual_Joists_VJ52_42 = ["American","SJI","Virtual Joists","VJ52-42"]
	American_SJI_Virtual_Joists_VJ52_43 = ["American","SJI","Virtual Joists","VJ52-43"]
	American_SJI_Virtual_Joists_VJ52_44 = ["American","SJI","Virtual Joists","VJ52-44"]
	American_SJI_Virtual_Joists_VJ52_45 = ["American","SJI","Virtual Joists","VJ52-45"]
	American_SJI_Virtual_Joists_VJ56_1 = ["American","SJI","Virtual Joists","VJ56-1"]
	American_SJI_Virtual_Joists_VJ56_2 = ["American","SJI","Virtual Joists","VJ56-2"]
	American_SJI_Virtual_Joists_VJ56_3 = ["American","SJI","Virtual Joists","VJ56-3"]
	American_SJI_Virtual_Joists_VJ56_4 = ["American","SJI","Virtual Joists","VJ56-4"]
	American_SJI_Virtual_Joists_VJ56_5 = ["American","SJI","Virtual Joists","VJ56-5"]
	American_SJI_Virtual_Joists_VJ56_6 = ["American","SJI","Virtual Joists","VJ56-6"]
	American_SJI_Virtual_Joists_VJ56_7 = ["American","SJI","Virtual Joists","VJ56-7"]
	American_SJI_Virtual_Joists_VJ56_8 = ["American","SJI","Virtual Joists","VJ56-8"]
	American_SJI_Virtual_Joists_VJ56_9 = ["American","SJI","Virtual Joists","VJ56-9"]
	American_SJI_Virtual_Joists_VJ56_10 = ["American","SJI","Virtual Joists","VJ56-10"]
	American_SJI_Virtual_Joists_VJ56_11 = ["American","SJI","Virtual Joists","VJ56-11"]
	American_SJI_Virtual_Joists_VJ56_12 = ["American","SJI","Virtual Joists","VJ56-12"]
	American_SJI_Virtual_Joists_VJ56_13 = ["American","SJI","Virtual Joists","VJ56-13"]
	American_SJI_Virtual_Joists_VJ56_14 = ["American","SJI","Virtual Joists","VJ56-14"]
	American_SJI_Virtual_Joists_VJ56_15 = ["American","SJI","Virtual Joists","VJ56-15"]
	American_SJI_Virtual_Joists_VJ56_16 = ["American","SJI","Virtual Joists","VJ56-16"]
	American_SJI_Virtual_Joists_VJ56_17 = ["American","SJI","Virtual Joists","VJ56-17"]
	American_SJI_Virtual_Joists_VJ56_18 = ["American","SJI","Virtual Joists","VJ56-18"]
	American_SJI_Virtual_Joists_VJ56_19 = ["American","SJI","Virtual Joists","VJ56-19"]
	American_SJI_Virtual_Joists_VJ56_20 = ["American","SJI","Virtual Joists","VJ56-20"]
	American_SJI_Virtual_Joists_VJ56_21 = ["American","SJI","Virtual Joists","VJ56-21"]
	American_SJI_Virtual_Joists_VJ56_22 = ["American","SJI","Virtual Joists","VJ56-22"]
	American_SJI_Virtual_Joists_VJ56_23 = ["American","SJI","Virtual Joists","VJ56-23"]
	American_SJI_Virtual_Joists_VJ56_24 = ["American","SJI","Virtual Joists","VJ56-24"]
	American_SJI_Virtual_Joists_VJ56_25 = ["American","SJI","Virtual Joists","VJ56-25"]
	American_SJI_Virtual_Joists_VJ56_26 = ["American","SJI","Virtual Joists","VJ56-26"]
	American_SJI_Virtual_Joists_VJ56_27 = ["American","SJI","Virtual Joists","VJ56-27"]
	American_SJI_Virtual_Joists_VJ56_28 = ["American","SJI","Virtual Joists","VJ56-28"]
	American_SJI_Virtual_Joists_VJ56_29 = ["American","SJI","Virtual Joists","VJ56-29"]
	American_SJI_Virtual_Joists_VJ56_30 = ["American","SJI","Virtual Joists","VJ56-30"]
	American_SJI_Virtual_Joists_VJ56_31 = ["American","SJI","Virtual Joists","VJ56-31"]
	American_SJI_Virtual_Joists_VJ56_32 = ["American","SJI","Virtual Joists","VJ56-32"]
	American_SJI_Virtual_Joists_VJ56_33 = ["American","SJI","Virtual Joists","VJ56-33"]
	American_SJI_Virtual_Joists_VJ56_34 = ["American","SJI","Virtual Joists","VJ56-34"]
	American_SJI_Virtual_Joists_VJ56_35 = ["American","SJI","Virtual Joists","VJ56-35"]
	American_SJI_Virtual_Joists_VJ56_36 = ["American","SJI","Virtual Joists","VJ56-36"]
	American_SJI_Virtual_Joists_VJ56_37 = ["American","SJI","Virtual Joists","VJ56-37"]
	American_SJI_Virtual_Joists_VJ56_38 = ["American","SJI","Virtual Joists","VJ56-38"]
	American_SJI_Virtual_Joists_VJ56_39 = ["American","SJI","Virtual Joists","VJ56-39"]
	American_SJI_Virtual_Joists_VJ56_40 = ["American","SJI","Virtual Joists","VJ56-40"]
	American_SJI_Virtual_Joists_VJ56_41 = ["American","SJI","Virtual Joists","VJ56-41"]
	American_SJI_Virtual_Joists_VJ56_42 = ["American","SJI","Virtual Joists","VJ56-42"]
	American_SJI_Virtual_Joists_VJ56_43 = ["American","SJI","Virtual Joists","VJ56-43"]
	American_SJI_Virtual_Joists_VJ56_44 = ["American","SJI","Virtual Joists","VJ56-44"]
	American_SJI_Virtual_Joists_VJ56_45 = ["American","SJI","Virtual Joists","VJ56-45"]
	American_SJI_Virtual_Joists_VJ60_1 = ["American","SJI","Virtual Joists","VJ60-1"]
	American_SJI_Virtual_Joists_VJ60_2 = ["American","SJI","Virtual Joists","VJ60-2"]
	American_SJI_Virtual_Joists_VJ60_3 = ["American","SJI","Virtual Joists","VJ60-3"]
	American_SJI_Virtual_Joists_VJ60_4 = ["American","SJI","Virtual Joists","VJ60-4"]
	American_SJI_Virtual_Joists_VJ60_5 = ["American","SJI","Virtual Joists","VJ60-5"]
	American_SJI_Virtual_Joists_VJ60_6 = ["American","SJI","Virtual Joists","VJ60-6"]
	American_SJI_Virtual_Joists_VJ60_7 = ["American","SJI","Virtual Joists","VJ60-7"]
	American_SJI_Virtual_Joists_VJ60_8 = ["American","SJI","Virtual Joists","VJ60-8"]
	American_SJI_Virtual_Joists_VJ60_9 = ["American","SJI","Virtual Joists","VJ60-9"]
	American_SJI_Virtual_Joists_VJ60_10 = ["American","SJI","Virtual Joists","VJ60-10"]
	American_SJI_Virtual_Joists_VJ60_11 = ["American","SJI","Virtual Joists","VJ60-11"]
	American_SJI_Virtual_Joists_VJ60_12 = ["American","SJI","Virtual Joists","VJ60-12"]
	American_SJI_Virtual_Joists_VJ60_13 = ["American","SJI","Virtual Joists","VJ60-13"]
	American_SJI_Virtual_Joists_VJ60_14 = ["American","SJI","Virtual Joists","VJ60-14"]
	American_SJI_Virtual_Joists_VJ60_15 = ["American","SJI","Virtual Joists","VJ60-15"]
	American_SJI_Virtual_Joists_VJ60_16 = ["American","SJI","Virtual Joists","VJ60-16"]
	American_SJI_Virtual_Joists_VJ60_17 = ["American","SJI","Virtual Joists","VJ60-17"]
	American_SJI_Virtual_Joists_VJ60_18 = ["American","SJI","Virtual Joists","VJ60-18"]
	American_SJI_Virtual_Joists_VJ60_19 = ["American","SJI","Virtual Joists","VJ60-19"]
	American_SJI_Virtual_Joists_VJ60_20 = ["American","SJI","Virtual Joists","VJ60-20"]
	American_SJI_Virtual_Joists_VJ60_21 = ["American","SJI","Virtual Joists","VJ60-21"]
	American_SJI_Virtual_Joists_VJ60_22 = ["American","SJI","Virtual Joists","VJ60-22"]
	American_SJI_Virtual_Joists_VJ60_23 = ["American","SJI","Virtual Joists","VJ60-23"]
	American_SJI_Virtual_Joists_VJ60_24 = ["American","SJI","Virtual Joists","VJ60-24"]
	American_SJI_Virtual_Joists_VJ60_25 = ["American","SJI","Virtual Joists","VJ60-25"]
	American_SJI_Virtual_Joists_VJ60_26 = ["American","SJI","Virtual Joists","VJ60-26"]
	American_SJI_Virtual_Joists_VJ60_27 = ["American","SJI","Virtual Joists","VJ60-27"]
	American_SJI_Virtual_Joists_VJ60_28 = ["American","SJI","Virtual Joists","VJ60-28"]
	American_SJI_Virtual_Joists_VJ60_29 = ["American","SJI","Virtual Joists","VJ60-29"]
	American_SJI_Virtual_Joists_VJ60_30 = ["American","SJI","Virtual Joists","VJ60-30"]
	American_SJI_Virtual_Joists_VJ60_31 = ["American","SJI","Virtual Joists","VJ60-31"]
	American_SJI_Virtual_Joists_VJ60_32 = ["American","SJI","Virtual Joists","VJ60-32"]
	American_SJI_Virtual_Joists_VJ60_33 = ["American","SJI","Virtual Joists","VJ60-33"]
	American_SJI_Virtual_Joists_VJ60_34 = ["American","SJI","Virtual Joists","VJ60-34"]
	American_SJI_Virtual_Joists_VJ60_35 = ["American","SJI","Virtual Joists","VJ60-35"]
	American_SJI_Virtual_Joists_VJ60_36 = ["American","SJI","Virtual Joists","VJ60-36"]
	American_SJI_Virtual_Joists_VJ60_37 = ["American","SJI","Virtual Joists","VJ60-37"]
	American_SJI_Virtual_Joists_VJ60_38 = ["American","SJI","Virtual Joists","VJ60-38"]
	American_SJI_Virtual_Joists_VJ60_39 = ["American","SJI","Virtual Joists","VJ60-39"]
	American_SJI_Virtual_Joists_VJ64_1 = ["American","SJI","Virtual Joists","VJ64-1"]
	American_SJI_Virtual_Joists_VJ64_2 = ["American","SJI","Virtual Joists","VJ64-2"]
	American_SJI_Virtual_Joists_VJ64_3 = ["American","SJI","Virtual Joists","VJ64-3"]
	American_SJI_Virtual_Joists_VJ64_4 = ["American","SJI","Virtual Joists","VJ64-4"]
	American_SJI_Virtual_Joists_VJ64_5 = ["American","SJI","Virtual Joists","VJ64-5"]
	American_SJI_Virtual_Joists_VJ64_6 = ["American","SJI","Virtual Joists","VJ64-6"]
	American_SJI_Virtual_Joists_VJ64_7 = ["American","SJI","Virtual Joists","VJ64-7"]
	American_SJI_Virtual_Joists_VJ64_8 = ["American","SJI","Virtual Joists","VJ64-8"]
	American_SJI_Virtual_Joists_VJ64_9 = ["American","SJI","Virtual Joists","VJ64-9"]
	American_SJI_Virtual_Joists_VJ64_10 = ["American","SJI","Virtual Joists","VJ64-10"]
	American_SJI_Virtual_Joists_VJ64_11 = ["American","SJI","Virtual Joists","VJ64-11"]
	American_SJI_Virtual_Joists_VJ64_12 = ["American","SJI","Virtual Joists","VJ64-12"]
	American_SJI_Virtual_Joists_VJ64_13 = ["American","SJI","Virtual Joists","VJ64-13"]
	American_SJI_Virtual_Joists_VJ64_14 = ["American","SJI","Virtual Joists","VJ64-14"]
	American_SJI_Virtual_Joists_VJ64_15 = ["American","SJI","Virtual Joists","VJ64-15"]
	American_SJI_Virtual_Joists_VJ64_16 = ["American","SJI","Virtual Joists","VJ64-16"]
	American_SJI_Virtual_Joists_VJ64_17 = ["American","SJI","Virtual Joists","VJ64-17"]
	American_SJI_Virtual_Joists_VJ64_18 = ["American","SJI","Virtual Joists","VJ64-18"]
	American_SJI_Virtual_Joists_VJ64_19 = ["American","SJI","Virtual Joists","VJ64-19"]
	American_SJI_Virtual_Joists_VJ64_20 = ["American","SJI","Virtual Joists","VJ64-20"]
	American_SJI_Virtual_Joists_VJ64_21 = ["American","SJI","Virtual Joists","VJ64-21"]
	American_SJI_Virtual_Joists_VJ64_22 = ["American","SJI","Virtual Joists","VJ64-22"]
	American_SJI_Virtual_Joists_VJ64_23 = ["American","SJI","Virtual Joists","VJ64-23"]
	American_SJI_Virtual_Joists_VJ64_24 = ["American","SJI","Virtual Joists","VJ64-24"]
	American_SJI_Virtual_Joists_VJ64_25 = ["American","SJI","Virtual Joists","VJ64-25"]
	American_SJI_Virtual_Joists_VJ64_26 = ["American","SJI","Virtual Joists","VJ64-26"]
	American_SJI_Virtual_Joists_VJ64_27 = ["American","SJI","Virtual Joists","VJ64-27"]
	American_SJI_Virtual_Joists_VJ64_28 = ["American","SJI","Virtual Joists","VJ64-28"]
	American_SJI_Virtual_Joists_VJ64_29 = ["American","SJI","Virtual Joists","VJ64-29"]
	American_SJI_Virtual_Joists_VJ64_30 = ["American","SJI","Virtual Joists","VJ64-30"]
	American_SJI_Virtual_Joists_VJ64_31 = ["American","SJI","Virtual Joists","VJ64-31"]
	American_SJI_Virtual_Joists_VJ64_32 = ["American","SJI","Virtual Joists","VJ64-32"]
	American_SJI_Virtual_Joists_VJ64_33 = ["American","SJI","Virtual Joists","VJ64-33"]
	American_SJI_Virtual_Joists_VJ64_34 = ["American","SJI","Virtual Joists","VJ64-34"]
	American_SJI_Virtual_Joists_VJ64_35 = ["American","SJI","Virtual Joists","VJ64-35"]
	American_SJI_Virtual_Joists_VJ64_36 = ["American","SJI","Virtual Joists","VJ64-36"]
	American_SJI_Virtual_Joists_VJ64_37 = ["American","SJI","Virtual Joists","VJ64-37"]
	American_SJI_Virtual_Joists_VJ64_38 = ["American","SJI","Virtual Joists","VJ64-38"]
	American_SJI_Virtual_Joists_VJ64_39 = ["American","SJI","Virtual Joists","VJ64-39"]
	American_SJI_Virtual_Joists_VJ64_40 = ["American","SJI","Virtual Joists","VJ64-40"]
	American_SJI_Virtual_Joists_VJ64_41 = ["American","SJI","Virtual Joists","VJ64-41"]
	American_SJI_Virtual_Joists_VJ64_42 = ["American","SJI","Virtual Joists","VJ64-42"]
	American_SJI_Virtual_Joists_VJ64_43 = ["American","SJI","Virtual Joists","VJ64-43"]
	American_SJI_Virtual_Joists_VJ64_44 = ["American","SJI","Virtual Joists","VJ64-44"]
	American_SJI_Virtual_Joists_VJ64_45 = ["American","SJI","Virtual Joists","VJ64-45"]
	American_SJI_Virtual_Joists_VJ68_1 = ["American","SJI","Virtual Joists","VJ68-1"]
	American_SJI_Virtual_Joists_VJ68_2 = ["American","SJI","Virtual Joists","VJ68-2"]
	American_SJI_Virtual_Joists_VJ68_3 = ["American","SJI","Virtual Joists","VJ68-3"]
	American_SJI_Virtual_Joists_VJ68_4 = ["American","SJI","Virtual Joists","VJ68-4"]
	American_SJI_Virtual_Joists_VJ68_5 = ["American","SJI","Virtual Joists","VJ68-5"]
	American_SJI_Virtual_Joists_VJ68_6 = ["American","SJI","Virtual Joists","VJ68-6"]
	American_SJI_Virtual_Joists_VJ68_7 = ["American","SJI","Virtual Joists","VJ68-7"]
	American_SJI_Virtual_Joists_VJ68_8 = ["American","SJI","Virtual Joists","VJ68-8"]
	American_SJI_Virtual_Joists_VJ68_9 = ["American","SJI","Virtual Joists","VJ68-9"]
	American_SJI_Virtual_Joists_VJ68_10 = ["American","SJI","Virtual Joists","VJ68-10"]
	American_SJI_Virtual_Joists_VJ68_11 = ["American","SJI","Virtual Joists","VJ68-11"]
	American_SJI_Virtual_Joists_VJ68_12 = ["American","SJI","Virtual Joists","VJ68-12"]
	American_SJI_Virtual_Joists_VJ68_13 = ["American","SJI","Virtual Joists","VJ68-13"]
	American_SJI_Virtual_Joists_VJ68_14 = ["American","SJI","Virtual Joists","VJ68-14"]
	American_SJI_Virtual_Joists_VJ68_15 = ["American","SJI","Virtual Joists","VJ68-15"]
	American_SJI_Virtual_Joists_VJ68_16 = ["American","SJI","Virtual Joists","VJ68-16"]
	American_SJI_Virtual_Joists_VJ68_17 = ["American","SJI","Virtual Joists","VJ68-17"]
	American_SJI_Virtual_Joists_VJ68_18 = ["American","SJI","Virtual Joists","VJ68-18"]
	American_SJI_Virtual_Joists_VJ68_19 = ["American","SJI","Virtual Joists","VJ68-19"]
	American_SJI_Virtual_Joists_VJ68_20 = ["American","SJI","Virtual Joists","VJ68-20"]
	American_SJI_Virtual_Joists_VJ68_21 = ["American","SJI","Virtual Joists","VJ68-21"]
	American_SJI_Virtual_Joists_VJ68_22 = ["American","SJI","Virtual Joists","VJ68-22"]
	American_SJI_Virtual_Joists_VJ68_23 = ["American","SJI","Virtual Joists","VJ68-23"]
	American_SJI_Virtual_Joists_VJ68_24 = ["American","SJI","Virtual Joists","VJ68-24"]
	American_SJI_Virtual_Joists_VJ68_25 = ["American","SJI","Virtual Joists","VJ68-25"]
	American_SJI_Virtual_Joists_VJ68_26 = ["American","SJI","Virtual Joists","VJ68-26"]
	American_SJI_Virtual_Joists_VJ68_27 = ["American","SJI","Virtual Joists","VJ68-27"]
	American_SJI_Virtual_Joists_VJ68_28 = ["American","SJI","Virtual Joists","VJ68-28"]
	American_SJI_Virtual_Joists_VJ68_29 = ["American","SJI","Virtual Joists","VJ68-29"]
	American_SJI_Virtual_Joists_VJ68_30 = ["American","SJI","Virtual Joists","VJ68-30"]
	American_SJI_Virtual_Joists_VJ68_31 = ["American","SJI","Virtual Joists","VJ68-31"]
	American_SJI_Virtual_Joists_VJ68_32 = ["American","SJI","Virtual Joists","VJ68-32"]
	American_SJI_Virtual_Joists_VJ68_33 = ["American","SJI","Virtual Joists","VJ68-33"]
	American_SJI_Virtual_Joists_VJ68_34 = ["American","SJI","Virtual Joists","VJ68-34"]
	American_SJI_Virtual_Joists_VJ68_35 = ["American","SJI","Virtual Joists","VJ68-35"]
	American_SJI_Virtual_Joists_VJ68_36 = ["American","SJI","Virtual Joists","VJ68-36"]
	American_SJI_Virtual_Joists_VJ68_37 = ["American","SJI","Virtual Joists","VJ68-37"]
	American_SJI_Virtual_Joists_VJ68_38 = ["American","SJI","Virtual Joists","VJ68-38"]
	American_SJI_Virtual_Joists_VJ68_39 = ["American","SJI","Virtual Joists","VJ68-39"]
	American_SJI_Virtual_Joists_VJ68_40 = ["American","SJI","Virtual Joists","VJ68-40"]
	American_SJI_Virtual_Joists_VJ68_41 = ["American","SJI","Virtual Joists","VJ68-41"]
	American_SJI_Virtual_Joists_VJ68_42 = ["American","SJI","Virtual Joists","VJ68-42"]
	American_SJI_Virtual_Joists_VJ68_43 = ["American","SJI","Virtual Joists","VJ68-43"]
	American_SJI_Virtual_Joists_VJ68_44 = ["American","SJI","Virtual Joists","VJ68-44"]
	American_SJI_Virtual_Joists_VJ68_45 = ["American","SJI","Virtual Joists","VJ68-45"]
	American_SJI_Virtual_Joists_VJ72_1 = ["American","SJI","Virtual Joists","VJ72-1"]
	American_SJI_Virtual_Joists_VJ72_2 = ["American","SJI","Virtual Joists","VJ72-2"]
	American_SJI_Virtual_Joists_VJ72_3 = ["American","SJI","Virtual Joists","VJ72-3"]
	American_SJI_Virtual_Joists_VJ72_4 = ["American","SJI","Virtual Joists","VJ72-4"]
	American_SJI_Virtual_Joists_VJ72_5 = ["American","SJI","Virtual Joists","VJ72-5"]
	American_SJI_Virtual_Joists_VJ72_6 = ["American","SJI","Virtual Joists","VJ72-6"]
	American_SJI_Virtual_Joists_VJ72_7 = ["American","SJI","Virtual Joists","VJ72-7"]
	American_SJI_Virtual_Joists_VJ72_8 = ["American","SJI","Virtual Joists","VJ72-8"]
	American_SJI_Virtual_Joists_VJ72_9 = ["American","SJI","Virtual Joists","VJ72-9"]
	American_SJI_Virtual_Joists_VJ72_10 = ["American","SJI","Virtual Joists","VJ72-10"]
	American_SJI_Virtual_Joists_VJ72_11 = ["American","SJI","Virtual Joists","VJ72-11"]
	American_SJI_Virtual_Joists_VJ72_12 = ["American","SJI","Virtual Joists","VJ72-12"]
	American_SJI_Virtual_Joists_VJ72_13 = ["American","SJI","Virtual Joists","VJ72-13"]
	American_SJI_Virtual_Joists_VJ72_14 = ["American","SJI","Virtual Joists","VJ72-14"]
	American_SJI_Virtual_Joists_VJ72_15 = ["American","SJI","Virtual Joists","VJ72-15"]
	American_SJI_Virtual_Joists_VJ72_16 = ["American","SJI","Virtual Joists","VJ72-16"]
	American_SJI_Virtual_Joists_VJ72_17 = ["American","SJI","Virtual Joists","VJ72-17"]
	American_SJI_Virtual_Joists_VJ72_18 = ["American","SJI","Virtual Joists","VJ72-18"]
	American_SJI_Virtual_Joists_VJ72_19 = ["American","SJI","Virtual Joists","VJ72-19"]
	American_SJI_Virtual_Joists_VJ72_20 = ["American","SJI","Virtual Joists","VJ72-20"]
	American_SJI_Virtual_Joists_VJ72_21 = ["American","SJI","Virtual Joists","VJ72-21"]
	American_SJI_Virtual_Joists_VJ72_22 = ["American","SJI","Virtual Joists","VJ72-22"]
	American_SJI_Virtual_Joists_VJ72_23 = ["American","SJI","Virtual Joists","VJ72-23"]
	American_SJI_Virtual_Joists_VJ72_24 = ["American","SJI","Virtual Joists","VJ72-24"]
	American_SJI_Virtual_Joists_VJ72_25 = ["American","SJI","Virtual Joists","VJ72-25"]
	American_SJI_Virtual_Joists_VJ72_26 = ["American","SJI","Virtual Joists","VJ72-26"]
	American_SJI_Virtual_Joists_VJ72_27 = ["American","SJI","Virtual Joists","VJ72-27"]
	American_SJI_Virtual_Joists_VJ72_28 = ["American","SJI","Virtual Joists","VJ72-28"]
	American_SJI_Virtual_Joists_VJ72_29 = ["American","SJI","Virtual Joists","VJ72-29"]
	American_SJI_Virtual_Joists_VJ72_30 = ["American","SJI","Virtual Joists","VJ72-30"]
	American_SJI_Virtual_Joists_VJ72_31 = ["American","SJI","Virtual Joists","VJ72-31"]
	American_SJI_Virtual_Joists_VJ72_32 = ["American","SJI","Virtual Joists","VJ72-32"]
	American_SJI_Virtual_Joists_VJ72_33 = ["American","SJI","Virtual Joists","VJ72-33"]
	American_SJI_Virtual_Joists_VJ72_34 = ["American","SJI","Virtual Joists","VJ72-34"]
	American_SJI_Virtual_Joists_VJ72_35 = ["American","SJI","Virtual Joists","VJ72-35"]
	American_SJI_Virtual_Joists_VJ72_36 = ["American","SJI","Virtual Joists","VJ72-36"]
	American_SJI_Virtual_Joists_VJ72_37 = ["American","SJI","Virtual Joists","VJ72-37"]
	American_SJI_Virtual_Joists_VJ72_38 = ["American","SJI","Virtual Joists","VJ72-38"]
	American_SJI_Virtual_Joists_VJ72_39 = ["American","SJI","Virtual Joists","VJ72-39"]
	American_SJI_Virtual_Joists_VJ72_40 = ["American","SJI","Virtual Joists","VJ72-40"]
	American_SJI_Virtual_Joists_VJ72_41 = ["American","SJI","Virtual Joists","VJ72-41"]
	American_SJI_Virtual_Joists_VJ72_42 = ["American","SJI","Virtual Joists","VJ72-42"]
	American_SJI_Virtual_Joists_VJ80_1 = ["American","SJI","Virtual Joists","VJ80-1"]
	American_SJI_Virtual_Joists_VJ80_2 = ["American","SJI","Virtual Joists","VJ80-2"]
	American_SJI_Virtual_Joists_VJ80_3 = ["American","SJI","Virtual Joists","VJ80-3"]
	American_SJI_Virtual_Joists_VJ80_4 = ["American","SJI","Virtual Joists","VJ80-4"]
	American_SJI_Virtual_Joists_VJ80_5 = ["American","SJI","Virtual Joists","VJ80-5"]
	American_SJI_Virtual_Joists_VJ80_6 = ["American","SJI","Virtual Joists","VJ80-6"]
	American_SJI_Virtual_Joists_VJ80_7 = ["American","SJI","Virtual Joists","VJ80-7"]
	American_SJI_Virtual_Joists_VJ80_8 = ["American","SJI","Virtual Joists","VJ80-8"]
	American_SJI_Virtual_Joists_VJ80_9 = ["American","SJI","Virtual Joists","VJ80-9"]
	American_SJI_Virtual_Joists_VJ80_10 = ["American","SJI","Virtual Joists","VJ80-10"]
	American_SJI_Virtual_Joists_VJ80_11 = ["American","SJI","Virtual Joists","VJ80-11"]
	American_SJI_Virtual_Joists_VJ80_12 = ["American","SJI","Virtual Joists","VJ80-12"]
	American_SJI_Virtual_Joists_VJ80_13 = ["American","SJI","Virtual Joists","VJ80-13"]
	American_SJI_Virtual_Joists_VJ80_14 = ["American","SJI","Virtual Joists","VJ80-14"]
	American_SJI_Virtual_Joists_VJ80_15 = ["American","SJI","Virtual Joists","VJ80-15"]
	American_SJI_Virtual_Joists_VJ80_16 = ["American","SJI","Virtual Joists","VJ80-16"]
	American_SJI_Virtual_Joists_VJ80_17 = ["American","SJI","Virtual Joists","VJ80-17"]
	American_SJI_Virtual_Joists_VJ80_18 = ["American","SJI","Virtual Joists","VJ80-18"]
	American_SJI_Virtual_Joists_VJ80_19 = ["American","SJI","Virtual Joists","VJ80-19"]
	American_SJI_Virtual_Joists_VJ80_20 = ["American","SJI","Virtual Joists","VJ80-20"]
	American_SJI_Virtual_Joists_VJ80_21 = ["American","SJI","Virtual Joists","VJ80-21"]
	American_SJI_Virtual_Joists_VJ80_22 = ["American","SJI","Virtual Joists","VJ80-22"]
	American_SJI_Virtual_Joists_VJ80_23 = ["American","SJI","Virtual Joists","VJ80-23"]
	American_SJI_Virtual_Joists_VJ80_24 = ["American","SJI","Virtual Joists","VJ80-24"]
	American_SJI_Virtual_Joists_VJ80_25 = ["American","SJI","Virtual Joists","VJ80-25"]
	American_SJI_Virtual_Joists_VJ80_26 = ["American","SJI","Virtual Joists","VJ80-26"]
	American_SJI_Virtual_Joists_VJ80_27 = ["American","SJI","Virtual Joists","VJ80-27"]
	American_SJI_Virtual_Joists_VJ80_28 = ["American","SJI","Virtual Joists","VJ80-28"]
	American_SJI_Virtual_Joists_VJ80_29 = ["American","SJI","Virtual Joists","VJ80-29"]
	American_SJI_Virtual_Joists_VJ80_30 = ["American","SJI","Virtual Joists","VJ80-30"]
	American_SJI_Virtual_Joists_VJ80_31 = ["American","SJI","Virtual Joists","VJ80-31"]
	American_SJI_Virtual_Joists_VJ80_32 = ["American","SJI","Virtual Joists","VJ80-32"]
	American_SJI_Virtual_Joists_VJ80_33 = ["American","SJI","Virtual Joists","VJ80-33"]
	American_SJI_Virtual_Joists_VJ88_1 = ["American","SJI","Virtual Joists","VJ88-1"]
	American_SJI_Virtual_Joists_VJ88_2 = ["American","SJI","Virtual Joists","VJ88-2"]
	American_SJI_Virtual_Joists_VJ88_3 = ["American","SJI","Virtual Joists","VJ88-3"]
	American_SJI_Virtual_Joists_VJ88_4 = ["American","SJI","Virtual Joists","VJ88-4"]
	American_SJI_Virtual_Joists_VJ88_5 = ["American","SJI","Virtual Joists","VJ88-5"]
	American_SJI_Virtual_Joists_VJ88_6 = ["American","SJI","Virtual Joists","VJ88-6"]
	American_SJI_Virtual_Joists_VJ88_7 = ["American","SJI","Virtual Joists","VJ88-7"]
	American_SJI_Virtual_Joists_VJ88_8 = ["American","SJI","Virtual Joists","VJ88-8"]
	American_SJI_Virtual_Joists_VJ88_9 = ["American","SJI","Virtual Joists","VJ88-9"]
	American_SJI_Virtual_Joists_VJ88_10 = ["American","SJI","Virtual Joists","VJ88-10"]
	American_SJI_Virtual_Joists_VJ88_11 = ["American","SJI","Virtual Joists","VJ88-11"]
	American_SJI_Virtual_Joists_VJ88_12 = ["American","SJI","Virtual Joists","VJ88-12"]
	American_SJI_Virtual_Joists_VJ88_13 = ["American","SJI","Virtual Joists","VJ88-13"]
	American_SJI_Virtual_Joists_VJ88_14 = ["American","SJI","Virtual Joists","VJ88-14"]
	American_SJI_Virtual_Joists_VJ88_15 = ["American","SJI","Virtual Joists","VJ88-15"]
	American_SJI_Virtual_Joists_VJ88_16 = ["American","SJI","Virtual Joists","VJ88-16"]
	American_SJI_Virtual_Joists_VJ88_17 = ["American","SJI","Virtual Joists","VJ88-17"]
	American_SJI_Virtual_Joists_VJ88_18 = ["American","SJI","Virtual Joists","VJ88-18"]
	American_SJI_Virtual_Joists_VJ88_19 = ["American","SJI","Virtual Joists","VJ88-19"]
	American_SJI_Virtual_Joists_VJ88_20 = ["American","SJI","Virtual Joists","VJ88-20"]
	American_SJI_Virtual_Joists_VJ88_21 = ["American","SJI","Virtual Joists","VJ88-21"]
	American_SJI_Virtual_Joists_VJ88_22 = ["American","SJI","Virtual Joists","VJ88-22"]
	American_SJI_Virtual_Joists_VJ88_23 = ["American","SJI","Virtual Joists","VJ88-23"]
	American_SJI_Virtual_Joists_VJ88_24 = ["American","SJI","Virtual Joists","VJ88-24"]
	American_SJI_Virtual_Joists_VJ88_25 = ["American","SJI","Virtual Joists","VJ88-25"]
	American_SJI_Virtual_Joists_VJ88_26 = ["American","SJI","Virtual Joists","VJ88-26"]
	American_SJI_Virtual_Joists_VJ88_27 = ["American","SJI","Virtual Joists","VJ88-27"]
	American_SJI_Virtual_Joists_VJ88_28 = ["American","SJI","Virtual Joists","VJ88-28"]
	American_SJI_Virtual_Joists_VJ88_29 = ["American","SJI","Virtual Joists","VJ88-29"]
	American_SJI_Virtual_Joists_VJ88_30 = ["American","SJI","Virtual Joists","VJ88-30"]
	American_SJI_Virtual_Joists_VJ96_1 = ["American","SJI","Virtual Joists","VJ96-1"]
	American_SJI_Virtual_Joists_VJ96_2 = ["American","SJI","Virtual Joists","VJ96-2"]
	American_SJI_Virtual_Joists_VJ96_3 = ["American","SJI","Virtual Joists","VJ96-3"]
	American_SJI_Virtual_Joists_VJ96_4 = ["American","SJI","Virtual Joists","VJ96-4"]
	American_SJI_Virtual_Joists_VJ96_5 = ["American","SJI","Virtual Joists","VJ96-5"]
	American_SJI_Virtual_Joists_VJ96_6 = ["American","SJI","Virtual Joists","VJ96-6"]
	American_SJI_Virtual_Joists_VJ96_7 = ["American","SJI","Virtual Joists","VJ96-7"]
	American_SJI_Virtual_Joists_VJ96_8 = ["American","SJI","Virtual Joists","VJ96-8"]
	American_SJI_Virtual_Joists_VJ96_9 = ["American","SJI","Virtual Joists","VJ96-9"]
	American_SJI_Virtual_Joists_VJ96_10 = ["American","SJI","Virtual Joists","VJ96-10"]
	American_SJI_Virtual_Joists_VJ96_11 = ["American","SJI","Virtual Joists","VJ96-11"]
	American_SJI_Virtual_Joists_VJ96_12 = ["American","SJI","Virtual Joists","VJ96-12"]
	American_SJI_Virtual_Joists_VJ96_13 = ["American","SJI","Virtual Joists","VJ96-13"]
	American_SJI_Virtual_Joists_VJ96_14 = ["American","SJI","Virtual Joists","VJ96-14"]
	American_SJI_Virtual_Joists_VJ96_15 = ["American","SJI","Virtual Joists","VJ96-15"]
	American_SJI_Virtual_Joists_VJ96_16 = ["American","SJI","Virtual Joists","VJ96-16"]
	American_SJI_Virtual_Joists_VJ96_17 = ["American","SJI","Virtual Joists","VJ96-17"]
	American_SJI_Virtual_Joists_VJ96_18 = ["American","SJI","Virtual Joists","VJ96-18"]
	American_SJI_Virtual_Joists_VJ96_19 = ["American","SJI","Virtual Joists","VJ96-19"]
	American_SJI_Virtual_Joists_VJ96_20 = ["American","SJI","Virtual Joists","VJ96-20"]
	American_SJI_Virtual_Joists_VJ96_21 = ["American","SJI","Virtual Joists","VJ96-21"]
	American_SJI_Virtual_Joists_VJ96_22 = ["American","SJI","Virtual Joists","VJ96-22"]
	American_SJI_Virtual_Joists_VJ96_23 = ["American","SJI","Virtual Joists","VJ96-23"]
	American_SJI_Virtual_Joists_VJ96_24 = ["American","SJI","Virtual Joists","VJ96-24"]
	American_SJI_Virtual_Joists_VJ96_25 = ["American","SJI","Virtual Joists","VJ96-25"]
	American_SJI_Virtual_Joists_VJ96_26 = ["American","SJI","Virtual Joists","VJ96-26"]
	American_SJI_Virtual_Joists_VJ96_27 = ["American","SJI","Virtual Joists","VJ96-27"]
	American_SJI_Virtual_Joists_VJ104_1 = ["American","SJI","Virtual Joists","VJ104-1"]
	American_SJI_Virtual_Joists_VJ104_2 = ["American","SJI","Virtual Joists","VJ104-2"]
	American_SJI_Virtual_Joists_VJ104_3 = ["American","SJI","Virtual Joists","VJ104-3"]
	American_SJI_Virtual_Joists_VJ104_4 = ["American","SJI","Virtual Joists","VJ104-4"]
	American_SJI_Virtual_Joists_VJ104_5 = ["American","SJI","Virtual Joists","VJ104-5"]
	American_SJI_Virtual_Joists_VJ104_6 = ["American","SJI","Virtual Joists","VJ104-6"]
	American_SJI_Virtual_Joists_VJ104_7 = ["American","SJI","Virtual Joists","VJ104-7"]
	American_SJI_Virtual_Joists_VJ104_8 = ["American","SJI","Virtual Joists","VJ104-8"]
	American_SJI_Virtual_Joists_VJ104_9 = ["American","SJI","Virtual Joists","VJ104-9"]
	American_SJI_Virtual_Joists_VJ104_10 = ["American","SJI","Virtual Joists","VJ104-10"]
	American_SJI_Virtual_Joists_VJ104_11 = ["American","SJI","Virtual Joists","VJ104-11"]
	American_SJI_Virtual_Joists_VJ104_12 = ["American","SJI","Virtual Joists","VJ104-12"]
	American_SJI_Virtual_Joists_VJ104_13 = ["American","SJI","Virtual Joists","VJ104-13"]
	American_SJI_Virtual_Joists_VJ104_14 = ["American","SJI","Virtual Joists","VJ104-14"]
	American_SJI_Virtual_Joists_VJ104_15 = ["American","SJI","Virtual Joists","VJ104-15"]
	American_SJI_Virtual_Joists_VJ104_16 = ["American","SJI","Virtual Joists","VJ104-16"]
	American_SJI_Virtual_Joists_VJ104_17 = ["American","SJI","Virtual Joists","VJ104-17"]
	American_SJI_Virtual_Joists_VJ104_18 = ["American","SJI","Virtual Joists","VJ104-18"]
	American_SJI_Virtual_Joists_VJ104_19 = ["American","SJI","Virtual Joists","VJ104-19"]
	American_SJI_Virtual_Joists_VJ104_20 = ["American","SJI","Virtual Joists","VJ104-20"]
	American_SJI_Virtual_Joists_VJ104_21 = ["American","SJI","Virtual Joists","VJ104-21"]
	American_SJI_Virtual_Joists_VJ104_22 = ["American","SJI","Virtual Joists","VJ104-22"]
	American_SJI_Virtual_Joists_VJ104_23 = ["American","SJI","Virtual Joists","VJ104-23"]
	American_SJI_Virtual_Joists_VJ104_24 = ["American","SJI","Virtual Joists","VJ104-24"]
	American_SJI_Virtual_Joists_VJ112_1 = ["American","SJI","Virtual Joists","VJ112-1"]
	American_SJI_Virtual_Joists_VJ112_2 = ["American","SJI","Virtual Joists","VJ112-2"]
	American_SJI_Virtual_Joists_VJ112_3 = ["American","SJI","Virtual Joists","VJ112-3"]
	American_SJI_Virtual_Joists_VJ112_4 = ["American","SJI","Virtual Joists","VJ112-4"]
	American_SJI_Virtual_Joists_VJ112_5 = ["American","SJI","Virtual Joists","VJ112-5"]
	American_SJI_Virtual_Joists_VJ112_6 = ["American","SJI","Virtual Joists","VJ112-6"]
	American_SJI_Virtual_Joists_VJ112_7 = ["American","SJI","Virtual Joists","VJ112-7"]
	American_SJI_Virtual_Joists_VJ112_8 = ["American","SJI","Virtual Joists","VJ112-8"]
	American_SJI_Virtual_Joists_VJ112_9 = ["American","SJI","Virtual Joists","VJ112-9"]
	American_SJI_Virtual_Joists_VJ112_10 = ["American","SJI","Virtual Joists","VJ112-10"]
	American_SJI_Virtual_Joists_VJ112_11 = ["American","SJI","Virtual Joists","VJ112-11"]
	American_SJI_Virtual_Joists_VJ112_12 = ["American","SJI","Virtual Joists","VJ112-12"]
	American_SJI_Virtual_Joists_VJ112_13 = ["American","SJI","Virtual Joists","VJ112-13"]
	American_SJI_Virtual_Joists_VJ112_14 = ["American","SJI","Virtual Joists","VJ112-14"]
	American_SJI_Virtual_Joists_VJ112_15 = ["American","SJI","Virtual Joists","VJ112-15"]
	American_SJI_Virtual_Joists_VJ112_16 = ["American","SJI","Virtual Joists","VJ112-16"]
	American_SJI_Virtual_Joists_VJ112_17 = ["American","SJI","Virtual Joists","VJ112-17"]
	American_SJI_Virtual_Joists_VJ112_18 = ["American","SJI","Virtual Joists","VJ112-18"]
	American_SJI_Virtual_Joists_VJ112_19 = ["American","SJI","Virtual Joists","VJ112-19"]
	American_SJI_Virtual_Joists_VJ112_20 = ["American","SJI","Virtual Joists","VJ112-20"]
	American_SJI_Virtual_Joists_VJ112_21 = ["American","SJI","Virtual Joists","VJ112-21"]
	American_SJI_Virtual_Joists_VJ120_1 = ["American","SJI","Virtual Joists","VJ120-1"]
	American_SJI_Virtual_Joists_VJ120_2 = ["American","SJI","Virtual Joists","VJ120-2"]
	American_SJI_Virtual_Joists_VJ120_3 = ["American","SJI","Virtual Joists","VJ120-3"]
	American_SJI_Virtual_Joists_VJ120_4 = ["American","SJI","Virtual Joists","VJ120-4"]
	American_SJI_Virtual_Joists_VJ120_5 = ["American","SJI","Virtual Joists","VJ120-5"]
	American_SJI_Virtual_Joists_VJ120_6 = ["American","SJI","Virtual Joists","VJ120-6"]
	American_SJI_Virtual_Joists_VJ120_7 = ["American","SJI","Virtual Joists","VJ120-7"]
	American_SJI_Virtual_Joists_VJ120_8 = ["American","SJI","Virtual Joists","VJ120-8"]
	American_SJI_Virtual_Joists_VJ120_9 = ["American","SJI","Virtual Joists","VJ120-9"]
	American_SJI_Virtual_Joists_VJ120_10 = ["American","SJI","Virtual Joists","VJ120-10"]
	American_SJI_Virtual_Joists_VJ120_11 = ["American","SJI","Virtual Joists","VJ120-11"]
	American_SJI_Virtual_Joists_VJ120_12 = ["American","SJI","Virtual Joists","VJ120-12"]
	American_SJI_Virtual_Joists_VJ120_13 = ["American","SJI","Virtual Joists","VJ120-13"]
	American_SJI_Virtual_Joists_VJ120_14 = ["American","SJI","Virtual Joists","VJ120-14"]
	American_SJI_Virtual_Joists_VJ120_15 = ["American","SJI","Virtual Joists","VJ120-15"]
	American_SJI_Virtual_Joists_VJ120_16 = ["American","SJI","Virtual Joists","VJ120-16"]
	American_SJI_Virtual_Joists_VJ120_17 = ["American","SJI","Virtual Joists","VJ120-17"]
	American_SJI_Virtual_Joists_VJ120_18 = ["American","SJI","Virtual Joists","VJ120-18"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_13_5x2_3_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","13.5x2.3 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_13_5x2_9_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","13.5x2.9 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_17x2_3_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","17x2.3 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_17x2_9_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","17x2.9 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_21x2_6_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","21x2.6 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_21x3_2_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","21x3.2 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_21x3_6_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","21x3.6 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_27x2_6_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","27x2.6 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_27x3_2_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","27x3.2 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_27x4_0_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","27x4.0 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_34x3_2_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","34x3.2 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_34x4_0_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","34x4.0 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_34x4_5_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","34x4.5 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_42x3_2_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","42x3.2 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_42x4_0_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","42x4.0 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_42x4_9_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","42x4.9 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_48x3_2_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","48x3.2 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_48x4_0_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","48x4.0 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_48x5_4_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","48x5.4 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_60x3_6_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","60x3.6 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_60x4_5_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","60x4.5 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_60x5_4_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","60x5.4 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_76x3_6_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","76x3.6 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_76x4_5_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","76x4.5 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_76x5_9_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","76x5.9 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_89x4_0_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","89x4.0 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_89x5_0_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","89x5.0 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_89x5_9_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","89x5.9 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_102x4_0_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","102x4.0 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_102x5_0_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","102x5.0 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_114x4_5_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","114x4.5 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_114x5_4_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","114x5.4 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_140x5_0_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","140x5.0 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_140x5_4_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","140x5.4 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_165x5_0_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","165x5.0 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_165x5_4_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","165x5.4 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_508x6_4_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","508x6.4 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_508x9_5_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","508x9.5 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_508x12_7_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","508x12.7 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_610x6_4_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","610x6.4 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_610x9_5_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","610x9.5 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_250_610x12_7_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (250)","610x12.7 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_21x2_0_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","21x2.0 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_27x2_0_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","27x2.0 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_27x2_3_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","27x2.3 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_34x2_0_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","34x2.0 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_34x2_6_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","34x2.6 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_42x2_0_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","42x2.0 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_42x2_6_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","42x2.6 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_48x2_3_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","48x2.3 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_48x2_9_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","48x2.9 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_60x2_3_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","60x2.3 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_60x2_9_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","60x2.9 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_76x2_3_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","76x2.3 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_76x3_2_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","76x3.2 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_89x2_6_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","89x2.6 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_89x3_2_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","89x3.2 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_89x4_8_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","89x4.8 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_89x5_5_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","89x5.5 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_102x2_6_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","102x2.6 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_102x3_2_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","102x3.2 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_114x3_2_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","114x3.2 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_114x3_6_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","114x3.6 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_114x4_8_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","114x4.8 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_114x6_0_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","114x6.0 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_140x3_0_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","140x3.0 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_140x3_5_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","140x3.5 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_165x3_0_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","165x3.0 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_165x3_5_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","165x3.5 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_168x4_8_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","168x4.8 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_168x6_4_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","168x6.4 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_168x7_1_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","168x7.1 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_219x4_8_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","219x4.8 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_219x6_4_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","219x6.4 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_219x8_2_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","219x8.2 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_273x4_8_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","273x4.8 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_273x6_4_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","273x6.4 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_273x9_3_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","273x9.3 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_324x6_4_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","324x6.4 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_324x9_5_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","324x9.5 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_324x12_7_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","324x12.7 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_356x6_4_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","356x6.4 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_356x9_5_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","356x9.5 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_356x12_7_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","356x12.7 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_406x6_4_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","406x6.4 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_406x9_5_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","406x9.5 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_406x12_7_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","406x12.7 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_457x6_4_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","457x6.4 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_457x9_5_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","457x9.5 CHS"]
	Australian_Steel_250_Grade_Circular_hollow_sections_350_457x12_7_CHS = ["Australian","Steel (250 Grade)","Circular hollow sections (350)","457x12.7 CHS"]
	Australian_Steel_250_Grade_Column_cores_310_CC_394 = ["Australian","Steel (250 Grade)","Column cores","310 CC 394"]
	Australian_Steel_250_Grade_Column_cores_310_CC_472 = ["Australian","Steel (250 Grade)","Column cores","310 CC 472"]
	Australian_Steel_250_Grade_Equal_angles_25x3_EA = ["Australian","Steel (250 Grade)","Equal angles","25x3 EA"]
	Australian_Steel_250_Grade_Equal_angles_25x5_EA = ["Australian","Steel (250 Grade)","Equal angles","25x5 EA"]
	Australian_Steel_250_Grade_Equal_angles_25x6_EA = ["Australian","Steel (250 Grade)","Equal angles","25x6 EA"]
	Australian_Steel_250_Grade_Equal_angles_30x3_EA = ["Australian","Steel (250 Grade)","Equal angles","30x3 EA"]
	Australian_Steel_250_Grade_Equal_angles_30x5_EA = ["Australian","Steel (250 Grade)","Equal angles","30x5 EA"]
	Australian_Steel_250_Grade_Equal_angles_30x6_EA = ["Australian","Steel (250 Grade)","Equal angles","30x6 EA"]
	Australian_Steel_250_Grade_Equal_angles_40x3_EA = ["Australian","Steel (250 Grade)","Equal angles","40x3 EA"]
	Australian_Steel_250_Grade_Equal_angles_40x5_EA = ["Australian","Steel (250 Grade)","Equal angles","40x5 EA"]
	Australian_Steel_250_Grade_Equal_angles_40x6_EA = ["Australian","Steel (250 Grade)","Equal angles","40x6 EA"]
	Australian_Steel_250_Grade_Equal_angles_45x3_EA = ["Australian","Steel (250 Grade)","Equal angles","45x3 EA"]
	Australian_Steel_250_Grade_Equal_angles_45x5_EA = ["Australian","Steel (250 Grade)","Equal angles","45x5 EA"]
	Australian_Steel_250_Grade_Equal_angles_45x6_EA = ["Australian","Steel (250 Grade)","Equal angles","45x6 EA"]
	Australian_Steel_250_Grade_Equal_angles_50x3_EA = ["Australian","Steel (250 Grade)","Equal angles","50x3 EA"]
	Australian_Steel_250_Grade_Equal_angles_50x5_EA = ["Australian","Steel (250 Grade)","Equal angles","50x5 EA"]
	Australian_Steel_250_Grade_Equal_angles_50x6_EA = ["Australian","Steel (250 Grade)","Equal angles","50x6 EA"]
	Australian_Steel_250_Grade_Equal_angles_50x8_EA = ["Australian","Steel (250 Grade)","Equal angles","50x8 EA"]
	Australian_Steel_250_Grade_Equal_angles_55x5_EA = ["Australian","Steel (250 Grade)","Equal angles","55x5 EA"]
	Australian_Steel_250_Grade_Equal_angles_55x6_EA = ["Australian","Steel (250 Grade)","Equal angles","55x6 EA"]
	Australian_Steel_250_Grade_Equal_angles_65x5_EA = ["Australian","Steel (250 Grade)","Equal angles","65x5 EA"]
	Australian_Steel_250_Grade_Equal_angles_65x6_EA = ["Australian","Steel (250 Grade)","Equal angles","65x6 EA"]
	Australian_Steel_250_Grade_Equal_angles_65x8_EA = ["Australian","Steel (250 Grade)","Equal angles","65x8 EA"]
	Australian_Steel_250_Grade_Equal_angles_65x10_EA = ["Australian","Steel (250 Grade)","Equal angles","65x10 EA"]
	Australian_Steel_250_Grade_Equal_angles_75x5_EA = ["Australian","Steel (250 Grade)","Equal angles","75x5 EA"]
	Australian_Steel_250_Grade_Equal_angles_75x6_EA = ["Australian","Steel (250 Grade)","Equal angles","75x6 EA"]
	Australian_Steel_250_Grade_Equal_angles_75x8_EA = ["Australian","Steel (250 Grade)","Equal angles","75x8 EA"]
	Australian_Steel_250_Grade_Equal_angles_75x10_EA = ["Australian","Steel (250 Grade)","Equal angles","75x10 EA"]
	Australian_Steel_250_Grade_Equal_angles_90x6_EA = ["Australian","Steel (250 Grade)","Equal angles","90x6 EA"]
	Australian_Steel_250_Grade_Equal_angles_90x8_EA = ["Australian","Steel (250 Grade)","Equal angles","90x8 EA"]
	Australian_Steel_250_Grade_Equal_angles_90x10_EA = ["Australian","Steel (250 Grade)","Equal angles","90x10 EA"]
	Australian_Steel_250_Grade_Equal_angles_100x6_EA = ["Australian","Steel (250 Grade)","Equal angles","100x6 EA"]
	Australian_Steel_250_Grade_Equal_angles_100x8_EA = ["Australian","Steel (250 Grade)","Equal angles","100x8 EA"]
	Australian_Steel_250_Grade_Equal_angles_100x10_EA = ["Australian","Steel (250 Grade)","Equal angles","100x10 EA"]
	Australian_Steel_250_Grade_Equal_angles_100x12_EA = ["Australian","Steel (250 Grade)","Equal angles","100x12 EA"]
	Australian_Steel_250_Grade_Equal_angles_125x8_EA = ["Australian","Steel (250 Grade)","Equal angles","125x8 EA"]
	Australian_Steel_250_Grade_Equal_angles_125x10_EA = ["Australian","Steel (250 Grade)","Equal angles","125x10 EA"]
	Australian_Steel_250_Grade_Equal_angles_125x12_EA = ["Australian","Steel (250 Grade)","Equal angles","125x12 EA"]
	Australian_Steel_250_Grade_Equal_angles_125x16_EA = ["Australian","Steel (250 Grade)","Equal angles","125x16 EA"]
	Australian_Steel_250_Grade_Equal_angles_150x10_EA = ["Australian","Steel (250 Grade)","Equal angles","150x10 EA"]
	Australian_Steel_250_Grade_Equal_angles_150x12_EA = ["Australian","Steel (250 Grade)","Equal angles","150x12 EA"]
	Australian_Steel_250_Grade_Equal_angles_150x16_EA = ["Australian","Steel (250 Grade)","Equal angles","150x16 EA"]
	Australian_Steel_250_Grade_Equal_angles_150x19_EA = ["Australian","Steel (250 Grade)","Equal angles","150x19 EA"]
	Australian_Steel_250_Grade_Equal_angles_200x13_EA = ["Australian","Steel (250 Grade)","Equal angles","200x13 EA"]
	Australian_Steel_250_Grade_Equal_angles_200x16_EA = ["Australian","Steel (250 Grade)","Equal angles","200x16 EA"]
	Australian_Steel_250_Grade_Equal_angles_200x18_EA = ["Australian","Steel (250 Grade)","Equal angles","200x18 EA"]
	Australian_Steel_250_Grade_Equal_angles_200x20_EA = ["Australian","Steel (250 Grade)","Equal angles","200x20 EA"]
	Australian_Steel_250_Grade_Equal_angles_200x26_EA = ["Australian","Steel (250 Grade)","Equal angles","200x26 EA"]
	Australian_Steel_250_Grade_Parallel_flange_channels_150x75_CH = ["Australian","Steel (250 Grade)","Parallel flange channels","150x75 CH"]
	Australian_Steel_250_Grade_Parallel_flange_channels_180x75_CH = ["Australian","Steel (250 Grade)","Parallel flange channels","180x75 CH"]
	Australian_Steel_250_Grade_Parallel_flange_channels_200x75_CH = ["Australian","Steel (250 Grade)","Parallel flange channels","200x75 CH"]
	Australian_Steel_250_Grade_Parallel_flange_channels_230x75_CH = ["Australian","Steel (250 Grade)","Parallel flange channels","230x75 CH"]
	Australian_Steel_250_Grade_Parallel_flange_channels_250x90_CH = ["Australian","Steel (250 Grade)","Parallel flange channels","250x90 CH"]
	Australian_Steel_250_Grade_Parallel_flange_channels_300x90_CH = ["Australian","Steel (250 Grade)","Parallel flange channels","300x90 CH"]
	Australian_Steel_250_Grade_Parallel_flange_channels_380x100_CH = ["Australian","Steel (250 Grade)","Parallel flange channels","380x100 CH"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_50x20x1_6_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","50x20x1.6 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_50x20x2_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","50x20x2.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_50x20x2_5_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","50x20x2.5 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_50x20x3_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","50x20x3.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_50x25x1_6_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","50x25x1.6 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_50x25x2_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","50x25x2.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_50x25x2_5_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","50x25x2.5 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_50x25x3_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","50x25x3.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_65x35x2_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","65x35x2.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_65x35x2_5_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","65x35x2.5 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_65x35x3_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","65x35x3.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_75x25x1_6_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","75x25x1.6 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_75x25x2_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","75x25x2.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_75x25x2_5_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","75x25x2.5 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_75x50x2_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","75x50x2.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_75x50x2_5_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","75x50x2.5 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_75x50x3_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","75x50x3.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_75x50x4_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","75x50x4.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_100x50x2_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","100x50x2.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_100x50x2_5_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","100x50x2.5 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_100x50x3_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","100x50x3.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_100x50x3_5_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","100x50x3.5 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_100x50x4_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","100x50x4.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_100x50x5_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","100x50x5.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_100x50x6_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","100x50x6.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_125x75x3_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","125x75x3.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_125x75x4_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","125x75x4.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_125x75x5_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","125x75x5.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_150x50x3_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","150x50x3.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_150x50x4_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","150x50x4.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_150x50x5_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","150x50x5.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_150x100x4_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","150x100x4.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_150x100x5_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","150x100x5.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_150x100x6_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","150x100x6.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_200x100x4_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","200x100x4.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_200x100x5_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","200x100x5.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_200x100x6_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","200x100x6.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_200x100x9_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","200x100x9.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_250x150x5_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","250x150x5.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_250x150x6_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","250x150x6.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_350_250x150x9_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (350)","250x150x9.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_50x20x1_6_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","50x20x1.6 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_50x20x2_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","50x20x2.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_50x20x2_3_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","50x20x2.3 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_50x20x2_5_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","50x20x2.5 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_50x20x2_8_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","50x20x2.8 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_50x20x3_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","50x20x3.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_50x25x1_6_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","50x25x1.6 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_50x25x2_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","50x25x2.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_50x25x2_3_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","50x25x2.3 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_50x25x2_5_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","50x25x2.5 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_50x25x2_8_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","50x25x2.8 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_50x25x3_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","50x25x3.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_65x35x2_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","65x35x2.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_65x35x2_3_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","65x35x2.3 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_65x35x2_5_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","65x35x2.5 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_65x35x2_8_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","65x35x2.8 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_65x35x3_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","65x35x3.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_75x25x1_6_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","75x25x1.6 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_75x25x2_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","75x25x2.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_75x25x2_5_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","75x25x2.5 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_75x50x1_6_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","75x50x1.6 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_75x50x2_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","75x50x2.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_75x50x2_3_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","75x50x2.3 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_75x50x2_5_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","75x50x2.5 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_75x50x2_8_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","75x50x2.8 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_75x50x3_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","75x50x3.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_75x50x4_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","75x50x4.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_75x50x5_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","75x50x5.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_75x50x6_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","75x50x6.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_100x50x2_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","100x50x2.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_100x50x2_3_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","100x50x2.3 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_100x50x2_5_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","100x50x2.5 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_100x50x2_8_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","100x50x2.8 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_100x50x3_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","100x50x3.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_100x50x3_3_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","100x50x3.3 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_100x50x3_5_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","100x50x3.5 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_100x50x4_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","100x50x4.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_100x50x5_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","100x50x5.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_100x50x6_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","100x50x6.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_125x75x2_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","125x75x2.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_125x75x2_5_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","125x75x2.5 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_125x75x2_8_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","125x75x2.8 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_125x75x3_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","125x75x3.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_125x75x3_3_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","125x75x3.3 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_125x75x3_8_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","125x75x3.8 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_125x75x4_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","125x75x4.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_125x75x5_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","125x75x5.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_125x75x6_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","125x75x6.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_150x50x2_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","150x50x2.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_150x50x2_5_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","150x50x2.5 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_150x50x3_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","150x50x3.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_150x50x4_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","150x50x4.0 RHS"]
	Australian_Steel_250_Grade_Rect_hollow_sections_450_150x50x5_0_RHS = ["Australian","Steel (250 Grade)","Rect hollow sections (450)","150x50x5.0 RHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_20x1_6_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","20x1.6 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_25x1_6_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","25x1.6 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_25x2_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","25x2.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_25x2_5_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","25x2.5 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_25x3_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","25x3.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_30x1_6_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","30x1.6 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_30x2_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","30x2.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_35x1_6_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","35x1.6 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_35x2_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","35x2.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_35x2_5_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","35x2.5 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_35x3_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","35x3.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_40x1_6_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","40x1.6 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_40x2_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","40x2.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_40x2_5_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","40x2.5 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_40x4_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","40x4.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_50x1_6_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","50x1.6 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_50x2_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","50x2.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_50x2_5_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","50x2.5 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_50x3_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","50x3.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_50x4_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","50x4.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_65x2_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","65x2.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_65x2_5_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","65x2.5 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_65x3_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","65x3.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_75x2_5_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","75x2.5 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_75x3_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","75x3.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_75x3_5_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","75x3.5 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_75x4_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","75x4.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_75x5_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","75x5.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_75x6_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","75x6.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_89x3_5_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","89x3.5 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_89x5_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","89x5.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_89x6_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","89x6.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_100x3_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","100x3.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_100x4_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","100x4.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_100x5_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","100x5.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_100x6_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","100x6.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_100x9_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","100x9.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_125x4_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","125x4.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_125x5_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","125x5.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_125x6_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","125x6.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_125x9_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","125x9.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_150x5_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","150x5.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_150x6_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","150x6.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_150x9_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","150x9.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_200x5_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","200x5.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_200x6_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","200x6.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_200x9_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","200x9.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_250x6_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","250x6.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_350_250x9_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (350)","250x9.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_20x1_6_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","20x1.6 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_25x1_6_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","25x1.6 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_25x2_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","25x2.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_25x2_3_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","25x2.3 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_25x2_5_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","25x2.5 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_25x3_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","25x3.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_30x1_6_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","30x1.6 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_30x2_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","30x2.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_30x2_5_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","30x2.5 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_35x1_6_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","35x1.6 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_35x2_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","35x2.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_35x2_3_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","35x2.3 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_35x2_5_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","35x2.5 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_35x2_8_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","35x2.8 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_35x3_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","35x3.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_40x1_6_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","40x1.6 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_40x2_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","40x2.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_40x2_5_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","40x2.5 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_40x3_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","40x3.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_40x4_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","40x4.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_50x1_6_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","50x1.6 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_50x2_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","50x2.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_50x2_3_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","50x2.3 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_50x2_5_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","50x2.5 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_50x2_8_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","50x2.8 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_50x3_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","50x3.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_50x4_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","50x4.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_50x5_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","50x5.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_65x1_6_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","65x1.6 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_65x2_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","65x2.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_65x2_3_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","65x2.3 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_65x2_5_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","65x2.5 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_65x3_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","65x3.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_65x4_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","65x4.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_65x5_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","65x5.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_65x6_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","65x6.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_75x2_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","75x2.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_75x2_3_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","75x2.3 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_75x2_5_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","75x2.5 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_75x2_8_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","75x2.8 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_75x3_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","75x3.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_75x3_3_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","75x3.3 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_75x3_5_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","75x3.5 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_75x4_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","75x4.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_75x5_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","75x5.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_75x6_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","75x6.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_100x2_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","100x2.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_100x2_5_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","100x2.5 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_100x2_8_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","100x2.8 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_100x3_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","100x3.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_100x3_3_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","100x3.3 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_100x3_8_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","100x3.8 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_100x4_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","100x4.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_100x5_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","100x5.0 SHS"]
	Australian_Steel_250_Grade_Square_hollow_sections_450_100x6_0_SHS = ["Australian","Steel (250 Grade)","Square hollow sections (450)","100x6.0 SHS"]
	Australian_Steel_250_Grade_Taper_flange_beams_100x45_TFB = ["Australian","Steel (250 Grade)","Taper flange beams","100x45 TFB"]
	Australian_Steel_250_Grade_Taper_flange_beams_125x65_TFB = ["Australian","Steel (250 Grade)","Taper flange beams","125x65 TFB"]
	Australian_Steel_250_Grade_Taper_flange_channels_75x40_CH = ["Australian","Steel (250 Grade)","Taper flange channels","75x40 CH"]
	Australian_Steel_250_Grade_Taper_flange_channels_100x50_CH = ["Australian","Steel (250 Grade)","Taper flange channels","100x50 CH"]
	Australian_Steel_250_Grade_Taper_flange_channels_125x65_CH = ["Australian","Steel (250 Grade)","Taper flange channels","125x65 CH"]
	Australian_Steel_250_Grade_Unequal_angles_65x50x5_UA = ["Australian","Steel (250 Grade)","Unequal angles","65x50x5 UA"]
	Australian_Steel_250_Grade_Unequal_angles_65x50x6_UA = ["Australian","Steel (250 Grade)","Unequal angles","65x50x6 UA"]
	Australian_Steel_250_Grade_Unequal_angles_65x50x8_UA = ["Australian","Steel (250 Grade)","Unequal angles","65x50x8 UA"]
	Australian_Steel_250_Grade_Unequal_angles_75x50x5_UA = ["Australian","Steel (250 Grade)","Unequal angles","75x50x5 UA"]
	Australian_Steel_250_Grade_Unequal_angles_75x50x6_UA = ["Australian","Steel (250 Grade)","Unequal angles","75x50x6 UA"]
	Australian_Steel_250_Grade_Unequal_angles_75x50x8_UA = ["Australian","Steel (250 Grade)","Unequal angles","75x50x8 UA"]
	Australian_Steel_250_Grade_Unequal_angles_100x75x6_UA = ["Australian","Steel (250 Grade)","Unequal angles","100x75x6 UA"]
	Australian_Steel_250_Grade_Unequal_angles_100x75x8_UA = ["Australian","Steel (250 Grade)","Unequal angles","100x75x8 UA"]
	Australian_Steel_250_Grade_Unequal_angles_100x75x10_UA = ["Australian","Steel (250 Grade)","Unequal angles","100x75x10 UA"]
	Australian_Steel_250_Grade_Unequal_angles_125x75x6_UA = ["Australian","Steel (250 Grade)","Unequal angles","125x75x6 UA"]
	Australian_Steel_250_Grade_Unequal_angles_125x75x8_UA = ["Australian","Steel (250 Grade)","Unequal angles","125x75x8 UA"]
	Australian_Steel_250_Grade_Unequal_angles_125x75x10_UA = ["Australian","Steel (250 Grade)","Unequal angles","125x75x10 UA"]
	Australian_Steel_250_Grade_Unequal_angles_125x75x12_UA = ["Australian","Steel (250 Grade)","Unequal angles","125x75x12 UA"]
	Australian_Steel_250_Grade_Unequal_angles_150x90x8_UA = ["Australian","Steel (250 Grade)","Unequal angles","150x90x8 UA"]
	Australian_Steel_250_Grade_Unequal_angles_150x90x10_UA = ["Australian","Steel (250 Grade)","Unequal angles","150x90x10 UA"]
	Australian_Steel_250_Grade_Unequal_angles_150x90x12_UA = ["Australian","Steel (250 Grade)","Unequal angles","150x90x12 UA"]
	Australian_Steel_250_Grade_Unequal_angles_150x90x16_UA = ["Australian","Steel (250 Grade)","Unequal angles","150x90x16 UA"]
	Australian_Steel_250_Grade_Unequal_angles_150x100x10_UA = ["Australian","Steel (250 Grade)","Unequal angles","150x100x10 UA"]
	Australian_Steel_250_Grade_Unequal_angles_150x100x12_UA = ["Australian","Steel (250 Grade)","Unequal angles","150x100x12 UA"]
	Australian_Steel_250_Grade_Universal_beam_tees_75_BT_7 = ["Australian","Steel (250 Grade)","Universal beam tees","75 BT 7"]
	Australian_Steel_250_Grade_Universal_beam_tees_75_BT_9 = ["Australian","Steel (250 Grade)","Universal beam tees","75 BT 9"]
	Australian_Steel_250_Grade_Universal_beam_tees_90_BT_9 = ["Australian","Steel (250 Grade)","Universal beam tees","90 BT 9"]
	Australian_Steel_250_Grade_Universal_beam_tees_90_BT_11 = ["Australian","Steel (250 Grade)","Universal beam tees","90 BT 11"]
	Australian_Steel_250_Grade_Universal_beam_tees_125_BT_15 = ["Australian","Steel (250 Grade)","Universal beam tees","125 BT 15"]
	Australian_Steel_250_Grade_Universal_beam_tees_125_BT_18 = ["Australian","Steel (250 Grade)","Universal beam tees","125 BT 18"]
	Australian_Steel_250_Grade_Universal_beam_tees_155_BT_20 = ["Australian","Steel (250 Grade)","Universal beam tees","155 BT 20"]
	Australian_Steel_250_Grade_Universal_beam_tees_155_BT_23 = ["Australian","Steel (250 Grade)","Universal beam tees","155 BT 23"]
	Australian_Steel_250_Grade_Universal_beam_tees_180_BT_22 = ["Australian","Steel (250 Grade)","Universal beam tees","180 BT 22"]
	Australian_Steel_250_Grade_Universal_beam_tees_180_BT_25 = ["Australian","Steel (250 Grade)","Universal beam tees","180 BT 25"]
	Australian_Steel_250_Grade_Universal_beam_tees_180_BT_28 = ["Australian","Steel (250 Grade)","Universal beam tees","180 BT 28"]
	Australian_Steel_250_Grade_Universal_beam_tees_205_BT_27 = ["Australian","Steel (250 Grade)","Universal beam tees","205 BT 27"]
	Australian_Steel_250_Grade_Universal_beam_tees_205_BT_30 = ["Australian","Steel (250 Grade)","Universal beam tees","205 BT 30"]
	Australian_Steel_250_Grade_Universal_beam_tees_230_BT_33 = ["Australian","Steel (250 Grade)","Universal beam tees","230 BT 33"]
	Australian_Steel_250_Grade_Universal_beam_tees_230_BT_37 = ["Australian","Steel (250 Grade)","Universal beam tees","230 BT 37"]
	Australian_Steel_250_Grade_Universal_beam_tees_230_BT_41 = ["Australian","Steel (250 Grade)","Universal beam tees","230 BT 41"]
	Australian_Steel_250_Grade_Universal_beam_tees_265_BT_41 = ["Australian","Steel (250 Grade)","Universal beam tees","265 BT 41"]
	Australian_Steel_250_Grade_Universal_beam_tees_265_BT_46 = ["Australian","Steel (250 Grade)","Universal beam tees","265 BT 46"]
	Australian_Steel_250_Grade_Universal_beam_tees_305_BT_50 = ["Australian","Steel (250 Grade)","Universal beam tees","305 BT 50"]
	Australian_Steel_250_Grade_Universal_beam_tees_305_BT_56 = ["Australian","Steel (250 Grade)","Universal beam tees","305 BT 56"]
	Australian_Steel_250_Grade_Universal_beam_tees_305_BT_62 = ["Australian","Steel (250 Grade)","Universal beam tees","305 BT 62"]
	Australian_Steel_250_Grade_Universal_beam_tees_345_BT_62 = ["Australian","Steel (250 Grade)","Universal beam tees","345 BT 62"]
	Australian_Steel_250_Grade_Universal_beam_tees_345_BT_70 = ["Australian","Steel (250 Grade)","Universal beam tees","345 BT 70"]
	Australian_Steel_250_Grade_Universal_beam_tees_380_BT_73 = ["Australian","Steel (250 Grade)","Universal beam tees","380 BT 73"]
	Australian_Steel_250_Grade_Universal_beam_tees_380_BT_86 = ["Australian","Steel (250 Grade)","Universal beam tees","380 BT 86"]
	Australian_Steel_250_Grade_Universal_beam_tees_380_BT_98 = ["Australian","Steel (250 Grade)","Universal beam tees","380 BT 98"]
	Australian_Steel_250_Grade_Universal_beam_tees_380_BT_110 = ["Australian","Steel (250 Grade)","Universal beam tees","380 BT 110"]
	Australian_Steel_250_Grade_Universal_beam_tees_380_BT_122 = ["Australian","Steel (250 Grade)","Universal beam tees","380 BT 122"]
	Australian_Steel_250_Grade_Universal_beams_150_UB_14 = ["Australian","Steel (250 Grade)","Universal beams","150 UB 14"]
	Australian_Steel_250_Grade_Universal_beams_150_UB_18 = ["Australian","Steel (250 Grade)","Universal beams","150 UB 18"]
	Australian_Steel_250_Grade_Universal_beams_180_UB_18 = ["Australian","Steel (250 Grade)","Universal beams","180 UB 18"]
	Australian_Steel_250_Grade_Universal_beams_180_UB_22 = ["Australian","Steel (250 Grade)","Universal beams","180 UB 22"]
	Australian_Steel_250_Grade_Universal_beams_200_UB_22 = ["Australian","Steel (250 Grade)","Universal beams","200 UB 22"]
	Australian_Steel_250_Grade_Universal_beams_200_UB_25 = ["Australian","Steel (250 Grade)","Universal beams","200 UB 25"]
	Australian_Steel_250_Grade_Universal_beams_200_UB_30 = ["Australian","Steel (250 Grade)","Universal beams","200 UB 30"]
	Australian_Steel_250_Grade_Universal_beams_250_UB_31 = ["Australian","Steel (250 Grade)","Universal beams","250 UB 31"]
	Australian_Steel_250_Grade_Universal_beams_250_UB_37 = ["Australian","Steel (250 Grade)","Universal beams","250 UB 37"]
	Australian_Steel_250_Grade_Universal_beams_310_UB_40 = ["Australian","Steel (250 Grade)","Universal beams","310 UB 40"]
	Australian_Steel_250_Grade_Universal_beams_310_UB_46 = ["Australian","Steel (250 Grade)","Universal beams","310 UB 46"]
	Australian_Steel_250_Grade_Universal_beams_360_UB_45 = ["Australian","Steel (250 Grade)","Universal beams","360 UB 45"]
	Australian_Steel_250_Grade_Universal_beams_360_UB_51 = ["Australian","Steel (250 Grade)","Universal beams","360 UB 51"]
	Australian_Steel_250_Grade_Universal_beams_360_UB_57 = ["Australian","Steel (250 Grade)","Universal beams","360 UB 57"]
	Australian_Steel_250_Grade_Universal_beams_410_UB_54 = ["Australian","Steel (250 Grade)","Universal beams","410 UB 54"]
	Australian_Steel_250_Grade_Universal_beams_410_UB_60 = ["Australian","Steel (250 Grade)","Universal beams","410 UB 60"]
	Australian_Steel_250_Grade_Universal_beams_460_UB_67 = ["Australian","Steel (250 Grade)","Universal beams","460 UB 67"]
	Australian_Steel_250_Grade_Universal_beams_460_UB_74 = ["Australian","Steel (250 Grade)","Universal beams","460 UB 74"]
	Australian_Steel_250_Grade_Universal_beams_460_UB_82 = ["Australian","Steel (250 Grade)","Universal beams","460 UB 82"]
	Australian_Steel_250_Grade_Universal_beams_530_UB_82 = ["Australian","Steel (250 Grade)","Universal beams","530 UB 82"]
	Australian_Steel_250_Grade_Universal_beams_530_UB_92 = ["Australian","Steel (250 Grade)","Universal beams","530 UB 92"]
	Australian_Steel_250_Grade_Universal_beams_610_UB_101 = ["Australian","Steel (250 Grade)","Universal beams","610 UB 101"]
	Australian_Steel_250_Grade_Universal_beams_610_UB_113 = ["Australian","Steel (250 Grade)","Universal beams","610 UB 113"]
	Australian_Steel_250_Grade_Universal_beams_610_UB_125 = ["Australian","Steel (250 Grade)","Universal beams","610 UB 125"]
	Australian_Steel_250_Grade_Universal_beams_690_UB_125 = ["Australian","Steel (250 Grade)","Universal beams","690 UB 125"]
	Australian_Steel_250_Grade_Universal_beams_690_UB_140 = ["Australian","Steel (250 Grade)","Universal beams","690 UB 140"]
	Australian_Steel_250_Grade_Universal_beams_760_UB_148 = ["Australian","Steel (250 Grade)","Universal beams","760 UB 148"]
	Australian_Steel_250_Grade_Universal_beams_760_UB_173 = ["Australian","Steel (250 Grade)","Universal beams","760 UB 173"]
	Australian_Steel_250_Grade_Universal_beams_760_UB_197 = ["Australian","Steel (250 Grade)","Universal beams","760 UB 197"]
	Australian_Steel_250_Grade_Universal_beams_760_UB_220 = ["Australian","Steel (250 Grade)","Universal beams","760 UB 220"]
	Australian_Steel_250_Grade_Universal_beams_760_UB_244 = ["Australian","Steel (250 Grade)","Universal beams","760 UB 244"]
	Australian_Steel_250_Grade_Universal_Bearing_piles_200_UBP_122 = ["Australian","Steel (250 Grade)","Universal Bearing piles","200 UBP 122"]
	Australian_Steel_250_Grade_Universal_Bearing_piles_200_UBP_146 = ["Australian","Steel (250 Grade)","Universal Bearing piles","200 UBP 146"]
	Australian_Steel_250_Grade_Universal_Bearing_piles_250_UBP_63 = ["Australian","Steel (250 Grade)","Universal Bearing piles","250 UBP 63"]
	Australian_Steel_250_Grade_Universal_Bearing_piles_250_UBP_85 = ["Australian","Steel (250 Grade)","Universal Bearing piles","250 UBP 85"]
	Australian_Steel_250_Grade_Universal_Bearing_piles_310_UBP_79 = ["Australian","Steel (250 Grade)","Universal Bearing piles","310 UBP 79"]
	Australian_Steel_250_Grade_Universal_column_tees_75_CT_12 = ["Australian","Steel (250 Grade)","Universal column tees","75 CT 12"]
	Australian_Steel_250_Grade_Universal_column_tees_75_CT_15 = ["Australian","Steel (250 Grade)","Universal column tees","75 CT 15"]
	Australian_Steel_250_Grade_Universal_column_tees_75_CT_18 = ["Australian","Steel (250 Grade)","Universal column tees","75 CT 18"]
	Australian_Steel_250_Grade_Universal_column_tees_100_BT_12 = ["Australian","Steel (250 Grade)","Universal column tees","100 BT 12"]
	Australian_Steel_250_Grade_Universal_column_tees_100_BT_15 = ["Australian","Steel (250 Grade)","Universal column tees","100 BT 15"]
	Australian_Steel_250_Grade_Universal_column_tees_100_CT_23 = ["Australian","Steel (250 Grade)","Universal column tees","100 CT 23"]
	Australian_Steel_250_Grade_Universal_column_tees_100_CT_26 = ["Australian","Steel (250 Grade)","Universal column tees","100 CT 26"]
	Australian_Steel_250_Grade_Universal_column_tees_100_CT_30 = ["Australian","Steel (250 Grade)","Universal column tees","100 CT 30"]
	Australian_Steel_250_Grade_Universal_column_tees_125_CT_36 = ["Australian","Steel (250 Grade)","Universal column tees","125 CT 36"]
	Australian_Steel_250_Grade_Universal_column_tees_125_CT_44 = ["Australian","Steel (250 Grade)","Universal column tees","125 CT 44"]
	Australian_Steel_250_Grade_Universal_column_tees_155_CT_48 = ["Australian","Steel (250 Grade)","Universal column tees","155 CT 48"]
	Australian_Steel_250_Grade_Universal_column_tees_155_CT_59 = ["Australian","Steel (250 Grade)","Universal column tees","155 CT 59"]
	Australian_Steel_250_Grade_Universal_column_tees_155_CT_68 = ["Australian","Steel (250 Grade)","Universal column tees","155 CT 68"]
	Australian_Steel_250_Grade_Universal_column_tees_155_CT_79 = ["Australian","Steel (250 Grade)","Universal column tees","155 CT 79"]
	Australian_Steel_250_Grade_Universal_column_tees_155_CT_99 = ["Australian","Steel (250 Grade)","Universal column tees","155 CT 99"]
	Australian_Steel_250_Grade_Universal_column_tees_155_CT_120 = ["Australian","Steel (250 Grade)","Universal column tees","155 CT 120"]
	Australian_Steel_250_Grade_Universal_column_tees_155_CT_142 = ["Australian","Steel (250 Grade)","Universal column tees","155 CT 142"]
	Australian_Steel_250_Grade_Universal_columns_100_UC_15 = ["Australian","Steel (250 Grade)","Universal columns","100 UC 15"]
	Australian_Steel_250_Grade_Universal_columns_150_UC_23 = ["Australian","Steel (250 Grade)","Universal columns","150 UC 23"]
	Australian_Steel_250_Grade_Universal_columns_150_UC_30 = ["Australian","Steel (250 Grade)","Universal columns","150 UC 30"]
	Australian_Steel_250_Grade_Universal_columns_150_UC_37 = ["Australian","Steel (250 Grade)","Universal columns","150 UC 37"]
	Australian_Steel_250_Grade_Universal_columns_150_UC_38 = ["Australian","Steel (250 Grade)","Universal columns","150 UC 38"]
	Australian_Steel_250_Grade_Universal_columns_200_UC_46 = ["Australian","Steel (250 Grade)","Universal columns","200 UC 46"]
	Australian_Steel_250_Grade_Universal_columns_200_UC_52 = ["Australian","Steel (250 Grade)","Universal columns","200 UC 52"]
	Australian_Steel_250_Grade_Universal_columns_200_UC_60 = ["Australian","Steel (250 Grade)","Universal columns","200 UC 60"]
	Australian_Steel_250_Grade_Universal_columns_250_UC_73 = ["Australian","Steel (250 Grade)","Universal columns","250 UC 73"]
	Australian_Steel_250_Grade_Universal_columns_250_UC_89 = ["Australian","Steel (250 Grade)","Universal columns","250 UC 89"]
	Australian_Steel_250_Grade_Universal_columns_310_UC_97 = ["Australian","Steel (250 Grade)","Universal columns","310 UC 97"]
	Australian_Steel_250_Grade_Universal_columns_310_UC_118 = ["Australian","Steel (250 Grade)","Universal columns","310 UC 118"]
	Australian_Steel_250_Grade_Universal_columns_310_UC_137 = ["Australian","Steel (250 Grade)","Universal columns","310 UC 137"]
	Australian_Steel_250_Grade_Universal_columns_310_UC_158 = ["Australian","Steel (250 Grade)","Universal columns","310 UC 158"]
	Australian_Steel_250_Grade_Universal_columns_310_UC_198 = ["Australian","Steel (250 Grade)","Universal columns","310 UC 198"]
	Australian_Steel_250_Grade_Universal_columns_310_UC_240 = ["Australian","Steel (250 Grade)","Universal columns","310 UC 240"]
	Australian_Steel_250_Grade_Universal_columns_310_UC_283 = ["Australian","Steel (250 Grade)","Universal columns","310 UC 283"]
	Australian_Steel_250_Grade_Welded_beams_700_WB_115 = ["Australian","Steel (250 Grade)","Welded beams","700 WB 115"]
	Australian_Steel_250_Grade_Welded_beams_700_WB_130 = ["Australian","Steel (250 Grade)","Welded beams","700 WB 130"]
	Australian_Steel_250_Grade_Welded_beams_700_WB_150 = ["Australian","Steel (250 Grade)","Welded beams","700 WB 150"]
	Australian_Steel_250_Grade_Welded_beams_700_WB_173 = ["Australian","Steel (250 Grade)","Welded beams","700 WB 173"]
	Australian_Steel_250_Grade_Welded_beams_800_WB_122 = ["Australian","Steel (250 Grade)","Welded beams","800 WB 122"]
	Australian_Steel_250_Grade_Welded_beams_800_WB_146 = ["Australian","Steel (250 Grade)","Welded beams","800 WB 146"]
	Australian_Steel_250_Grade_Welded_beams_800_WB_168 = ["Australian","Steel (250 Grade)","Welded beams","800 WB 168"]
	Australian_Steel_250_Grade_Welded_beams_800_WB_192 = ["Australian","Steel (250 Grade)","Welded beams","800 WB 192"]
	Australian_Steel_250_Grade_Welded_beams_900_WB_175 = ["Australian","Steel (250 Grade)","Welded beams","900 WB 175"]
	Australian_Steel_250_Grade_Welded_beams_900_WB_218 = ["Australian","Steel (250 Grade)","Welded beams","900 WB 218"]
	Australian_Steel_250_Grade_Welded_beams_900_WB_257 = ["Australian","Steel (250 Grade)","Welded beams","900 WB 257"]
	Australian_Steel_250_Grade_Welded_beams_900_WB_282 = ["Australian","Steel (250 Grade)","Welded beams","900 WB 282"]
	Australian_Steel_250_Grade_Welded_beams_1000_WB_215 = ["Australian","Steel (250 Grade)","Welded beams","1000 WB 215"]
	Australian_Steel_250_Grade_Welded_beams_1000_WB_258 = ["Australian","Steel (250 Grade)","Welded beams","1000 WB 258"]
	Australian_Steel_250_Grade_Welded_beams_1000_WB_296 = ["Australian","Steel (250 Grade)","Welded beams","1000 WB 296"]
	Australian_Steel_250_Grade_Welded_beams_1000_WB_322 = ["Australian","Steel (250 Grade)","Welded beams","1000 WB 322"]
	Australian_Steel_250_Grade_Welded_beams_1200_WB_249 = ["Australian","Steel (250 Grade)","Welded beams","1200 WB 249"]
	Australian_Steel_250_Grade_Welded_beams_1200_WB_278 = ["Australian","Steel (250 Grade)","Welded beams","1200 WB 278"]
	Australian_Steel_250_Grade_Welded_beams_1200_WB_317 = ["Australian","Steel (250 Grade)","Welded beams","1200 WB 317"]
	Australian_Steel_250_Grade_Welded_beams_1200_WB_342 = ["Australian","Steel (250 Grade)","Welded beams","1200 WB 342"]
	Australian_Steel_250_Grade_Welded_beams_1200_WB_392 = ["Australian","Steel (250 Grade)","Welded beams","1200 WB 392"]
	Australian_Steel_250_Grade_Welded_beams_1200_WB_423 = ["Australian","Steel (250 Grade)","Welded beams","1200 WB 423"]
	Australian_Steel_250_Grade_Welded_beams_1200_WB_455 = ["Australian","Steel (250 Grade)","Welded beams","1200 WB 455"]
	Australian_Steel_250_Grade_Welded_columns_350_WC_197 = ["Australian","Steel (250 Grade)","Welded columns","350 WC 197"]
	Australian_Steel_250_Grade_Welded_columns_350_WC_230 = ["Australian","Steel (250 Grade)","Welded columns","350 WC 230"]
	Australian_Steel_250_Grade_Welded_columns_350_WC_258 = ["Australian","Steel (250 Grade)","Welded columns","350 WC 258"]
	Australian_Steel_250_Grade_Welded_columns_350_WC_280 = ["Australian","Steel (250 Grade)","Welded columns","350 WC 280"]
	Australian_Steel_250_Grade_Welded_columns_400_WC_144 = ["Australian","Steel (250 Grade)","Welded columns","400 WC 144"]
	Australian_Steel_250_Grade_Welded_columns_400_WC_181 = ["Australian","Steel (250 Grade)","Welded columns","400 WC 181"]
	Australian_Steel_250_Grade_Welded_columns_400_WC_212 = ["Australian","Steel (250 Grade)","Welded columns","400 WC 212"]
	Australian_Steel_250_Grade_Welded_columns_400_WC_270 = ["Australian","Steel (250 Grade)","Welded columns","400 WC 270"]
	Australian_Steel_250_Grade_Welded_columns_400_WC_303 = ["Australian","Steel (250 Grade)","Welded columns","400 WC 303"]
	Australian_Steel_250_Grade_Welded_columns_400_WC_328 = ["Australian","Steel (250 Grade)","Welded columns","400 WC 328"]
	Australian_Steel_250_Grade_Welded_columns_400_WC_361 = ["Australian","Steel (250 Grade)","Welded columns","400 WC 361"]
	Australian_Steel_250_Grade_Welded_columns_500_WC_228 = ["Australian","Steel (250 Grade)","Welded columns","500 WC 228"]
	Australian_Steel_250_Grade_Welded_columns_500_WC_267 = ["Australian","Steel (250 Grade)","Welded columns","500 WC 267"]
	Australian_Steel_250_Grade_Welded_columns_500_WC_290 = ["Australian","Steel (250 Grade)","Welded columns","500 WC 290"]
	Australian_Steel_250_Grade_Welded_columns_500_WC_340 = ["Australian","Steel (250 Grade)","Welded columns","500 WC 340"]
	Australian_Steel_250_Grade_Welded_columns_500_WC_383 = ["Australian","Steel (250 Grade)","Welded columns","500 WC 383"]
	Australian_Steel_250_Grade_Welded_columns_500_WC_414 = ["Australian","Steel (250 Grade)","Welded columns","500 WC 414"]
	Australian_Steel_250_Grade_Welded_columns_500_WC_440 = ["Australian","Steel (250 Grade)","Welded columns","500 WC 440"]
	Australian_Steel_300_Grade_CHS_Grade_250_21_3x2_6_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","21.3x2.6 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_21_3x3_2_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","21.3x3.2 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_21_3x3_6_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","21.3x3.6 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_26_7x1_65_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","26.7x1.65 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_26_9x2_6_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","26.9x2.6 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_26_9x3_2_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","26.9x3.2 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_26_9x4_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","26.9x4 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_33_4x1_65_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","33.4x1.65 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_33_7x3_2_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","33.7x3.2 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_33_7x4_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","33.7x4 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_33_7x4_5_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","33.7x4.5 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_42_2x1_65_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","42.2x1.65 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_42_4x3_2_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","42.4x3.2 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_42_4x4_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","42.4x4 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_42_4x4_9_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","42.4x4.9 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_48_3x1_65_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","48.3x1.65 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_48_3x3_2_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","48.3x3.2 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_48_3x4_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","48.3x4 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_48_3x5_4_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","48.3x5.4 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_60_3x1_65_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","60.3x1.65 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_60_3x3_6_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","60.3x3.6 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_60_3x4_5_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","60.3x4.5 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_60_3x5_4_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","60.3x5.4 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_76_1x3_6_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","76.1x3.6 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_76_1x4_5_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","76.1x4.5 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_76_1x5_9_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","76.1x5.9 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_88_9x4_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","88.9x4 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_88_9x5_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","88.9x5 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_88_9x5_9_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","88.9x5.9 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_101_6x4_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","101.6x4 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_101_6x5_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","101.6x5 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_114_3x3_2_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","114.3x3.2 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_114_3x4_5_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","114.3x4.5 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_114_3x5_4_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","114.3x5.4 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_139_7x5_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","139.7x5 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_139_7x5_4_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","139.7x5.4 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_165_1x5_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","165.1x5 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_165_1x5_4_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","165.1x5.4 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_508x6_4_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","508x6.4 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_508x9_5_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","508x9.5 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_508x12_7_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","508x12.7 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_610x6_4_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","610x6.4 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_610x9_5_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","610x9.5 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_250_610x12_7_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 250)","610x12.7 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_13_5x2_3_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","13.5x2.3 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_13_5x2_9_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","13.5x2.9 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_17_2x2_3_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","17.2x2.3 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_17_2x2_9_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","17.2x2.9 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_21_3x2_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","21.3x2 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_21_3x2_6_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","21.3x2.6 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_21_3x3_2_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","21.3x3.2 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_26_9x2_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","26.9x2 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_26_9x2_3_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","26.9x2.3 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_33_7x2_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","33.7x2 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_33_7x2_6_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","33.7x2.6 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_42_4x2_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","42.4x2 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_42_4x2_6_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","42.4x2.6 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_48_3x2_3_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","48.3x2.3 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_48_3x2_9_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","48.3x2.9 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_48_3x3_2_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","48.3x3.2 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_60_3x2_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","60.3x2 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_60_3x2_3_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","60.3x2.3 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_60_3x2_9_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","60.3x2.9 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_60_3x3_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","60.3x3 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_76_1x2_3_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","76.1x2.3 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_76_1x2_11_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","76.1x2.11 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_76_1x3_2_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","76.1x3.2 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_88_9x2_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","88.9x2 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_88_9x2_6_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","88.9x2.6 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_88_9x2_11_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","88.9x2.11 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_88_9x3_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","88.9x3 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_88_9x3_2_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","88.9x3.2 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_88_9x4_8_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","88.9x4.8 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_88_9x5_5_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","88.9x5.5 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_101_6x2_6_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","101.6x2.6 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_101_6x3_2_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","101.6x3.2 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_114_3x2_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","114.3x2 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_114_3x2_5_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","114.3x2.5 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_114_3x2_11_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","114.3x2.11 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_114_3x3_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","114.3x3 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_114_3x3_2_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","114.3x3.2 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_114_3x3_6_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","114.3x3.6 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_114_3x4_8_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","114.3x4.8 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_114_3x6_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","114.3x6 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_127x3_2_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","127x3.2 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_127x3_6_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","127x3.6 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_127x4_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","127x4 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_127x4_8_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","127x4.8 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_127x6_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","127x6 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_139_7x2_5_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","139.7x2.5 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_139_7x2_8_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","139.7x2.8 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_139_7x3_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","139.7x3 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_139_7x3_5_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","139.7x3.5 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_152_4x4_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","152.4x4 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_152_4x4_8_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","152.4x4.8 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_152_4x6_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","152.4x6 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_165_1x2_5_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","165.1x2.5 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_165_1x2_77_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","165.1x2.77 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_165_1x3_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","165.1x3 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_165_1x3_5_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","165.1x3.5 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_168_3x3_2_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","168.3x3.2 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_168_3x4_8_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","168.3x4.8 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_168_3x6_4_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","168.3x6.4 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_168_3x7_1_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","168.3x7.1 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_219_1x3_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","219.1x3 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_219_1x4_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","219.1x4 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_219_1x4_8_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","219.1x4.8 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_219_1x6_4_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","219.1x6.4 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_219_1x8_2_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","219.1x8.2 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_273_1x3_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","273.1x3 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_273_1x4_8_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","273.1x4.8 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_273_1x6_4_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","273.1x6.4 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_273_1x9_3_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","273.1x9.3 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_273_1x12_7_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","273.1x12.7 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_323_9x3_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","323.9x3 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_323_9x4_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","323.9x4 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_323_9x4_8_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","323.9x4.8 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_323_9x6_4_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","323.9x6.4 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_323_9x9_5_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","323.9x9.5 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_323_9x12_7_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","323.9x12.7 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_355_6x4_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","355.6x4 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_355_6x6_4_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","355.6x6.4 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_355_6x9_5_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","355.6x9.5 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_355_6x12_7_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","355.6x12.7 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_406_4x6_4_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","406.4x6.4 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_406_4x9_5_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","406.4x9.5 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_406_4x12_7_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","406.4x12.7 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_457x6_4_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","457x6.4 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_457x9_5_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","457x9.5 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_457x12_7_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","457x12.7 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_508x6_4_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","508x6.4 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_508x9_5_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","508x9.5 CHS"]
	Australian_Steel_300_Grade_CHS_Grade_350_508x12_7_CHS = ["Australian","Steel (300 Grade)","CHS (Grade 350)","508x12.7 CHS"]
	Australian_Steel_300_Grade_Equal_angles_25x3_EA = ["Australian","Steel (300 Grade)","Equal angles","25x3 EA"]
	Australian_Steel_300_Grade_Equal_angles_25x5_EA = ["Australian","Steel (300 Grade)","Equal angles","25x5 EA"]
	Australian_Steel_300_Grade_Equal_angles_25x6_EA = ["Australian","Steel (300 Grade)","Equal angles","25x6 EA"]
	Australian_Steel_300_Grade_Equal_angles_30x3_EA = ["Australian","Steel (300 Grade)","Equal angles","30x3 EA"]
	Australian_Steel_300_Grade_Equal_angles_30x5_EA = ["Australian","Steel (300 Grade)","Equal angles","30x5 EA"]
	Australian_Steel_300_Grade_Equal_angles_30x6_EA = ["Australian","Steel (300 Grade)","Equal angles","30x6 EA"]
	Australian_Steel_300_Grade_Equal_angles_40x3_EA = ["Australian","Steel (300 Grade)","Equal angles","40x3 EA"]
	Australian_Steel_300_Grade_Equal_angles_40x5_EA = ["Australian","Steel (300 Grade)","Equal angles","40x5 EA"]
	Australian_Steel_300_Grade_Equal_angles_40x6_EA = ["Australian","Steel (300 Grade)","Equal angles","40x6 EA"]
	Australian_Steel_300_Grade_Equal_angles_45x3_EA = ["Australian","Steel (300 Grade)","Equal angles","45x3 EA"]
	Australian_Steel_300_Grade_Equal_angles_45x5_EA = ["Australian","Steel (300 Grade)","Equal angles","45x5 EA"]
	Australian_Steel_300_Grade_Equal_angles_45x6_EA = ["Australian","Steel (300 Grade)","Equal angles","45x6 EA"]
	Australian_Steel_300_Grade_Equal_angles_50x3_EA = ["Australian","Steel (300 Grade)","Equal angles","50x3 EA"]
	Australian_Steel_300_Grade_Equal_angles_50x5_EA = ["Australian","Steel (300 Grade)","Equal angles","50x5 EA"]
	Australian_Steel_300_Grade_Equal_angles_50x6_EA = ["Australian","Steel (300 Grade)","Equal angles","50x6 EA"]
	Australian_Steel_300_Grade_Equal_angles_50x8_EA = ["Australian","Steel (300 Grade)","Equal angles","50x8 EA"]
	Australian_Steel_300_Grade_Equal_angles_55x5_EA = ["Australian","Steel (300 Grade)","Equal angles","55x5 EA"]
	Australian_Steel_300_Grade_Equal_angles_55x6_EA = ["Australian","Steel (300 Grade)","Equal angles","55x6 EA"]
	Australian_Steel_300_Grade_Equal_angles_65x5_EA = ["Australian","Steel (300 Grade)","Equal angles","65x5 EA"]
	Australian_Steel_300_Grade_Equal_angles_65x6_EA = ["Australian","Steel (300 Grade)","Equal angles","65x6 EA"]
	Australian_Steel_300_Grade_Equal_angles_65x8_EA = ["Australian","Steel (300 Grade)","Equal angles","65x8 EA"]
	Australian_Steel_300_Grade_Equal_angles_65x10_EA = ["Australian","Steel (300 Grade)","Equal angles","65x10 EA"]
	Australian_Steel_300_Grade_Equal_angles_75x5_EA = ["Australian","Steel (300 Grade)","Equal angles","75x5 EA"]
	Australian_Steel_300_Grade_Equal_angles_75x6_EA = ["Australian","Steel (300 Grade)","Equal angles","75x6 EA"]
	Australian_Steel_300_Grade_Equal_angles_75x8_EA = ["Australian","Steel (300 Grade)","Equal angles","75x8 EA"]
	Australian_Steel_300_Grade_Equal_angles_75x10_EA = ["Australian","Steel (300 Grade)","Equal angles","75x10 EA"]
	Australian_Steel_300_Grade_Equal_angles_90x6_EA = ["Australian","Steel (300 Grade)","Equal angles","90x6 EA"]
	Australian_Steel_300_Grade_Equal_angles_90x8_EA = ["Australian","Steel (300 Grade)","Equal angles","90x8 EA"]
	Australian_Steel_300_Grade_Equal_angles_90x10_EA = ["Australian","Steel (300 Grade)","Equal angles","90x10 EA"]
	Australian_Steel_300_Grade_Equal_angles_100x6_EA = ["Australian","Steel (300 Grade)","Equal angles","100x6 EA"]
	Australian_Steel_300_Grade_Equal_angles_100x8_EA = ["Australian","Steel (300 Grade)","Equal angles","100x8 EA"]
	Australian_Steel_300_Grade_Equal_angles_100x10_EA = ["Australian","Steel (300 Grade)","Equal angles","100x10 EA"]
	Australian_Steel_300_Grade_Equal_angles_100x12_EA = ["Australian","Steel (300 Grade)","Equal angles","100x12 EA"]
	Australian_Steel_300_Grade_Equal_angles_125x8_EA = ["Australian","Steel (300 Grade)","Equal angles","125x8 EA"]
	Australian_Steel_300_Grade_Equal_angles_125x10_EA = ["Australian","Steel (300 Grade)","Equal angles","125x10 EA"]
	Australian_Steel_300_Grade_Equal_angles_125x12_EA = ["Australian","Steel (300 Grade)","Equal angles","125x12 EA"]
	Australian_Steel_300_Grade_Equal_angles_125x16_EA = ["Australian","Steel (300 Grade)","Equal angles","125x16 EA"]
	Australian_Steel_300_Grade_Equal_angles_150x10_EA = ["Australian","Steel (300 Grade)","Equal angles","150x10 EA"]
	Australian_Steel_300_Grade_Equal_angles_150x12_EA = ["Australian","Steel (300 Grade)","Equal angles","150x12 EA"]
	Australian_Steel_300_Grade_Equal_angles_150x16_EA = ["Australian","Steel (300 Grade)","Equal angles","150x16 EA"]
	Australian_Steel_300_Grade_Equal_angles_150x19_EA = ["Australian","Steel (300 Grade)","Equal angles","150x19 EA"]
	Australian_Steel_300_Grade_Equal_angles_200x13_EA = ["Australian","Steel (300 Grade)","Equal angles","200x13 EA"]
	Australian_Steel_300_Grade_Equal_angles_200x16_EA = ["Australian","Steel (300 Grade)","Equal angles","200x16 EA"]
	Australian_Steel_300_Grade_Equal_angles_200x18_EA = ["Australian","Steel (300 Grade)","Equal angles","200x18 EA"]
	Australian_Steel_300_Grade_Equal_angles_200x20_EA = ["Australian","Steel (300 Grade)","Equal angles","200x20 EA"]
	Australian_Steel_300_Grade_Equal_angles_200x26_EA = ["Australian","Steel (300 Grade)","Equal angles","200x26 EA"]
	Australian_Steel_300_Grade_Parallel_flange_channels_75_PFC = ["Australian","Steel (300 Grade)","Parallel flange channels","75 PFC"]
	Australian_Steel_300_Grade_Parallel_flange_channels_100_PFC = ["Australian","Steel (300 Grade)","Parallel flange channels","100 PFC"]
	Australian_Steel_300_Grade_Parallel_flange_channels_125_PFC = ["Australian","Steel (300 Grade)","Parallel flange channels","125 PFC"]
	Australian_Steel_300_Grade_Parallel_flange_channels_150_PFC = ["Australian","Steel (300 Grade)","Parallel flange channels","150 PFC"]
	Australian_Steel_300_Grade_Parallel_flange_channels_180_PFC = ["Australian","Steel (300 Grade)","Parallel flange channels","180 PFC"]
	Australian_Steel_300_Grade_Parallel_flange_channels_200_PFC = ["Australian","Steel (300 Grade)","Parallel flange channels","200 PFC"]
	Australian_Steel_300_Grade_Parallel_flange_channels_230_PFC = ["Australian","Steel (300 Grade)","Parallel flange channels","230 PFC"]
	Australian_Steel_300_Grade_Parallel_flange_channels_250_PFC = ["Australian","Steel (300 Grade)","Parallel flange channels","250 PFC"]
	Australian_Steel_300_Grade_Parallel_flange_channels_300_PFC = ["Australian","Steel (300 Grade)","Parallel flange channels","300 PFC"]
	Australian_Steel_300_Grade_Parallel_flange_channels_380_PFC = ["Australian","Steel (300 Grade)","Parallel flange channels","380 PFC"]
	Australian_Steel_300_Grade_RHS_Grade_350_50x20x1_6_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","50x20x1.6 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_50x20x2_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","50x20x2 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_50x20x2_5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","50x20x2.5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_50x20x3_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","50x20x3 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_50x25x1_6_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","50x25x1.6 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_50x25x2_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","50x25x2 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_50x25x2_5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","50x25x2.5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_50x25x3_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","50x25x3 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_65x35x2_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","65x35x2 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_65x35x2_5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","65x35x2.5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_65x35x3_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","65x35x3 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_65x35x4_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","65x35x4 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_75x25x1_6_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","75x25x1.6 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_75x25x2_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","75x25x2 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_75x25x2_5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","75x25x2.5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_75x50x1_6_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","75x50x1.6 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_75x50x2_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","75x50x2 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_75x50x2_5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","75x50x2.5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_75x50x3_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","75x50x3 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_75x50x4_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","75x50x4 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_75x50x5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","75x50x5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_75x50x6_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","75x50x6 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_76x38x2_5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","76x38x2.5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_76x38x3_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","76x38x3 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_76x38x4_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","76x38x4 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_100x50x1_6_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","100x50x1.6 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_100x50x2_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","100x50x2 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_100x50x2_5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","100x50x2.5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_100x50x3_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","100x50x3 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_100x50x3_5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","100x50x3.5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_100x50x4_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","100x50x4 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_100x50x5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","100x50x5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_100x50x6_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","100x50x6 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_102x76x3_5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","102x76x3.5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_102x76x5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","102x76x5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_102x76x6_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","102x76x6 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_125x75x2_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","125x75x2 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_125x75x2_5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","125x75x2.5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_125x75x3_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","125x75x3 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_125x75x4_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","125x75x4 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_125x75x5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","125x75x5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_125x75x6_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","125x75x6 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_127x51x3_5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","127x51x3.5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_127x51x5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","127x51x5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_127x51x6_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","127x51x6 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_150x50x2_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","150x50x2 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_150x50x2_5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","150x50x2.5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_150x50x3_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","150x50x3 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_150x50x4_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","150x50x4 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_150x50x5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","150x50x5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_150x50x6_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","150x50x6 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_150x100x4_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","150x100x4 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_150x100x5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","150x100x5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_150x100x6_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","150x100x6 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_150x100x8_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","150x100x8 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_150x100x9_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","150x100x9 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_150x100x10_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","150x100x10 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_152x76x5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","152x76x5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_152x76x6_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","152x76x6 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_185x65x3_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","185x65x3 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_185x65x4_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","185x65x4 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_185x65x5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","185x65x5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_185x65x6_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","185x65x6 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_200x50x3_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","200x50x3 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_200x50x4_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","200x50x4 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_200x50x5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","200x50x5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_200x50x6_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","200x50x6 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_200x100x3_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","200x100x3 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_200x100x4_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","200x100x4 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_200x100x5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","200x100x5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_200x100x6_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","200x100x6 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_200x100x8_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","200x100x8 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_200x100x9_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","200x100x9 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_200x100x10_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","200x100x10 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_250x150x5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","250x150x5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_250x150x6_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","250x150x6 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_250x150x8_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","250x150x8 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_250x150x9_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","250x150x9 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_250x150x10_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","250x150x10 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_250x150x12_5RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","250x150x12.5RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_250x150x16_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","250x150x16 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_300x200x6_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","300x200x6 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_300x200x8_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","300x200x8 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_300x200x10_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","300x200x10 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_300x200x12_5RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","300x200x12.5RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_300x200x16_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","300x200x16 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_350x250x8_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","350x250x8 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_350x250x10_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","350x250x10 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_350x250x12_5RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","350x250x12.5RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_350x250x16_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","350x250x16 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_400x200x8_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","400x200x8 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_400x200x10_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","400x200x10 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_400x200x12_5RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","400x200x12.5RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_400x200x16_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","400x200x16 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_400x300x8_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","400x300x8 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_400x300x10_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","400x300x10 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_400x300x12_5RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","400x300x12.5RHS"]
	Australian_Steel_300_Grade_RHS_Grade_350_400x300x16_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 350)","400x300x16 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_50x20x1_6_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","50x20x1.6 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_50x20x2_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","50x20x2 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_50x20x2_3_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","50x20x2.3 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_50x20x2_5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","50x20x2.5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_50x20x2_8_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","50x20x2.8 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_50x20x3_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","50x20x3 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_50x25x1_6_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","50x25x1.6 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_50x25x2_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","50x25x2 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_50x25x2_3_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","50x25x2.3 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_50x25x2_5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","50x25x2.5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_50x25x2_8_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","50x25x2.8 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_50x25x3_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","50x25x3 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_65x35x2_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","65x35x2 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_65x35x2_3_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","65x35x2.3 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_65x35x2_5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","65x35x2.5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_65x35x2_8_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","65x35x2.8 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_65x35x3_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","65x35x3 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_65x35x4_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","65x35x4 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_75x25x1_6_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","75x25x1.6 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_75x25x2_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","75x25x2 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_75x25x2_5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","75x25x2.5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_75x50x1_6_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","75x50x1.6 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_75x50x2_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","75x50x2 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_75x50x2_3_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","75x50x2.3 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_75x50x2_5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","75x50x2.5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_75x50x2_8_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","75x50x2.8 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_75x50x3_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","75x50x3 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_75x50x4_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","75x50x4 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_75x50x5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","75x50x5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_75x50x6_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","75x50x6 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_76x38x2_5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","76x38x2.5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_76x38x3_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","76x38x3 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_76x38x4_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","76x38x4 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_100x50x1_6_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","100x50x1.6 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_100x50x2_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","100x50x2 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_100x50x2_3_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","100x50x2.3 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_100x50x2_5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","100x50x2.5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_100x50x2_8_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","100x50x2.8 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_100x50x3_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","100x50x3 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_100x50x3_5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","100x50x3.5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_100x50x4_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","100x50x4 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_100x50x5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","100x50x5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_100x50x6_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","100x50x6 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_102x76x3_5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","102x76x3.5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_102x76x5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","102x76x5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_102x76x6_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","102x76x6 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_125x75x2_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","125x75x2 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_125x75x2_3_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","125x75x2.3 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_125x75x2_5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","125x75x2.5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_125x75x2_8_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","125x75x2.8 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_125x75x3_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","125x75x3 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_125x75x4_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","125x75x4 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_125x75x5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","125x75x5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_125x75x6_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","125x75x6 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_127x51x3_5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","127x51x3.5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_127x51x5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","127x51x5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_127x51x6_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","127x51x6 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_150x50x2_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","150x50x2 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_150x50x2_5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","150x50x2.5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_150x50x3_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","150x50x3 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_150x50x4_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","150x50x4 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_150x50x5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","150x50x5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_150x50x6_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","150x50x6 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_150x100x4_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","150x100x4 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_150x100x5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","150x100x5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_150x100x6_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","150x100x6 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_150x100x8_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","150x100x8 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_150x100x9_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","150x100x9 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_150x100x10_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","150x100x10 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_152x76x5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","152x76x5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_152x76x6_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","152x76x6 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_200x100x4_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","200x100x4 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_200x100x5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","200x100x5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_200x100x6_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","200x100x6 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_200x100x8_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","200x100x8 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_200x100x9_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","200x100x9 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_200x100x10_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","200x100x10 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_250x150x5_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","250x150x5 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_250x150x6_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","250x150x6 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_250x150x8_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","250x150x8 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_250x150x9_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","250x150x9 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_250x150x10_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","250x150x10 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_250x150x12_5RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","250x150x12.5RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_250x150x16_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","250x150x16 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_300x200x6_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","300x200x6 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_300x200x8_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","300x200x8 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_300x200x10_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","300x200x10 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_300x200x12_5RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","300x200x12.5RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_300x200x16_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","300x200x16 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_350x250x8_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","350x250x8 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_350x250x10_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","350x250x10 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_350x250x12_5RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","350x250x12.5RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_350x250x16_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","350x250x16 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_400x200x8_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","400x200x8 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_400x200x10_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","400x200x10 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_400x200x12_5RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","400x200x12.5RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_400x200x16_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","400x200x16 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_400x300x8_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","400x300x8 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_400x300x10_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","400x300x10 RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_400x300x12_5RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","400x300x12.5RHS"]
	Australian_Steel_300_Grade_RHS_Grade_450_400x300x16_RHS = ["Australian","Steel (300 Grade)","RHS (Grade 450)","400x300x16 RHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_13x1_8_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","13x1.8 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_15x1_8_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","15x1.8 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_20x1_6_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","20x1.6 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_20x2_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","20x2 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_25x1_6_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","25x1.6 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_25x2_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","25x2 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_25x2_5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","25x2.5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_25x3_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","25x3 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_30x1_6_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","30x1.6 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_30x2_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","30x2 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_30x2_5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","30x2.5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_30x3_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","30x3 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_35x1_6_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","35x1.6 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_35x2_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","35x2 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_35x2_5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","35x2.5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_35x3_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","35x3 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_40x1_6_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","40x1.6 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_40x2_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","40x2 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_40x2_5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","40x2.5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_40x3_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","40x3 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_40x4_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","40x4 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_50x1_6_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","50x1.6 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_50x2_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","50x2 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_50x2_5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","50x2.5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_50x3_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","50x3 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_50x4_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","50x4 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_50x5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","50x5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_50x6_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","50x6 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_65x1_6_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","65x1.6 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_65x2_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","65x2 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_65x2_5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","65x2.5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_65x3_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","65x3 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_65x4_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","65x4 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_65x5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","65x5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_65x6_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","65x6 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_75x2_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","75x2 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_75x2_5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","75x2.5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_75x3_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","75x3 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_75x3_5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","75x3.5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_75x4_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","75x4 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_75x5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","75x5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_75x6_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","75x6 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_89x2_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","89x2 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_89x3_5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","89x3.5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_89x5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","89x5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_89x6_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","89x6 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_90x2_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","90x2 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_90x2_5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","90x2.5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_100x2_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","100x2 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_100x2_5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","100x2.5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_100x3_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","100x3 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_100x4_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","100x4 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_100x5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","100x5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_100x6_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","100x6 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_100x8_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","100x8 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_100x9_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","100x9 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_100x10_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","100x10 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_125x4_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","125x4 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_125x5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","125x5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_125x6_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","125x6 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_125x8_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","125x8 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_125x9_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","125x9 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_125x10_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","125x10 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_150x3_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","150x3 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_150x4_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","150x4 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_150x5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","150x5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_150x6_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","150x6 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_150x8_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","150x8 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_150x9_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","150x9 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_150x10_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","150x10 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_200x5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","200x5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_200x6_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","200x6 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_200x8_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","200x8 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_200x9_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","200x9 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_200x10_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","200x10 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_200x12_5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","200x12.5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_200x16_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","200x16 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_250x6_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","250x6 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_250x8_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","250x8 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_250x9_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","250x9 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_250x10_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","250x10 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_250x12_5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","250x12.5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_250x16_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","250x16 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_300x8_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","300x8 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_300x10_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","300x10 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_300x12_5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","300x12.5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_300x16_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","300x16 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_350x8_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","350x8 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_350x10_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","350x10 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_350x12_5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","350x12.5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_350x16_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","350x16 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_400x10_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","400x10 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_400x12_5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","400x12.5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_350_400x16_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 350)","400x16 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_20x1_6_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","20x1.6 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_20x2_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","20x2 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_25x1_6_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","25x1.6 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_25x2_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","25x2 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_25x2_5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","25x2.5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_25x3_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","25x3 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_30x1_6_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","30x1.6 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_30x2_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","30x2 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_30x2_5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","30x2.5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_30x3_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","30x3 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_35x1_6_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","35x1.6 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_35x2_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","35x2 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_35x2_3_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","35x2.3 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_35x2_5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","35x2.5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_35x2_8_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","35x2.8 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_35x3_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","35x3 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_40x1_6_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","40x1.6 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_40x2_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","40x2 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_40x2_3_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","40x2.3 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_40x2_5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","40x2.5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_40x2_8_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","40x2.8 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_40x3_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","40x3 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_40x4_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","40x4 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_50x1_6_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","50x1.6 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_50x2_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","50x2 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_50x2_3_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","50x2.3 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_50x2_5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","50x2.5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_50x2_8_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","50x2.8 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_50x3_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","50x3 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_50x4_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","50x4 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_50x5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","50x5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_50x6_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","50x6 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_65x1_6_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","65x1.6 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_65x2_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","65x2 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_65x2_3_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","65x2.3 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_65x2_5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","65x2.5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_65x3_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","65x3 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_65x4_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","65x4 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_65x5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","65x5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_65x6_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","65x6 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_75x2_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","75x2 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_75x2_3_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","75x2.3 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_75x2_5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","75x2.5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_75x2_8_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","75x2.8 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_75x3_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","75x3 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_75x3_5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","75x3.5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_75x4_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","75x4 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_75x5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","75x5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_75x6_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","75x6 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_89x2_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","89x2 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_89x3_5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","89x3.5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_89x5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","89x5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_89x6_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","89x6 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_90x2_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","90x2 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_90x2_5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","90x2.5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_90x3_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","90x3 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_100x2_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","100x2 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_100x2_3_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","100x2.3 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_100x2_5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","100x2.5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_100x2_8_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","100x2.8 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_100x3_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","100x3 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_100x4_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","100x4 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_100x5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","100x5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_100x6_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","100x6 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_100x8_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","100x8 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_100x9_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","100x9 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_100x10_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","100x10 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_125x4_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","125x4 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_125x5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","125x5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_125x6_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","125x6 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_125x8_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","125x8 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_125x9_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","125x9 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_125x10_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","125x10 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_150x5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","150x5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_150x6_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","150x6 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_150x8_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","150x8 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_150x9_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","150x9 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_150x10_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","150x10 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_200x5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","200x5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_200x6_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","200x6 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_200x8_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","200x8 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_200x9_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","200x9 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_200x10_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","200x10 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_200x12_5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","200x12.5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_200x16_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","200x16 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_250x6_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","250x6 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_250x8_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","250x8 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_250x9_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","250x9 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_250x10_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","250x10 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_250x12_5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","250x12.5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_250x16_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","250x16 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_300x8_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","300x8 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_300x10_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","300x10 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_300x12_5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","300x12.5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_300x16_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","300x16 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_350x8_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","350x8 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_350x10_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","350x10 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_350x12_5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","350x12.5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_350x16_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","350x16 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_400x10_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","400x10 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_400x12_5_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","400x12.5 SHS"]
	Australian_Steel_300_Grade_SHS_Grade_450_400x16_SHS = ["Australian","Steel (300 Grade)","SHS (Grade 450)","400x16 SHS"]
	Australian_Steel_300_Grade_Taper_flange_beams_100_TFB = ["Australian","Steel (300 Grade)","Taper flange beams","100 TFB"]
	Australian_Steel_300_Grade_Taper_flange_beams_125_TFB = ["Australian","Steel (300 Grade)","Taper flange beams","125 TFB"]
	Australian_Steel_300_Grade_Unequal_angles_65x50x5_UA = ["Australian","Steel (300 Grade)","Unequal angles","65x50x5 UA"]
	Australian_Steel_300_Grade_Unequal_angles_65x50x6_UA = ["Australian","Steel (300 Grade)","Unequal angles","65x50x6 UA"]
	Australian_Steel_300_Grade_Unequal_angles_65x50x8_UA = ["Australian","Steel (300 Grade)","Unequal angles","65x50x8 UA"]
	Australian_Steel_300_Grade_Unequal_angles_75x50x5_UA = ["Australian","Steel (300 Grade)","Unequal angles","75x50x5 UA"]
	Australian_Steel_300_Grade_Unequal_angles_75x50x6_UA = ["Australian","Steel (300 Grade)","Unequal angles","75x50x6 UA"]
	Australian_Steel_300_Grade_Unequal_angles_75x50x8_UA = ["Australian","Steel (300 Grade)","Unequal angles","75x50x8 UA"]
	Australian_Steel_300_Grade_Unequal_angles_100x75x6_UA = ["Australian","Steel (300 Grade)","Unequal angles","100x75x6 UA"]
	Australian_Steel_300_Grade_Unequal_angles_100x75x8_UA = ["Australian","Steel (300 Grade)","Unequal angles","100x75x8 UA"]
	Australian_Steel_300_Grade_Unequal_angles_100x75x10_UA = ["Australian","Steel (300 Grade)","Unequal angles","100x75x10 UA"]
	Australian_Steel_300_Grade_Unequal_angles_125x75x6_UA = ["Australian","Steel (300 Grade)","Unequal angles","125x75x6 UA"]
	Australian_Steel_300_Grade_Unequal_angles_125x75x8_UA = ["Australian","Steel (300 Grade)","Unequal angles","125x75x8 UA"]
	Australian_Steel_300_Grade_Unequal_angles_125x75x10_UA = ["Australian","Steel (300 Grade)","Unequal angles","125x75x10 UA"]
	Australian_Steel_300_Grade_Unequal_angles_125x75x12_UA = ["Australian","Steel (300 Grade)","Unequal angles","125x75x12 UA"]
	Australian_Steel_300_Grade_Unequal_angles_150x90x8_UA = ["Australian","Steel (300 Grade)","Unequal angles","150x90x8 UA"]
	Australian_Steel_300_Grade_Unequal_angles_150x90x10_UA = ["Australian","Steel (300 Grade)","Unequal angles","150x90x10 UA"]
	Australian_Steel_300_Grade_Unequal_angles_150x90x12_UA = ["Australian","Steel (300 Grade)","Unequal angles","150x90x12 UA"]
	Australian_Steel_300_Grade_Unequal_angles_150x90x16_UA = ["Australian","Steel (300 Grade)","Unequal angles","150x90x16 UA"]
	Australian_Steel_300_Grade_Unequal_angles_150x100x10_UA = ["Australian","Steel (300 Grade)","Unequal angles","150x100x10 UA"]
	Australian_Steel_300_Grade_Unequal_angles_150x100x12_UA = ["Australian","Steel (300 Grade)","Unequal angles","150x100x12 UA"]
	Australian_Steel_300_Grade_Universal_beam_tees_75_BT_7 = ["Australian","Steel (300 Grade)","Universal beam tees","75 BT 7"]
	Australian_Steel_300_Grade_Universal_beam_tees_75_BT_9 = ["Australian","Steel (300 Grade)","Universal beam tees","75 BT 9"]
	Australian_Steel_300_Grade_Universal_beam_tees_90_BT_8 = ["Australian","Steel (300 Grade)","Universal beam tees","90 BT 8"]
	Australian_Steel_300_Grade_Universal_beam_tees_90_BT_9 = ["Australian","Steel (300 Grade)","Universal beam tees","90 BT 9"]
	Australian_Steel_300_Grade_Universal_beam_tees_90_BT_11 = ["Australian","Steel (300 Grade)","Universal beam tees","90 BT 11"]
	Australian_Steel_300_Grade_Universal_beam_tees_100_BT_9 = ["Australian","Steel (300 Grade)","Universal beam tees","100 BT 9"]
	Australian_Steel_300_Grade_Universal_beam_tees_125_BT_13 = ["Australian","Steel (300 Grade)","Universal beam tees","125 BT 13"]
	Australian_Steel_300_Grade_Universal_beam_tees_125_BT_15 = ["Australian","Steel (300 Grade)","Universal beam tees","125 BT 15"]
	Australian_Steel_300_Grade_Universal_beam_tees_125_BT_18 = ["Australian","Steel (300 Grade)","Universal beam tees","125 BT 18"]
	Australian_Steel_300_Grade_Universal_beam_tees_155_BT_16 = ["Australian","Steel (300 Grade)","Universal beam tees","155 BT 16"]
	Australian_Steel_300_Grade_Universal_beam_tees_155_BT_20 = ["Australian","Steel (300 Grade)","Universal beam tees","155 BT 20"]
	Australian_Steel_300_Grade_Universal_beam_tees_155_BT_23 = ["Australian","Steel (300 Grade)","Universal beam tees","155 BT 23"]
	Australian_Steel_300_Grade_Universal_beam_tees_180_BT_22 = ["Australian","Steel (300 Grade)","Universal beam tees","180 BT 22"]
	Australian_Steel_300_Grade_Universal_beam_tees_180_BT_25 = ["Australian","Steel (300 Grade)","Universal beam tees","180 BT 25"]
	Australian_Steel_300_Grade_Universal_beam_tees_180_BT_28 = ["Australian","Steel (300 Grade)","Universal beam tees","180 BT 28"]
	Australian_Steel_300_Grade_Universal_beam_tees_205_BT_27 = ["Australian","Steel (300 Grade)","Universal beam tees","205 BT 27"]
	Australian_Steel_300_Grade_Universal_beam_tees_205_BT_30 = ["Australian","Steel (300 Grade)","Universal beam tees","205 BT 30"]
	Australian_Steel_300_Grade_Universal_beam_tees_230_BT_33 = ["Australian","Steel (300 Grade)","Universal beam tees","230 BT 33"]
	Australian_Steel_300_Grade_Universal_beam_tees_230_BT_37 = ["Australian","Steel (300 Grade)","Universal beam tees","230 BT 37"]
	Australian_Steel_300_Grade_Universal_beam_tees_230_BT_41 = ["Australian","Steel (300 Grade)","Universal beam tees","230 BT 41"]
	Australian_Steel_300_Grade_Universal_beam_tees_265_BT_41 = ["Australian","Steel (300 Grade)","Universal beam tees","265 BT 41"]
	Australian_Steel_300_Grade_Universal_beam_tees_265_BT_46 = ["Australian","Steel (300 Grade)","Universal beam tees","265 BT 46"]
	Australian_Steel_300_Grade_Universal_beam_tees_305_BT_50 = ["Australian","Steel (300 Grade)","Universal beam tees","305 BT 50"]
	Australian_Steel_300_Grade_Universal_beam_tees_305_BT_56 = ["Australian","Steel (300 Grade)","Universal beam tees","305 BT 56"]
	Australian_Steel_300_Grade_Universal_beam_tees_305_BT_62 = ["Australian","Steel (300 Grade)","Universal beam tees","305 BT 62"]
	Australian_Steel_300_Grade_Universal_beam_tees_345_BT_62 = ["Australian","Steel (300 Grade)","Universal beam tees","345 BT 62"]
	Australian_Steel_300_Grade_Universal_beam_tees_345_BT_70 = ["Australian","Steel (300 Grade)","Universal beam tees","345 BT 70"]
	Australian_Steel_300_Grade_Universal_beam_tees_380_BT_73 = ["Australian","Steel (300 Grade)","Universal beam tees","380 BT 73"]
	Australian_Steel_300_Grade_Universal_beam_tees_380_BT_86 = ["Australian","Steel (300 Grade)","Universal beam tees","380 BT 86"]
	Australian_Steel_300_Grade_Universal_beam_tees_380_BT_98 = ["Australian","Steel (300 Grade)","Universal beam tees","380 BT 98"]
	Australian_Steel_300_Grade_Universal_beam_tees_380_BT_110 = ["Australian","Steel (300 Grade)","Universal beam tees","380 BT 110"]
	Australian_Steel_300_Grade_Universal_beam_tees_380_BT_122 = ["Australian","Steel (300 Grade)","Universal beam tees","380 BT 122"]
	Australian_Steel_300_Grade_Universal_beams_150_UB_14_0 = ["Australian","Steel (300 Grade)","Universal beams","150 UB 14.0"]
	Australian_Steel_300_Grade_Universal_beams_150_UB_18_0 = ["Australian","Steel (300 Grade)","Universal beams","150 UB 18.0"]
	Australian_Steel_300_Grade_Universal_beams_180_UB_16_1 = ["Australian","Steel (300 Grade)","Universal beams","180 UB 16.1"]
	Australian_Steel_300_Grade_Universal_beams_180_UB_18_1 = ["Australian","Steel (300 Grade)","Universal beams","180 UB 18.1"]
	Australian_Steel_300_Grade_Universal_beams_180_UB_22_2 = ["Australian","Steel (300 Grade)","Universal beams","180 UB 22.2"]
	Australian_Steel_300_Grade_Universal_beams_200_UB_18_2 = ["Australian","Steel (300 Grade)","Universal beams","200 UB 18.2"]
	Australian_Steel_300_Grade_Universal_beams_200_UB_22_3 = ["Australian","Steel (300 Grade)","Universal beams","200 UB 22.3"]
	Australian_Steel_300_Grade_Universal_beams_200_UB_25_4 = ["Australian","Steel (300 Grade)","Universal beams","200 UB 25.4"]
	Australian_Steel_300_Grade_Universal_beams_200_UB_29_8 = ["Australian","Steel (300 Grade)","Universal beams","200 UB 29.8"]
	Australian_Steel_300_Grade_Universal_beams_250_UB_25_7 = ["Australian","Steel (300 Grade)","Universal beams","250 UB 25.7"]
	Australian_Steel_300_Grade_Universal_beams_250_UB_31_4 = ["Australian","Steel (300 Grade)","Universal beams","250 UB 31.4"]
	Australian_Steel_300_Grade_Universal_beams_250_UB_37_3 = ["Australian","Steel (300 Grade)","Universal beams","250 UB 37.3"]
	Australian_Steel_300_Grade_Universal_beams_310_UB_32_0 = ["Australian","Steel (300 Grade)","Universal beams","310 UB 32.0"]
	Australian_Steel_300_Grade_Universal_beams_310_UB_40_4 = ["Australian","Steel (300 Grade)","Universal beams","310 UB 40.4"]
	Australian_Steel_300_Grade_Universal_beams_310_UB_46_2 = ["Australian","Steel (300 Grade)","Universal beams","310 UB 46.2"]
	Australian_Steel_300_Grade_Universal_beams_360_UB_44_7 = ["Australian","Steel (300 Grade)","Universal beams","360 UB 44.7"]
	Australian_Steel_300_Grade_Universal_beams_360_UB_50_7 = ["Australian","Steel (300 Grade)","Universal beams","360 UB 50.7"]
	Australian_Steel_300_Grade_Universal_beams_360_UB_56_7 = ["Australian","Steel (300 Grade)","Universal beams","360 UB 56.7"]
	Australian_Steel_300_Grade_Universal_beams_410_UB_53_7 = ["Australian","Steel (300 Grade)","Universal beams","410 UB 53.7"]
	Australian_Steel_300_Grade_Universal_beams_410_UB_59_7 = ["Australian","Steel (300 Grade)","Universal beams","410 UB 59.7"]
	Australian_Steel_300_Grade_Universal_beams_460_UB_67_1 = ["Australian","Steel (300 Grade)","Universal beams","460 UB 67.1"]
	Australian_Steel_300_Grade_Universal_beams_460_UB_74_6 = ["Australian","Steel (300 Grade)","Universal beams","460 UB 74.6"]
	Australian_Steel_300_Grade_Universal_beams_460_UB_82_1 = ["Australian","Steel (300 Grade)","Universal beams","460 UB 82.1"]
	Australian_Steel_300_Grade_Universal_beams_530_UB_82_0 = ["Australian","Steel (300 Grade)","Universal beams","530 UB 82.0"]
	Australian_Steel_300_Grade_Universal_beams_530_UB_92_4 = ["Australian","Steel (300 Grade)","Universal beams","530 UB 92.4"]
	Australian_Steel_300_Grade_Universal_beams_610_UB_101 = ["Australian","Steel (300 Grade)","Universal beams","610 UB 101"]
	Australian_Steel_300_Grade_Universal_beams_610_UB_113 = ["Australian","Steel (300 Grade)","Universal beams","610 UB 113"]
	Australian_Steel_300_Grade_Universal_beams_610_UB_125 = ["Australian","Steel (300 Grade)","Universal beams","610 UB 125"]
	Australian_Steel_300_Grade_Universal_bearing_piles_200_UBP_122 = ["Australian","Steel (300 Grade)","Universal bearing piles","200 UBP 122"]
	Australian_Steel_300_Grade_Universal_bearing_piles_200_UBP_146 = ["Australian","Steel (300 Grade)","Universal bearing piles","200 UBP 146"]
	Australian_Steel_300_Grade_Universal_bearing_piles_250_UBP_62_6 = ["Australian","Steel (300 Grade)","Universal bearing piles","250 UBP 62.6"]
	Australian_Steel_300_Grade_Universal_bearing_piles_250_UBP_84_9 = ["Australian","Steel (300 Grade)","Universal bearing piles","250 UBP 84.9"]
	Australian_Steel_300_Grade_Universal_bearing_piles_310_UBP_78_8 = ["Australian","Steel (300 Grade)","Universal bearing piles","310 UBP 78.8"]
	Australian_Steel_300_Grade_Universal_bearing_piles_310_UBP_110 = ["Australian","Steel (300 Grade)","Universal bearing piles","310 UBP 110"]
	Australian_Steel_300_Grade_Universal_bearing_piles_310_UBP_149 = ["Australian","Steel (300 Grade)","Universal bearing piles","310 UBP 149"]
	Australian_Steel_300_Grade_Universal_column_tees_75_CT_12 = ["Australian","Steel (300 Grade)","Universal column tees","75 CT 12"]
	Australian_Steel_300_Grade_Universal_column_tees_75_CT_15 = ["Australian","Steel (300 Grade)","Universal column tees","75 CT 15"]
	Australian_Steel_300_Grade_Universal_column_tees_75_CT_18 = ["Australian","Steel (300 Grade)","Universal column tees","75 CT 18"]
	Australian_Steel_300_Grade_Universal_column_tees_100_BT_11 = ["Australian","Steel (300 Grade)","Universal column tees","100 BT 11"]
	Australian_Steel_300_Grade_Universal_column_tees_100_BT_12 = ["Australian","Steel (300 Grade)","Universal column tees","100 BT 12"]
	Australian_Steel_300_Grade_Universal_column_tees_100_BT_15 = ["Australian","Steel (300 Grade)","Universal column tees","100 BT 15"]
	Australian_Steel_300_Grade_Universal_column_tees_100_CT_23 = ["Australian","Steel (300 Grade)","Universal column tees","100 CT 23"]
	Australian_Steel_300_Grade_Universal_column_tees_100_CT_26 = ["Australian","Steel (300 Grade)","Universal column tees","100 CT 26"]
	Australian_Steel_300_Grade_Universal_column_tees_100_CT_30 = ["Australian","Steel (300 Grade)","Universal column tees","100 CT 30"]
	Australian_Steel_300_Grade_Universal_column_tees_125_CT_36 = ["Australian","Steel (300 Grade)","Universal column tees","125 CT 36"]
	Australian_Steel_300_Grade_Universal_column_tees_125_CT_44 = ["Australian","Steel (300 Grade)","Universal column tees","125 CT 44"]
	Australian_Steel_300_Grade_Universal_column_tees_155_CT_48 = ["Australian","Steel (300 Grade)","Universal column tees","155 CT 48"]
	Australian_Steel_300_Grade_Universal_column_tees_155_CT_59 = ["Australian","Steel (300 Grade)","Universal column tees","155 CT 59"]
	Australian_Steel_300_Grade_Universal_column_tees_155_CT_68 = ["Australian","Steel (300 Grade)","Universal column tees","155 CT 68"]
	Australian_Steel_300_Grade_Universal_column_tees_155_CT_79 = ["Australian","Steel (300 Grade)","Universal column tees","155 CT 79"]
	Australian_Steel_300_Grade_Universal_column_tees_155_CT_99 = ["Australian","Steel (300 Grade)","Universal column tees","155 CT 99"]
	Australian_Steel_300_Grade_Universal_column_tees_155_CT_120 = ["Australian","Steel (300 Grade)","Universal column tees","155 CT 120"]
	Australian_Steel_300_Grade_Universal_column_tees_155_CT_142 = ["Australian","Steel (300 Grade)","Universal column tees","155 CT 142"]
	Australian_Steel_300_Grade_Universal_columns_100_UC_14_8 = ["Australian","Steel (300 Grade)","Universal columns","100 UC 14.8"]
	Australian_Steel_300_Grade_Universal_columns_150_UC_23_4 = ["Australian","Steel (300 Grade)","Universal columns","150 UC 23.4"]
	Australian_Steel_300_Grade_Universal_columns_150_UC_30_0 = ["Australian","Steel (300 Grade)","Universal columns","150 UC 30.0"]
	Australian_Steel_300_Grade_Universal_columns_150_UC_37_2 = ["Australian","Steel (300 Grade)","Universal columns","150 UC 37.2"]
	Australian_Steel_300_Grade_Universal_columns_200_UC_46_2 = ["Australian","Steel (300 Grade)","Universal columns","200 UC 46.2"]
	Australian_Steel_300_Grade_Universal_columns_200_UC_52_2 = ["Australian","Steel (300 Grade)","Universal columns","200 UC 52.2"]
	Australian_Steel_300_Grade_Universal_columns_200_UC_59_5 = ["Australian","Steel (300 Grade)","Universal columns","200 UC 59.5"]
	Australian_Steel_300_Grade_Universal_columns_250_UC_72_9 = ["Australian","Steel (300 Grade)","Universal columns","250 UC 72.9"]
	Australian_Steel_300_Grade_Universal_columns_250_UC_89_5 = ["Australian","Steel (300 Grade)","Universal columns","250 UC 89.5"]
	Australian_Steel_300_Grade_Universal_columns_310_UC_96_8 = ["Australian","Steel (300 Grade)","Universal columns","310 UC 96.8"]
	Australian_Steel_300_Grade_Universal_columns_310_UC_118 = ["Australian","Steel (300 Grade)","Universal columns","310 UC 118"]
	Australian_Steel_300_Grade_Universal_columns_310_UC_137 = ["Australian","Steel (300 Grade)","Universal columns","310 UC 137"]
	Australian_Steel_300_Grade_Universal_columns_310_UC_158 = ["Australian","Steel (300 Grade)","Universal columns","310 UC 158"]
	Australian_Steel_300_Grade_Welded_beams_700_WB_115 = ["Australian","Steel (300 Grade)","Welded beams","700 WB 115"]
	Australian_Steel_300_Grade_Welded_beams_700_WB_130 = ["Australian","Steel (300 Grade)","Welded beams","700 WB 130"]
	Australian_Steel_300_Grade_Welded_beams_700_WB_150 = ["Australian","Steel (300 Grade)","Welded beams","700 WB 150"]
	Australian_Steel_300_Grade_Welded_beams_700_WB_173 = ["Australian","Steel (300 Grade)","Welded beams","700 WB 173"]
	Australian_Steel_300_Grade_Welded_beams_800_WB_122 = ["Australian","Steel (300 Grade)","Welded beams","800 WB 122"]
	Australian_Steel_300_Grade_Welded_beams_800_WB_146 = ["Australian","Steel (300 Grade)","Welded beams","800 WB 146"]
	Australian_Steel_300_Grade_Welded_beams_800_WB_168 = ["Australian","Steel (300 Grade)","Welded beams","800 WB 168"]
	Australian_Steel_300_Grade_Welded_beams_800_WB_192 = ["Australian","Steel (300 Grade)","Welded beams","800 WB 192"]
	Australian_Steel_300_Grade_Welded_beams_900_WB_175 = ["Australian","Steel (300 Grade)","Welded beams","900 WB 175"]
	Australian_Steel_300_Grade_Welded_beams_900_WB_218 = ["Australian","Steel (300 Grade)","Welded beams","900 WB 218"]
	Australian_Steel_300_Grade_Welded_beams_900_WB_257 = ["Australian","Steel (300 Grade)","Welded beams","900 WB 257"]
	Australian_Steel_300_Grade_Welded_beams_900_WB_282 = ["Australian","Steel (300 Grade)","Welded beams","900 WB 282"]
	Australian_Steel_300_Grade_Welded_beams_1000_WB_215 = ["Australian","Steel (300 Grade)","Welded beams","1000 WB 215"]
	Australian_Steel_300_Grade_Welded_beams_1000_WB_258 = ["Australian","Steel (300 Grade)","Welded beams","1000 WB 258"]
	Australian_Steel_300_Grade_Welded_beams_1000_WB_296 = ["Australian","Steel (300 Grade)","Welded beams","1000 WB 296"]
	Australian_Steel_300_Grade_Welded_beams_1000_WB_322 = ["Australian","Steel (300 Grade)","Welded beams","1000 WB 322"]
	Australian_Steel_300_Grade_Welded_beams_1200_WB_249 = ["Australian","Steel (300 Grade)","Welded beams","1200 WB 249"]
	Australian_Steel_300_Grade_Welded_beams_1200_WB_278 = ["Australian","Steel (300 Grade)","Welded beams","1200 WB 278"]
	Australian_Steel_300_Grade_Welded_beams_1200_WB_317 = ["Australian","Steel (300 Grade)","Welded beams","1200 WB 317"]
	Australian_Steel_300_Grade_Welded_beams_1200_WB_342 = ["Australian","Steel (300 Grade)","Welded beams","1200 WB 342"]
	Australian_Steel_300_Grade_Welded_beams_1200_WB_392 = ["Australian","Steel (300 Grade)","Welded beams","1200 WB 392"]
	Australian_Steel_300_Grade_Welded_beams_1200_WB_423 = ["Australian","Steel (300 Grade)","Welded beams","1200 WB 423"]
	Australian_Steel_300_Grade_Welded_beams_1200_WB_455 = ["Australian","Steel (300 Grade)","Welded beams","1200 WB 455"]
	Australian_Steel_300_Grade_Welded_columns_350_WC_197 = ["Australian","Steel (300 Grade)","Welded columns","350 WC 197"]
	Australian_Steel_300_Grade_Welded_columns_350_WC_230 = ["Australian","Steel (300 Grade)","Welded columns","350 WC 230"]
	Australian_Steel_300_Grade_Welded_columns_350_WC_258 = ["Australian","Steel (300 Grade)","Welded columns","350 WC 258"]
	Australian_Steel_300_Grade_Welded_columns_350_WC_280 = ["Australian","Steel (300 Grade)","Welded columns","350 WC 280"]
	Australian_Steel_300_Grade_Welded_columns_400_WC_144 = ["Australian","Steel (300 Grade)","Welded columns","400 WC 144"]
	Australian_Steel_300_Grade_Welded_columns_400_WC_181 = ["Australian","Steel (300 Grade)","Welded columns","400 WC 181"]
	Australian_Steel_300_Grade_Welded_columns_400_WC_212 = ["Australian","Steel (300 Grade)","Welded columns","400 WC 212"]
	Australian_Steel_300_Grade_Welded_columns_400_WC_270 = ["Australian","Steel (300 Grade)","Welded columns","400 WC 270"]
	Australian_Steel_300_Grade_Welded_columns_400_WC_303 = ["Australian","Steel (300 Grade)","Welded columns","400 WC 303"]
	Australian_Steel_300_Grade_Welded_columns_400_WC_328 = ["Australian","Steel (300 Grade)","Welded columns","400 WC 328"]
	Australian_Steel_300_Grade_Welded_columns_400_WC_361 = ["Australian","Steel (300 Grade)","Welded columns","400 WC 361"]
	Australian_Steel_300_Grade_Welded_columns_500_WC_228 = ["Australian","Steel (300 Grade)","Welded columns","500 WC 228"]
	Australian_Steel_300_Grade_Welded_columns_500_WC_267 = ["Australian","Steel (300 Grade)","Welded columns","500 WC 267"]
	Australian_Steel_300_Grade_Welded_columns_500_WC_290 = ["Australian","Steel (300 Grade)","Welded columns","500 WC 290"]
	Australian_Steel_300_Grade_Welded_columns_500_WC_340 = ["Australian","Steel (300 Grade)","Welded columns","500 WC 340"]
	Australian_Steel_300_Grade_Welded_columns_500_WC_383 = ["Australian","Steel (300 Grade)","Welded columns","500 WC 383"]
	Australian_Steel_300_Grade_Welded_columns_500_WC_414 = ["Australian","Steel (300 Grade)","Welded columns","500 WC 414"]
	Australian_Steel_300_Grade_Welded_columns_500_WC_440 = ["Australian","Steel (300 Grade)","Welded columns","500 WC 440"]
	Australian_Cold_Formed_Steel_Lysaght_Angles_LA4630 = ["Australian","Cold Formed Steel (Lysaght)","Angles","LA4630"]
	Australian_Cold_Formed_Steel_Lysaght_Angles_LA5130 = ["Australian","Cold Formed Steel (Lysaght)","Angles","LA5130"]
	Australian_Cold_Formed_Steel_Lysaght_Channels_Lipped_C10010 = ["Australian","Cold Formed Steel (Lysaght)","Channels (Lipped)","C10010"]
	Australian_Cold_Formed_Steel_Lysaght_Channels_Lipped_C10012 = ["Australian","Cold Formed Steel (Lysaght)","Channels (Lipped)","C10012"]
	Australian_Cold_Formed_Steel_Lysaght_Channels_Lipped_C10015 = ["Australian","Cold Formed Steel (Lysaght)","Channels (Lipped)","C10015"]
	Australian_Cold_Formed_Steel_Lysaght_Channels_Lipped_C10019 = ["Australian","Cold Formed Steel (Lysaght)","Channels (Lipped)","C10019"]
	Australian_Cold_Formed_Steel_Lysaght_Channels_Lipped_C15012 = ["Australian","Cold Formed Steel (Lysaght)","Channels (Lipped)","C15012"]
	Australian_Cold_Formed_Steel_Lysaght_Channels_Lipped_C15015 = ["Australian","Cold Formed Steel (Lysaght)","Channels (Lipped)","C15015"]
	Australian_Cold_Formed_Steel_Lysaght_Channels_Lipped_C15019 = ["Australian","Cold Formed Steel (Lysaght)","Channels (Lipped)","C15019"]
	Australian_Cold_Formed_Steel_Lysaght_Channels_Lipped_C15024 = ["Australian","Cold Formed Steel (Lysaght)","Channels (Lipped)","C15024"]
	Australian_Cold_Formed_Steel_Lysaght_Channels_Lipped_C20015 = ["Australian","Cold Formed Steel (Lysaght)","Channels (Lipped)","C20015"]
	Australian_Cold_Formed_Steel_Lysaght_Channels_Lipped_C20019 = ["Australian","Cold Formed Steel (Lysaght)","Channels (Lipped)","C20019"]
	Australian_Cold_Formed_Steel_Lysaght_Channels_Lipped_C20024 = ["Australian","Cold Formed Steel (Lysaght)","Channels (Lipped)","C20024"]
	Australian_Cold_Formed_Steel_Lysaght_Channels_Lipped_C25019 = ["Australian","Cold Formed Steel (Lysaght)","Channels (Lipped)","C25019"]
	Australian_Cold_Formed_Steel_Lysaght_Channels_Lipped_C25024 = ["Australian","Cold Formed Steel (Lysaght)","Channels (Lipped)","C25024"]
	Australian_Cold_Formed_Steel_Lysaght_Channels_Lipped_C30024 = ["Australian","Cold Formed Steel (Lysaght)","Channels (Lipped)","C30024"]
	Australian_Cold_Formed_Steel_Lysaght_Channels_Lipped_C30030 = ["Australian","Cold Formed Steel (Lysaght)","Channels (Lipped)","C30030"]
	Australian_Cold_Formed_Steel_Lysaght_Channels_Lipped_C35030 = ["Australian","Cold Formed Steel (Lysaght)","Channels (Lipped)","C35030"]
	Australian_Cold_Formed_Steel_Lysaght_Channels_Lipped_LL06425 = ["Australian","Cold Formed Steel (Lysaght)","Channels (Lipped)","LL06425"]
	Australian_Cold_Formed_Steel_Lysaght_Channels_Lipped_LL07610 = ["Australian","Cold Formed Steel (Lysaght)","Channels (Lipped)","LL07610"]
	Australian_Cold_Formed_Steel_Lysaght_Channels_Lipped_LL07625 = ["Australian","Cold Formed Steel (Lysaght)","Channels (Lipped)","LL07625"]
	Australian_Cold_Formed_Steel_Lysaght_Channels_Lipped_LL10225 = ["Australian","Cold Formed Steel (Lysaght)","Channels (Lipped)","LL10225"]
	Australian_Cold_Formed_Steel_Lysaght_Channels_Lipped_LL10230 = ["Australian","Cold Formed Steel (Lysaght)","Channels (Lipped)","LL10230"]
	Australian_Cold_Formed_Steel_Lysaght_Channels_Lipped_LL12725 = ["Australian","Cold Formed Steel (Lysaght)","Channels (Lipped)","LL12725"]
	Australian_Cold_Formed_Steel_Lysaght_Channels_Lipped_LL12730 = ["Australian","Cold Formed Steel (Lysaght)","Channels (Lipped)","LL12730"]
	Australian_Cold_Formed_Steel_Lysaght_Channels_Lipped_LL15230 = ["Australian","Cold Formed Steel (Lysaght)","Channels (Lipped)","LL15230"]
	Australian_Cold_Formed_Steel_Lysaght_Channels_Lipped_LL20330 = ["Australian","Cold Formed Steel (Lysaght)","Channels (Lipped)","LL20330"]
	Australian_Cold_Formed_Steel_Lysaght_Channels_LC05130 = ["Australian","Cold Formed Steel (Lysaght)","Channels","LC05130"]
	Australian_Cold_Formed_Steel_Lysaght_Channels_LC06425 = ["Australian","Cold Formed Steel (Lysaght)","Channels","LC06425"]
	Australian_Cold_Formed_Steel_Lysaght_Channels_LC07630 = ["Australian","Cold Formed Steel (Lysaght)","Channels","LC07630"]
	Australian_Cold_Formed_Steel_Lysaght_Channels_LC08330 = ["Australian","Cold Formed Steel (Lysaght)","Channels","LC08330"]
	Australian_Cold_Formed_Steel_Lysaght_Channels_LC08930 = ["Australian","Cold Formed Steel (Lysaght)","Channels","LC08930"]
	Australian_Cold_Formed_Steel_Lysaght_Channels_LC09530 = ["Australian","Cold Formed Steel (Lysaght)","Channels","LC09530"]
	Australian_Cold_Formed_Steel_Lysaght_Channels_LC10230 = ["Australian","Cold Formed Steel (Lysaght)","Channels","LC10230"]
	Australian_Cold_Formed_Steel_Lysaght_Channels_LC10330 = ["Australian","Cold Formed Steel (Lysaght)","Channels","LC10330"]
	Australian_Cold_Formed_Steel_Lysaght_Channels_LC12730 = ["Australian","Cold Formed Steel (Lysaght)","Channels","LC12730"]
	Australian_Cold_Formed_Steel_Lysaght_Channels_LC15230 = ["Australian","Cold Formed Steel (Lysaght)","Channels","LC15230"]
	Australian_Cold_Formed_Steel_Lysaght_Z_Sections_Lipped_Z10010 = ["Australian","Cold Formed Steel (Lysaght)","Z-Sections (Lipped)","Z10010"]
	Australian_Cold_Formed_Steel_Lysaght_Z_Sections_Lipped_Z10012 = ["Australian","Cold Formed Steel (Lysaght)","Z-Sections (Lipped)","Z10012"]
	Australian_Cold_Formed_Steel_Lysaght_Z_Sections_Lipped_Z10015 = ["Australian","Cold Formed Steel (Lysaght)","Z-Sections (Lipped)","Z10015"]
	Australian_Cold_Formed_Steel_Lysaght_Z_Sections_Lipped_Z10019 = ["Australian","Cold Formed Steel (Lysaght)","Z-Sections (Lipped)","Z10019"]
	Australian_Cold_Formed_Steel_Lysaght_Z_Sections_Lipped_Z15012 = ["Australian","Cold Formed Steel (Lysaght)","Z-Sections (Lipped)","Z15012"]
	Australian_Cold_Formed_Steel_Lysaght_Z_Sections_Lipped_Z15015 = ["Australian","Cold Formed Steel (Lysaght)","Z-Sections (Lipped)","Z15015"]
	Australian_Cold_Formed_Steel_Lysaght_Z_Sections_Lipped_Z15019 = ["Australian","Cold Formed Steel (Lysaght)","Z-Sections (Lipped)","Z15019"]
	Australian_Cold_Formed_Steel_Lysaght_Z_Sections_Lipped_Z15024 = ["Australian","Cold Formed Steel (Lysaght)","Z-Sections (Lipped)","Z15024"]
	Australian_Cold_Formed_Steel_Lysaght_Z_Sections_Lipped_Z20015 = ["Australian","Cold Formed Steel (Lysaght)","Z-Sections (Lipped)","Z20015"]
	Australian_Cold_Formed_Steel_Lysaght_Z_Sections_Lipped_Z20019 = ["Australian","Cold Formed Steel (Lysaght)","Z-Sections (Lipped)","Z20019"]
	Australian_Cold_Formed_Steel_Lysaght_Z_Sections_Lipped_Z20024 = ["Australian","Cold Formed Steel (Lysaght)","Z-Sections (Lipped)","Z20024"]
	Australian_Cold_Formed_Steel_Lysaght_Z_Sections_Lipped_Z25019 = ["Australian","Cold Formed Steel (Lysaght)","Z-Sections (Lipped)","Z25019"]
	Australian_Cold_Formed_Steel_Lysaght_Z_Sections_Lipped_Z25024 = ["Australian","Cold Formed Steel (Lysaght)","Z-Sections (Lipped)","Z25024"]
	Australian_Cold_Formed_Steel_Lysaght_Z_Sections_Lipped_Z30024 = ["Australian","Cold Formed Steel (Lysaght)","Z-Sections (Lipped)","Z30024"]
	Australian_Cold_Formed_Steel_Lysaght_Z_Sections_Lipped_Z30030 = ["Australian","Cold Formed Steel (Lysaght)","Z-Sections (Lipped)","Z30030"]
	Australian_Cold_Formed_Steel_Lysaght_Z_Sections_Lipped_Z35030 = ["Australian","Cold Formed Steel (Lysaght)","Z-Sections (Lipped)","Z35030"]
	Australian_Aluminium_Flat_bars_ALFL__150_10_00 = ["Australian","Aluminium","Flat bars","ALFL--150-10.00"]
	Australian_Aluminium_Flat_bars_ALFL_9_55_2_90 = ["Australian","Aluminium","Flat bars","ALFL-9.55-2.90"]
	Australian_Aluminium_Flat_bars_ALFL_25_3 = ["Australian","Aluminium","Flat bars","ALFL-25-3"]
	Australian_Aluminium_Flat_bars_ALFL_25_3_00 = ["Australian","Aluminium","Flat bars","ALFL-25-3.00"]
	Australian_Aluminium_Flat_bars_ALFL_25_6 = ["Australian","Aluminium","Flat bars","ALFL-25-6"]
	Australian_Aluminium_Flat_bars_ALFL_25_0_10_00 = ["Australian","Aluminium","Flat bars","ALFL-25.0-10.00"]
	Australian_Aluminium_Flat_bars_ALFL_32_3 = ["Australian","Aluminium","Flat bars","ALFL-32-3"]
	Australian_Aluminium_Flat_bars_ALFL_32_6 = ["Australian","Aluminium","Flat bars","ALFL-32-6"]
	Australian_Aluminium_Flat_bars_ALFL_40_3 = ["Australian","Aluminium","Flat bars","ALFL-40-3"]
	Australian_Aluminium_Flat_bars_ALFL_40_3_00 = ["Australian","Aluminium","Flat bars","ALFL-40-3.00"]
	Australian_Aluminium_Flat_bars_ALFL_40_6 = ["Australian","Aluminium","Flat bars","ALFL-40-6"]
	Australian_Aluminium_Flat_bars_ALFL_40_10 = ["Australian","Aluminium","Flat bars","ALFL-40-10"]
	Australian_Aluminium_Flat_bars_ALFL_50_3 = ["Australian","Aluminium","Flat bars","ALFL-50-3"]
	Australian_Aluminium_Flat_bars_ALFL_50_4_00 = ["Australian","Aluminium","Flat bars","ALFL-50-4.00"]
	Australian_Aluminium_Flat_bars_ALFL_50_6 = ["Australian","Aluminium","Flat bars","ALFL-50-6"]
	Australian_Aluminium_Flat_bars_ALFL_50_6_00 = ["Australian","Aluminium","Flat bars","ALFL-50-6.00"]
	Australian_Aluminium_Flat_bars_ALFL_50_10 = ["Australian","Aluminium","Flat bars","ALFL-50-10"]
	Australian_Aluminium_Flat_bars_ALFL_50_10_00 = ["Australian","Aluminium","Flat bars","ALFL-50-10.00"]
	Australian_Aluminium_Flat_bars_ALFL_50_12 = ["Australian","Aluminium","Flat bars","ALFL-50-12"]
	Australian_Aluminium_Flat_bars_ALFL_60_3 = ["Australian","Aluminium","Flat bars","ALFL-60-3"]
	Australian_Aluminium_Flat_bars_ALFL_60_6 = ["Australian","Aluminium","Flat bars","ALFL-60-6"]
	Australian_Aluminium_Flat_bars_ALFL_60_10 = ["Australian","Aluminium","Flat bars","ALFL-60-10"]
	Australian_Aluminium_Flat_bars_ALFL_80_3 = ["Australian","Aluminium","Flat bars","ALFL-80-3"]
	Australian_Aluminium_Flat_bars_ALFL_80_6 = ["Australian","Aluminium","Flat bars","ALFL-80-6"]
	Australian_Aluminium_Flat_bars_ALFL_80_6_00 = ["Australian","Aluminium","Flat bars","ALFL-80-6.00"]
	Australian_Aluminium_Flat_bars_ALFL_80_10 = ["Australian","Aluminium","Flat bars","ALFL-80-10"]
	Australian_Aluminium_Flat_bars_ALFL_80_10_00 = ["Australian","Aluminium","Flat bars","ALFL-80-10.00"]
	Australian_Aluminium_Flat_bars_ALFL_80_12 = ["Australian","Aluminium","Flat bars","ALFL-80-12"]
	Australian_Aluminium_Flat_bars_ALFL_100_3 = ["Australian","Aluminium","Flat bars","ALFL-100-3"]
	Australian_Aluminium_Flat_bars_ALFL_100_4 = ["Australian","Aluminium","Flat bars","ALFL-100-4"]
	Australian_Aluminium_Flat_bars_ALFL_100_6 = ["Australian","Aluminium","Flat bars","ALFL-100-6"]
	Australian_Aluminium_Flat_bars_ALFL_100_10 = ["Australian","Aluminium","Flat bars","ALFL-100-10"]
	Australian_Aluminium_Flat_bars_ALFL_100_12 = ["Australian","Aluminium","Flat bars","ALFL-100-12"]
	Australian_Aluminium_Flat_bars_ALFL_120_10 = ["Australian","Aluminium","Flat bars","ALFL-120-10"]
	Australian_Aluminium_Flat_bars_ALFL_150_10_00 = ["Australian","Aluminium","Flat bars","ALFL-150-10.00"]
	Australian_Aluminium_Flat_bars_ALFL_160_6 = ["Australian","Aluminium","Flat bars","ALFL-160-6"]
	Australian_Aluminium_Flat_bars_ALFL_160_10 = ["Australian","Aluminium","Flat bars","ALFL-160-10"]
	Australian_Aluminium_Flat_bars_ALFL20_3 = ["Australian","Aluminium","Flat bars","ALFL20-3"]
	Australian_Aluminium_Round_bars_ALRD_010_00 = ["Australian","Aluminium","Round bars","ALRD-010.00"]
	Australian_Aluminium_Round_bars_ALRD_012_00 = ["Australian","Aluminium","Round bars","ALRD-012.00"]
	Australian_Aluminium_Round_bars_ALRD_016_00 = ["Australian","Aluminium","Round bars","ALRD-016.00"]
	Australian_Aluminium_Round_bars_ALRD_020_00 = ["Australian","Aluminium","Round bars","ALRD-020.00"]
	Australian_Aluminium_Round_bars_ALRD_025_40 = ["Australian","Aluminium","Round bars","ALRD-025.40"]
	Australian_Aluminium_Round_bars_ALRD_050_0 = ["Australian","Aluminium","Round bars","ALRD-050.0"]
	Australian_Aluminium_Channels_ALCH_10_10_1_6_1_6 = ["Australian","Aluminium","Channels","ALCH-10-10-1.6-1.6"]
	Australian_Aluminium_Channels_ALCH_25_25_3_3 = ["Australian","Aluminium","Channels","ALCH-25-25-3-3"]
	Australian_Aluminium_Channels_ALCH_29_16_1_2_1_2 = ["Australian","Aluminium","Channels","ALCH-29-16-1.2-1.2"]
	Australian_Aluminium_Channels_ALCH_32_16_1_2_1_2 = ["Australian","Aluminium","Channels","ALCH-32-16-1.2-1.2"]
	Australian_Aluminium_Channels_ALCH_32_25_3_3 = ["Australian","Aluminium","Channels","ALCH-32-25-3-3"]
	Australian_Aluminium_Channels_ALCH_040_012_1_4 = ["Australian","Aluminium","Channels","ALCH-040-012-1.4"]
	Australian_Aluminium_Channels_ALCH_40_20_2_2 = ["Australian","Aluminium","Channels","ALCH-40-20-2-2"]
	Australian_Aluminium_Channels_ALCH_40_20_3_3 = ["Australian","Aluminium","Channels","ALCH-40-20-3-3"]
	Australian_Aluminium_Channels_ALCH_40_25_3_3 = ["Australian","Aluminium","Channels","ALCH-40-25-3-3"]
	Australian_Aluminium_Channels_ALCH_44_25_3_2_3_2 = ["Australian","Aluminium","Channels","ALCH-44-25-3.2-3.2"]
	Australian_Aluminium_Channels_ALCH_50_25_3_0_3_0 = ["Australian","Aluminium","Channels","ALCH-50-25-3.0-3.0"]
	Australian_Aluminium_Channels_ALCH_60_32_3_3 = ["Australian","Aluminium","Channels","ALCH-60-32-3-3"]
	Australian_Aluminium_Channels_ALCH_63_5_20_1_5 = ["Australian","Aluminium","Channels","ALCH-63.5-20-1.5"]
	Australian_Aluminium_Channels_ALCH_76_38_4_4 = ["Australian","Aluminium","Channels","ALCH-76-38-4-4"]
	Australian_Aluminium_Channels_ALCH_80_40_4_4 = ["Australian","Aluminium","Channels","ALCH-80-40-4-4"]
	Australian_Aluminium_Channels_ALCH_80_40_6_6 = ["Australian","Aluminium","Channels","ALCH-80-40-6-6"]
	Australian_Aluminium_Channels_ALCH_80_40_6_8 = ["Australian","Aluminium","Channels","ALCH-80-40-6-8"]
	Australian_Aluminium_Channels_ALCH_100_50_5_5 = ["Australian","Aluminium","Channels","ALCH-100-50-5-5"]
	Australian_Aluminium_Channels_ALCH_102_51_7_9_6_3 = ["Australian","Aluminium","Channels","ALCH-102-51-7.9-6.3"]
	Australian_Aluminium_Channels_ALCH_152_64_7_9_6_3 = ["Australian","Aluminium","Channels","ALCH-152-64-7.9-6.3"]
	Australian_Aluminium_Channels_ALCH_178_76_11_1_6_3 = ["Australian","Aluminium","Channels","ALCH-178-76-11.1-6.3"]
	Australian_Aluminium_Channels_ALCH_16016_1_6_1_6 = ["Australian","Aluminium","Channels","ALCH-16016-1.6-1.6"]
	Australian_Aluminium_Rectangular_tubes_ALRET_38_16_16 = ["Australian","Aluminium","Rectangular tubes","ALRET-38-16-16"]
	Australian_Aluminium_Rectangular_tubes_ALRET_38_25_15 = ["Australian","Aluminium","Rectangular tubes","ALRET-38-25-15"]
	Australian_Aluminium_Rectangular_tubes_ALRET_40_25_18 = ["Australian","Aluminium","Rectangular tubes","ALRET-40-25-18"]
	Australian_Aluminium_Rectangular_tubes_ALRET_40_25_25 = ["Australian","Aluminium","Rectangular tubes","ALRET-40-25-25"]
	Australian_Aluminium_Rectangular_tubes_ALRET_50_25_2 = ["Australian","Aluminium","Rectangular tubes","ALRET-50-25-2"]
	Australian_Aluminium_Rectangular_tubes_ALRET_50_25_3 = ["Australian","Aluminium","Rectangular tubes","ALRET-50-25-3"]
	Australian_Aluminium_Rectangular_tubes_ALRET_50_25_16 = ["Australian","Aluminium","Rectangular tubes","ALRET-50-25-16"]
	Australian_Aluminium_Rectangular_tubes_ALRET_50_40_1_8 = ["Australian","Aluminium","Rectangular tubes","ALRET-50-40-1.8"]
	Australian_Aluminium_Rectangular_tubes_ALRET_50_40_3 = ["Australian","Aluminium","Rectangular tubes","ALRET-50-40-3"]
	Australian_Aluminium_Rectangular_tubes_ALRET_60_40_3 = ["Australian","Aluminium","Rectangular tubes","ALRET-60-40-3"]
	Australian_Aluminium_Rectangular_tubes_ALRET_60_40_21 = ["Australian","Aluminium","Rectangular tubes","ALRET-60-40-21"]
	Australian_Aluminium_Rectangular_tubes_ALRET_65_16_14 = ["Australian","Aluminium","Rectangular tubes","ALRET-65-16-14"]
	Australian_Aluminium_Rectangular_tubes_ALRET_67_47_3 = ["Australian","Aluminium","Rectangular tubes","ALRET-67-47-3"]
	Australian_Aluminium_Rectangular_tubes_ALRET_70_30_3 = ["Australian","Aluminium","Rectangular tubes","ALRET-70-30-3"]
	Australian_Aluminium_Rectangular_tubes_ALRET_76_25_2_4 = ["Australian","Aluminium","Rectangular tubes","ALRET-76-25-2.4"]
	Australian_Aluminium_Rectangular_tubes_ALRET_80_40_3 = ["Australian","Aluminium","Rectangular tubes","ALRET-80-40-3"]
	Australian_Aluminium_Rectangular_tubes_ALRET_80_50_3 = ["Australian","Aluminium","Rectangular tubes","ALRET-80-50-3"]
	Australian_Aluminium_Rectangular_tubes_ALRET_100_25_25 = ["Australian","Aluminium","Rectangular tubes","ALRET-100-25-25"]
	Australian_Aluminium_Rectangular_tubes_ALRET_100_50_3 = ["Australian","Aluminium","Rectangular tubes","ALRET-100-50-3"]
	Australian_Aluminium_Rectangular_tubes_ALRET_100_50_6 = ["Australian","Aluminium","Rectangular tubes","ALRET-100-50-6"]
	Australian_Aluminium_Rectangular_tubes_ALRET_150_50_3 = ["Australian","Aluminium","Rectangular tubes","ALRET-150-50-3"]
	Australian_Aluminium_Rectangular_tubes_ALRET_152_38_32 = ["Australian","Aluminium","Rectangular tubes","ALRET-152-38-32"]
	Australian_Aluminium_Rectangular_tubes_ALRET_200_50_3 = ["Australian","Aluminium","Rectangular tubes","ALRET-200-50-3"]
	Australian_Aluminium_Rectangular_tubes_ALRET100_50_3 = ["Australian","Aluminium","Rectangular tubes","ALRET100-50-3"]
	Australian_Aluminium_Square_tubes_ALSQT_12_7_1_6 = ["Australian","Aluminium","Square tubes","ALSQT-12.7-1.6"]
	Australian_Aluminium_Square_tubes_ALSQT_16_1_5 = ["Australian","Aluminium","Square tubes","ALSQT-16-1.5"]
	Australian_Aluminium_Square_tubes_ALSQT_19_05_1_57 = ["Australian","Aluminium","Square tubes","ALSQT-19.05-1.57"]
	Australian_Aluminium_Square_tubes_ALSQT_20_3 = ["Australian","Aluminium","Square tubes","ALSQT-20-3"]
	Australian_Aluminium_Square_tubes_ALSQT_25_1_5 = ["Australian","Aluminium","Square tubes","ALSQT-25-1.5"]
	Australian_Aluminium_Square_tubes_ALSQT_25_2 = ["Australian","Aluminium","Square tubes","ALSQT-25-2"]
	Australian_Aluminium_Square_tubes_ALSQT_25_3 = ["Australian","Aluminium","Square tubes","ALSQT-25-3"]
	Australian_Aluminium_Square_tubes_ALSQT_25_4_1_2 = ["Australian","Aluminium","Square tubes","ALSQT-25.4-1.2"]
	Australian_Aluminium_Square_tubes_ALSQT_25_4_1_22 = ["Australian","Aluminium","Square tubes","ALSQT-25.4-1.22"]
	Australian_Aluminium_Square_tubes_ALSQT_32_2 = ["Australian","Aluminium","Square tubes","ALSQT-32-2"]
	Australian_Aluminium_Square_tubes_ALSQT_32_3 = ["Australian","Aluminium","Square tubes","ALSQT-32-3"]
	Australian_Aluminium_Square_tubes_ALSQT_40_1_6 = ["Australian","Aluminium","Square tubes","ALSQT-40-1.6"]
	Australian_Aluminium_Square_tubes_ALSQT_40_2 = ["Australian","Aluminium","Square tubes","ALSQT-40-2"]
	Australian_Aluminium_Square_tubes_ALSQT_40_2_5 = ["Australian","Aluminium","Square tubes","ALSQT-40-2.5"]
	Australian_Aluminium_Square_tubes_ALSQT_40_3 = ["Australian","Aluminium","Square tubes","ALSQT-40-3"]
	Australian_Aluminium_Square_tubes_ALSQT_044_5_2_5 = ["Australian","Aluminium","Square tubes","ALSQT-044.5-2.5"]
	Australian_Aluminium_Square_tubes_ALSQT_50_1 = ["Australian","Aluminium","Square tubes","ALSQT-50-1"]
	Australian_Aluminium_Square_tubes_ALSQT_50_1_6 = ["Australian","Aluminium","Square tubes","ALSQT-50-1.6"]
	Australian_Aluminium_Square_tubes_ALSQT_50_2 = ["Australian","Aluminium","Square tubes","ALSQT-50-2"]
	Australian_Aluminium_Square_tubes_ALSQT_50_2_5 = ["Australian","Aluminium","Square tubes","ALSQT-50-2.5"]
	Australian_Aluminium_Square_tubes_ALSQT_50_3 = ["Australian","Aluminium","Square tubes","ALSQT-50-3"]
	Australian_Aluminium_Square_tubes_ALSQT_50_0_3_0 = ["Australian","Aluminium","Square tubes","ALSQT-50.0-3.0"]
	Australian_Aluminium_Square_tubes_ALSQT_50_0_5_0 = ["Australian","Aluminium","Square tubes","ALSQT-50.0-5.0"]
	Australian_Aluminium_Square_tubes_ALSQT_50_8_2_03 = ["Australian","Aluminium","Square tubes","ALSQT-50.8-2.03"]
	Australian_Aluminium_Square_tubes_ALSQT_50_8_3_18 = ["Australian","Aluminium","Square tubes","ALSQT-50.8-3.18"]
	Australian_Aluminium_Square_tubes_ALSQT_65_0_3_0 = ["Australian","Aluminium","Square tubes","ALSQT-65.0-3.0"]
	Australian_Aluminium_Square_tubes_ALSQT_76_2_6_35 = ["Australian","Aluminium","Square tubes","ALSQT-76.2-6.35"]
	Australian_Aluminium_Square_tubes_ALSQT_80_2_5 = ["Australian","Aluminium","Square tubes","ALSQT-80-2.5"]
	Australian_Aluminium_Square_tubes_ALSQT_100_6 = ["Australian","Aluminium","Square tubes","ALSQT-100-6"]
	Australian_Aluminium_Square_tubes_ALSQT_100_00_3_00 = ["Australian","Aluminium","Square tubes","ALSQT-100.00-3.00"]
	Australian_Aluminium_Unequal_angles_ALAN_20_12_1_5 = ["Australian","Aluminium","Unequal angles","ALAN-20-12-1.5"]
	Australian_Aluminium_Unequal_angles_ALAN_25_12_1_5 = ["Australian","Aluminium","Unequal angles","ALAN-25-12-1.5"]
	Australian_Aluminium_Unequal_angles_ALAN_32_20_1_6 = ["Australian","Aluminium","Unequal angles","ALAN-32-20-1.6"]
	Australian_Aluminium_Unequal_angles_ALAN_40_20_1_60 = ["Australian","Aluminium","Unequal angles","ALAN-40-20-1.60"]
	Australian_Aluminium_Unequal_angles_ALAN_40_25_1_60 = ["Australian","Aluminium","Unequal angles","ALAN-40-25-1.60"]
	Australian_Aluminium_Unequal_angles_ALAN_40_25_3 = ["Australian","Aluminium","Unequal angles","ALAN-40-25-3"]
	Australian_Aluminium_Unequal_angles_ALAN_50_25_1_60 = ["Australian","Aluminium","Unequal angles","ALAN-50-25-1.60"]
	Australian_Aluminium_Unequal_angles_ALAN_50_25_3 = ["Australian","Aluminium","Unequal angles","ALAN-50-25-3"]
	Australian_Aluminium_Unequal_angles_ALAN_76_55_5 = ["Australian","Aluminium","Unequal angles","ALAN-76-55-5"]
	Australian_Aluminium_Unequal_angles_ALAN_100_50_3_0 = ["Australian","Aluminium","Unequal angles","ALAN-100-50-3.0"]
	Australian_Aluminium_Unequal_angles_ALAN_100_50_6 = ["Australian","Aluminium","Unequal angles","ALAN-100-50-6"]
	Australian_Aluminium_Equal_angles_ALAN_12_12_1_6 = ["Australian","Aluminium","Equal angles","ALAN-12-12-1.6"]
	Australian_Aluminium_Equal_angles_ALAN_20_20_1_6 = ["Australian","Aluminium","Equal angles","ALAN-20-20-1.6"]
	Australian_Aluminium_Equal_angles_ALAN_20_20_3 = ["Australian","Aluminium","Equal angles","ALAN-20-20-3"]
	Australian_Aluminium_Equal_angles_ALAN_25_25_1_6 = ["Australian","Aluminium","Equal angles","ALAN-25-25-1.6"]
	Australian_Aluminium_Equal_angles_ALAN_25_25_3 = ["Australian","Aluminium","Equal angles","ALAN-25-25-3"]
	Australian_Aluminium_Equal_angles_ALAN_32_32_3 = ["Australian","Aluminium","Equal angles","ALAN-32-32-3"]
	Australian_Aluminium_Equal_angles_ALAN_40_40_1_6 = ["Australian","Aluminium","Equal angles","ALAN-40-40-1.6"]
	Australian_Aluminium_Equal_angles_ALAN_40_40_3 = ["Australian","Aluminium","Equal angles","ALAN-40-40-3"]
	Australian_Aluminium_Equal_angles_ALAN_40_40_4 = ["Australian","Aluminium","Equal angles","ALAN-40-40-4"]
	Australian_Aluminium_Equal_angles_ALAN_40_40_4_00 = ["Australian","Aluminium","Equal angles","ALAN-40-40-4.00"]
	Australian_Aluminium_Equal_angles_ALAN_40_40_6 = ["Australian","Aluminium","Equal angles","ALAN-40-40-6"]
	Australian_Aluminium_Equal_angles_ALAN_50_50_1_6 = ["Australian","Aluminium","Equal angles","ALAN-50-50-1.6"]
	Australian_Aluminium_Equal_angles_ALAN_50_50_3 = ["Australian","Aluminium","Equal angles","ALAN-50-50-3"]
	Australian_Aluminium_Equal_angles_ALAN_50_50_4 = ["Australian","Aluminium","Equal angles","ALAN-50-50-4"]
	Australian_Aluminium_Equal_angles_ALAN_50_50_6 = ["Australian","Aluminium","Equal angles","ALAN-50-50-6"]
	Australian_Aluminium_Equal_angles_ALAN_50_50_6_00 = ["Australian","Aluminium","Equal angles","ALAN-50-50-6.00"]
	Australian_Aluminium_Equal_angles_ALAN_76_76_9_53 = ["Australian","Aluminium","Equal angles","ALAN-76-76-9.53"]
	Australian_Aluminium_Equal_angles_ALAN_80_80_6 = ["Australian","Aluminium","Equal angles","ALAN-80-80-6"]
	Australian_Aluminium_Round_tubes_ALRT_10_1_6 = ["Australian","Aluminium","Round tubes","ALRT-10-1.6"]
	Australian_Aluminium_Round_tubes_ALRT_12_1_6 = ["Australian","Aluminium","Round tubes","ALRT-12-1.6"]
	Australian_Aluminium_Round_tubes_ALRT_15_88_1_22 = ["Australian","Aluminium","Round tubes","ALRT-15.88-1.22"]
	Australian_Aluminium_Round_tubes_ALRT_16_1_2 = ["Australian","Aluminium","Round tubes","ALRT-16-1.2"]
	Australian_Aluminium_Round_tubes_ALRT_16_1_6 = ["Australian","Aluminium","Round tubes","ALRT-16-1.6"]
	Australian_Aluminium_Round_tubes_ALRT_19_1_2 = ["Australian","Aluminium","Round tubes","ALRT-19-1.2"]
	Australian_Aluminium_Round_tubes_ALRT_20_1_6 = ["Australian","Aluminium","Round tubes","ALRT-20-1.6"]
	Australian_Aluminium_Round_tubes_ALRT_20_3 = ["Australian","Aluminium","Round tubes","ALRT-20-3"]
	Australian_Aluminium_Round_tubes_ALRT_25_1_6 = ["Australian","Aluminium","Round tubes","ALRT-25-1.6"]
	Australian_Aluminium_Round_tubes_ALRT_25_3 = ["Australian","Aluminium","Round tubes","ALRT-25-3"]
	Australian_Aluminium_Round_tubes_ALRT_32_1_6 = ["Australian","Aluminium","Round tubes","ALRT-32-1.6"]
	Australian_Aluminium_Round_tubes_ALRT_32_3 = ["Australian","Aluminium","Round tubes","ALRT-32-3"]
	Australian_Aluminium_Round_tubes_ALRT_38_1_3_25 = ["Australian","Aluminium","Round tubes","ALRT-38.1-3.25"]
	Australian_Aluminium_Round_tubes_ALRT_40_1_6 = ["Australian","Aluminium","Round tubes","ALRT-40-1.6"]
	Australian_Aluminium_Round_tubes_ALRT_44_45_3_25 = ["Australian","Aluminium","Round tubes","ALRT-44.45-3.25"]
	Australian_Aluminium_Round_tubes_ALRT_48_4_4_47 = ["Australian","Aluminium","Round tubes","ALRT-48.4-4.47"]
	Australian_Aluminium_Round_tubes_ALRT_50_2 = ["Australian","Aluminium","Round tubes","ALRT-50-2"]
	Australian_Aluminium_Round_tubes_ALRT_50_3 = ["Australian","Aluminium","Round tubes","ALRT-50-3"]
	Australian_Aluminium_Round_tubes_ALRT_50_4 = ["Australian","Aluminium","Round tubes","ALRT-50-4"]
	Australian_Aluminium_Round_tubes_ALRT_50_5 = ["Australian","Aluminium","Round tubes","ALRT-50-5"]
	Australian_Aluminium_Round_tubes_ALRT_50_6 = ["Australian","Aluminium","Round tubes","ALRT-50-6"]
	Australian_Aluminium_Round_tubes_ALRT_50_0_4_00 = ["Australian","Aluminium","Round tubes","ALRT-50.0-4.00"]
	Australian_Aluminium_Round_tubes_ALRT_60_2 = ["Australian","Aluminium","Round tubes","ALRT-60-2"]
	Australian_Aluminium_Round_tubes_ALRT_60_3 = ["Australian","Aluminium","Round tubes","ALRT-60-3"]
	Australian_Aluminium_Round_tubes_ALRT_60_5 = ["Australian","Aluminium","Round tubes","ALRT-60-5"]
	Australian_Aluminium_Round_tubes_ALRT_63_5_6_35 = ["Australian","Aluminium","Round tubes","ALRT-63.5-6.35"]
	Australian_Aluminium_Round_tubes_ALRT_76_1_6 = ["Australian","Aluminium","Round tubes","ALRT-76-1.6"]
	Australian_Aluminium_Round_tubes_ALRT_76_2_4_75 = ["Australian","Aluminium","Round tubes","ALRT-76.2-4.75"]
	Australian_Aluminium_Round_tubes_ALRT_76_2_6_35 = ["Australian","Aluminium","Round tubes","ALRT-76.2-6.35"]
	Australian_Aluminium_Round_tubes_ALRT_80_3 = ["Australian","Aluminium","Round tubes","ALRT-80-3"]
	Australian_Aluminium_Round_tubes_ALRT_88_9_5_35 = ["Australian","Aluminium","Round tubes","ALRT-88.9-5.35"]
	Australian_Aluminium_Round_tubes_ALRT_100_3 = ["Australian","Aluminium","Round tubes","ALRT-100-3"]
	Australian_Aluminium_Round_tubes_ALRT_100_6 = ["Australian","Aluminium","Round tubes","ALRT-100-6"]
	Australian_Aluminium_Round_tubes_ALRT_101_6_1_8 = ["Australian","Aluminium","Round tubes","ALRT-101.6-1.8"]
	Australian_Aluminium_Round_tubes_ALRT_127_1_6 = ["Australian","Aluminium","Round tubes","ALRT-127-1.6"]
	Australian_Aluminium_Round_tubes_ALRT_152_2_03 = ["Australian","Aluminium","Round tubes","ALRT-152-2.03"]
	Australian_Aluminium_Round_tubes_ALRT_203_2_3 = ["Australian","Aluminium","Round tubes","ALRT-203.2-3"]
	Australian_Aluminium_Round_tubes_ALRT_MF_40_3 = ["Australian","Aluminium","Round tubes","ALRT-MF-40-3"]
	Australian_Aluminium_Tees_ALTE_40_40_4_4 = ["Australian","Aluminium","Tees","ALTE-40-40-4-4"]
	Australian_Aluminium_Tees_ALTE_50_50_4_4 = ["Australian","Aluminium","Tees","ALTE-50-50-4-4"]
	Australian_Aluminium_Tees_ALTE_50_50_6_6 = ["Australian","Aluminium","Tees","ALTE-50-50-6-6"]
	Australian_Wood_GluLam_GL8_130x38 = ["Australian","Wood","GluLam GL8","130x38"]
	Australian_Wood_GluLam_GL8_130x60 = ["Australian","Wood","GluLam GL8","130x60"]
	Australian_Wood_GluLam_GL8_130x80 = ["Australian","Wood","GluLam GL8","130x80"]
	Australian_Wood_GluLam_GL8_130x110 = ["Australian","Wood","GluLam GL8","130x110"]
	Australian_Wood_GluLam_GL8_165x38 = ["Australian","Wood","GluLam GL8","165x38"]
	Australian_Wood_GluLam_GL8_165x60 = ["Australian","Wood","GluLam GL8","165x60"]
	Australian_Wood_GluLam_GL8_165x80 = ["Australian","Wood","GluLam GL8","165x80"]
	Australian_Wood_GluLam_GL8_165x110 = ["Australian","Wood","GluLam GL8","165x110"]
	Australian_Wood_GluLam_GL8_195x38 = ["Australian","Wood","GluLam GL8","195x38"]
	Australian_Wood_GluLam_GL8_195x60 = ["Australian","Wood","GluLam GL8","195x60"]
	Australian_Wood_GluLam_GL8_195x80 = ["Australian","Wood","GluLam GL8","195x80"]
	Australian_Wood_GluLam_GL8_195x110 = ["Australian","Wood","GluLam GL8","195x110"]
	Australian_Wood_GluLam_GL8_230x38 = ["Australian","Wood","GluLam GL8","230x38"]
	Australian_Wood_GluLam_GL8_230x60 = ["Australian","Wood","GluLam GL8","230x60"]
	Australian_Wood_GluLam_GL8_230x80 = ["Australian","Wood","GluLam GL8","230x80"]
	Australian_Wood_GluLam_GL8_230x110 = ["Australian","Wood","GluLam GL8","230x110"]
	Australian_Wood_GluLam_GL8_260x38 = ["Australian","Wood","GluLam GL8","260x38"]
	Australian_Wood_GluLam_GL8_260x60 = ["Australian","Wood","GluLam GL8","260x60"]
	Australian_Wood_GluLam_GL8_260x80 = ["Australian","Wood","GluLam GL8","260x80"]
	Australian_Wood_GluLam_GL8_260x110 = ["Australian","Wood","GluLam GL8","260x110"]
	Australian_Wood_GluLam_GL8_295x38 = ["Australian","Wood","GluLam GL8","295x38"]
	Australian_Wood_GluLam_GL8_295x60 = ["Australian","Wood","GluLam GL8","295x60"]
	Australian_Wood_GluLam_GL8_295x80 = ["Australian","Wood","GluLam GL8","295x80"]
	Australian_Wood_GluLam_GL8_295x110 = ["Australian","Wood","GluLam GL8","295x110"]
	Australian_Wood_GluLam_GL8_330x60 = ["Australian","Wood","GluLam GL8","330x60"]
	Australian_Wood_GluLam_GL8_330x80 = ["Australian","Wood","GluLam GL8","330x80"]
	Australian_Wood_GluLam_GL8_330x110 = ["Australian","Wood","GluLam GL8","330x110"]
	Australian_Wood_GluLam_GL8_360x60 = ["Australian","Wood","GluLam GL8","360x60"]
	Australian_Wood_GluLam_GL8_360x80 = ["Australian","Wood","GluLam GL8","360x80"]
	Australian_Wood_GluLam_GL8_360x110 = ["Australian","Wood","GluLam GL8","360x110"]
	Australian_Wood_GluLam_GL8_395x60 = ["Australian","Wood","GluLam GL8","395x60"]
	Australian_Wood_GluLam_GL8_395x80 = ["Australian","Wood","GluLam GL8","395x80"]
	Australian_Wood_GluLam_GL8_395x110 = ["Australian","Wood","GluLam GL8","395x110"]
	Australian_Wood_GluLam_GL8_425x60 = ["Australian","Wood","GluLam GL8","425x60"]
	Australian_Wood_GluLam_GL8_425x80 = ["Australian","Wood","GluLam GL8","425x80"]
	Australian_Wood_GluLam_GL8_425x110 = ["Australian","Wood","GluLam GL8","425x110"]
	Australian_Wood_GluLam_GL8_460x80 = ["Australian","Wood","GluLam GL8","460x80"]
	Australian_Wood_GluLam_GL8_460x110 = ["Australian","Wood","GluLam GL8","460x110"]
	Australian_Wood_GluLam_GL8_495x80 = ["Australian","Wood","GluLam GL8","495x80"]
	Australian_Wood_GluLam_GL8_495x110 = ["Australian","Wood","GluLam GL8","495x110"]
	Australian_Wood_GluLam_GL8_525x80 = ["Australian","Wood","GluLam GL8","525x80"]
	Australian_Wood_GluLam_GL8_525x110 = ["Australian","Wood","GluLam GL8","525x110"]
	Australian_Wood_GluLam_GL8_560x80 = ["Australian","Wood","GluLam GL8","560x80"]
	Australian_Wood_GluLam_GL8_560x110 = ["Australian","Wood","GluLam GL8","560x110"]
	Australian_Wood_GluLam_GL8_590x80 = ["Australian","Wood","GluLam GL8","590x80"]
	Australian_Wood_GluLam_GL8_590x110 = ["Australian","Wood","GluLam GL8","590x110"]
	Australian_Wood_GluLam_GL8_625x110 = ["Australian","Wood","GluLam GL8","625x110"]
	Australian_Wood_GluLam_GL8_655x110 = ["Australian","Wood","GluLam GL8","655x110"]
	Australian_Wood_GluLam_GL10_130x38 = ["Australian","Wood","GluLam GL10","130x38"]
	Australian_Wood_GluLam_GL10_130x60 = ["Australian","Wood","GluLam GL10","130x60"]
	Australian_Wood_GluLam_GL10_130x80 = ["Australian","Wood","GluLam GL10","130x80"]
	Australian_Wood_GluLam_GL10_130x110 = ["Australian","Wood","GluLam GL10","130x110"]
	Australian_Wood_GluLam_GL10_165x38 = ["Australian","Wood","GluLam GL10","165x38"]
	Australian_Wood_GluLam_GL10_165x60 = ["Australian","Wood","GluLam GL10","165x60"]
	Australian_Wood_GluLam_GL10_165x80 = ["Australian","Wood","GluLam GL10","165x80"]
	Australian_Wood_GluLam_GL10_165x110 = ["Australian","Wood","GluLam GL10","165x110"]
	Australian_Wood_GluLam_GL10_195x38 = ["Australian","Wood","GluLam GL10","195x38"]
	Australian_Wood_GluLam_GL10_195x60 = ["Australian","Wood","GluLam GL10","195x60"]
	Australian_Wood_GluLam_GL10_195x80 = ["Australian","Wood","GluLam GL10","195x80"]
	Australian_Wood_GluLam_GL10_195x110 = ["Australian","Wood","GluLam GL10","195x110"]
	Australian_Wood_GluLam_GL10_230x38 = ["Australian","Wood","GluLam GL10","230x38"]
	Australian_Wood_GluLam_GL10_230x60 = ["Australian","Wood","GluLam GL10","230x60"]
	Australian_Wood_GluLam_GL10_230x80 = ["Australian","Wood","GluLam GL10","230x80"]
	Australian_Wood_GluLam_GL10_230x110 = ["Australian","Wood","GluLam GL10","230x110"]
	Australian_Wood_GluLam_GL10_260x38 = ["Australian","Wood","GluLam GL10","260x38"]
	Australian_Wood_GluLam_GL10_260x60 = ["Australian","Wood","GluLam GL10","260x60"]
	Australian_Wood_GluLam_GL10_260x80 = ["Australian","Wood","GluLam GL10","260x80"]
	Australian_Wood_GluLam_GL10_260x110 = ["Australian","Wood","GluLam GL10","260x110"]
	Australian_Wood_GluLam_GL10_295x38 = ["Australian","Wood","GluLam GL10","295x38"]
	Australian_Wood_GluLam_GL10_295x60 = ["Australian","Wood","GluLam GL10","295x60"]
	Australian_Wood_GluLam_GL10_295x80 = ["Australian","Wood","GluLam GL10","295x80"]
	Australian_Wood_GluLam_GL10_295x110 = ["Australian","Wood","GluLam GL10","295x110"]
	Australian_Wood_GluLam_GL10_330x60 = ["Australian","Wood","GluLam GL10","330x60"]
	Australian_Wood_GluLam_GL10_330x80 = ["Australian","Wood","GluLam GL10","330x80"]
	Australian_Wood_GluLam_GL10_330x110 = ["Australian","Wood","GluLam GL10","330x110"]
	Australian_Wood_GluLam_GL10_360x60 = ["Australian","Wood","GluLam GL10","360x60"]
	Australian_Wood_GluLam_GL10_360x80 = ["Australian","Wood","GluLam GL10","360x80"]
	Australian_Wood_GluLam_GL10_360x110 = ["Australian","Wood","GluLam GL10","360x110"]
	Australian_Wood_GluLam_GL10_395x60 = ["Australian","Wood","GluLam GL10","395x60"]
	Australian_Wood_GluLam_GL10_395x80 = ["Australian","Wood","GluLam GL10","395x80"]
	Australian_Wood_GluLam_GL10_395x110 = ["Australian","Wood","GluLam GL10","395x110"]
	Australian_Wood_GluLam_GL10_425x60 = ["Australian","Wood","GluLam GL10","425x60"]
	Australian_Wood_GluLam_GL10_425x80 = ["Australian","Wood","GluLam GL10","425x80"]
	Australian_Wood_GluLam_GL10_425x110 = ["Australian","Wood","GluLam GL10","425x110"]
	Australian_Wood_GluLam_GL10_460x80 = ["Australian","Wood","GluLam GL10","460x80"]
	Australian_Wood_GluLam_GL10_460x110 = ["Australian","Wood","GluLam GL10","460x110"]
	Australian_Wood_GluLam_GL10_495x80 = ["Australian","Wood","GluLam GL10","495x80"]
	Australian_Wood_GluLam_GL10_495x110 = ["Australian","Wood","GluLam GL10","495x110"]
	Australian_Wood_GluLam_GL10_525x80 = ["Australian","Wood","GluLam GL10","525x80"]
	Australian_Wood_GluLam_GL10_525x110 = ["Australian","Wood","GluLam GL10","525x110"]
	Australian_Wood_GluLam_GL10_560x80 = ["Australian","Wood","GluLam GL10","560x80"]
	Australian_Wood_GluLam_GL10_560x110 = ["Australian","Wood","GluLam GL10","560x110"]
	Australian_Wood_GluLam_GL10_590x80 = ["Australian","Wood","GluLam GL10","590x80"]
	Australian_Wood_GluLam_GL10_590x110 = ["Australian","Wood","GluLam GL10","590x110"]
	Australian_Wood_GluLam_GL10_625x110 = ["Australian","Wood","GluLam GL10","625x110"]
	Australian_Wood_GluLam_GL10_655x110 = ["Australian","Wood","GluLam GL10","655x110"]
	Australian_Wood_GluLam_GL12_130x40 = ["Australian","Wood","GluLam GL12","130x40"]
	Australian_Wood_GluLam_GL12_130x65 = ["Australian","Wood","GluLam GL12","130x65"]
	Australian_Wood_GluLam_GL12_130x85 = ["Australian","Wood","GluLam GL12","130x85"]
	Australian_Wood_GluLam_GL12_130x115 = ["Australian","Wood","GluLam GL12","130x115"]
	Australian_Wood_GluLam_GL12_165x40 = ["Australian","Wood","GluLam GL12","165x40"]
	Australian_Wood_GluLam_GL12_165x65 = ["Australian","Wood","GluLam GL12","165x65"]
	Australian_Wood_GluLam_GL12_165x85 = ["Australian","Wood","GluLam GL12","165x85"]
	Australian_Wood_GluLam_GL12_165x115 = ["Australian","Wood","GluLam GL12","165x115"]
	Australian_Wood_GluLam_GL12_195x40 = ["Australian","Wood","GluLam GL12","195x40"]
	Australian_Wood_GluLam_GL12_195x65 = ["Australian","Wood","GluLam GL12","195x65"]
	Australian_Wood_GluLam_GL12_195x85 = ["Australian","Wood","GluLam GL12","195x85"]
	Australian_Wood_GluLam_GL12_195x115 = ["Australian","Wood","GluLam GL12","195x115"]
	Australian_Wood_GluLam_GL12_230x40 = ["Australian","Wood","GluLam GL12","230x40"]
	Australian_Wood_GluLam_GL12_230x65 = ["Australian","Wood","GluLam GL12","230x65"]
	Australian_Wood_GluLam_GL12_230x85 = ["Australian","Wood","GluLam GL12","230x85"]
	Australian_Wood_GluLam_GL12_230x115 = ["Australian","Wood","GluLam GL12","230x115"]
	Australian_Wood_GluLam_GL12_260x40 = ["Australian","Wood","GluLam GL12","260x40"]
	Australian_Wood_GluLam_GL12_260x65 = ["Australian","Wood","GluLam GL12","260x65"]
	Australian_Wood_GluLam_GL12_260x85 = ["Australian","Wood","GluLam GL12","260x85"]
	Australian_Wood_GluLam_GL12_260x115 = ["Australian","Wood","GluLam GL12","260x115"]
	Australian_Wood_GluLam_GL12_295x40 = ["Australian","Wood","GluLam GL12","295x40"]
	Australian_Wood_GluLam_GL12_295x65 = ["Australian","Wood","GluLam GL12","295x65"]
	Australian_Wood_GluLam_GL12_295x85 = ["Australian","Wood","GluLam GL12","295x85"]
	Australian_Wood_GluLam_GL12_295x115 = ["Australian","Wood","GluLam GL12","295x115"]
	Australian_Wood_GluLam_GL12_330x65 = ["Australian","Wood","GluLam GL12","330x65"]
	Australian_Wood_GluLam_GL12_330x85 = ["Australian","Wood","GluLam GL12","330x85"]
	Australian_Wood_GluLam_GL12_330x115 = ["Australian","Wood","GluLam GL12","330x115"]
	Australian_Wood_GluLam_GL12_360x65 = ["Australian","Wood","GluLam GL12","360x65"]
	Australian_Wood_GluLam_GL12_360x85 = ["Australian","Wood","GluLam GL12","360x85"]
	Australian_Wood_GluLam_GL12_360x115 = ["Australian","Wood","GluLam GL12","360x115"]
	Australian_Wood_GluLam_GL12_395x65 = ["Australian","Wood","GluLam GL12","395x65"]
	Australian_Wood_GluLam_GL12_395x85 = ["Australian","Wood","GluLam GL12","395x85"]
	Australian_Wood_GluLam_GL12_395x115 = ["Australian","Wood","GluLam GL12","395x115"]
	Australian_Wood_GluLam_GL12_425x65 = ["Australian","Wood","GluLam GL12","425x65"]
	Australian_Wood_GluLam_GL12_425x85 = ["Australian","Wood","GluLam GL12","425x85"]
	Australian_Wood_GluLam_GL12_425x115 = ["Australian","Wood","GluLam GL12","425x115"]
	Australian_Wood_GluLam_GL12_460x85 = ["Australian","Wood","GluLam GL12","460x85"]
	Australian_Wood_GluLam_GL12_460x115 = ["Australian","Wood","GluLam GL12","460x115"]
	Australian_Wood_GluLam_GL12_495x85 = ["Australian","Wood","GluLam GL12","495x85"]
	Australian_Wood_GluLam_GL12_495x115 = ["Australian","Wood","GluLam GL12","495x115"]
	Australian_Wood_GluLam_GL12_525x85 = ["Australian","Wood","GluLam GL12","525x85"]
	Australian_Wood_GluLam_GL12_525x115 = ["Australian","Wood","GluLam GL12","525x115"]
	Australian_Wood_GluLam_GL12_560x85 = ["Australian","Wood","GluLam GL12","560x85"]
	Australian_Wood_GluLam_GL12_560x115 = ["Australian","Wood","GluLam GL12","560x115"]
	Australian_Wood_GluLam_GL12_590x85 = ["Australian","Wood","GluLam GL12","590x85"]
	Australian_Wood_GluLam_GL12_590x115 = ["Australian","Wood","GluLam GL12","590x115"]
	Australian_Wood_GluLam_GL12_625x115 = ["Australian","Wood","GluLam GL12","625x115"]
	Australian_Wood_GluLam_GL12_655x115 = ["Australian","Wood","GluLam GL12","655x115"]
	Australian_Wood_GluLam_GL13_152x80 = ["Australian","Wood","GluLam GL13","152x80"]
	Australian_Wood_GluLam_GL13_152x130 = ["Australian","Wood","GluLam GL13","152x130"]
	Australian_Wood_GluLam_GL13_190x80 = ["Australian","Wood","GluLam GL13","190x80"]
	Australian_Wood_GluLam_GL13_190x130 = ["Australian","Wood","GluLam GL13","190x130"]
	Australian_Wood_GluLam_GL13_229x80 = ["Australian","Wood","GluLam GL13","229x80"]
	Australian_Wood_GluLam_GL13_229x130 = ["Australian","Wood","GluLam GL13","229x130"]
	Australian_Wood_GluLam_GL13_267x80 = ["Australian","Wood","GluLam GL13","267x80"]
	Australian_Wood_GluLam_GL13_267x130 = ["Australian","Wood","GluLam GL13","267x130"]
	Australian_Wood_GluLam_GL13_305x80 = ["Australian","Wood","GluLam GL13","305x80"]
	Australian_Wood_GluLam_GL13_305x130 = ["Australian","Wood","GluLam GL13","305x130"]
	Australian_Wood_GluLam_GL13_343x80 = ["Australian","Wood","GluLam GL13","343x80"]
	Australian_Wood_GluLam_GL13_343x130 = ["Australian","Wood","GluLam GL13","343x130"]
	Australian_Wood_GluLam_GL13_381x80 = ["Australian","Wood","GluLam GL13","381x80"]
	Australian_Wood_GluLam_GL13_381x130 = ["Australian","Wood","GluLam GL13","381x130"]
	Australian_Wood_GluLam_GL13_419x80 = ["Australian","Wood","GluLam GL13","419x80"]
	Australian_Wood_GluLam_GL13_419x130 = ["Australian","Wood","GluLam GL13","419x130"]
	Australian_Wood_GluLam_GL13_457x130 = ["Australian","Wood","GluLam GL13","457x130"]
	Australian_Wood_GluLam_GL13_495x130 = ["Australian","Wood","GluLam GL13","495x130"]
	Australian_Wood_GluLam_GL13_533x130 = ["Australian","Wood","GluLam GL13","533x130"]
	Australian_Wood_GluLam_GL13_572x130 = ["Australian","Wood","GluLam GL13","572x130"]
	Australian_Wood_GluLam_GL13_610x130 = ["Australian","Wood","GluLam GL13","610x130"]
	Australian_Wood_GluLam_GL13_648x130 = ["Australian","Wood","GluLam GL13","648x130"]
	Australian_Wood_GluLam_GL13_686x130 = ["Australian","Wood","GluLam GL13","686x130"]
	Australian_Wood_GluLam_GL17_130x40 = ["Australian","Wood","GluLam GL17","130x40"]
	Australian_Wood_GluLam_GL17_130x65 = ["Australian","Wood","GluLam GL17","130x65"]
	Australian_Wood_GluLam_GL17_130x85 = ["Australian","Wood","GluLam GL17","130x85"]
	Australian_Wood_GluLam_GL17_130x115 = ["Australian","Wood","GluLam GL17","130x115"]
	Australian_Wood_GluLam_GL17_165x40 = ["Australian","Wood","GluLam GL17","165x40"]
	Australian_Wood_GluLam_GL17_165x65 = ["Australian","Wood","GluLam GL17","165x65"]
	Australian_Wood_GluLam_GL17_165x85 = ["Australian","Wood","GluLam GL17","165x85"]
	Australian_Wood_GluLam_GL17_165x115 = ["Australian","Wood","GluLam GL17","165x115"]
	Australian_Wood_GluLam_GL17_195x40 = ["Australian","Wood","GluLam GL17","195x40"]
	Australian_Wood_GluLam_GL17_195x65 = ["Australian","Wood","GluLam GL17","195x65"]
	Australian_Wood_GluLam_GL17_195x85 = ["Australian","Wood","GluLam GL17","195x85"]
	Australian_Wood_GluLam_GL17_195x115 = ["Australian","Wood","GluLam GL17","195x115"]
	Australian_Wood_GluLam_GL17_230x40 = ["Australian","Wood","GluLam GL17","230x40"]
	Australian_Wood_GluLam_GL17_230x65 = ["Australian","Wood","GluLam GL17","230x65"]
	Australian_Wood_GluLam_GL17_230x85 = ["Australian","Wood","GluLam GL17","230x85"]
	Australian_Wood_GluLam_GL17_230x115 = ["Australian","Wood","GluLam GL17","230x115"]
	Australian_Wood_GluLam_GL17_260x40 = ["Australian","Wood","GluLam GL17","260x40"]
	Australian_Wood_GluLam_GL17_260x65 = ["Australian","Wood","GluLam GL17","260x65"]
	Australian_Wood_GluLam_GL17_260x85 = ["Australian","Wood","GluLam GL17","260x85"]
	Australian_Wood_GluLam_GL17_260x115 = ["Australian","Wood","GluLam GL17","260x115"]
	Australian_Wood_GluLam_GL17_295x40 = ["Australian","Wood","GluLam GL17","295x40"]
	Australian_Wood_GluLam_GL17_295x65 = ["Australian","Wood","GluLam GL17","295x65"]
	Australian_Wood_GluLam_GL17_295x85 = ["Australian","Wood","GluLam GL17","295x85"]
	Australian_Wood_GluLam_GL17_295x115 = ["Australian","Wood","GluLam GL17","295x115"]
	Australian_Wood_GluLam_GL17_330x65 = ["Australian","Wood","GluLam GL17","330x65"]
	Australian_Wood_GluLam_GL17_330x85 = ["Australian","Wood","GluLam GL17","330x85"]
	Australian_Wood_GluLam_GL17_330x115 = ["Australian","Wood","GluLam GL17","330x115"]
	Australian_Wood_GluLam_GL17_360x65 = ["Australian","Wood","GluLam GL17","360x65"]
	Australian_Wood_GluLam_GL17_360x85 = ["Australian","Wood","GluLam GL17","360x85"]
	Australian_Wood_GluLam_GL17_360x115 = ["Australian","Wood","GluLam GL17","360x115"]
	Australian_Wood_GluLam_GL17_395x65 = ["Australian","Wood","GluLam GL17","395x65"]
	Australian_Wood_GluLam_GL17_395x85 = ["Australian","Wood","GluLam GL17","395x85"]
	Australian_Wood_GluLam_GL17_395x115 = ["Australian","Wood","GluLam GL17","395x115"]
	Australian_Wood_GluLam_GL17_425x65 = ["Australian","Wood","GluLam GL17","425x65"]
	Australian_Wood_GluLam_GL17_425x85 = ["Australian","Wood","GluLam GL17","425x85"]
	Australian_Wood_GluLam_GL17_425x115 = ["Australian","Wood","GluLam GL17","425x115"]
	Australian_Wood_GluLam_GL17_460x85 = ["Australian","Wood","GluLam GL17","460x85"]
	Australian_Wood_GluLam_GL17_460x115 = ["Australian","Wood","GluLam GL17","460x115"]
	Australian_Wood_GluLam_GL17_495x85 = ["Australian","Wood","GluLam GL17","495x85"]
	Australian_Wood_GluLam_GL17_495x115 = ["Australian","Wood","GluLam GL17","495x115"]
	Australian_Wood_GluLam_GL17_525x85 = ["Australian","Wood","GluLam GL17","525x85"]
	Australian_Wood_GluLam_GL17_525x115 = ["Australian","Wood","GluLam GL17","525x115"]
	Australian_Wood_GluLam_GL17_560x85 = ["Australian","Wood","GluLam GL17","560x85"]
	Australian_Wood_GluLam_GL17_560x115 = ["Australian","Wood","GluLam GL17","560x115"]
	Australian_Wood_GluLam_GL17_590x85 = ["Australian","Wood","GluLam GL17","590x85"]
	Australian_Wood_GluLam_GL17_590x115 = ["Australian","Wood","GluLam GL17","590x115"]
	Australian_Wood_GluLam_GL17_625x115 = ["Australian","Wood","GluLam GL17","625x115"]
	Australian_Wood_GluLam_GL17_655x115 = ["Australian","Wood","GluLam GL17","655x115"]
	Australian_Wood_LVL_100x36 = ["Australian","Wood","LVL","100x36"]
	Australian_Wood_LVL_100x45 = ["Australian","Wood","LVL","100x45"]
	Australian_Wood_LVL_100x63 = ["Australian","Wood","LVL","100x63"]
	Australian_Wood_LVL_130x36 = ["Australian","Wood","LVL","130x36"]
	Australian_Wood_LVL_130x45 = ["Australian","Wood","LVL","130x45"]
	Australian_Wood_LVL_130x63 = ["Australian","Wood","LVL","130x63"]
	Australian_Wood_LVL_150x36 = ["Australian","Wood","LVL","150x36"]
	Australian_Wood_LVL_150x45 = ["Australian","Wood","LVL","150x45"]
	Australian_Wood_LVL_150x63 = ["Australian","Wood","LVL","150x63"]
	Australian_Wood_LVL_170x36 = ["Australian","Wood","LVL","170x36"]
	Australian_Wood_LVL_170x45 = ["Australian","Wood","LVL","170x45"]
	Australian_Wood_LVL_170x63 = ["Australian","Wood","LVL","170x63"]
	Australian_Wood_LVL_200x36 = ["Australian","Wood","LVL","200x36"]
	Australian_Wood_LVL_200x45 = ["Australian","Wood","LVL","200x45"]
	Australian_Wood_LVL_200x63 = ["Australian","Wood","LVL","200x63"]
	Australian_Wood_LVL_240x36 = ["Australian","Wood","LVL","240x36"]
	Australian_Wood_LVL_240x45 = ["Australian","Wood","LVL","240x45"]
	Australian_Wood_LVL_240x63 = ["Australian","Wood","LVL","240x63"]
	Australian_Wood_LVL_300x45 = ["Australian","Wood","LVL","300x45"]
	Australian_Wood_LVL_300x63 = ["Australian","Wood","LVL","300x63"]
	Australian_Wood_LVL_360x45 = ["Australian","Wood","LVL","360x45"]
	Australian_Wood_LVL_360x63 = ["Australian","Wood","LVL","360x63"]
	Australian_Wood_LVL_400x45 = ["Australian","Wood","LVL","400x45"]
	Australian_Wood_LVL_400x63 = ["Australian","Wood","LVL","400x63"]
	Australian_Wood_LVL_450x63 = ["Australian","Wood","LVL","450x63"]
	Australian_Wood_LVL_500x63 = ["Australian","Wood","LVL","500x63"]
	Australian_Wood_LVL_600x63 = ["Australian","Wood","LVL","600x63"]
	Australian_Wood_Seasoned_Timber_42x35 = ["Australian","Wood","Seasoned Timber","42x35"]
	Australian_Wood_Seasoned_Timber_42x45 = ["Australian","Wood","Seasoned Timber","42x45"]
	Australian_Wood_Seasoned_Timber_70x35 = ["Australian","Wood","Seasoned Timber","70x35"]
	Australian_Wood_Seasoned_Timber_70x45 = ["Australian","Wood","Seasoned Timber","70x45"]
	Australian_Wood_Seasoned_Timber_70x70 = ["Australian","Wood","Seasoned Timber","70x70"]
	Australian_Wood_Seasoned_Timber_90x35 = ["Australian","Wood","Seasoned Timber","90x35"]
	Australian_Wood_Seasoned_Timber_90x45 = ["Australian","Wood","Seasoned Timber","90x45"]
	Australian_Wood_Seasoned_Timber_90x70 = ["Australian","Wood","Seasoned Timber","90x70"]
	Australian_Wood_Seasoned_Timber_90x90 = ["Australian","Wood","Seasoned Timber","90x90"]
	Australian_Wood_Seasoned_Timber_120x35 = ["Australian","Wood","Seasoned Timber","120x35"]
	Australian_Wood_Seasoned_Timber_120x45 = ["Australian","Wood","Seasoned Timber","120x45"]
	Australian_Wood_Seasoned_Timber_120x70 = ["Australian","Wood","Seasoned Timber","120x70"]
	Australian_Wood_Seasoned_Timber_140x35 = ["Australian","Wood","Seasoned Timber","140x35"]
	Australian_Wood_Seasoned_Timber_140x45 = ["Australian","Wood","Seasoned Timber","140x45"]
	Australian_Wood_Seasoned_Timber_140x70 = ["Australian","Wood","Seasoned Timber","140x70"]
	Australian_Wood_Seasoned_Timber_170x35 = ["Australian","Wood","Seasoned Timber","170x35"]
	Australian_Wood_Seasoned_Timber_170x45 = ["Australian","Wood","Seasoned Timber","170x45"]
	Australian_Wood_Seasoned_Timber_170x70 = ["Australian","Wood","Seasoned Timber","170x70"]
	Australian_Wood_Seasoned_Timber_190x35 = ["Australian","Wood","Seasoned Timber","190x35"]
	Australian_Wood_Seasoned_Timber_190x45 = ["Australian","Wood","Seasoned Timber","190x45"]
	Australian_Wood_Seasoned_Timber_190x70 = ["Australian","Wood","Seasoned Timber","190x70"]
	Australian_Wood_Seasoned_Timber_240x35 = ["Australian","Wood","Seasoned Timber","240x35"]
	Australian_Wood_Seasoned_Timber_240x45 = ["Australian","Wood","Seasoned Timber","240x45"]
	Australian_Wood_Seasoned_Timber_240x70 = ["Australian","Wood","Seasoned Timber","240x70"]
	Australian_Wood_Seasoned_Timber_290x35 = ["Australian","Wood","Seasoned Timber","290x35"]
	Australian_Wood_Seasoned_Timber_290x45 = ["Australian","Wood","Seasoned Timber","290x45"]
	Australian_Wood_Seasoned_Timber_290x70 = ["Australian","Wood","Seasoned Timber","290x70"]
	Australian_Wood_Unseasoned_Timber_75x38 = ["Australian","Wood","Unseasoned Timber","75x38"]
	Australian_Wood_Unseasoned_Timber_75x50 = ["Australian","Wood","Unseasoned Timber","75x50"]
	Australian_Wood_Unseasoned_Timber_75x75 = ["Australian","Wood","Unseasoned Timber","75x75"]
	Australian_Wood_Unseasoned_Timber_100x38 = ["Australian","Wood","Unseasoned Timber","100x38"]
	Australian_Wood_Unseasoned_Timber_100x50 = ["Australian","Wood","Unseasoned Timber","100x50"]
	Australian_Wood_Unseasoned_Timber_100x75 = ["Australian","Wood","Unseasoned Timber","100x75"]
	Australian_Wood_Unseasoned_Timber_100x100 = ["Australian","Wood","Unseasoned Timber","100x100"]
	Australian_Wood_Unseasoned_Timber_125x38 = ["Australian","Wood","Unseasoned Timber","125x38"]
	Australian_Wood_Unseasoned_Timber_125x50 = ["Australian","Wood","Unseasoned Timber","125x50"]
	Australian_Wood_Unseasoned_Timber_125x75 = ["Australian","Wood","Unseasoned Timber","125x75"]
	Australian_Wood_Unseasoned_Timber_150x38 = ["Australian","Wood","Unseasoned Timber","150x38"]
	Australian_Wood_Unseasoned_Timber_150x50 = ["Australian","Wood","Unseasoned Timber","150x50"]
	Australian_Wood_Unseasoned_Timber_150x75 = ["Australian","Wood","Unseasoned Timber","150x75"]
	Australian_Wood_Unseasoned_Timber_175x38 = ["Australian","Wood","Unseasoned Timber","175x38"]
	Australian_Wood_Unseasoned_Timber_175x50 = ["Australian","Wood","Unseasoned Timber","175x50"]
	Australian_Wood_Unseasoned_Timber_175x75 = ["Australian","Wood","Unseasoned Timber","175x75"]
	Australian_Wood_Unseasoned_Timber_200x38 = ["Australian","Wood","Unseasoned Timber","200x38"]
	Australian_Wood_Unseasoned_Timber_200x50 = ["Australian","Wood","Unseasoned Timber","200x50"]
	Australian_Wood_Unseasoned_Timber_200x75 = ["Australian","Wood","Unseasoned Timber","200x75"]
	Australian_Wood_Unseasoned_Timber_250x50 = ["Australian","Wood","Unseasoned Timber","250x50"]
	Australian_Wood_Unseasoned_Timber_250x75 = ["Australian","Wood","Unseasoned Timber","250x75"]
	British_Steel_Universal_beams_127x76_UB_13 = ["British","Steel","Universal beams","127x76 UB 13"]
	British_Steel_Universal_beams_152x89_UB_16 = ["British","Steel","Universal beams","152x89 UB 16"]
	British_Steel_Universal_beams_178x102_UB_19 = ["British","Steel","Universal beams","178x102 UB 19"]
	British_Steel_Universal_beams_203x102_UB_23 = ["British","Steel","Universal beams","203x102 UB 23"]
	British_Steel_Universal_beams_203x133_UB_25 = ["British","Steel","Universal beams","203x133 UB 25"]
	British_Steel_Universal_beams_203x133_UB_30 = ["British","Steel","Universal beams","203x133 UB 30"]
	British_Steel_Universal_beams_254x102_UB_22 = ["British","Steel","Universal beams","254x102 UB 22"]
	British_Steel_Universal_beams_254x102_UB_25 = ["British","Steel","Universal beams","254x102 UB 25"]
	British_Steel_Universal_beams_254x102_UB_28 = ["British","Steel","Universal beams","254x102 UB 28"]
	British_Steel_Universal_beams_254x146_UB_31 = ["British","Steel","Universal beams","254x146 UB 31"]
	British_Steel_Universal_beams_254x146_UB_37 = ["British","Steel","Universal beams","254x146 UB 37"]
	British_Steel_Universal_beams_254x146_UB_43 = ["British","Steel","Universal beams","254x146 UB 43"]
	British_Steel_Universal_beams_305x102_UB_25 = ["British","Steel","Universal beams","305x102 UB 25"]
	British_Steel_Universal_beams_305x102_UB_28 = ["British","Steel","Universal beams","305x102 UB 28"]
	British_Steel_Universal_beams_305x102_UB_33 = ["British","Steel","Universal beams","305x102 UB 33"]
	British_Steel_Universal_beams_305x127_UB_37 = ["British","Steel","Universal beams","305x127 UB 37"]
	British_Steel_Universal_beams_305x127_UB_42 = ["British","Steel","Universal beams","305x127 UB 42"]
	British_Steel_Universal_beams_305x127_UB_48 = ["British","Steel","Universal beams","305x127 UB 48"]
	British_Steel_Universal_beams_305x165_UB_40 = ["British","Steel","Universal beams","305x165 UB 40"]
	British_Steel_Universal_beams_305x165_UB_46 = ["British","Steel","Universal beams","305x165 UB 46"]
	British_Steel_Universal_beams_305x165_UB_54 = ["British","Steel","Universal beams","305x165 UB 54"]
	British_Steel_Universal_beams_356x127_UB_33 = ["British","Steel","Universal beams","356x127 UB 33"]
	British_Steel_Universal_beams_356x127_UB_39 = ["British","Steel","Universal beams","356x127 UB 39"]
	British_Steel_Universal_beams_356x171_UB_45 = ["British","Steel","Universal beams","356x171 UB 45"]
	British_Steel_Universal_beams_356x171_UB_51 = ["British","Steel","Universal beams","356x171 UB 51"]
	British_Steel_Universal_beams_356x171_UB_57 = ["British","Steel","Universal beams","356x171 UB 57"]
	British_Steel_Universal_beams_356x171_UB_67 = ["British","Steel","Universal beams","356x171 UB 67"]
	British_Steel_Universal_beams_406x140_UB_39 = ["British","Steel","Universal beams","406x140 UB 39"]
	British_Steel_Universal_beams_406x140_UB_46 = ["British","Steel","Universal beams","406x140 UB 46"]
	British_Steel_Universal_beams_406x140_UB_53 = ["British","Steel","Universal beams","406x140 UB 53"]
	British_Steel_Universal_beams_406x178_UB_54 = ["British","Steel","Universal beams","406x178 UB 54"]
	British_Steel_Universal_beams_406x178_UB_60 = ["British","Steel","Universal beams","406x178 UB 60"]
	British_Steel_Universal_beams_406x178_UB_67 = ["British","Steel","Universal beams","406x178 UB 67"]
	British_Steel_Universal_beams_406x178_UB_74 = ["British","Steel","Universal beams","406x178 UB 74"]
	British_Steel_Universal_beams_406x178_UB_85 = ["British","Steel","Universal beams","406x178 UB 85"]
	British_Steel_Universal_beams_457x152_UB_52 = ["British","Steel","Universal beams","457x152 UB 52"]
	British_Steel_Universal_beams_457x152_UB_60 = ["British","Steel","Universal beams","457x152 UB 60"]
	British_Steel_Universal_beams_457x152_UB_67 = ["British","Steel","Universal beams","457x152 UB 67"]
	British_Steel_Universal_beams_457x152_UB_74 = ["British","Steel","Universal beams","457x152 UB 74"]
	British_Steel_Universal_beams_457x152_UB_82 = ["British","Steel","Universal beams","457x152 UB 82"]
	British_Steel_Universal_beams_457x191_UB_67 = ["British","Steel","Universal beams","457x191 UB 67"]
	British_Steel_Universal_beams_457x191_UB_74 = ["British","Steel","Universal beams","457x191 UB 74"]
	British_Steel_Universal_beams_457x191_UB_82 = ["British","Steel","Universal beams","457x191 UB 82"]
	British_Steel_Universal_beams_457x191_UB_89 = ["British","Steel","Universal beams","457x191 UB 89"]
	British_Steel_Universal_beams_457x191_UB_98 = ["British","Steel","Universal beams","457x191 UB 98"]
	British_Steel_Universal_beams_457x191_UB_106 = ["British","Steel","Universal beams","457x191 UB 106"]
	British_Steel_Universal_beams_457x191_UB_133 = ["British","Steel","Universal beams","457x191 UB 133"]
	British_Steel_Universal_beams_457x191_UB_161 = ["British","Steel","Universal beams","457x191 UB 161"]
	British_Steel_Universal_beams_533x165_UB_66 = ["British","Steel","Universal beams","533x165 UB 66"]
	British_Steel_Universal_beams_533x165_UB_74 = ["British","Steel","Universal beams","533x165 UB 74"]
	British_Steel_Universal_beams_533x165_UB_85 = ["British","Steel","Universal beams","533x165 UB 85"]
	British_Steel_Universal_beams_533x210_UB_82 = ["British","Steel","Universal beams","533x210 UB 82"]
	British_Steel_Universal_beams_533x210_UB_92 = ["British","Steel","Universal beams","533x210 UB 92"]
	British_Steel_Universal_beams_533x210_UB_101 = ["British","Steel","Universal beams","533x210 UB 101"]
	British_Steel_Universal_beams_533x210_UB_109 = ["British","Steel","Universal beams","533x210 UB 109"]
	British_Steel_Universal_beams_533x210_UB_122 = ["British","Steel","Universal beams","533x210 UB 122"]
	British_Steel_Universal_beams_533x210_UB_138 = ["British","Steel","Universal beams","533x210 UB 138"]
	British_Steel_Universal_beams_533x312_UB_150 = ["British","Steel","Universal beams","533x312 UB 150"]
	British_Steel_Universal_beams_533x312_UB_182 = ["British","Steel","Universal beams","533x312 UB 182"]
	British_Steel_Universal_beams_533x312_UB_219 = ["British","Steel","Universal beams","533x312 UB 219"]
	British_Steel_Universal_beams_533x312_UB_272 = ["British","Steel","Universal beams","533x312 UB 272"]
	British_Steel_Universal_beams_610x178_UB_82 = ["British","Steel","Universal beams","610x178 UB 82"]
	British_Steel_Universal_beams_610x178_UB_92 = ["British","Steel","Universal beams","610x178 UB 92"]
	British_Steel_Universal_beams_610x178_UB_100 = ["British","Steel","Universal beams","610x178 UB 100"]
	British_Steel_Universal_beams_610x229_UB_101 = ["British","Steel","Universal beams","610x229 UB 101"]
	British_Steel_Universal_beams_610x229_UB_113 = ["British","Steel","Universal beams","610x229 UB 113"]
	British_Steel_Universal_beams_610x229_UB_125 = ["British","Steel","Universal beams","610x229 UB 125"]
	British_Steel_Universal_beams_610x229_UB_140 = ["British","Steel","Universal beams","610x229 UB 140"]
	British_Steel_Universal_beams_610x305_UB_149 = ["British","Steel","Universal beams","610x305 UB 149"]
	British_Steel_Universal_beams_610x305_UB_179 = ["British","Steel","Universal beams","610x305 UB 179"]
	British_Steel_Universal_beams_610x305_UB_238 = ["British","Steel","Universal beams","610x305 UB 238"]
	British_Steel_Universal_beams_686x254_UB_125 = ["British","Steel","Universal beams","686x254 UB 125"]
	British_Steel_Universal_beams_686x254_UB_140 = ["British","Steel","Universal beams","686x254 UB 140"]
	British_Steel_Universal_beams_686x254_UB_152 = ["British","Steel","Universal beams","686x254 UB 152"]
	British_Steel_Universal_beams_686x254_UB_170 = ["British","Steel","Universal beams","686x254 UB 170"]
	British_Steel_Universal_beams_762x267_UB_134 = ["British","Steel","Universal beams","762x267 UB 134"]
	British_Steel_Universal_beams_762x267_UB_147 = ["British","Steel","Universal beams","762x267 UB 147"]
	British_Steel_Universal_beams_762x267_UB_173 = ["British","Steel","Universal beams","762x267 UB 173"]
	British_Steel_Universal_beams_762x267_UB_197 = ["British","Steel","Universal beams","762x267 UB 197"]
	British_Steel_Universal_beams_838x292_UB_176 = ["British","Steel","Universal beams","838x292 UB 176"]
	British_Steel_Universal_beams_838x292_UB_194 = ["British","Steel","Universal beams","838x292 UB 194"]
	British_Steel_Universal_beams_838x292_UB_226 = ["British","Steel","Universal beams","838x292 UB 226"]
	British_Steel_Universal_beams_914x305_UB_201 = ["British","Steel","Universal beams","914x305 UB 201"]
	British_Steel_Universal_beams_914x305_UB_224 = ["British","Steel","Universal beams","914x305 UB 224"]
	British_Steel_Universal_beams_914x305_UB_253 = ["British","Steel","Universal beams","914x305 UB 253"]
	British_Steel_Universal_beams_914x305_UB_289 = ["British","Steel","Universal beams","914x305 UB 289"]
	British_Steel_Universal_beams_914x419_UB_343 = ["British","Steel","Universal beams","914x419 UB 343"]
	British_Steel_Universal_beams_914x419_UB_388 = ["British","Steel","Universal beams","914x419 UB 388"]
	British_Steel_Universal_beams_1016x305_UB_222 = ["British","Steel","Universal beams","1016x305 UB 222"]
	British_Steel_Universal_beams_1016x305_UB_249 = ["British","Steel","Universal beams","1016x305 UB 249"]
	British_Steel_Universal_beams_1016x305_UB_272 = ["British","Steel","Universal beams","1016x305 UB 272"]
	British_Steel_Universal_beams_1016x305_UB_314 = ["British","Steel","Universal beams","1016x305 UB 314"]
	British_Steel_Universal_beams_1016x305_UB_349 = ["British","Steel","Universal beams","1016x305 UB 349"]
	British_Steel_Universal_beams_1016x305_UB_393 = ["British","Steel","Universal beams","1016x305 UB 393"]
	British_Steel_Universal_beams_1016x305_UB_437 = ["British","Steel","Universal beams","1016x305 UB 437"]
	British_Steel_Universal_beams_1016x305_UB_487 = ["British","Steel","Universal beams","1016x305 UB 487"]
	British_Steel_Universal_columns_152x152_UC_23 = ["British","Steel","Universal columns","152x152 UC 23"]
	British_Steel_Universal_columns_152x152_UC_30 = ["British","Steel","Universal columns","152x152 UC 30"]
	British_Steel_Universal_columns_152x152_UC_37 = ["British","Steel","Universal columns","152x152 UC 37"]
	British_Steel_Universal_columns_152x152_UC_44 = ["British","Steel","Universal columns","152x152 UC 44"]
	British_Steel_Universal_columns_152x152_UC_51 = ["British","Steel","Universal columns","152x152 UC 51"]
	British_Steel_Universal_columns_203x203_UC_46 = ["British","Steel","Universal columns","203x203 UC 46"]
	British_Steel_Universal_columns_203x203_UC_52 = ["British","Steel","Universal columns","203x203 UC 52"]
	British_Steel_Universal_columns_203x203_UC_60 = ["British","Steel","Universal columns","203x203 UC 60"]
	British_Steel_Universal_columns_203x203_UC_71 = ["British","Steel","Universal columns","203x203 UC 71"]
	British_Steel_Universal_columns_203x203_UC_86 = ["British","Steel","Universal columns","203x203 UC 86"]
	British_Steel_Universal_columns_203x203_UC_100 = ["British","Steel","Universal columns","203x203 UC 100"]
	British_Steel_Universal_columns_203x203_UC_113 = ["British","Steel","Universal columns","203x203 UC 113"]
	British_Steel_Universal_columns_203x203_UC_127 = ["British","Steel","Universal columns","203x203 UC 127"]
	British_Steel_Universal_columns_254x254_UC_73 = ["British","Steel","Universal columns","254x254 UC 73"]
	British_Steel_Universal_columns_254x254_UC_89 = ["British","Steel","Universal columns","254x254 UC 89"]
	British_Steel_Universal_columns_254x254_UC_107 = ["British","Steel","Universal columns","254x254 UC 107"]
	British_Steel_Universal_columns_254x254_UC_132 = ["British","Steel","Universal columns","254x254 UC 132"]
	British_Steel_Universal_columns_254x254_UC_167 = ["British","Steel","Universal columns","254x254 UC 167"]
	British_Steel_Universal_columns_305x305_UC_97 = ["British","Steel","Universal columns","305x305 UC 97"]
	British_Steel_Universal_columns_305x305_UC_118 = ["British","Steel","Universal columns","305x305 UC 118"]
	British_Steel_Universal_columns_305x305_UC_137 = ["British","Steel","Universal columns","305x305 UC 137"]
	British_Steel_Universal_columns_305x305_UC_158 = ["British","Steel","Universal columns","305x305 UC 158"]
	British_Steel_Universal_columns_305x305_UC_198 = ["British","Steel","Universal columns","305x305 UC 198"]
	British_Steel_Universal_columns_305x305_UC_240 = ["British","Steel","Universal columns","305x305 UC 240"]
	British_Steel_Universal_columns_305x305_UC_283 = ["British","Steel","Universal columns","305x305 UC 283"]
	British_Steel_Universal_columns_356x368_UC_129 = ["British","Steel","Universal columns","356x368 UC 129"]
	British_Steel_Universal_columns_356x368_UC_153 = ["British","Steel","Universal columns","356x368 UC 153"]
	British_Steel_Universal_columns_356x368_UC_177 = ["British","Steel","Universal columns","356x368 UC 177"]
	British_Steel_Universal_columns_356x368_UC_202 = ["British","Steel","Universal columns","356x368 UC 202"]
	British_Steel_Universal_columns_356x406_UC_235 = ["British","Steel","Universal columns","356x406 UC 235"]
	British_Steel_Universal_columns_356x406_UC_287 = ["British","Steel","Universal columns","356x406 UC 287"]
	British_Steel_Universal_columns_356x406_UC_340 = ["British","Steel","Universal columns","356x406 UC 340"]
	British_Steel_Universal_columns_356x406_UC_393 = ["British","Steel","Universal columns","356x406 UC 393"]
	British_Steel_Universal_columns_356x406_UC_467 = ["British","Steel","Universal columns","356x406 UC 467"]
	British_Steel_Universal_columns_356x406_UC_551 = ["British","Steel","Universal columns","356x406 UC 551"]
	British_Steel_Universal_columns_356x406_UC_634 = ["British","Steel","Universal columns","356x406 UC 634"]
	British_Steel_Universal_bearing_piles_203x203x45_UBT = ["British","Steel","Universal bearing piles","203x203x45 UBT"]
	British_Steel_Universal_bearing_piles_203x203x54_UBT = ["British","Steel","Universal bearing piles","203x203x54 UBT"]
	British_Steel_Universal_bearing_piles_254x254x63_UBT = ["British","Steel","Universal bearing piles","254x254x63 UBT"]
	British_Steel_Universal_bearing_piles_254x254x71_UBT = ["British","Steel","Universal bearing piles","254x254x71 UBT"]
	British_Steel_Universal_bearing_piles_254x254x85_UBT = ["British","Steel","Universal bearing piles","254x254x85 UBT"]
	British_Steel_Universal_bearing_piles_305x305x79_UBT = ["British","Steel","Universal bearing piles","305x305x79 UBT"]
	British_Steel_Universal_bearing_piles_305x305x88_UBT = ["British","Steel","Universal bearing piles","305x305x88 UBT"]
	British_Steel_Universal_bearing_piles_305x305x95_UBT = ["British","Steel","Universal bearing piles","305x305x95 UBT"]
	British_Steel_Universal_bearing_piles_305x305x110_UBT = ["British","Steel","Universal bearing piles","305x305x110 UBT"]
	British_Steel_Universal_bearing_piles_305x305x126_UBT = ["British","Steel","Universal bearing piles","305x305x126 UBT"]
	British_Steel_Universal_bearing_piles_305x305x149_UBT = ["British","Steel","Universal bearing piles","305x305x149 UBT"]
	British_Steel_Universal_bearing_piles_305x305x186_UBT = ["British","Steel","Universal bearing piles","305x305x186 UBT"]
	British_Steel_Universal_bearing_piles_305x305x223_UBT = ["British","Steel","Universal bearing piles","305x305x223 UBT"]
	British_Steel_Universal_bearing_piles_356x368x109_UBT = ["British","Steel","Universal bearing piles","356x368x109 UBT"]
	British_Steel_Universal_bearing_piles_356x368x133_UBT = ["British","Steel","Universal bearing piles","356x368x133 UBT"]
	British_Steel_Universal_bearing_piles_356x368x152_UBT = ["British","Steel","Universal bearing piles","356x368x152 UBT"]
	British_Steel_Universal_bearing_piles_356x368x174_UBT = ["British","Steel","Universal bearing piles","356x368x174 UBT"]
	British_Steel_Joists_76x76x13_JST = ["British","Steel","Joists","76x76x13 JST"]
	British_Steel_Joists_89x89x19_JST = ["British","Steel","Joists","89x89x19 JST"]
	British_Steel_Joists_102x44x7_JST = ["British","Steel","Joists","102x44x7 JST"]
	British_Steel_Joists_102x102x23_JST = ["British","Steel","Joists","102x102x23 JST"]
	British_Steel_Joists_127x114x27_JST = ["British","Steel","Joists","127x114x27 JST"]
	British_Steel_Joists_127x114x29_JST = ["British","Steel","Joists","127x114x29 JST"]
	British_Steel_Joists_152x127x37_JST = ["British","Steel","Joists","152x127x37 JST"]
	British_Steel_Joists_203x152x52_JST = ["British","Steel","Joists","203x152x52 JST"]
	British_Steel_Joists_254x203x82_JST = ["British","Steel","Joists","254x203x82 JST"]
	British_Steel_Channels_100x50x10_CH = ["British","Steel","Channels","100x50x10 CH"]
	British_Steel_Channels_125x65x15_CH = ["British","Steel","Channels","125x65x15 CH"]
	British_Steel_Channels_150x75x18_CH = ["British","Steel","Channels","150x75x18 CH"]
	British_Steel_Channels_150x90x24_CH = ["British","Steel","Channels","150x90x24 CH"]
	British_Steel_Channels_180x75x20_CH = ["British","Steel","Channels","180x75x20 CH"]
	British_Steel_Channels_180x90x26_CH = ["British","Steel","Channels","180x90x26 CH"]
	British_Steel_Channels_200x75x23_CH = ["British","Steel","Channels","200x75x23 CH"]
	British_Steel_Channels_200x90x30_CH = ["British","Steel","Channels","200x90x30 CH"]
	British_Steel_Channels_230x75x26_CH = ["British","Steel","Channels","230x75x26 CH"]
	British_Steel_Channels_230x90x32_CH = ["British","Steel","Channels","230x90x32 CH"]
	British_Steel_Channels_260x75x28_CH = ["British","Steel","Channels","260x75x28 CH"]
	British_Steel_Channels_260x90x35_CH = ["British","Steel","Channels","260x90x35 CH"]
	British_Steel_Channels_300x90x41_CH = ["British","Steel","Channels","300x90x41 CH"]
	British_Steel_Channels_300x100x46_CH = ["British","Steel","Channels","300x100x46 CH"]
	British_Steel_Channels_380x100x54_CH = ["British","Steel","Channels","380x100x54 CH"]
	British_Steel_Channels_430x100x64_CH = ["British","Steel","Channels","430x100x64 CH"]
	British_Steel_Rectangular_hollow_sections_50x30x2_5RHS = ["British","Steel","Rectangular hollow sections","50x30x2.5RHS"]
	British_Steel_Rectangular_hollow_sections_50x30x3_0RHS = ["British","Steel","Rectangular hollow sections","50x30x3.0RHS"]
	British_Steel_Rectangular_hollow_sections_50x30x3_2RHS = ["British","Steel","Rectangular hollow sections","50x30x3.2RHS"]
	British_Steel_Rectangular_hollow_sections_50x30x3_6RHS = ["British","Steel","Rectangular hollow sections","50x30x3.6RHS"]
	British_Steel_Rectangular_hollow_sections_50x30x4_0RHS = ["British","Steel","Rectangular hollow sections","50x30x4.0RHS"]
	British_Steel_Rectangular_hollow_sections_50x30x5_0RHS = ["British","Steel","Rectangular hollow sections","50x30x5.0RHS"]
	British_Steel_Rectangular_hollow_sections_60x40x2_5RHS = ["British","Steel","Rectangular hollow sections","60x40x2.5RHS"]
	British_Steel_Rectangular_hollow_sections_60x40x3_0RHS = ["British","Steel","Rectangular hollow sections","60x40x3.0RHS"]
	British_Steel_Rectangular_hollow_sections_60x40x3_2RHS = ["British","Steel","Rectangular hollow sections","60x40x3.2RHS"]
	British_Steel_Rectangular_hollow_sections_60x40x3_6RHS = ["British","Steel","Rectangular hollow sections","60x40x3.6RHS"]
	British_Steel_Rectangular_hollow_sections_60x40x4_0RHS = ["British","Steel","Rectangular hollow sections","60x40x4.0RHS"]
	British_Steel_Rectangular_hollow_sections_60x40x5_0RHS = ["British","Steel","Rectangular hollow sections","60x40x5.0RHS"]
	British_Steel_Rectangular_hollow_sections_60x40x6_0RHS = ["British","Steel","Rectangular hollow sections","60x40x6.0RHS"]
	British_Steel_Rectangular_hollow_sections_60x40x6_3RHS = ["British","Steel","Rectangular hollow sections","60x40x6.3RHS"]
	British_Steel_Rectangular_hollow_sections_76x50_8x3_0RHS = ["British","Steel","Rectangular hollow sections","76x50.8x3.0RHS"]
	British_Steel_Rectangular_hollow_sections_76x50_8x3_2RHS = ["British","Steel","Rectangular hollow sections","76x50.8x3.2RHS"]
	British_Steel_Rectangular_hollow_sections_76x50_8x3_6RHS = ["British","Steel","Rectangular hollow sections","76x50.8x3.6RHS"]
	British_Steel_Rectangular_hollow_sections_76x50_8x4_0RHS = ["British","Steel","Rectangular hollow sections","76x50.8x4.0RHS"]
	British_Steel_Rectangular_hollow_sections_76x50_8x5_0RHS = ["British","Steel","Rectangular hollow sections","76x50.8x5.0RHS"]
	British_Steel_Rectangular_hollow_sections_76x50_8x6_0RHS = ["British","Steel","Rectangular hollow sections","76x50.8x6.0RHS"]
	British_Steel_Rectangular_hollow_sections_76x50_8x6_3RHS = ["British","Steel","Rectangular hollow sections","76x50.8x6.3RHS"]
	British_Steel_Rectangular_hollow_sections_76x50_8x8_0RHS = ["British","Steel","Rectangular hollow sections","76x50.8x8.0RHS"]
	British_Steel_Rectangular_hollow_sections_80x40x3_0RHS = ["British","Steel","Rectangular hollow sections","80x40x3.0RHS"]
	British_Steel_Rectangular_hollow_sections_80x40x3_2RHS = ["British","Steel","Rectangular hollow sections","80x40x3.2RHS"]
	British_Steel_Rectangular_hollow_sections_80x40x3_6RHS = ["British","Steel","Rectangular hollow sections","80x40x3.6RHS"]
	British_Steel_Rectangular_hollow_sections_80x40x4_0RHS = ["British","Steel","Rectangular hollow sections","80x40x4.0RHS"]
	British_Steel_Rectangular_hollow_sections_80x40x5_0RHS = ["British","Steel","Rectangular hollow sections","80x40x5.0RHS"]
	British_Steel_Rectangular_hollow_sections_80x40x6_0RHS = ["British","Steel","Rectangular hollow sections","80x40x6.0RHS"]
	British_Steel_Rectangular_hollow_sections_80x40x6_3RHS = ["British","Steel","Rectangular hollow sections","80x40x6.3RHS"]
	British_Steel_Rectangular_hollow_sections_80x40x8_0RHS = ["British","Steel","Rectangular hollow sections","80x40x8.0RHS"]
	British_Steel_Rectangular_hollow_sections_90x50x3_0RHS = ["British","Steel","Rectangular hollow sections","90x50x3.0RHS"]
	British_Steel_Rectangular_hollow_sections_90x50x3_2RHS = ["British","Steel","Rectangular hollow sections","90x50x3.2RHS"]
	British_Steel_Rectangular_hollow_sections_90x50x3_6RHS = ["British","Steel","Rectangular hollow sections","90x50x3.6RHS"]
	British_Steel_Rectangular_hollow_sections_90x50x4_0RHS = ["British","Steel","Rectangular hollow sections","90x50x4.0RHS"]
	British_Steel_Rectangular_hollow_sections_90x50x5_0RHS = ["British","Steel","Rectangular hollow sections","90x50x5.0RHS"]
	British_Steel_Rectangular_hollow_sections_90x50x6_0RHS = ["British","Steel","Rectangular hollow sections","90x50x6.0RHS"]
	British_Steel_Rectangular_hollow_sections_90x50x6_3RHS = ["British","Steel","Rectangular hollow sections","90x50x6.3RHS"]
	British_Steel_Rectangular_hollow_sections_90x50x8_0RHS = ["British","Steel","Rectangular hollow sections","90x50x8.0RHS"]
	British_Steel_Rectangular_hollow_sections_100x50x3_0RHS = ["British","Steel","Rectangular hollow sections","100x50x3.0RHS"]
	British_Steel_Rectangular_hollow_sections_100x50x3_2RHS = ["British","Steel","Rectangular hollow sections","100x50x3.2RHS"]
	British_Steel_Rectangular_hollow_sections_100x50x3_6RHS = ["British","Steel","Rectangular hollow sections","100x50x3.6RHS"]
	British_Steel_Rectangular_hollow_sections_100x50x4_0RHS = ["British","Steel","Rectangular hollow sections","100x50x4.0RHS"]
	British_Steel_Rectangular_hollow_sections_100x50x5_0RHS = ["British","Steel","Rectangular hollow sections","100x50x5.0RHS"]
	British_Steel_Rectangular_hollow_sections_100x50x6_0RHS = ["British","Steel","Rectangular hollow sections","100x50x6.0RHS"]
	British_Steel_Rectangular_hollow_sections_100x50x6_3RHS = ["British","Steel","Rectangular hollow sections","100x50x6.3RHS"]
	British_Steel_Rectangular_hollow_sections_100x50x8_0RHS = ["British","Steel","Rectangular hollow sections","100x50x8.0RHS"]
	British_Steel_Rectangular_hollow_sections_100x60x3_0RHS = ["British","Steel","Rectangular hollow sections","100x60x3.0RHS"]
	British_Steel_Rectangular_hollow_sections_100x60x3_2RHS = ["British","Steel","Rectangular hollow sections","100x60x3.2RHS"]
	British_Steel_Rectangular_hollow_sections_100x60x3_6RHS = ["British","Steel","Rectangular hollow sections","100x60x3.6RHS"]
	British_Steel_Rectangular_hollow_sections_100x60x4_0RHS = ["British","Steel","Rectangular hollow sections","100x60x4.0RHS"]
	British_Steel_Rectangular_hollow_sections_100x60x5_0RHS = ["British","Steel","Rectangular hollow sections","100x60x5.0RHS"]
	British_Steel_Rectangular_hollow_sections_100x60x6_0RHS = ["British","Steel","Rectangular hollow sections","100x60x6.0RHS"]
	British_Steel_Rectangular_hollow_sections_100x60x6_3RHS = ["British","Steel","Rectangular hollow sections","100x60x6.3RHS"]
	British_Steel_Rectangular_hollow_sections_100x60x8_0RHS = ["British","Steel","Rectangular hollow sections","100x60x8.0RHS"]
	British_Steel_Rectangular_hollow_sections_120x60x3_6RHS = ["British","Steel","Rectangular hollow sections","120x60x3.6RHS"]
	British_Steel_Rectangular_hollow_sections_120x60x4_0RHS = ["British","Steel","Rectangular hollow sections","120x60x4.0RHS"]
	British_Steel_Rectangular_hollow_sections_120x60x5_0RHS = ["British","Steel","Rectangular hollow sections","120x60x5.0RHS"]
	British_Steel_Rectangular_hollow_sections_120x60x6_0RHS = ["British","Steel","Rectangular hollow sections","120x60x6.0RHS"]
	British_Steel_Rectangular_hollow_sections_120x60x6_3RHS = ["British","Steel","Rectangular hollow sections","120x60x6.3RHS"]
	British_Steel_Rectangular_hollow_sections_120x60x8_0RHS = ["British","Steel","Rectangular hollow sections","120x60x8.0RHS"]
	British_Steel_Rectangular_hollow_sections_120x80x3_6RHS = ["British","Steel","Rectangular hollow sections","120x80x3.6RHS"]
	British_Steel_Rectangular_hollow_sections_120x80x4_0RHS = ["British","Steel","Rectangular hollow sections","120x80x4.0RHS"]
	British_Steel_Rectangular_hollow_sections_120x80x5_0RHS = ["British","Steel","Rectangular hollow sections","120x80x5.0RHS"]
	British_Steel_Rectangular_hollow_sections_120x80x6_0RHS = ["British","Steel","Rectangular hollow sections","120x80x6.0RHS"]
	British_Steel_Rectangular_hollow_sections_120x80x6_3RHS = ["British","Steel","Rectangular hollow sections","120x80x6.3RHS"]
	British_Steel_Rectangular_hollow_sections_120x80x8_0RHS = ["British","Steel","Rectangular hollow sections","120x80x8.0RHS"]
	British_Steel_Rectangular_hollow_sections_120x80x10_0RHS = ["British","Steel","Rectangular hollow sections","120x80x10.0RHS"]
	British_Steel_Rectangular_hollow_sections_150x100x4_0RHS = ["British","Steel","Rectangular hollow sections","150x100x4.0RHS"]
	British_Steel_Rectangular_hollow_sections_150x100x5_0RHS = ["British","Steel","Rectangular hollow sections","150x100x5.0RHS"]
	British_Steel_Rectangular_hollow_sections_150x100x6_0RHS = ["British","Steel","Rectangular hollow sections","150x100x6.0RHS"]
	British_Steel_Rectangular_hollow_sections_150x100x6_3RHS = ["British","Steel","Rectangular hollow sections","150x100x6.3RHS"]
	British_Steel_Rectangular_hollow_sections_150x100x8_0RHS = ["British","Steel","Rectangular hollow sections","150x100x8.0RHS"]
	British_Steel_Rectangular_hollow_sections_150x100x10_0RHS = ["British","Steel","Rectangular hollow sections","150x100x10.0RHS"]
	British_Steel_Rectangular_hollow_sections_150x100x12_0RHS = ["British","Steel","Rectangular hollow sections","150x100x12.0RHS"]
	British_Steel_Rectangular_hollow_sections_150x100x12_5RHS = ["British","Steel","Rectangular hollow sections","150x100x12.5RHS"]
	British_Steel_Rectangular_hollow_sections_160x80x4_0RHS = ["British","Steel","Rectangular hollow sections","160x80x4.0RHS"]
	British_Steel_Rectangular_hollow_sections_160x80x5_0RHS = ["British","Steel","Rectangular hollow sections","160x80x5.0RHS"]
	British_Steel_Rectangular_hollow_sections_160x80x6_0RHS = ["British","Steel","Rectangular hollow sections","160x80x6.0RHS"]
	British_Steel_Rectangular_hollow_sections_160x80x6_3RHS = ["British","Steel","Rectangular hollow sections","160x80x6.3RHS"]
	British_Steel_Rectangular_hollow_sections_160x80x8_0RHS = ["British","Steel","Rectangular hollow sections","160x80x8.0RHS"]
	British_Steel_Rectangular_hollow_sections_160x80x10_0RHS = ["British","Steel","Rectangular hollow sections","160x80x10.0RHS"]
	British_Steel_Rectangular_hollow_sections_160x80x12_0RHS = ["British","Steel","Rectangular hollow sections","160x80x12.0RHS"]
	British_Steel_Rectangular_hollow_sections_160x80x12_5RHS = ["British","Steel","Rectangular hollow sections","160x80x12.5RHS"]
	British_Steel_Rectangular_hollow_sections_200x100x5_0RHS = ["British","Steel","Rectangular hollow sections","200x100x5.0RHS"]
	British_Steel_Rectangular_hollow_sections_200x100x6_0RHS = ["British","Steel","Rectangular hollow sections","200x100x6.0RHS"]
	British_Steel_Rectangular_hollow_sections_200x100x6_3RHS = ["British","Steel","Rectangular hollow sections","200x100x6.3RHS"]
	British_Steel_Rectangular_hollow_sections_200x100x8_0RHS = ["British","Steel","Rectangular hollow sections","200x100x8.0RHS"]
	British_Steel_Rectangular_hollow_sections_200x100x10_0RHS = ["British","Steel","Rectangular hollow sections","200x100x10.0RHS"]
	British_Steel_Rectangular_hollow_sections_200x100x12_0RHS = ["British","Steel","Rectangular hollow sections","200x100x12.0RHS"]
	British_Steel_Rectangular_hollow_sections_200x100x12_5RHS = ["British","Steel","Rectangular hollow sections","200x100x12.5RHS"]
	British_Steel_Rectangular_hollow_sections_200x100x16_0RHS = ["British","Steel","Rectangular hollow sections","200x100x16.0RHS"]
	British_Steel_Rectangular_hollow_sections_250x150x5_0RHS = ["British","Steel","Rectangular hollow sections","250x150x5.0RHS"]
	British_Steel_Rectangular_hollow_sections_250x150x6_0RHS = ["British","Steel","Rectangular hollow sections","250x150x6.0RHS"]
	British_Steel_Rectangular_hollow_sections_250x150x6_3RHS = ["British","Steel","Rectangular hollow sections","250x150x6.3RHS"]
	British_Steel_Rectangular_hollow_sections_250x150x8_0RHS = ["British","Steel","Rectangular hollow sections","250x150x8.0RHS"]
	British_Steel_Rectangular_hollow_sections_250x150x10_0RHS = ["British","Steel","Rectangular hollow sections","250x150x10.0RHS"]
	British_Steel_Rectangular_hollow_sections_250x150x12_0RHS = ["British","Steel","Rectangular hollow sections","250x150x12.0RHS"]
	British_Steel_Rectangular_hollow_sections_250x150x12_5RHS = ["British","Steel","Rectangular hollow sections","250x150x12.5RHS"]
	British_Steel_Rectangular_hollow_sections_250x150x16_0RHS = ["British","Steel","Rectangular hollow sections","250x150x16.0RHS"]
	British_Steel_Rectangular_hollow_sections_300x200x5_0RHS = ["British","Steel","Rectangular hollow sections","300x200x5.0RHS"]
	British_Steel_Rectangular_hollow_sections_300x200x6_0RHS = ["British","Steel","Rectangular hollow sections","300x200x6.0RHS"]
	British_Steel_Rectangular_hollow_sections_300x200x6_3RHS = ["British","Steel","Rectangular hollow sections","300x200x6.3RHS"]
	British_Steel_Rectangular_hollow_sections_300x200x8_0RHS = ["British","Steel","Rectangular hollow sections","300x200x8.0RHS"]
	British_Steel_Rectangular_hollow_sections_300x200x10_0RHS = ["British","Steel","Rectangular hollow sections","300x200x10.0RHS"]
	British_Steel_Rectangular_hollow_sections_300x200x12_0RHS = ["British","Steel","Rectangular hollow sections","300x200x12.0RHS"]
	British_Steel_Rectangular_hollow_sections_300x200x12_5RHS = ["British","Steel","Rectangular hollow sections","300x200x12.5RHS"]
	British_Steel_Rectangular_hollow_sections_300x200x16_0RHS = ["British","Steel","Rectangular hollow sections","300x200x16.0RHS"]
	British_Steel_Rectangular_hollow_sections_400x200x6_0RHS = ["British","Steel","Rectangular hollow sections","400x200x6.0RHS"]
	British_Steel_Rectangular_hollow_sections_400x200x6_3RHS = ["British","Steel","Rectangular hollow sections","400x200x6.3RHS"]
	British_Steel_Rectangular_hollow_sections_400x200x8_0RHS = ["British","Steel","Rectangular hollow sections","400x200x8.0RHS"]
	British_Steel_Rectangular_hollow_sections_400x200x10_0RHS = ["British","Steel","Rectangular hollow sections","400x200x10.0RHS"]
	British_Steel_Rectangular_hollow_sections_400x200x12_0RHS = ["British","Steel","Rectangular hollow sections","400x200x12.0RHS"]
	British_Steel_Rectangular_hollow_sections_400x200x12_5RHS = ["British","Steel","Rectangular hollow sections","400x200x12.5RHS"]
	British_Steel_Rectangular_hollow_sections_400x200x16_0RHS = ["British","Steel","Rectangular hollow sections","400x200x16.0RHS"]
	British_Steel_Rectangular_hollow_sections_450x250x8_0RHS = ["British","Steel","Rectangular hollow sections","450x250x8.0RHS"]
	British_Steel_Rectangular_hollow_sections_450x250x10_0RHS = ["British","Steel","Rectangular hollow sections","450x250x10.0RHS"]
	British_Steel_Rectangular_hollow_sections_450x250x12_0RHS = ["British","Steel","Rectangular hollow sections","450x250x12.0RHS"]
	British_Steel_Rectangular_hollow_sections_450x250x12_5RHS = ["British","Steel","Rectangular hollow sections","450x250x12.5RHS"]
	British_Steel_Rectangular_hollow_sections_450x250x16_0RHS = ["British","Steel","Rectangular hollow sections","450x250x16.0RHS"]
	British_Steel_Rectangular_hollow_sections_500x300x8_0RHS = ["British","Steel","Rectangular hollow sections","500x300x8.0RHS"]
	British_Steel_Rectangular_hollow_sections_500x300x10_0RHS = ["British","Steel","Rectangular hollow sections","500x300x10.0RHS"]
	British_Steel_Rectangular_hollow_sections_500x300x12_0RHS = ["British","Steel","Rectangular hollow sections","500x300x12.0RHS"]
	British_Steel_Rectangular_hollow_sections_500x300x12_5RHS = ["British","Steel","Rectangular hollow sections","500x300x12.5RHS"]
	British_Steel_Rectangular_hollow_sections_500x300x16_0RHS = ["British","Steel","Rectangular hollow sections","500x300x16.0RHS"]
	British_Steel_Rectangular_hollow_sections_500x300x20_0RHS = ["British","Steel","Rectangular hollow sections","500x300x20.0RHS"]
	British_Steel_Square_hollow_sections_40x2_5_SHS = ["British","Steel","Square hollow sections","40x2.5 SHS"]
	British_Steel_Square_hollow_sections_40x3_0_SHS = ["British","Steel","Square hollow sections","40x3.0 SHS"]
	British_Steel_Square_hollow_sections_40x3_2_SHS = ["British","Steel","Square hollow sections","40x3.2 SHS"]
	British_Steel_Square_hollow_sections_40x3_6_SHS = ["British","Steel","Square hollow sections","40x3.6 SHS"]
	British_Steel_Square_hollow_sections_40x4_0_SHS = ["British","Steel","Square hollow sections","40x4.0 SHS"]
	British_Steel_Square_hollow_sections_40x5_0_SHS = ["British","Steel","Square hollow sections","40x5.0 SHS"]
	British_Steel_Square_hollow_sections_50x2_5_SHS = ["British","Steel","Square hollow sections","50x2.5 SHS"]
	British_Steel_Square_hollow_sections_50x3_0_SHS = ["British","Steel","Square hollow sections","50x3.0 SHS"]
	British_Steel_Square_hollow_sections_50x3_2_SHS = ["British","Steel","Square hollow sections","50x3.2 SHS"]
	British_Steel_Square_hollow_sections_50x3_6_SHS = ["British","Steel","Square hollow sections","50x3.6 SHS"]
	British_Steel_Square_hollow_sections_50x4_0_SHS = ["British","Steel","Square hollow sections","50x4.0 SHS"]
	British_Steel_Square_hollow_sections_50x5_0_SHS = ["British","Steel","Square hollow sections","50x5.0 SHS"]
	British_Steel_Square_hollow_sections_50x6_0_SHS = ["British","Steel","Square hollow sections","50x6.0 SHS"]
	British_Steel_Square_hollow_sections_50x6_3_SHS = ["British","Steel","Square hollow sections","50x6.3 SHS"]
	British_Steel_Square_hollow_sections_60x3_0_SHS = ["British","Steel","Square hollow sections","60x3.0 SHS"]
	British_Steel_Square_hollow_sections_60x3_2_SHS = ["British","Steel","Square hollow sections","60x3.2 SHS"]
	British_Steel_Square_hollow_sections_60x3_6_SHS = ["British","Steel","Square hollow sections","60x3.6 SHS"]
	British_Steel_Square_hollow_sections_60x4_0_SHS = ["British","Steel","Square hollow sections","60x4.0 SHS"]
	British_Steel_Square_hollow_sections_60x5_0_SHS = ["British","Steel","Square hollow sections","60x5.0 SHS"]
	British_Steel_Square_hollow_sections_60x6_0_SHS = ["British","Steel","Square hollow sections","60x6.0 SHS"]
	British_Steel_Square_hollow_sections_60x6_3_SHS = ["British","Steel","Square hollow sections","60x6.3 SHS"]
	British_Steel_Square_hollow_sections_60x8_0_SHS = ["British","Steel","Square hollow sections","60x8.0 SHS"]
	British_Steel_Square_hollow_sections_70x3_0_SHS = ["British","Steel","Square hollow sections","70x3.0 SHS"]
	British_Steel_Square_hollow_sections_70x3_2_SHS = ["British","Steel","Square hollow sections","70x3.2 SHS"]
	British_Steel_Square_hollow_sections_70x3_6_SHS = ["British","Steel","Square hollow sections","70x3.6 SHS"]
	British_Steel_Square_hollow_sections_70x4_0_SHS = ["British","Steel","Square hollow sections","70x4.0 SHS"]
	British_Steel_Square_hollow_sections_70x5_0_SHS = ["British","Steel","Square hollow sections","70x5.0 SHS"]
	British_Steel_Square_hollow_sections_70x6_0_SHS = ["British","Steel","Square hollow sections","70x6.0 SHS"]
	British_Steel_Square_hollow_sections_70x6_3_SHS = ["British","Steel","Square hollow sections","70x6.3 SHS"]
	British_Steel_Square_hollow_sections_70x8_0_SHS = ["British","Steel","Square hollow sections","70x8.0 SHS"]
	British_Steel_Square_hollow_sections_80x3_2_SHS = ["British","Steel","Square hollow sections","80x3.2 SHS"]
	British_Steel_Square_hollow_sections_80x3_6_SHS = ["British","Steel","Square hollow sections","80x3.6 SHS"]
	British_Steel_Square_hollow_sections_80x4_0_SHS = ["British","Steel","Square hollow sections","80x4.0 SHS"]
	British_Steel_Square_hollow_sections_80x5_0_SHS = ["British","Steel","Square hollow sections","80x5.0 SHS"]
	British_Steel_Square_hollow_sections_80x6_0_SHS = ["British","Steel","Square hollow sections","80x6.0 SHS"]
	British_Steel_Square_hollow_sections_80x6_3_SHS = ["British","Steel","Square hollow sections","80x6.3 SHS"]
	British_Steel_Square_hollow_sections_80x8_0_SHS = ["British","Steel","Square hollow sections","80x8.0 SHS"]
	British_Steel_Square_hollow_sections_90x3_6_SHS = ["British","Steel","Square hollow sections","90x3.6 SHS"]
	British_Steel_Square_hollow_sections_90x4_0_SHS = ["British","Steel","Square hollow sections","90x4.0 SHS"]
	British_Steel_Square_hollow_sections_90x5_0_SHS = ["British","Steel","Square hollow sections","90x5.0 SHS"]
	British_Steel_Square_hollow_sections_90x6_0_SHS = ["British","Steel","Square hollow sections","90x6.0 SHS"]
	British_Steel_Square_hollow_sections_90x6_3_SHS = ["British","Steel","Square hollow sections","90x6.3 SHS"]
	British_Steel_Square_hollow_sections_90x8_0_SHS = ["British","Steel","Square hollow sections","90x8.0 SHS"]
	British_Steel_Square_hollow_sections_100x3_6_SHS = ["British","Steel","Square hollow sections","100x3.6 SHS"]
	British_Steel_Square_hollow_sections_100x4_0_SHS = ["British","Steel","Square hollow sections","100x4.0 SHS"]
	British_Steel_Square_hollow_sections_100x5_0_SHS = ["British","Steel","Square hollow sections","100x5.0 SHS"]
	British_Steel_Square_hollow_sections_100x6_0_SHS = ["British","Steel","Square hollow sections","100x6.0 SHS"]
	British_Steel_Square_hollow_sections_100x6_3_SHS = ["British","Steel","Square hollow sections","100x6.3 SHS"]
	British_Steel_Square_hollow_sections_100x8_0_SHS = ["British","Steel","Square hollow sections","100x8.0 SHS"]
	British_Steel_Square_hollow_sections_100x10_0_SHS = ["British","Steel","Square hollow sections","100x10.0 SHS"]
	British_Steel_Square_hollow_sections_120x4_0_SHS = ["British","Steel","Square hollow sections","120x4.0 SHS"]
	British_Steel_Square_hollow_sections_120x5_0_SHS = ["British","Steel","Square hollow sections","120x5.0 SHS"]
	British_Steel_Square_hollow_sections_120x6_0_SHS = ["British","Steel","Square hollow sections","120x6.0 SHS"]
	British_Steel_Square_hollow_sections_120x6_3_SHS = ["British","Steel","Square hollow sections","120x6.3 SHS"]
	British_Steel_Square_hollow_sections_120x8_0_SHS = ["British","Steel","Square hollow sections","120x8.0 SHS"]
	British_Steel_Square_hollow_sections_120x10_0_SHS = ["British","Steel","Square hollow sections","120x10.0 SHS"]
	British_Steel_Square_hollow_sections_120x12_SHS = ["British","Steel","Square hollow sections","120x12 SHS"]
	British_Steel_Square_hollow_sections_120x12_5_SHS = ["British","Steel","Square hollow sections","120x12.5 SHS"]
	British_Steel_Square_hollow_sections_140x5_0_SHS = ["British","Steel","Square hollow sections","140x5.0 SHS"]
	British_Steel_Square_hollow_sections_140x6_0_SHS = ["British","Steel","Square hollow sections","140x6.0 SHS"]
	British_Steel_Square_hollow_sections_140x6_3_SHS = ["British","Steel","Square hollow sections","140x6.3 SHS"]
	British_Steel_Square_hollow_sections_140x8_0_SHS = ["British","Steel","Square hollow sections","140x8.0 SHS"]
	British_Steel_Square_hollow_sections_140x10_0_SHS = ["British","Steel","Square hollow sections","140x10.0 SHS"]
	British_Steel_Square_hollow_sections_140x12_0_SHS = ["British","Steel","Square hollow sections","140x12.0 SHS"]
	British_Steel_Square_hollow_sections_140x12_5_SHS = ["British","Steel","Square hollow sections","140x12.5 SHS"]
	British_Steel_Square_hollow_sections_150x5_0_SHS = ["British","Steel","Square hollow sections","150x5.0 SHS"]
	British_Steel_Square_hollow_sections_150x6_0_SHS = ["British","Steel","Square hollow sections","150x6.0 SHS"]
	British_Steel_Square_hollow_sections_150x6_3_SHS = ["British","Steel","Square hollow sections","150x6.3 SHS"]
	British_Steel_Square_hollow_sections_150x8_0_SHS = ["British","Steel","Square hollow sections","150x8.0 SHS"]
	British_Steel_Square_hollow_sections_150x10_0_SHS = ["British","Steel","Square hollow sections","150x10.0 SHS"]
	British_Steel_Square_hollow_sections_150x12_0_SHS = ["British","Steel","Square hollow sections","150x12.0 SHS"]
	British_Steel_Square_hollow_sections_150x12_5_SHS = ["British","Steel","Square hollow sections","150x12.5 SHS"]
	British_Steel_Square_hollow_sections_150x16_0_SHS = ["British","Steel","Square hollow sections","150x16.0 SHS"]
	British_Steel_Square_hollow_sections_160x5_0_SHS = ["British","Steel","Square hollow sections","160x5.0 SHS"]
	British_Steel_Square_hollow_sections_160x6_0_SHS = ["British","Steel","Square hollow sections","160x6.0 SHS"]
	British_Steel_Square_hollow_sections_160x6_3_SHS = ["British","Steel","Square hollow sections","160x6.3 SHS"]
	British_Steel_Square_hollow_sections_160x8_0_SHS = ["British","Steel","Square hollow sections","160x8.0 SHS"]
	British_Steel_Square_hollow_sections_160x10_0_SHS = ["British","Steel","Square hollow sections","160x10.0 SHS"]
	British_Steel_Square_hollow_sections_160x12_0_SHS = ["British","Steel","Square hollow sections","160x12.0 SHS"]
	British_Steel_Square_hollow_sections_160x12_5_SHS = ["British","Steel","Square hollow sections","160x12.5 SHS"]
	British_Steel_Square_hollow_sections_160x16_0_SHS = ["British","Steel","Square hollow sections","160x16.0 SHS"]
	British_Steel_Square_hollow_sections_180x5_0_SHS = ["British","Steel","Square hollow sections","180x5.0 SHS"]
	British_Steel_Square_hollow_sections_180x6_0_SHS = ["British","Steel","Square hollow sections","180x6.0 SHS"]
	British_Steel_Square_hollow_sections_180x6_3_SHS = ["British","Steel","Square hollow sections","180x6.3 SHS"]
	British_Steel_Square_hollow_sections_180x8_0_SHS = ["British","Steel","Square hollow sections","180x8.0 SHS"]
	British_Steel_Square_hollow_sections_180x10_0_SHS = ["British","Steel","Square hollow sections","180x10.0 SHS"]
	British_Steel_Square_hollow_sections_180x12_0_SHS = ["British","Steel","Square hollow sections","180x12.0 SHS"]
	British_Steel_Square_hollow_sections_180x12_5_SHS = ["British","Steel","Square hollow sections","180x12.5 SHS"]
	British_Steel_Square_hollow_sections_180x16_0_SHS = ["British","Steel","Square hollow sections","180x16.0 SHS"]
	British_Steel_Square_hollow_sections_200x5_0_SHS = ["British","Steel","Square hollow sections","200x5.0 SHS"]
	British_Steel_Square_hollow_sections_200x6_0_SHS = ["British","Steel","Square hollow sections","200x6.0 SHS"]
	British_Steel_Square_hollow_sections_200x6_3_SHS = ["British","Steel","Square hollow sections","200x6.3 SHS"]
	British_Steel_Square_hollow_sections_200x8_0_SHS = ["British","Steel","Square hollow sections","200x8.0 SHS"]
	British_Steel_Square_hollow_sections_200x10_0_SHS = ["British","Steel","Square hollow sections","200x10.0 SHS"]
	British_Steel_Square_hollow_sections_200x12_0_SHS = ["British","Steel","Square hollow sections","200x12.0 SHS"]
	British_Steel_Square_hollow_sections_200x12_5_SHS = ["British","Steel","Square hollow sections","200x12.5 SHS"]
	British_Steel_Square_hollow_sections_200x16_0_SHS = ["British","Steel","Square hollow sections","200x16.0 SHS"]
	British_Steel_Square_hollow_sections_250x5_0_SHS = ["British","Steel","Square hollow sections","250x5.0 SHS"]
	British_Steel_Square_hollow_sections_250x6_0_SHS = ["British","Steel","Square hollow sections","250x6.0 SHS"]
	British_Steel_Square_hollow_sections_250x6_3_SHS = ["British","Steel","Square hollow sections","250x6.3 SHS"]
	British_Steel_Square_hollow_sections_250x8_0_SHS = ["British","Steel","Square hollow sections","250x8.0 SHS"]
	British_Steel_Square_hollow_sections_250x10_0_SHS = ["British","Steel","Square hollow sections","250x10.0 SHS"]
	British_Steel_Square_hollow_sections_250x12_0_SHS = ["British","Steel","Square hollow sections","250x12.0 SHS"]
	British_Steel_Square_hollow_sections_250x12_5_SHS = ["British","Steel","Square hollow sections","250x12.5 SHS"]
	British_Steel_Square_hollow_sections_250x16_0_SHS = ["British","Steel","Square hollow sections","250x16.0 SHS"]
	British_Steel_Square_hollow_sections_300x6_0_SHS = ["British","Steel","Square hollow sections","300x6.0 SHS"]
	British_Steel_Square_hollow_sections_300x6_3_SHS = ["British","Steel","Square hollow sections","300x6.3 SHS"]
	British_Steel_Square_hollow_sections_300x8_0_SHS = ["British","Steel","Square hollow sections","300x8.0 SHS"]
	British_Steel_Square_hollow_sections_300x10_0_SHS = ["British","Steel","Square hollow sections","300x10.0 SHS"]
	British_Steel_Square_hollow_sections_300x12_0_SHS = ["British","Steel","Square hollow sections","300x12.0 SHS"]
	British_Steel_Square_hollow_sections_300x12_5_SHS = ["British","Steel","Square hollow sections","300x12.5 SHS"]
	British_Steel_Square_hollow_sections_300x16_0_SHS = ["British","Steel","Square hollow sections","300x16.0 SHS"]
	British_Steel_Square_hollow_sections_350x8_0_SHS = ["British","Steel","Square hollow sections","350x8.0 SHS"]
	British_Steel_Square_hollow_sections_350x10_0_SHS = ["British","Steel","Square hollow sections","350x10.0 SHS"]
	British_Steel_Square_hollow_sections_350x12_0_SHS = ["British","Steel","Square hollow sections","350x12.0 SHS"]
	British_Steel_Square_hollow_sections_350x12_5_SHS = ["British","Steel","Square hollow sections","350x12.5 SHS"]
	British_Steel_Square_hollow_sections_350x16_0_SHS = ["British","Steel","Square hollow sections","350x16.0 SHS"]
	British_Steel_Square_hollow_sections_350x19_0_SHS = ["British","Steel","Square hollow sections","350x19.0 SHS"]
	British_Steel_Square_hollow_sections_350x22_0_SHS = ["British","Steel","Square hollow sections","350x22.0 SHS"]
	British_Steel_Square_hollow_sections_350x25_0_SHS = ["British","Steel","Square hollow sections","350x25.0 SHS"]
	British_Steel_Square_hollow_sections_400x8_0_SHS = ["British","Steel","Square hollow sections","400x8.0 SHS"]
	British_Steel_Square_hollow_sections_400x10_0_SHS = ["British","Steel","Square hollow sections","400x10.0 SHS"]
	British_Steel_Square_hollow_sections_400x12_0_SHS = ["British","Steel","Square hollow sections","400x12.0 SHS"]
	British_Steel_Square_hollow_sections_400x12_5_SHS = ["British","Steel","Square hollow sections","400x12.5 SHS"]
	British_Steel_Square_hollow_sections_400x16_0_SHS = ["British","Steel","Square hollow sections","400x16.0 SHS"]
	British_Steel_Square_hollow_sections_400x20_0_SHS = ["British","Steel","Square hollow sections","400x20.0 SHS"]
	British_Steel_Square_hollow_sections_400x22_0_SHS = ["British","Steel","Square hollow sections","400x22.0 SHS"]
	British_Steel_Square_hollow_sections_400x25_0_SHS = ["British","Steel","Square hollow sections","400x25.0 SHS"]
	British_Steel_Square_hollow_sections_450x12_0_SHS = ["British","Steel","Square hollow sections","450x12.0 SHS"]
	British_Steel_Square_hollow_sections_450x16_0_SHS = ["British","Steel","Square hollow sections","450x16.0 SHS"]
	British_Steel_Square_hollow_sections_450x19_0_SHS = ["British","Steel","Square hollow sections","450x19.0 SHS"]
	British_Steel_Square_hollow_sections_450x22_0_SHS = ["British","Steel","Square hollow sections","450x22.0 SHS"]
	British_Steel_Square_hollow_sections_450x25_0_SHS = ["British","Steel","Square hollow sections","450x25.0 SHS"]
	British_Steel_Square_hollow_sections_450x28_0_SHS = ["British","Steel","Square hollow sections","450x28.0 SHS"]
	British_Steel_Square_hollow_sections_450x32_0_SHS = ["British","Steel","Square hollow sections","450x32.0 SHS"]
	British_Steel_Square_hollow_sections_500x12_0_SHS = ["British","Steel","Square hollow sections","500x12.0 SHS"]
	British_Steel_Square_hollow_sections_500x16_0_SHS = ["British","Steel","Square hollow sections","500x16.0 SHS"]
	British_Steel_Square_hollow_sections_500x19_0_SHS = ["British","Steel","Square hollow sections","500x19.0 SHS"]
	British_Steel_Square_hollow_sections_500x22_0_SHS = ["British","Steel","Square hollow sections","500x22.0 SHS"]
	British_Steel_Square_hollow_sections_500x25_0_SHS = ["British","Steel","Square hollow sections","500x25.0 SHS"]
	British_Steel_Square_hollow_sections_500x28_0_SHS = ["British","Steel","Square hollow sections","500x28.0 SHS"]
	British_Steel_Square_hollow_sections_500x32_0_SHS = ["British","Steel","Square hollow sections","500x32.0 SHS"]
	British_Steel_Square_hollow_sections_500x36_0_SHS = ["British","Steel","Square hollow sections","500x36.0 SHS"]
	British_Steel_Square_hollow_sections_550x16_0_SHS = ["British","Steel","Square hollow sections","550x16.0 SHS"]
	British_Steel_Square_hollow_sections_550x19_0_SHS = ["British","Steel","Square hollow sections","550x19.0 SHS"]
	British_Steel_Square_hollow_sections_550x22_0_SHS = ["British","Steel","Square hollow sections","550x22.0 SHS"]
	British_Steel_Square_hollow_sections_550x25_0_SHS = ["British","Steel","Square hollow sections","550x25.0 SHS"]
	British_Steel_Square_hollow_sections_550x28_0_SHS = ["British","Steel","Square hollow sections","550x28.0 SHS"]
	British_Steel_Square_hollow_sections_550x32_0_SHS = ["British","Steel","Square hollow sections","550x32.0 SHS"]
	British_Steel_Square_hollow_sections_550x36_0_SHS = ["British","Steel","Square hollow sections","550x36.0 SHS"]
	British_Steel_Square_hollow_sections_550x40_0_SHS = ["British","Steel","Square hollow sections","550x40.0 SHS"]
	British_Steel_Square_hollow_sections_600x25_0_SHS = ["British","Steel","Square hollow sections","600x25.0 SHS"]
	British_Steel_Square_hollow_sections_600x28_0_SHS = ["British","Steel","Square hollow sections","600x28.0 SHS"]
	British_Steel_Square_hollow_sections_600x32_0_SHS = ["British","Steel","Square hollow sections","600x32.0 SHS"]
	British_Steel_Square_hollow_sections_600x36_0_SHS = ["British","Steel","Square hollow sections","600x36.0 SHS"]
	British_Steel_Square_hollow_sections_600x40_0_SHS = ["British","Steel","Square hollow sections","600x40.0 SHS"]
	British_Steel_Square_hollow_sections_700x25_0_SHS = ["British","Steel","Square hollow sections","700x25.0 SHS"]
	British_Steel_Square_hollow_sections_700x28_0_SHS = ["British","Steel","Square hollow sections","700x28.0 SHS"]
	British_Steel_Square_hollow_sections_700x32_0_SHS = ["British","Steel","Square hollow sections","700x32.0 SHS"]
	British_Steel_Square_hollow_sections_700x36_0_SHS = ["British","Steel","Square hollow sections","700x36.0 SHS"]
	British_Steel_Square_hollow_sections_700x40_0_SHS = ["British","Steel","Square hollow sections","700x40.0 SHS"]
	British_Steel_Circular_hollow_sections_21_3x3_2_CHS = ["British","Steel","Circular hollow sections","21.3x3.2 CHS"]
	British_Steel_Circular_hollow_sections_26_9x3_2_CHS = ["British","Steel","Circular hollow sections","26.9x3.2 CHS"]
	British_Steel_Circular_hollow_sections_33_7x2_6_CHS = ["British","Steel","Circular hollow sections","33.7x2.6 CHS"]
	British_Steel_Circular_hollow_sections_33_7x3_0_CHS = ["British","Steel","Circular hollow sections","33.7x3.0 CHS"]
	British_Steel_Circular_hollow_sections_33_7x3_2_CHS = ["British","Steel","Circular hollow sections","33.7x3.2 CHS"]
	British_Steel_Circular_hollow_sections_33_7x3_6_CHS = ["British","Steel","Circular hollow sections","33.7x3.6 CHS"]
	British_Steel_Circular_hollow_sections_33_7x4_0_CHS = ["British","Steel","Circular hollow sections","33.7x4.0 CHS"]
	British_Steel_Circular_hollow_sections_42_4x2_6_CHS = ["British","Steel","Circular hollow sections","42.4x2.6 CHS"]
	British_Steel_Circular_hollow_sections_42_4x3_0_CHS = ["British","Steel","Circular hollow sections","42.4x3.0 CHS"]
	British_Steel_Circular_hollow_sections_42_4x3_2_CHS = ["British","Steel","Circular hollow sections","42.4x3.2 CHS"]
	British_Steel_Circular_hollow_sections_42_4x3_6_CHS = ["British","Steel","Circular hollow sections","42.4x3.6 CHS"]
	British_Steel_Circular_hollow_sections_42_4x4_0_CHS = ["British","Steel","Circular hollow sections","42.4x4.0 CHS"]
	British_Steel_Circular_hollow_sections_48_3x2_5_CHS = ["British","Steel","Circular hollow sections","48.3x2.5 CHS"]
	British_Steel_Circular_hollow_sections_48_3x3_0_CHS = ["British","Steel","Circular hollow sections","48.3x3.0 CHS"]
	British_Steel_Circular_hollow_sections_48_3x3_2_CHS = ["British","Steel","Circular hollow sections","48.3x3.2 CHS"]
	British_Steel_Circular_hollow_sections_48_3x3_6_CHS = ["British","Steel","Circular hollow sections","48.3x3.6 CHS"]
	British_Steel_Circular_hollow_sections_48_3x4_0_CHS = ["British","Steel","Circular hollow sections","48.3x4.0 CHS"]
	British_Steel_Circular_hollow_sections_48_3x5_0_CHS = ["British","Steel","Circular hollow sections","48.3x5.0 CHS"]
	British_Steel_Circular_hollow_sections_60_3x2_5_CHS = ["British","Steel","Circular hollow sections","60.3x2.5 CHS"]
	British_Steel_Circular_hollow_sections_60_3x3_0_CHS = ["British","Steel","Circular hollow sections","60.3x3.0 CHS"]
	British_Steel_Circular_hollow_sections_60_3x3_2_CHS = ["British","Steel","Circular hollow sections","60.3x3.2 CHS"]
	British_Steel_Circular_hollow_sections_60_3x3_6_CHS = ["British","Steel","Circular hollow sections","60.3x3.6 CHS"]
	British_Steel_Circular_hollow_sections_60_3x4_0_CHS = ["British","Steel","Circular hollow sections","60.3x4.0 CHS"]
	British_Steel_Circular_hollow_sections_60_3x5_0_CHS = ["British","Steel","Circular hollow sections","60.3x5.0 CHS"]
	British_Steel_Circular_hollow_sections_76_1x2_5_CHS = ["British","Steel","Circular hollow sections","76.1x2.5 CHS"]
	British_Steel_Circular_hollow_sections_76_1x3_0_CHS = ["British","Steel","Circular hollow sections","76.1x3.0 CHS"]
	British_Steel_Circular_hollow_sections_76_1x3_2_CHS = ["British","Steel","Circular hollow sections","76.1x3.2 CHS"]
	British_Steel_Circular_hollow_sections_76_1x3_6_CHS = ["British","Steel","Circular hollow sections","76.1x3.6 CHS"]
	British_Steel_Circular_hollow_sections_76_1x4_0_CHS = ["British","Steel","Circular hollow sections","76.1x4.0 CHS"]
	British_Steel_Circular_hollow_sections_76_1x5_0_CHS = ["British","Steel","Circular hollow sections","76.1x5.0 CHS"]
	British_Steel_Circular_hollow_sections_76_1x6_0_CHS = ["British","Steel","Circular hollow sections","76.1x6.0 CHS"]
	British_Steel_Circular_hollow_sections_76_1x6_3_CHS = ["British","Steel","Circular hollow sections","76.1x6.3 CHS"]
	British_Steel_Circular_hollow_sections_88_9x2_5_CHS = ["British","Steel","Circular hollow sections","88.9x2.5 CHS"]
	British_Steel_Circular_hollow_sections_88_9x3_0_CHS = ["British","Steel","Circular hollow sections","88.9x3.0 CHS"]
	British_Steel_Circular_hollow_sections_88_9x3_2_CHS = ["British","Steel","Circular hollow sections","88.9x3.2 CHS"]
	British_Steel_Circular_hollow_sections_88_9x3_6_CHS = ["British","Steel","Circular hollow sections","88.9x3.6 CHS"]
	British_Steel_Circular_hollow_sections_88_9x4_0_CHS = ["British","Steel","Circular hollow sections","88.9x4.0 CHS"]
	British_Steel_Circular_hollow_sections_88_9x5_0_CHS = ["British","Steel","Circular hollow sections","88.9x5.0 CHS"]
	British_Steel_Circular_hollow_sections_88_9x6_0_CHS = ["British","Steel","Circular hollow sections","88.9x6.0 CHS"]
	British_Steel_Circular_hollow_sections_88_9x6_3_CHS = ["British","Steel","Circular hollow sections","88.9x6.3 CHS"]
	British_Steel_Circular_hollow_sections_114_3x3_0_CHS = ["British","Steel","Circular hollow sections","114.3x3.0 CHS"]
	British_Steel_Circular_hollow_sections_114_3x3_2_CHS = ["British","Steel","Circular hollow sections","114.3x3.2 CHS"]
	British_Steel_Circular_hollow_sections_114_3x3_6_CHS = ["British","Steel","Circular hollow sections","114.3x3.6 CHS"]
	British_Steel_Circular_hollow_sections_114_3x4_0_CHS = ["British","Steel","Circular hollow sections","114.3x4.0 CHS"]
	British_Steel_Circular_hollow_sections_114_3x5_0_CHS = ["British","Steel","Circular hollow sections","114.3x5.0 CHS"]
	British_Steel_Circular_hollow_sections_114_3x6_0_CHS = ["British","Steel","Circular hollow sections","114.3x6.0 CHS"]
	British_Steel_Circular_hollow_sections_114_3x6_3_CHS = ["British","Steel","Circular hollow sections","114.3x6.3 CHS"]
	British_Steel_Circular_hollow_sections_139_7x3_2_CHS = ["British","Steel","Circular hollow sections","139.7x3.2 CHS"]
	British_Steel_Circular_hollow_sections_139_7x3_6_CHS = ["British","Steel","Circular hollow sections","139.7x3.6 CHS"]
	British_Steel_Circular_hollow_sections_139_7x4_0_CHS = ["British","Steel","Circular hollow sections","139.7x4.0 CHS"]
	British_Steel_Circular_hollow_sections_139_7x5_0_CHS = ["British","Steel","Circular hollow sections","139.7x5.0 CHS"]
	British_Steel_Circular_hollow_sections_139_7x6_0_CHS = ["British","Steel","Circular hollow sections","139.7x6.0 CHS"]
	British_Steel_Circular_hollow_sections_139_7x6_3_CHS = ["British","Steel","Circular hollow sections","139.7x6.3 CHS"]
	British_Steel_Circular_hollow_sections_139_7x8_0_CHS = ["British","Steel","Circular hollow sections","139.7x8.0 CHS"]
	British_Steel_Circular_hollow_sections_139_7x10_0_CHS = ["British","Steel","Circular hollow sections","139.7x10.0 CHS"]
	British_Steel_Circular_hollow_sections_168_3x3_2_CHS = ["British","Steel","Circular hollow sections","168.3x3.2 CHS"]
	British_Steel_Circular_hollow_sections_168_3x3_6_CHS = ["British","Steel","Circular hollow sections","168.3x3.6 CHS"]
	British_Steel_Circular_hollow_sections_168_3x4_0_CHS = ["British","Steel","Circular hollow sections","168.3x4.0 CHS"]
	British_Steel_Circular_hollow_sections_168_3x5_0_CHS = ["British","Steel","Circular hollow sections","168.3x5.0 CHS"]
	British_Steel_Circular_hollow_sections_168_3x6_0_CHS = ["British","Steel","Circular hollow sections","168.3x6.0 CHS"]
	British_Steel_Circular_hollow_sections_168_3x6_3_CHS = ["British","Steel","Circular hollow sections","168.3x6.3 CHS"]
	British_Steel_Circular_hollow_sections_168_3x8_0_CHS = ["British","Steel","Circular hollow sections","168.3x8.0 CHS"]
	British_Steel_Circular_hollow_sections_168_3x10_0_CHS = ["British","Steel","Circular hollow sections","168.3x10.0 CHS"]
	British_Steel_Circular_hollow_sections_168_3x12_0_CHS = ["British","Steel","Circular hollow sections","168.3x12.0 CHS"]
	British_Steel_Circular_hollow_sections_168_3x12_5_CHS = ["British","Steel","Circular hollow sections","168.3x12.5 CHS"]
	British_Steel_Circular_hollow_sections_193_7x5_0_CHS = ["British","Steel","Circular hollow sections","193.7x5.0 CHS"]
	British_Steel_Circular_hollow_sections_193_7x6_0_CHS = ["British","Steel","Circular hollow sections","193.7x6.0 CHS"]
	British_Steel_Circular_hollow_sections_193_7x6_3_CHS = ["British","Steel","Circular hollow sections","193.7x6.3 CHS"]
	British_Steel_Circular_hollow_sections_193_7x8_0_CHS = ["British","Steel","Circular hollow sections","193.7x8.0 CHS"]
	British_Steel_Circular_hollow_sections_193_7x10_0_CHS = ["British","Steel","Circular hollow sections","193.7x10.0 CHS"]
	British_Steel_Circular_hollow_sections_193_7x12_0_CHS = ["British","Steel","Circular hollow sections","193.7x12.0 CHS"]
	British_Steel_Circular_hollow_sections_193_7x12_5_CHS = ["British","Steel","Circular hollow sections","193.7x12.5 CHS"]
	British_Steel_Circular_hollow_sections_193_7x16_0_CHS = ["British","Steel","Circular hollow sections","193.7x16.0 CHS"]
	British_Steel_Circular_hollow_sections_219_1x5_0_CHS = ["British","Steel","Circular hollow sections","219.1x5.0 CHS"]
	British_Steel_Circular_hollow_sections_219_1x6_0_CHS = ["British","Steel","Circular hollow sections","219.1x6.0 CHS"]
	British_Steel_Circular_hollow_sections_219_1x6_3_CHS = ["British","Steel","Circular hollow sections","219.1x6.3 CHS"]
	British_Steel_Circular_hollow_sections_219_1x8_0_CHS = ["British","Steel","Circular hollow sections","219.1x8.0 CHS"]
	British_Steel_Circular_hollow_sections_219_1x10_0_CHS = ["British","Steel","Circular hollow sections","219.1x10.0 CHS"]
	British_Steel_Circular_hollow_sections_219_1x12_0_CHS = ["British","Steel","Circular hollow sections","219.1x12.0 CHS"]
	British_Steel_Circular_hollow_sections_219_1x12_5_CHS = ["British","Steel","Circular hollow sections","219.1x12.5 CHS"]
	British_Steel_Circular_hollow_sections_219_1x16_0_CHS = ["British","Steel","Circular hollow sections","219.1x16.0 CHS"]
	British_Steel_Circular_hollow_sections_219_1x20_0_CHS = ["British","Steel","Circular hollow sections","219.1x20.0 CHS"]
	British_Steel_Circular_hollow_sections_244_5x5_0_CHS = ["British","Steel","Circular hollow sections","244.5x5.0 CHS"]
	British_Steel_Circular_hollow_sections_244_5x6_0_CHS = ["British","Steel","Circular hollow sections","244.5x6.0 CHS"]
	British_Steel_Circular_hollow_sections_244_5x6_3_CHS = ["British","Steel","Circular hollow sections","244.5x6.3 CHS"]
	British_Steel_Circular_hollow_sections_244_5x8_0_CHS = ["British","Steel","Circular hollow sections","244.5x8.0 CHS"]
	British_Steel_Circular_hollow_sections_244_5x10_0_CHS = ["British","Steel","Circular hollow sections","244.5x10.0 CHS"]
	British_Steel_Circular_hollow_sections_244_5x12_0_CHS = ["British","Steel","Circular hollow sections","244.5x12.0 CHS"]
	British_Steel_Circular_hollow_sections_244_5x12_5_CHS = ["British","Steel","Circular hollow sections","244.5x12.5 CHS"]
	British_Steel_Circular_hollow_sections_244_5x16_0_CHS = ["British","Steel","Circular hollow sections","244.5x16.0 CHS"]
	British_Steel_Circular_hollow_sections_244_5x20_0_CHS = ["British","Steel","Circular hollow sections","244.5x20.0 CHS"]
	British_Steel_Circular_hollow_sections_244_5x25_0_CHS = ["British","Steel","Circular hollow sections","244.5x25.0 CHS"]
	British_Steel_Circular_hollow_sections_273x5_0_CHS = ["British","Steel","Circular hollow sections","273x5.0 CHS"]
	British_Steel_Circular_hollow_sections_273x6_0_CHS = ["British","Steel","Circular hollow sections","273x6.0 CHS"]
	British_Steel_Circular_hollow_sections_273x6_3_CHS = ["British","Steel","Circular hollow sections","273x6.3 CHS"]
	British_Steel_Circular_hollow_sections_273x8_0_CHS = ["British","Steel","Circular hollow sections","273x8.0 CHS"]
	British_Steel_Circular_hollow_sections_273x10_0_CHS = ["British","Steel","Circular hollow sections","273x10.0 CHS"]
	British_Steel_Circular_hollow_sections_273x12_0_CHS = ["British","Steel","Circular hollow sections","273x12.0 CHS"]
	British_Steel_Circular_hollow_sections_273x12_5_CHS = ["British","Steel","Circular hollow sections","273x12.5 CHS"]
	British_Steel_Circular_hollow_sections_273x16_0_CHS = ["British","Steel","Circular hollow sections","273x16.0 CHS"]
	British_Steel_Circular_hollow_sections_273x20_0_CHS = ["British","Steel","Circular hollow sections","273x20.0 CHS"]
	British_Steel_Circular_hollow_sections_273x25_0_CHS = ["British","Steel","Circular hollow sections","273x25.0 CHS"]
	British_Steel_Circular_hollow_sections_323_9x5_0_CHS = ["British","Steel","Circular hollow sections","323.9x5.0 CHS"]
	British_Steel_Circular_hollow_sections_323_9x6_0_CHS = ["British","Steel","Circular hollow sections","323.9x6.0 CHS"]
	British_Steel_Circular_hollow_sections_323_9x6_3_CHS = ["British","Steel","Circular hollow sections","323.9x6.3 CHS"]
	British_Steel_Circular_hollow_sections_323_9x8_0_CHS = ["British","Steel","Circular hollow sections","323.9x8.0 CHS"]
	British_Steel_Circular_hollow_sections_323_9x10_0_CHS = ["British","Steel","Circular hollow sections","323.9x10.0 CHS"]
	British_Steel_Circular_hollow_sections_323_9x12_0_CHS = ["British","Steel","Circular hollow sections","323.9x12.0 CHS"]
	British_Steel_Circular_hollow_sections_323_9x12_5_CHS = ["British","Steel","Circular hollow sections","323.9x12.5 CHS"]
	British_Steel_Circular_hollow_sections_323_9x16_0_CHS = ["British","Steel","Circular hollow sections","323.9x16.0 CHS"]
	British_Steel_Circular_hollow_sections_323_9x20_0_CHS = ["British","Steel","Circular hollow sections","323.9x20.0 CHS"]
	British_Steel_Circular_hollow_sections_323_9x25_0_CHS = ["British","Steel","Circular hollow sections","323.9x25.0 CHS"]
	British_Steel_Circular_hollow_sections_355_6x6_3_CHS = ["British","Steel","Circular hollow sections","355.6x6.3 CHS"]
	British_Steel_Circular_hollow_sections_355_6x8_0_CHS = ["British","Steel","Circular hollow sections","355.6x8.0 CHS"]
	British_Steel_Circular_hollow_sections_355_6x10_0_CHS = ["British","Steel","Circular hollow sections","355.6x10.0 CHS"]
	British_Steel_Circular_hollow_sections_355_6x12_0_CHS = ["British","Steel","Circular hollow sections","355.6x12.0 CHS"]
	British_Steel_Circular_hollow_sections_355_6x12_5_CHS = ["British","Steel","Circular hollow sections","355.6x12.5 CHS"]
	British_Steel_Circular_hollow_sections_355_6x16_0_CHS = ["British","Steel","Circular hollow sections","355.6x16.0 CHS"]
	British_Steel_Circular_hollow_sections_355_6x20_0_CHS = ["British","Steel","Circular hollow sections","355.6x20.0 CHS"]
	British_Steel_Circular_hollow_sections_355_6x25_0_CHS = ["British","Steel","Circular hollow sections","355.6x25.0 CHS"]
	British_Steel_Circular_hollow_sections_406_4x6_3_CHS = ["British","Steel","Circular hollow sections","406.4x6.3 CHS"]
	British_Steel_Circular_hollow_sections_406_4x8_0_CHS = ["British","Steel","Circular hollow sections","406.4x8.0 CHS"]
	British_Steel_Circular_hollow_sections_406_4x10_0_CHS = ["British","Steel","Circular hollow sections","406.4x10.0 CHS"]
	British_Steel_Circular_hollow_sections_406_4x12_0_CHS = ["British","Steel","Circular hollow sections","406.4x12.0 CHS"]
	British_Steel_Circular_hollow_sections_406_4x12_5_CHS = ["British","Steel","Circular hollow sections","406.4x12.5 CHS"]
	British_Steel_Circular_hollow_sections_406_4x16_0_CHS = ["British","Steel","Circular hollow sections","406.4x16.0 CHS"]
	British_Steel_Circular_hollow_sections_406_4x20_0_CHS = ["British","Steel","Circular hollow sections","406.4x20.0 CHS"]
	British_Steel_Circular_hollow_sections_406_4x25_0_CHS = ["British","Steel","Circular hollow sections","406.4x25.0 CHS"]
	British_Steel_Circular_hollow_sections_406_4x32_0_CHS = ["British","Steel","Circular hollow sections","406.4x32.0 CHS"]
	British_Steel_Circular_hollow_sections_457x6_3_CHS = ["British","Steel","Circular hollow sections","457x6.3 CHS"]
	British_Steel_Circular_hollow_sections_457x8_0_CHS = ["British","Steel","Circular hollow sections","457x8.0 CHS"]
	British_Steel_Circular_hollow_sections_457x10_0_CHS = ["British","Steel","Circular hollow sections","457x10.0 CHS"]
	British_Steel_Circular_hollow_sections_457x12_0_CHS = ["British","Steel","Circular hollow sections","457x12.0 CHS"]
	British_Steel_Circular_hollow_sections_457x12_5_CHS = ["British","Steel","Circular hollow sections","457x12.5 CHS"]
	British_Steel_Circular_hollow_sections_457x16_0_CHS = ["British","Steel","Circular hollow sections","457x16.0 CHS"]
	British_Steel_Circular_hollow_sections_457x20_0_CHS = ["British","Steel","Circular hollow sections","457x20.0 CHS"]
	British_Steel_Circular_hollow_sections_457x25_0_CHS = ["British","Steel","Circular hollow sections","457x25.0 CHS"]
	British_Steel_Circular_hollow_sections_457x32_0_CHS = ["British","Steel","Circular hollow sections","457x32.0 CHS"]
	British_Steel_Circular_hollow_sections_457x40_0_CHS = ["British","Steel","Circular hollow sections","457x40.0 CHS"]
	British_Steel_Circular_hollow_sections_508x6_3_CHS = ["British","Steel","Circular hollow sections","508x6.3 CHS"]
	British_Steel_Circular_hollow_sections_508x8_0_CHS = ["British","Steel","Circular hollow sections","508x8.0 CHS"]
	British_Steel_Circular_hollow_sections_508x10_0_CHS = ["British","Steel","Circular hollow sections","508x10.0 CHS"]
	British_Steel_Circular_hollow_sections_508x12_0_CHS = ["British","Steel","Circular hollow sections","508x12.0 CHS"]
	British_Steel_Circular_hollow_sections_508x12_5_CHS = ["British","Steel","Circular hollow sections","508x12.5 CHS"]
	British_Steel_Circular_hollow_sections_508x16_0_CHS = ["British","Steel","Circular hollow sections","508x16.0 CHS"]
	British_Steel_Circular_hollow_sections_508x20_0_CHS = ["British","Steel","Circular hollow sections","508x20.0 CHS"]
	British_Steel_Circular_hollow_sections_508x25_0_CHS = ["British","Steel","Circular hollow sections","508x25.0 CHS"]
	British_Steel_Circular_hollow_sections_508x32_0_CHS = ["British","Steel","Circular hollow sections","508x32.0 CHS"]
	British_Steel_Circular_hollow_sections_508x40_0_CHS = ["British","Steel","Circular hollow sections","508x40.0 CHS"]
	British_Steel_Circular_hollow_sections_508x50_0_CHS = ["British","Steel","Circular hollow sections","508x50.0 CHS"]
	British_Steel_Circular_hollow_sections_559x20_0_CHS = ["British","Steel","Circular hollow sections","559x20.0 CHS"]
	British_Steel_Circular_hollow_sections_559x25_0_CHS = ["British","Steel","Circular hollow sections","559x25.0 CHS"]
	British_Steel_Circular_hollow_sections_559x32_0_CHS = ["British","Steel","Circular hollow sections","559x32.0 CHS"]
	British_Steel_Circular_hollow_sections_559x40_0_CHS = ["British","Steel","Circular hollow sections","559x40.0 CHS"]
	British_Steel_Circular_hollow_sections_559x50_0_CHS = ["British","Steel","Circular hollow sections","559x50.0 CHS"]
	British_Steel_Circular_hollow_sections_610x20_0_CHS = ["British","Steel","Circular hollow sections","610x20.0 CHS"]
	British_Steel_Circular_hollow_sections_610x25_0_CHS = ["British","Steel","Circular hollow sections","610x25.0 CHS"]
	British_Steel_Circular_hollow_sections_610x32_0_CHS = ["British","Steel","Circular hollow sections","610x32.0 CHS"]
	British_Steel_Circular_hollow_sections_610x40_0_CHS = ["British","Steel","Circular hollow sections","610x40.0 CHS"]
	British_Steel_Circular_hollow_sections_610x50_0_CHS = ["British","Steel","Circular hollow sections","610x50.0 CHS"]
	British_Steel_Circular_hollow_sections_660x20_0_CHS = ["British","Steel","Circular hollow sections","660x20.0 CHS"]
	British_Steel_Circular_hollow_sections_660x25_0_CHS = ["British","Steel","Circular hollow sections","660x25.0 CHS"]
	British_Steel_Circular_hollow_sections_660x32_0_CHS = ["British","Steel","Circular hollow sections","660x32.0 CHS"]
	British_Steel_Circular_hollow_sections_660x40_0_CHS = ["British","Steel","Circular hollow sections","660x40.0 CHS"]
	British_Steel_Circular_hollow_sections_660x50_0_CHS = ["British","Steel","Circular hollow sections","660x50.0 CHS"]
	British_Steel_Unequal_angles_40x25x4_UA = ["British","Steel","Unequal angles","40x25x4 UA"]
	British_Steel_Unequal_angles_60x30x5_UA = ["British","Steel","Unequal angles","60x30x5 UA"]
	British_Steel_Unequal_angles_60x30x6_UA = ["British","Steel","Unequal angles","60x30x6 UA"]
	British_Steel_Unequal_angles_65x50x5_UA = ["British","Steel","Unequal angles","65x50x5 UA"]
	British_Steel_Unequal_angles_65x50x6_UA = ["British","Steel","Unequal angles","65x50x6 UA"]
	British_Steel_Unequal_angles_65x50x8_UA = ["British","Steel","Unequal angles","65x50x8 UA"]
	British_Steel_Unequal_angles_75x50x6_UA = ["British","Steel","Unequal angles","75x50x6 UA"]
	British_Steel_Unequal_angles_75x50x8_UA = ["British","Steel","Unequal angles","75x50x8 UA"]
	British_Steel_Unequal_angles_80x60x6_UA = ["British","Steel","Unequal angles","80x60x6 UA"]
	British_Steel_Unequal_angles_80x60x7_UA = ["British","Steel","Unequal angles","80x60x7 UA"]
	British_Steel_Unequal_angles_80x60x8_UA = ["British","Steel","Unequal angles","80x60x8 UA"]
	British_Steel_Unequal_angles_100x65x7_UA = ["British","Steel","Unequal angles","100x65x7 UA"]
	British_Steel_Unequal_angles_100x65x8_UA = ["British","Steel","Unequal angles","100x65x8 UA"]
	British_Steel_Unequal_angles_100x65x10_UA = ["British","Steel","Unequal angles","100x65x10 UA"]
	British_Steel_Unequal_angles_100x75x8_UA = ["British","Steel","Unequal angles","100x75x8 UA"]
	British_Steel_Unequal_angles_100x75x10_UA = ["British","Steel","Unequal angles","100x75x10 UA"]
	British_Steel_Unequal_angles_100x75x12_UA = ["British","Steel","Unequal angles","100x75x12 UA"]
	British_Steel_Unequal_angles_125x75x8_UA = ["British","Steel","Unequal angles","125x75x8 UA"]
	British_Steel_Unequal_angles_125x75x10_UA = ["British","Steel","Unequal angles","125x75x10 UA"]
	British_Steel_Unequal_angles_125x75x12_UA = ["British","Steel","Unequal angles","125x75x12 UA"]
	British_Steel_Unequal_angles_150x75x10_UA = ["British","Steel","Unequal angles","150x75x10 UA"]
	British_Steel_Unequal_angles_150x75x12_UA = ["British","Steel","Unequal angles","150x75x12 UA"]
	British_Steel_Unequal_angles_150x75x15_UA = ["British","Steel","Unequal angles","150x75x15 UA"]
	British_Steel_Unequal_angles_150x90x10_UA = ["British","Steel","Unequal angles","150x90x10 UA"]
	British_Steel_Unequal_angles_150x90x12_UA = ["British","Steel","Unequal angles","150x90x12 UA"]
	British_Steel_Unequal_angles_150x90x15_UA = ["British","Steel","Unequal angles","150x90x15 UA"]
	British_Steel_Unequal_angles_200x100x10_UA = ["British","Steel","Unequal angles","200x100x10 UA"]
	British_Steel_Unequal_angles_200x100x12_UA = ["British","Steel","Unequal angles","200x100x12 UA"]
	British_Steel_Unequal_angles_200x100x15_UA = ["British","Steel","Unequal angles","200x100x15 UA"]
	British_Steel_Unequal_angles_200x150x12_UA = ["British","Steel","Unequal angles","200x150x12 UA"]
	British_Steel_Unequal_angles_200x150x15_UA = ["British","Steel","Unequal angles","200x150x15 UA"]
	British_Steel_Unequal_angles_200x150x18_UA = ["British","Steel","Unequal angles","200x150x18 UA"]
	British_Steel_Equal_angles_25x3plus_EA = ["British","Steel","Equal angles","25x3+ EA"]
	British_Steel_Equal_angles_25x4plus_EA = ["British","Steel","Equal angles","25x4+ EA"]
	British_Steel_Equal_angles_25x5plus_EA = ["British","Steel","Equal angles","25x5+ EA"]
	British_Steel_Equal_angles_30x3plus_EA = ["British","Steel","Equal angles","30x3+ EA"]
	British_Steel_Equal_angles_30x4plus_EA = ["British","Steel","Equal angles","30x4+ EA"]
	British_Steel_Equal_angles_30x5plus_EA = ["British","Steel","Equal angles","30x5+ EA"]
	British_Steel_Equal_angles_40x3plus_EA = ["British","Steel","Equal angles","40x3+ EA"]
	British_Steel_Equal_angles_40x4plus_EA = ["British","Steel","Equal angles","40x4+ EA"]
	British_Steel_Equal_angles_40x5plus_EA = ["British","Steel","Equal angles","40x5+ EA"]
	British_Steel_Equal_angles_40x6plus_EA = ["British","Steel","Equal angles","40x6+ EA"]
	British_Steel_Equal_angles_45x3plus_EA = ["British","Steel","Equal angles","45x3+ EA"]
	British_Steel_Equal_angles_45x4plus_EA = ["British","Steel","Equal angles","45x4+ EA"]
	British_Steel_Equal_angles_45x5plus_EA = ["British","Steel","Equal angles","45x5+ EA"]
	British_Steel_Equal_angles_45x6plus_EA = ["British","Steel","Equal angles","45x6+ EA"]
	British_Steel_Equal_angles_50x3plus_EA = ["British","Steel","Equal angles","50x3+ EA"]
	British_Steel_Equal_angles_50x4plus_EA = ["British","Steel","Equal angles","50x4+ EA"]
	British_Steel_Equal_angles_50x5plus_EA = ["British","Steel","Equal angles","50x5+ EA"]
	British_Steel_Equal_angles_50x6plus_EA = ["British","Steel","Equal angles","50x6+ EA"]
	British_Steel_Equal_angles_50x8plus_EA = ["British","Steel","Equal angles","50x8+ EA"]
	British_Steel_Equal_angles_60x5plus_EA = ["British","Steel","Equal angles","60x5+ EA"]
	British_Steel_Equal_angles_60x6plus_EA = ["British","Steel","Equal angles","60x6+ EA"]
	British_Steel_Equal_angles_60x8plus_EA = ["British","Steel","Equal angles","60x8+ EA"]
	British_Steel_Equal_angles_60x10plus_EA = ["British","Steel","Equal angles","60x10+ EA"]
	British_Steel_Equal_angles_70x6plus_EA = ["British","Steel","Equal angles","70x6+ EA"]
	British_Steel_Equal_angles_70x8plus_EA = ["British","Steel","Equal angles","70x8+ EA"]
	British_Steel_Equal_angles_70x10plus_EA = ["British","Steel","Equal angles","70x10+ EA"]
	British_Steel_Equal_angles_80x6plus_EA = ["British","Steel","Equal angles","80x6+ EA"]
	British_Steel_Equal_angles_80x8plus_EA = ["British","Steel","Equal angles","80x8+ EA"]
	British_Steel_Equal_angles_80x10plus_EA = ["British","Steel","Equal angles","80x10+ EA"]
	British_Steel_Equal_angles_90x6_EA = ["British","Steel","Equal angles","90x6 EA"]
	British_Steel_Equal_angles_90x7_EA = ["British","Steel","Equal angles","90x7 EA"]
	British_Steel_Equal_angles_90x8_EA = ["British","Steel","Equal angles","90x8 EA"]
	British_Steel_Equal_angles_90x10_EA = ["British","Steel","Equal angles","90x10 EA"]
	British_Steel_Equal_angles_90x12_EA = ["British","Steel","Equal angles","90x12 EA"]
	British_Steel_Equal_angles_100x8_EA = ["British","Steel","Equal angles","100x8 EA"]
	British_Steel_Equal_angles_100x10_EA = ["British","Steel","Equal angles","100x10 EA"]
	British_Steel_Equal_angles_100x12_EA = ["British","Steel","Equal angles","100x12 EA"]
	British_Steel_Equal_angles_100x15_EA = ["British","Steel","Equal angles","100x15 EA"]
	British_Steel_Equal_angles_120x8_EA = ["British","Steel","Equal angles","120x8 EA"]
	British_Steel_Equal_angles_120x10_EA = ["British","Steel","Equal angles","120x10 EA"]
	British_Steel_Equal_angles_120x12_EA = ["British","Steel","Equal angles","120x12 EA"]
	British_Steel_Equal_angles_120x15_EA = ["British","Steel","Equal angles","120x15 EA"]
	British_Steel_Equal_angles_150x10_EA = ["British","Steel","Equal angles","150x10 EA"]
	British_Steel_Equal_angles_150x12_EA = ["British","Steel","Equal angles","150x12 EA"]
	British_Steel_Equal_angles_150x15_EA = ["British","Steel","Equal angles","150x15 EA"]
	British_Steel_Equal_angles_150x18_EA = ["British","Steel","Equal angles","150x18 EA"]
	British_Steel_Equal_angles_200x16_EA = ["British","Steel","Equal angles","200x16 EA"]
	British_Steel_Equal_angles_200x18_EA = ["British","Steel","Equal angles","200x18 EA"]
	British_Steel_Equal_angles_200x20_EA = ["British","Steel","Equal angles","200x20 EA"]
	British_Steel_Equal_angles_200x24_EA = ["British","Steel","Equal angles","200x24 EA"]
	British_Steel_Universal_beam_tees_102x127x11_UBT = ["British","Steel","Universal beam tees","102x127x11 UBT"]
	British_Steel_Universal_beam_tees_102x127x13_UBT = ["British","Steel","Universal beam tees","102x127x13 UBT"]
	British_Steel_Universal_beam_tees_102x127x14_UBT = ["British","Steel","Universal beam tees","102x127x14 UBT"]
	British_Steel_Universal_beam_tees_102x152x13_UBT = ["British","Steel","Universal beam tees","102x152x13 UBT"]
	British_Steel_Universal_beam_tees_102x152x14_UBT = ["British","Steel","Universal beam tees","102x152x14 UBT"]
	British_Steel_Universal_beam_tees_102x152x17_UBT = ["British","Steel","Universal beam tees","102x152x17 UBT"]
	British_Steel_Universal_beam_tees_127x152x19_UBT = ["British","Steel","Universal beam tees","127x152x19 UBT"]
	British_Steel_Universal_beam_tees_127x152x21_UBT = ["British","Steel","Universal beam tees","127x152x21 UBT"]
	British_Steel_Universal_beam_tees_127x152x24_UBT = ["British","Steel","Universal beam tees","127x152x24 UBT"]
	British_Steel_Universal_beam_tees_127x178x17_UBT = ["British","Steel","Universal beam tees","127x178x17 UBT"]
	British_Steel_Universal_beam_tees_127x178x20_UBT = ["British","Steel","Universal beam tees","127x178x20 UBT"]
	British_Steel_Universal_beam_tees_140x203x20_UBT = ["British","Steel","Universal beam tees","140x203x20 UBT"]
	British_Steel_Universal_beam_tees_140x203x23_UBT = ["British","Steel","Universal beam tees","140x203x23 UBT"]
	British_Steel_Universal_beam_tees_146x127x16_UBT = ["British","Steel","Universal beam tees","146x127x16 UBT"]
	British_Steel_Universal_beam_tees_146x127x19_UBT = ["British","Steel","Universal beam tees","146x127x19 UBT"]
	British_Steel_Universal_beam_tees_146x127x22_UBT = ["British","Steel","Universal beam tees","146x127x22 UBT"]
	British_Steel_Universal_beam_tees_152x229x26_UBT = ["British","Steel","Universal beam tees","152x229x26 UBT"]
	British_Steel_Universal_beam_tees_152x229x30_UBT = ["British","Steel","Universal beam tees","152x229x30 UBT"]
	British_Steel_Universal_beam_tees_152x229x34_UBT = ["British","Steel","Universal beam tees","152x229x34 UBT"]
	British_Steel_Universal_beam_tees_152x229x37_UBT = ["British","Steel","Universal beam tees","152x229x37 UBT"]
	British_Steel_Universal_beam_tees_152x229x41_UBT = ["British","Steel","Universal beam tees","152x229x41 UBT"]
	British_Steel_Universal_beam_tees_165x152x20_UBT = ["British","Steel","Universal beam tees","165x152x20 UBT"]
	British_Steel_Universal_beam_tees_165x152x23_UBT = ["British","Steel","Universal beam tees","165x152x23 UBT"]
	British_Steel_Universal_beam_tees_165x152x27_UBT = ["British","Steel","Universal beam tees","165x152x27 UBT"]
	British_Steel_Universal_beam_tees_171x178x23_UBT = ["British","Steel","Universal beam tees","171x178x23 UBT"]
	British_Steel_Universal_beam_tees_171x178x26_UBT = ["British","Steel","Universal beam tees","171x178x26 UBT"]
	British_Steel_Universal_beam_tees_171x178x29_UBT = ["British","Steel","Universal beam tees","171x178x29 UBT"]
	British_Steel_Universal_beam_tees_171x178x34_UBT = ["British","Steel","Universal beam tees","171x178x34 UBT"]
	British_Steel_Universal_beam_tees_178x203x27_UBT = ["British","Steel","Universal beam tees","178x203x27 UBT"]
	British_Steel_Universal_beam_tees_178x203x30_UBT = ["British","Steel","Universal beam tees","178x203x30 UBT"]
	British_Steel_Universal_beam_tees_178x203x34_UBT = ["British","Steel","Universal beam tees","178x203x34 UBT"]
	British_Steel_Universal_beam_tees_178x203x37_UBT = ["British","Steel","Universal beam tees","178x203x37 UBT"]
	British_Steel_Universal_beam_tees_191x229x34_UBT = ["British","Steel","Universal beam tees","191x229x34 UBT"]
	British_Steel_Universal_beam_tees_191x229x37_UBT = ["British","Steel","Universal beam tees","191x229x37 UBT"]
	British_Steel_Universal_beam_tees_191x229x41_UBT = ["British","Steel","Universal beam tees","191x229x41 UBT"]
	British_Steel_Universal_beam_tees_191x229x45_UBT = ["British","Steel","Universal beam tees","191x229x45 UBT"]
	British_Steel_Universal_beam_tees_191x229x49_UBT = ["British","Steel","Universal beam tees","191x229x49 UBT"]
	British_Steel_Universal_beam_tees_210x267x41_UBT = ["British","Steel","Universal beam tees","210x267x41 UBT"]
	British_Steel_Universal_beam_tees_210x267x46_UBT = ["British","Steel","Universal beam tees","210x267x46 UBT"]
	British_Steel_Universal_beam_tees_210x267x51_UBT = ["British","Steel","Universal beam tees","210x267x51 UBT"]
	British_Steel_Universal_beam_tees_210x267x55_UBT = ["British","Steel","Universal beam tees","210x267x55 UBT"]
	British_Steel_Universal_beam_tees_210x267x61_UBT = ["British","Steel","Universal beam tees","210x267x61 UBT"]
	British_Steel_Universal_beam_tees_229x305x51_UBT = ["British","Steel","Universal beam tees","229x305x51 UBT"]
	British_Steel_Universal_beam_tees_229x305x57_UBT = ["British","Steel","Universal beam tees","229x305x57 UBT"]
	British_Steel_Universal_beam_tees_229x305x63_UBT = ["British","Steel","Universal beam tees","229x305x63 UBT"]
	British_Steel_Universal_beam_tees_229x305x70_UBT = ["British","Steel","Universal beam tees","229x305x70 UBT"]
	British_Steel_Universal_beam_tees_254x343x63_UBT = ["British","Steel","Universal beam tees","254x343x63 UBT"]
	British_Steel_Universal_beam_tees_254x343x70_UBT = ["British","Steel","Universal beam tees","254x343x70 UBT"]
	British_Steel_Universal_beam_tees_254x343x76_UBT = ["British","Steel","Universal beam tees","254x343x76 UBT"]
	British_Steel_Universal_beam_tees_254x343x85_UBT = ["British","Steel","Universal beam tees","254x343x85 UBT"]
	British_Steel_Universal_beam_tees_267x381x74_UBT = ["British","Steel","Universal beam tees","267x381x74 UBT"]
	British_Steel_Universal_beam_tees_267x381x87_UBT = ["British","Steel","Universal beam tees","267x381x87 UBT"]
	British_Steel_Universal_beam_tees_267x381x99_UBT = ["British","Steel","Universal beam tees","267x381x99 UBT"]
	British_Steel_Universal_beam_tees_292x419x88_UBT = ["British","Steel","Universal beam tees","292x419x88 UBT"]
	British_Steel_Universal_beam_tees_292x419x97_UBT = ["British","Steel","Universal beam tees","292x419x97 UBT"]
	British_Steel_Universal_beam_tees_292x419x113_UBT = ["British","Steel","Universal beam tees","292x419x113 UBT"]
	British_Steel_Universal_beam_tees_305x305x75_UBT = ["British","Steel","Universal beam tees","305x305x75 UBT"]
	British_Steel_Universal_beam_tees_305x305x90_UBT = ["British","Steel","Universal beam tees","305x305x90 UBT"]
	British_Steel_Universal_beam_tees_305x305x119_UBT = ["British","Steel","Universal beam tees","305x305x119 UBT"]
	British_Steel_Universal_beam_tees_305x457x101_UBT = ["British","Steel","Universal beam tees","305x457x101 UBT"]
	British_Steel_Universal_beam_tees_305x457x112_UBT = ["British","Steel","Universal beam tees","305x457x112 UBT"]
	British_Steel_Universal_beam_tees_305x457x127_UBT = ["British","Steel","Universal beam tees","305x457x127 UBT"]
	British_Steel_Universal_column_tees_133x102x13_UBT = ["British","Steel","Universal column tees","133x102x13 UBT"]
	British_Steel_Universal_column_tees_133x102x15_UBT = ["British","Steel","Universal column tees","133x102x15 UBT"]
	British_Steel_Universal_column_tees_152x76x12_UCT = ["British","Steel","Universal column tees","152x76x12 UCT"]
	British_Steel_Universal_column_tees_152x76x15_UCT = ["British","Steel","Universal column tees","152x76x15 UCT"]
	British_Steel_Universal_column_tees_152x76x19_UCT = ["British","Steel","Universal column tees","152x76x19 UCT"]
	British_Steel_Universal_column_tees_203x102x23_UCT = ["British","Steel","Universal column tees","203x102x23 UCT"]
	British_Steel_Universal_column_tees_203x102x26_UCT = ["British","Steel","Universal column tees","203x102x26 UCT"]
	British_Steel_Universal_column_tees_203x102x30_UCT = ["British","Steel","Universal column tees","203x102x30 UCT"]
	British_Steel_Universal_column_tees_203x102x36_UCT = ["British","Steel","Universal column tees","203x102x36 UCT"]
	British_Steel_Universal_column_tees_203x102x43_UCT = ["British","Steel","Universal column tees","203x102x43 UCT"]
	British_Steel_Universal_column_tees_254x127x37_UCT = ["British","Steel","Universal column tees","254x127x37 UCT"]
	British_Steel_Universal_column_tees_254x127x45_UCT = ["British","Steel","Universal column tees","254x127x45 UCT"]
	British_Steel_Universal_column_tees_254x127x54_UCT = ["British","Steel","Universal column tees","254x127x54 UCT"]
	British_Steel_Universal_column_tees_254x127x66_UCT = ["British","Steel","Universal column tees","254x127x66 UCT"]
	British_Steel_Universal_column_tees_305x152x49_UCT = ["British","Steel","Universal column tees","305x152x49 UCT"]
	British_Steel_Universal_column_tees_305x152x59_UCT = ["British","Steel","Universal column tees","305x152x59 UCT"]
	British_Steel_Universal_column_tees_305x152x69_UCT = ["British","Steel","Universal column tees","305x152x69 UCT"]
	British_Steel_Universal_column_tees_305x152x79_UCT = ["British","Steel","Universal column tees","305x152x79 UCT"]
	British_Steel_Universal_column_tees_368x178x65_UCT = ["British","Steel","Universal column tees","368x178x65 UCT"]
	British_Steel_Universal_column_tees_368x178x77_UCT = ["British","Steel","Universal column tees","368x178x77 UCT"]
	British_Steel_Universal_column_tees_368x178x89_UCT = ["British","Steel","Universal column tees","368x178x89 UCT"]
	British_Steel_Universal_column_tees_368x178x101_UCT = ["British","Steel","Universal column tees","368x178x101 UCT"]
	British_Steel_Universal_column_tees_406x178x118_UCT = ["British","Steel","Universal column tees","406x178x118 UCT"]
	British_Steel_Bulb_Flats_160x7 = ["British","Steel","Bulb Flats","160x7"]
	British_Steel_Bulb_Flats_160x8 = ["British","Steel","Bulb Flats","160x8"]
	British_Steel_Bulb_Flats_160x9 = ["British","Steel","Bulb Flats","160x9"]
	British_Steel_Bulb_Flats_160x10 = ["British","Steel","Bulb Flats","160x10"]
	British_Steel_Bulb_Flats_160x11 = ["British","Steel","Bulb Flats","160x11"]
	British_Steel_Bulb_Flats_160x11_5 = ["British","Steel","Bulb Flats","160x11.5"]
	British_Steel_Bulb_Flats_180x8 = ["British","Steel","Bulb Flats","180x8"]
	British_Steel_Bulb_Flats_180x9 = ["British","Steel","Bulb Flats","180x9"]
	British_Steel_Bulb_Flats_180x10 = ["British","Steel","Bulb Flats","180x10"]
	British_Steel_Bulb_Flats_180x11 = ["British","Steel","Bulb Flats","180x11"]
	British_Steel_Bulb_Flats_180x11_5 = ["British","Steel","Bulb Flats","180x11.5"]
	British_Steel_Bulb_Flats_200x8_5 = ["British","Steel","Bulb Flats","200x8.5"]
	British_Steel_Bulb_Flats_200x9 = ["British","Steel","Bulb Flats","200x9"]
	British_Steel_Bulb_Flats_200x10 = ["British","Steel","Bulb Flats","200x10"]
	British_Steel_Bulb_Flats_200x11 = ["British","Steel","Bulb Flats","200x11"]
	British_Steel_Bulb_Flats_200x11_5 = ["British","Steel","Bulb Flats","200x11.5"]
	British_Steel_Bulb_Flats_200x12 = ["British","Steel","Bulb Flats","200x12"]
	British_Steel_Bulb_Flats_220x9 = ["British","Steel","Bulb Flats","220x9"]
	British_Steel_Bulb_Flats_220x10 = ["British","Steel","Bulb Flats","220x10"]
	British_Steel_Bulb_Flats_220x11 = ["British","Steel","Bulb Flats","220x11"]
	British_Steel_Bulb_Flats_220x11_5 = ["British","Steel","Bulb Flats","220x11.5"]
	British_Steel_Bulb_Flats_220x12 = ["British","Steel","Bulb Flats","220x12"]
	British_Steel_Bulb_Flats_230x11 = ["British","Steel","Bulb Flats","230x11"]
	British_Steel_Bulb_Flats_240x9_5 = ["British","Steel","Bulb Flats","240x9.5"]
	British_Steel_Bulb_Flats_240x10 = ["British","Steel","Bulb Flats","240x10"]
	British_Steel_Bulb_Flats_240x10_5 = ["British","Steel","Bulb Flats","240x10.5"]
	British_Steel_Bulb_Flats_240x11 = ["British","Steel","Bulb Flats","240x11"]
	British_Steel_Bulb_Flats_240x11_5 = ["British","Steel","Bulb Flats","240x11.5"]
	British_Steel_Bulb_Flats_240x12 = ["British","Steel","Bulb Flats","240x12"]
	British_Steel_Bulb_Flats_260x10 = ["British","Steel","Bulb Flats","260x10"]
	British_Steel_Bulb_Flats_260x11 = ["British","Steel","Bulb Flats","260x11"]
	British_Steel_Bulb_Flats_260x12 = ["British","Steel","Bulb Flats","260x12"]
	British_Steel_Bulb_Flats_260x13 = ["British","Steel","Bulb Flats","260x13"]
	British_Steel_Bulb_Flats_280x10_5 = ["British","Steel","Bulb Flats","280x10.5"]
	British_Steel_Bulb_Flats_280x11 = ["British","Steel","Bulb Flats","280x11"]
	British_Steel_Bulb_Flats_280x12 = ["British","Steel","Bulb Flats","280x12"]
	British_Steel_Bulb_Flats_280x13 = ["British","Steel","Bulb Flats","280x13"]
	British_Steel_Bulb_Flats_300x11 = ["British","Steel","Bulb Flats","300x11"]
	British_Steel_Bulb_Flats_300x12 = ["British","Steel","Bulb Flats","300x12"]
	British_Steel_Bulb_Flats_300x13 = ["British","Steel","Bulb Flats","300x13"]
	British_Steel_Bulb_Flats_320x11_5 = ["British","Steel","Bulb Flats","320x11.5"]
	British_Steel_Bulb_Flats_320x12 = ["British","Steel","Bulb Flats","320x12"]
	British_Steel_Bulb_Flats_320x12_5 = ["British","Steel","Bulb Flats","320x12.5"]
	British_Steel_Bulb_Flats_320x13 = ["British","Steel","Bulb Flats","320x13"]
	British_Steel_Bulb_Flats_320x13_5 = ["British","Steel","Bulb Flats","320x13.5"]
	British_Steel_Bulb_Flats_320x14 = ["British","Steel","Bulb Flats","320x14"]
	British_Steel_Bulb_Flats_340x12 = ["British","Steel","Bulb Flats","340x12"]
	British_Steel_Bulb_Flats_340x12_5 = ["British","Steel","Bulb Flats","340x12.5"]
	British_Steel_Bulb_Flats_340x13 = ["British","Steel","Bulb Flats","340x13"]
	British_Steel_Bulb_Flats_340x14 = ["British","Steel","Bulb Flats","340x14"]
	British_Steel_Bulb_Flats_340x15 = ["British","Steel","Bulb Flats","340x15"]
	British_Steel_Bulb_Flats_370x12_5 = ["British","Steel","Bulb Flats","370x12.5"]
	British_Steel_Bulb_Flats_370x13 = ["British","Steel","Bulb Flats","370x13"]
	British_Steel_Bulb_Flats_370x14 = ["British","Steel","Bulb Flats","370x14"]
	British_Steel_Bulb_Flats_370x15 = ["British","Steel","Bulb Flats","370x15"]
	British_Steel_Bulb_Flats_370x16 = ["British","Steel","Bulb Flats","370x16"]
	British_Steel_Bulb_Flats_400x13 = ["British","Steel","Bulb Flats","400x13"]
	British_Steel_Bulb_Flats_400x14 = ["British","Steel","Bulb Flats","400x14"]
	British_Steel_Bulb_Flats_400x15 = ["British","Steel","Bulb Flats","400x15"]
	British_Steel_Bulb_Flats_400x16 = ["British","Steel","Bulb Flats","400x16"]
	British_Steel_Bulb_Flats_430x14 = ["British","Steel","Bulb Flats","430x14"]
	British_Steel_Bulb_Flats_430x15 = ["British","Steel","Bulb Flats","430x15"]
	British_Steel_Bulb_Flats_430x17 = ["British","Steel","Bulb Flats","430x17"]
	British_Steel_Bulb_Flats_430x18 = ["British","Steel","Bulb Flats","430x18"]
	British_Steel_Bulb_Flats_430x19 = ["British","Steel","Bulb Flats","430x19"]
	British_Steel_Bulb_Flats_430x20 = ["British","Steel","Bulb Flats","430x20"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_26_9x2_5 = ["British","Cold Formed Steel","Cold Formed Circular","26.9x2.5"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_26_9x3_2 = ["British","Cold Formed Steel","Cold Formed Circular","26.9x3.2"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_33_7x3 = ["British","Cold Formed Steel","Cold Formed Circular","33.7x3"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_33_7x3_2 = ["British","Cold Formed Steel","Cold Formed Circular","33.7x3.2"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_33_7x4 = ["British","Cold Formed Steel","Cold Formed Circular","33.7x4"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_42_4x3 = ["British","Cold Formed Steel","Cold Formed Circular","42.4x3"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_42_4x3_2 = ["British","Cold Formed Steel","Cold Formed Circular","42.4x3.2"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_42_4x3_6 = ["British","Cold Formed Steel","Cold Formed Circular","42.4x3.6"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_42_4x4 = ["British","Cold Formed Steel","Cold Formed Circular","42.4x4"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_48_3x3 = ["British","Cold Formed Steel","Cold Formed Circular","48.3x3"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_48_3x3_2 = ["British","Cold Formed Steel","Cold Formed Circular","48.3x3.2"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_48_3x3_6 = ["British","Cold Formed Steel","Cold Formed Circular","48.3x3.6"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_48_3x4 = ["British","Cold Formed Steel","Cold Formed Circular","48.3x4"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_60_3x3 = ["British","Cold Formed Steel","Cold Formed Circular","60.3x3"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_60_3x3_2 = ["British","Cold Formed Steel","Cold Formed Circular","60.3x3.2"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_60_3x3_6 = ["British","Cold Formed Steel","Cold Formed Circular","60.3x3.6"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_60_3x4 = ["British","Cold Formed Steel","Cold Formed Circular","60.3x4"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_60_3x5 = ["British","Cold Formed Steel","Cold Formed Circular","60.3x5"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_76_1x3 = ["British","Cold Formed Steel","Cold Formed Circular","76.1x3"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_76_1x3_2 = ["British","Cold Formed Steel","Cold Formed Circular","76.1x3.2"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_76_1x3_6 = ["British","Cold Formed Steel","Cold Formed Circular","76.1x3.6"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_76_1x4 = ["British","Cold Formed Steel","Cold Formed Circular","76.1x4"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_76_1x5 = ["British","Cold Formed Steel","Cold Formed Circular","76.1x5"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_88_9x3 = ["British","Cold Formed Steel","Cold Formed Circular","88.9x3"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_88_9x3_2 = ["British","Cold Formed Steel","Cold Formed Circular","88.9x3.2"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_88_9x4 = ["British","Cold Formed Steel","Cold Formed Circular","88.9x4"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_88_9x5 = ["British","Cold Formed Steel","Cold Formed Circular","88.9x5"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_101_6x4 = ["British","Cold Formed Steel","Cold Formed Circular","101.6x4"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_101_6x4_5 = ["British","Cold Formed Steel","Cold Formed Circular","101.6x4.5"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_101_6x5 = ["British","Cold Formed Steel","Cold Formed Circular","101.6x5"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_101_6x6 = ["British","Cold Formed Steel","Cold Formed Circular","101.6x6"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_114_3x3 = ["British","Cold Formed Steel","Cold Formed Circular","114.3x3"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_114_3x3_2 = ["British","Cold Formed Steel","Cold Formed Circular","114.3x3.2"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_114_3x3_6 = ["British","Cold Formed Steel","Cold Formed Circular","114.3x3.6"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_114_3x5 = ["British","Cold Formed Steel","Cold Formed Circular","114.3x5"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_114_3x6 = ["British","Cold Formed Steel","Cold Formed Circular","114.3x6"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_114_3x6_3 = ["British","Cold Formed Steel","Cold Formed Circular","114.3x6.3"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_139_7x5 = ["British","Cold Formed Steel","Cold Formed Circular","139.7x5"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_139_7x6 = ["British","Cold Formed Steel","Cold Formed Circular","139.7x6"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_139_7x6_3 = ["British","Cold Formed Steel","Cold Formed Circular","139.7x6.3"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_139_7x8 = ["British","Cold Formed Steel","Cold Formed Circular","139.7x8"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_139_7x10 = ["British","Cold Formed Steel","Cold Formed Circular","139.7x10"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_168_3x4 = ["British","Cold Formed Steel","Cold Formed Circular","168.3x4"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_168_3x5 = ["British","Cold Formed Steel","Cold Formed Circular","168.3x5"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_168_3x6_3 = ["British","Cold Formed Steel","Cold Formed Circular","168.3x6.3"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_168_3x8 = ["British","Cold Formed Steel","Cold Formed Circular","168.3x8"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_168_3x10 = ["British","Cold Formed Steel","Cold Formed Circular","168.3x10"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_168_3x12_5 = ["British","Cold Formed Steel","Cold Formed Circular","168.3x12.5"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_193_7x4 = ["British","Cold Formed Steel","Cold Formed Circular","193.7x4"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_193_7x4_5 = ["British","Cold Formed Steel","Cold Formed Circular","193.7x4.5"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_193_7x5 = ["British","Cold Formed Steel","Cold Formed Circular","193.7x5"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_193_7x6 = ["British","Cold Formed Steel","Cold Formed Circular","193.7x6"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_193_7x6_3 = ["British","Cold Formed Steel","Cold Formed Circular","193.7x6.3"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_193_7x8 = ["British","Cold Formed Steel","Cold Formed Circular","193.7x8"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_193_7x10 = ["British","Cold Formed Steel","Cold Formed Circular","193.7x10"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_193_7x12_5 = ["British","Cold Formed Steel","Cold Formed Circular","193.7x12.5"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_219_1x4_5 = ["British","Cold Formed Steel","Cold Formed Circular","219.1x4.5"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_219_1x5 = ["British","Cold Formed Steel","Cold Formed Circular","219.1x5"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_219_1x6 = ["British","Cold Formed Steel","Cold Formed Circular","219.1x6"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_219_1x6_3 = ["British","Cold Formed Steel","Cold Formed Circular","219.1x6.3"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_219_1x8 = ["British","Cold Formed Steel","Cold Formed Circular","219.1x8"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_219_1x10 = ["British","Cold Formed Steel","Cold Formed Circular","219.1x10"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_219_1x12 = ["British","Cold Formed Steel","Cold Formed Circular","219.1x12"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_219_1x12_5 = ["British","Cold Formed Steel","Cold Formed Circular","219.1x12.5"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_219_1x16 = ["British","Cold Formed Steel","Cold Formed Circular","219.1x16"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_244_5x5 = ["British","Cold Formed Steel","Cold Formed Circular","244.5x5"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_244_5x6 = ["British","Cold Formed Steel","Cold Formed Circular","244.5x6"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_244_5x6_3 = ["British","Cold Formed Steel","Cold Formed Circular","244.5x6.3"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_244_5x8 = ["British","Cold Formed Steel","Cold Formed Circular","244.5x8"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_244_5x10 = ["British","Cold Formed Steel","Cold Formed Circular","244.5x10"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_244_5x12 = ["British","Cold Formed Steel","Cold Formed Circular","244.5x12"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_244_5x12_5 = ["British","Cold Formed Steel","Cold Formed Circular","244.5x12.5"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_244_5x16 = ["British","Cold Formed Steel","Cold Formed Circular","244.5x16"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_273x5 = ["British","Cold Formed Steel","Cold Formed Circular","273x5"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_273x6 = ["British","Cold Formed Steel","Cold Formed Circular","273x6"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_273x6_3 = ["British","Cold Formed Steel","Cold Formed Circular","273x6.3"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_273x8 = ["British","Cold Formed Steel","Cold Formed Circular","273x8"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_273x10 = ["British","Cold Formed Steel","Cold Formed Circular","273x10"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_273x12 = ["British","Cold Formed Steel","Cold Formed Circular","273x12"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_273x12_5 = ["British","Cold Formed Steel","Cold Formed Circular","273x12.5"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_273x16 = ["British","Cold Formed Steel","Cold Formed Circular","273x16"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_323_9x5 = ["British","Cold Formed Steel","Cold Formed Circular","323.9x5"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_323_9x6 = ["British","Cold Formed Steel","Cold Formed Circular","323.9x6"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_323_9x6_3 = ["British","Cold Formed Steel","Cold Formed Circular","323.9x6.3"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_323_9x8 = ["British","Cold Formed Steel","Cold Formed Circular","323.9x8"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_323_9x10 = ["British","Cold Formed Steel","Cold Formed Circular","323.9x10"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_323_9x12 = ["British","Cold Formed Steel","Cold Formed Circular","323.9x12"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_323_9x12_5 = ["British","Cold Formed Steel","Cold Formed Circular","323.9x12.5"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_323_9x16 = ["British","Cold Formed Steel","Cold Formed Circular","323.9x16"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_355_6x5 = ["British","Cold Formed Steel","Cold Formed Circular","355.6x5"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_355_6x6 = ["British","Cold Formed Steel","Cold Formed Circular","355.6x6"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_355_6x6_3 = ["British","Cold Formed Steel","Cold Formed Circular","355.6x6.3"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_355_6x8 = ["British","Cold Formed Steel","Cold Formed Circular","355.6x8"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_355_6x10 = ["British","Cold Formed Steel","Cold Formed Circular","355.6x10"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_355_6x12 = ["British","Cold Formed Steel","Cold Formed Circular","355.6x12"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_355_6x12_5 = ["British","Cold Formed Steel","Cold Formed Circular","355.6x12.5"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_355_6x16 = ["British","Cold Formed Steel","Cold Formed Circular","355.6x16"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_406_4x6 = ["British","Cold Formed Steel","Cold Formed Circular","406.4x6"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_406_4x6_3 = ["British","Cold Formed Steel","Cold Formed Circular","406.4x6.3"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_406_4x8 = ["British","Cold Formed Steel","Cold Formed Circular","406.4x8"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_406_4x10 = ["British","Cold Formed Steel","Cold Formed Circular","406.4x10"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_406_4x12 = ["British","Cold Formed Steel","Cold Formed Circular","406.4x12"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_406_4x12_5 = ["British","Cold Formed Steel","Cold Formed Circular","406.4x12.5"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_406_4x16 = ["British","Cold Formed Steel","Cold Formed Circular","406.4x16"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_457x6 = ["British","Cold Formed Steel","Cold Formed Circular","457x6"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_457x6_3 = ["British","Cold Formed Steel","Cold Formed Circular","457x6.3"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_457x8 = ["British","Cold Formed Steel","Cold Formed Circular","457x8"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_457x10 = ["British","Cold Formed Steel","Cold Formed Circular","457x10"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_457x12 = ["British","Cold Formed Steel","Cold Formed Circular","457x12"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_457x12_5 = ["British","Cold Formed Steel","Cold Formed Circular","457x12.5"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_457x16 = ["British","Cold Formed Steel","Cold Formed Circular","457x16"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_508x6 = ["British","Cold Formed Steel","Cold Formed Circular","508x6"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_508x6_3 = ["British","Cold Formed Steel","Cold Formed Circular","508x6.3"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_508x8 = ["British","Cold Formed Steel","Cold Formed Circular","508x8"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_508x10 = ["British","Cold Formed Steel","Cold Formed Circular","508x10"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_508x12 = ["British","Cold Formed Steel","Cold Formed Circular","508x12"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_508x12_5 = ["British","Cold Formed Steel","Cold Formed Circular","508x12.5"]
	British_Cold_Formed_Steel_Cold_Formed_Circular_508x16 = ["British","Cold Formed Steel","Cold Formed Circular","508x16"]
	British_Cold_Formed_Steel_Cold_Formed_Square_12x12x1 = ["British","Cold Formed Steel","Cold Formed Square","12x12x1"]
	British_Cold_Formed_Steel_Cold_Formed_Square_12x12x1_2 = ["British","Cold Formed Steel","Cold Formed Square","12x12x1.2"]
	British_Cold_Formed_Steel_Cold_Formed_Square_12x12x1_6 = ["British","Cold Formed Steel","Cold Formed Square","12x12x1.6"]
	British_Cold_Formed_Steel_Cold_Formed_Square_13x13x1_2 = ["British","Cold Formed Steel","Cold Formed Square","13x13x1.2"]
	British_Cold_Formed_Steel_Cold_Formed_Square_13x13x1_6 = ["British","Cold Formed Steel","Cold Formed Square","13x13x1.6"]
	British_Cold_Formed_Steel_Cold_Formed_Square_16x16x1 = ["British","Cold Formed Steel","Cold Formed Square","16x16x1"]
	British_Cold_Formed_Steel_Cold_Formed_Square_16x16x1_2 = ["British","Cold Formed Steel","Cold Formed Square","16x16x1.2"]
	British_Cold_Formed_Steel_Cold_Formed_Square_16x16x1_6 = ["British","Cold Formed Steel","Cold Formed Square","16x16x1.6"]
	British_Cold_Formed_Steel_Cold_Formed_Square_19x19x1 = ["British","Cold Formed Steel","Cold Formed Square","19x19x1"]
	British_Cold_Formed_Steel_Cold_Formed_Square_19x19x1_2 = ["British","Cold Formed Steel","Cold Formed Square","19x19x1.2"]
	British_Cold_Formed_Steel_Cold_Formed_Square_19x19x1_6 = ["British","Cold Formed Steel","Cold Formed Square","19x19x1.6"]
	British_Cold_Formed_Steel_Cold_Formed_Square_20x20x2 = ["British","Cold Formed Steel","Cold Formed Square","20x20x2"]
	British_Cold_Formed_Steel_Cold_Formed_Square_20x20x2_5 = ["British","Cold Formed Steel","Cold Formed Square","20x20x2.5"]
	British_Cold_Formed_Steel_Cold_Formed_Square_25x25x1_2 = ["British","Cold Formed Steel","Cold Formed Square","25x25x1.2"]
	British_Cold_Formed_Steel_Cold_Formed_Square_25x25x1_6 = ["British","Cold Formed Steel","Cold Formed Square","25x25x1.6"]
	British_Cold_Formed_Steel_Cold_Formed_Square_25x25x1_8 = ["British","Cold Formed Steel","Cold Formed Square","25x25x1.8"]
	British_Cold_Formed_Steel_Cold_Formed_Square_25x25x2 = ["British","Cold Formed Steel","Cold Formed Square","25x25x2"]
	British_Cold_Formed_Steel_Cold_Formed_Square_25x25x2_3 = ["British","Cold Formed Steel","Cold Formed Square","25x25x2.3"]
	British_Cold_Formed_Steel_Cold_Formed_Square_25x25x2_4 = ["British","Cold Formed Steel","Cold Formed Square","25x25x2.4"]
	British_Cold_Formed_Steel_Cold_Formed_Square_25x25x2_5 = ["British","Cold Formed Steel","Cold Formed Square","25x25x2.5"]
	British_Cold_Formed_Steel_Cold_Formed_Square_25x25x3 = ["British","Cold Formed Steel","Cold Formed Square","25x25x3"]
	British_Cold_Formed_Steel_Cold_Formed_Square_30x30x1_2 = ["British","Cold Formed Steel","Cold Formed Square","30x30x1.2"]
	British_Cold_Formed_Steel_Cold_Formed_Square_30x30x1_6 = ["British","Cold Formed Steel","Cold Formed Square","30x30x1.6"]
	British_Cold_Formed_Steel_Cold_Formed_Square_30x30x1_8 = ["British","Cold Formed Steel","Cold Formed Square","30x30x1.8"]
	British_Cold_Formed_Steel_Cold_Formed_Square_30x30x2_3 = ["British","Cold Formed Steel","Cold Formed Square","30x30x2.3"]
	British_Cold_Formed_Steel_Cold_Formed_Square_30x30x3 = ["British","Cold Formed Steel","Cold Formed Square","30x30x3"]
	British_Cold_Formed_Steel_Cold_Formed_Square_30x30x3_2 = ["British","Cold Formed Steel","Cold Formed Square","30x30x3.2"]
	British_Cold_Formed_Steel_Cold_Formed_Square_32x32x1_2 = ["British","Cold Formed Steel","Cold Formed Square","32x32x1.2"]
	British_Cold_Formed_Steel_Cold_Formed_Square_32x32x1_6 = ["British","Cold Formed Steel","Cold Formed Square","32x32x1.6"]
	British_Cold_Formed_Steel_Cold_Formed_Square_32x32x2 = ["British","Cold Formed Steel","Cold Formed Square","32x32x2"]
	British_Cold_Formed_Steel_Cold_Formed_Square_32x32x2_3 = ["British","Cold Formed Steel","Cold Formed Square","32x32x2.3"]
	British_Cold_Formed_Steel_Cold_Formed_Square_32x32x3 = ["British","Cold Formed Steel","Cold Formed Square","32x32x3"]
	British_Cold_Formed_Steel_Cold_Formed_Square_38x38x1_6 = ["British","Cold Formed Steel","Cold Formed Square","38x38x1.6"]
	British_Cold_Formed_Steel_Cold_Formed_Square_38x38x2 = ["British","Cold Formed Steel","Cold Formed Square","38x38x2"]
	British_Cold_Formed_Steel_Cold_Formed_Square_38x38x2_3 = ["British","Cold Formed Steel","Cold Formed Square","38x38x2.3"]
	British_Cold_Formed_Steel_Cold_Formed_Square_38x38x3 = ["British","Cold Formed Steel","Cold Formed Square","38x38x3"]
	British_Cold_Formed_Steel_Cold_Formed_Square_40x40x2 = ["British","Cold Formed Steel","Cold Formed Square","40x40x2"]
	British_Cold_Formed_Steel_Cold_Formed_Square_40x40x2_5 = ["British","Cold Formed Steel","Cold Formed Square","40x40x2.5"]
	British_Cold_Formed_Steel_Cold_Formed_Square_40x40x3 = ["British","Cold Formed Steel","Cold Formed Square","40x40x3"]
	British_Cold_Formed_Steel_Cold_Formed_Square_40x40x4 = ["British","Cold Formed Steel","Cold Formed Square","40x40x4"]
	British_Cold_Formed_Steel_Cold_Formed_Square_50x50x1_5 = ["British","Cold Formed Steel","Cold Formed Square","50x50x1.5"]
	British_Cold_Formed_Steel_Cold_Formed_Square_50x50x1_6 = ["British","Cold Formed Steel","Cold Formed Square","50x50x1.6"]
	British_Cold_Formed_Steel_Cold_Formed_Square_50x50x2 = ["British","Cold Formed Steel","Cold Formed Square","50x50x2"]
	British_Cold_Formed_Steel_Cold_Formed_Square_50x50x2_3 = ["British","Cold Formed Steel","Cold Formed Square","50x50x2.3"]
	British_Cold_Formed_Steel_Cold_Formed_Square_50x50x3 = ["British","Cold Formed Steel","Cold Formed Square","50x50x3"]
	British_Cold_Formed_Steel_Cold_Formed_Square_50x50x3_2 = ["British","Cold Formed Steel","Cold Formed Square","50x50x3.2"]
	British_Cold_Formed_Steel_Cold_Formed_Square_50x50x4 = ["British","Cold Formed Steel","Cold Formed Square","50x50x4"]
	British_Cold_Formed_Steel_Cold_Formed_Square_50x50x4_5 = ["British","Cold Formed Steel","Cold Formed Square","50x50x4.5"]
	British_Cold_Formed_Steel_Cold_Formed_Square_50x50x5 = ["British","Cold Formed Steel","Cold Formed Square","50x50x5"]
	British_Cold_Formed_Steel_Cold_Formed_Square_50x50x6 = ["British","Cold Formed Steel","Cold Formed Square","50x50x6"]
	British_Cold_Formed_Steel_Cold_Formed_Square_60x60x1_6 = ["British","Cold Formed Steel","Cold Formed Square","60x60x1.6"]
	British_Cold_Formed_Steel_Cold_Formed_Square_60x60x2_3 = ["British","Cold Formed Steel","Cold Formed Square","60x60x2.3"]
	British_Cold_Formed_Steel_Cold_Formed_Square_60x60x3 = ["British","Cold Formed Steel","Cold Formed Square","60x60x3"]
	British_Cold_Formed_Steel_Cold_Formed_Square_60x60x4 = ["British","Cold Formed Steel","Cold Formed Square","60x60x4"]
	British_Cold_Formed_Steel_Cold_Formed_Square_60x60x4_5 = ["British","Cold Formed Steel","Cold Formed Square","60x60x4.5"]
	British_Cold_Formed_Steel_Cold_Formed_Square_60x60x5 = ["British","Cold Formed Steel","Cold Formed Square","60x60x5"]
	British_Cold_Formed_Steel_Cold_Formed_Square_60x60x6 = ["British","Cold Formed Steel","Cold Formed Square","60x60x6"]
	British_Cold_Formed_Steel_Cold_Formed_Square_63_5x63_5x2_3 = ["British","Cold Formed Steel","Cold Formed Square","63.5x63.5x2.3"]
	British_Cold_Formed_Steel_Cold_Formed_Square_63_5x63_5x3 = ["British","Cold Formed Steel","Cold Formed Square","63.5x63.5x3"]
	British_Cold_Formed_Steel_Cold_Formed_Square_63_5x63_5x4_5 = ["British","Cold Formed Steel","Cold Formed Square","63.5x63.5x4.5"]
	British_Cold_Formed_Steel_Cold_Formed_Square_63_5x63_5x5 = ["British","Cold Formed Steel","Cold Formed Square","63.5x63.5x5"]
	British_Cold_Formed_Steel_Cold_Formed_Square_63_5x63_5x6 = ["British","Cold Formed Steel","Cold Formed Square","63.5x63.5x6"]
	British_Cold_Formed_Steel_Cold_Formed_Square_65x65x1_6 = ["British","Cold Formed Steel","Cold Formed Square","65x65x1.6"]
	British_Cold_Formed_Steel_Cold_Formed_Square_65x65x2_3 = ["British","Cold Formed Steel","Cold Formed Square","65x65x2.3"]
	British_Cold_Formed_Steel_Cold_Formed_Square_65x65x3 = ["British","Cold Formed Steel","Cold Formed Square","65x65x3"]
	British_Cold_Formed_Steel_Cold_Formed_Square_65x65x4 = ["British","Cold Formed Steel","Cold Formed Square","65x65x4"]
	British_Cold_Formed_Steel_Cold_Formed_Square_65x65x4_5 = ["British","Cold Formed Steel","Cold Formed Square","65x65x4.5"]
	British_Cold_Formed_Steel_Cold_Formed_Square_65x65x5 = ["British","Cold Formed Steel","Cold Formed Square","65x65x5"]
	British_Cold_Formed_Steel_Cold_Formed_Square_65x65x6 = ["British","Cold Formed Steel","Cold Formed Square","65x65x6"]
	British_Cold_Formed_Steel_Cold_Formed_Square_70x70x2_5 = ["British","Cold Formed Steel","Cold Formed Square","70x70x2.5"]
	British_Cold_Formed_Steel_Cold_Formed_Square_70x70x3 = ["British","Cold Formed Steel","Cold Formed Square","70x70x3"]
	British_Cold_Formed_Steel_Cold_Formed_Square_70x70x3_6 = ["British","Cold Formed Steel","Cold Formed Square","70x70x3.6"]
	British_Cold_Formed_Steel_Cold_Formed_Square_70x70x4 = ["British","Cold Formed Steel","Cold Formed Square","70x70x4"]
	British_Cold_Formed_Steel_Cold_Formed_Square_70x70x5 = ["British","Cold Formed Steel","Cold Formed Square","70x70x5"]
	British_Cold_Formed_Steel_Cold_Formed_Square_75x75x2_3 = ["British","Cold Formed Steel","Cold Formed Square","75x75x2.3"]
	British_Cold_Formed_Steel_Cold_Formed_Square_75x75x3 = ["British","Cold Formed Steel","Cold Formed Square","75x75x3"]
	British_Cold_Formed_Steel_Cold_Formed_Square_75x75x4 = ["British","Cold Formed Steel","Cold Formed Square","75x75x4"]
	British_Cold_Formed_Steel_Cold_Formed_Square_75x75x4_5 = ["British","Cold Formed Steel","Cold Formed Square","75x75x4.5"]
	British_Cold_Formed_Steel_Cold_Formed_Square_75x75x5 = ["British","Cold Formed Steel","Cold Formed Square","75x75x5"]
	British_Cold_Formed_Steel_Cold_Formed_Square_75x75x6 = ["British","Cold Formed Steel","Cold Formed Square","75x75x6"]
	British_Cold_Formed_Steel_Cold_Formed_Square_80x80x3 = ["British","Cold Formed Steel","Cold Formed Square","80x80x3"]
	British_Cold_Formed_Steel_Cold_Formed_Square_80x80x3_6 = ["British","Cold Formed Steel","Cold Formed Square","80x80x3.6"]
	British_Cold_Formed_Steel_Cold_Formed_Square_80x80x4 = ["British","Cold Formed Steel","Cold Formed Square","80x80x4"]
	British_Cold_Formed_Steel_Cold_Formed_Square_80x80x5 = ["British","Cold Formed Steel","Cold Formed Square","80x80x5"]
	British_Cold_Formed_Steel_Cold_Formed_Square_80x80x6 = ["British","Cold Formed Steel","Cold Formed Square","80x80x6"]
	British_Cold_Formed_Steel_Cold_Formed_Square_80x80x6_3 = ["British","Cold Formed Steel","Cold Formed Square","80x80x6.3"]
	British_Cold_Formed_Steel_Cold_Formed_Square_90x90x2_3 = ["British","Cold Formed Steel","Cold Formed Square","90x90x2.3"]
	British_Cold_Formed_Steel_Cold_Formed_Square_90x90x3 = ["British","Cold Formed Steel","Cold Formed Square","90x90x3"]
	British_Cold_Formed_Steel_Cold_Formed_Square_90x90x3_2 = ["British","Cold Formed Steel","Cold Formed Square","90x90x3.2"]
	British_Cold_Formed_Steel_Cold_Formed_Square_90x90x3_6 = ["British","Cold Formed Steel","Cold Formed Square","90x90x3.6"]
	British_Cold_Formed_Steel_Cold_Formed_Square_90x90x4 = ["British","Cold Formed Steel","Cold Formed Square","90x90x4"]
	British_Cold_Formed_Steel_Cold_Formed_Square_90x90x4_5 = ["British","Cold Formed Steel","Cold Formed Square","90x90x4.5"]
	British_Cold_Formed_Steel_Cold_Formed_Square_90x90x5 = ["British","Cold Formed Steel","Cold Formed Square","90x90x5"]
	British_Cold_Formed_Steel_Cold_Formed_Square_90x90x6 = ["British","Cold Formed Steel","Cold Formed Square","90x90x6"]
	British_Cold_Formed_Steel_Cold_Formed_Square_100x100x2_3 = ["British","Cold Formed Steel","Cold Formed Square","100x100x2.3"]
	British_Cold_Formed_Steel_Cold_Formed_Square_100x100x3 = ["British","Cold Formed Steel","Cold Formed Square","100x100x3"]
	British_Cold_Formed_Steel_Cold_Formed_Square_100x100x3_2 = ["British","Cold Formed Steel","Cold Formed Square","100x100x3.2"]
	British_Cold_Formed_Steel_Cold_Formed_Square_100x100x4 = ["British","Cold Formed Steel","Cold Formed Square","100x100x4"]
	British_Cold_Formed_Steel_Cold_Formed_Square_100x100x4_5 = ["British","Cold Formed Steel","Cold Formed Square","100x100x4.5"]
	British_Cold_Formed_Steel_Cold_Formed_Square_100x100x5 = ["British","Cold Formed Steel","Cold Formed Square","100x100x5"]
	British_Cold_Formed_Steel_Cold_Formed_Square_100x100x6 = ["British","Cold Formed Steel","Cold Formed Square","100x100x6"]
	British_Cold_Formed_Steel_Cold_Formed_Square_100x100x6_3 = ["British","Cold Formed Steel","Cold Formed Square","100x100x6.3"]
	British_Cold_Formed_Steel_Cold_Formed_Square_100x100x8 = ["British","Cold Formed Steel","Cold Formed Square","100x100x8"]
	British_Cold_Formed_Steel_Cold_Formed_Square_100x100x9 = ["British","Cold Formed Steel","Cold Formed Square","100x100x9"]
	British_Cold_Formed_Steel_Cold_Formed_Square_100x100x10 = ["British","Cold Formed Steel","Cold Formed Square","100x100x10"]
	British_Cold_Formed_Steel_Cold_Formed_Square_120x120x4 = ["British","Cold Formed Steel","Cold Formed Square","120x120x4"]
	British_Cold_Formed_Steel_Cold_Formed_Square_120x120x5 = ["British","Cold Formed Steel","Cold Formed Square","120x120x5"]
	British_Cold_Formed_Steel_Cold_Formed_Square_120x120x6 = ["British","Cold Formed Steel","Cold Formed Square","120x120x6"]
	British_Cold_Formed_Steel_Cold_Formed_Square_120x120x6_3 = ["British","Cold Formed Steel","Cold Formed Square","120x120x6.3"]
	British_Cold_Formed_Steel_Cold_Formed_Square_120x120x8 = ["British","Cold Formed Steel","Cold Formed Square","120x120x8"]
	British_Cold_Formed_Steel_Cold_Formed_Square_125x125x2_3 = ["British","Cold Formed Steel","Cold Formed Square","125x125x2.3"]
	British_Cold_Formed_Steel_Cold_Formed_Square_125x125x3 = ["British","Cold Formed Steel","Cold Formed Square","125x125x3"]
	British_Cold_Formed_Steel_Cold_Formed_Square_125x125x3_2 = ["British","Cold Formed Steel","Cold Formed Square","125x125x3.2"]
	British_Cold_Formed_Steel_Cold_Formed_Square_125x125x4_5 = ["British","Cold Formed Steel","Cold Formed Square","125x125x4.5"]
	British_Cold_Formed_Steel_Cold_Formed_Square_125x125x5 = ["British","Cold Formed Steel","Cold Formed Square","125x125x5"]
	British_Cold_Formed_Steel_Cold_Formed_Square_125x125x6 = ["British","Cold Formed Steel","Cold Formed Square","125x125x6"]
	British_Cold_Formed_Steel_Cold_Formed_Square_125x125x6_4 = ["British","Cold Formed Steel","Cold Formed Square","125x125x6.4"]
	British_Cold_Formed_Steel_Cold_Formed_Square_125x125x9 = ["British","Cold Formed Steel","Cold Formed Square","125x125x9"]
	British_Cold_Formed_Steel_Cold_Formed_Square_150x150x3 = ["British","Cold Formed Steel","Cold Formed Square","150x150x3"]
	British_Cold_Formed_Steel_Cold_Formed_Square_150x150x4 = ["British","Cold Formed Steel","Cold Formed Square","150x150x4"]
	British_Cold_Formed_Steel_Cold_Formed_Square_150x150x4_5 = ["British","Cold Formed Steel","Cold Formed Square","150x150x4.5"]
	British_Cold_Formed_Steel_Cold_Formed_Square_150x150x5 = ["British","Cold Formed Steel","Cold Formed Square","150x150x5"]
	British_Cold_Formed_Steel_Cold_Formed_Square_150x150x6 = ["British","Cold Formed Steel","Cold Formed Square","150x150x6"]
	British_Cold_Formed_Steel_Cold_Formed_Square_150x150x6_3 = ["British","Cold Formed Steel","Cold Formed Square","150x150x6.3"]
	British_Cold_Formed_Steel_Cold_Formed_Square_150x150x8 = ["British","Cold Formed Steel","Cold Formed Square","150x150x8"]
	British_Cold_Formed_Steel_Cold_Formed_Square_150x150x9 = ["British","Cold Formed Steel","Cold Formed Square","150x150x9"]
	British_Cold_Formed_Steel_Cold_Formed_Square_150x150x10 = ["British","Cold Formed Steel","Cold Formed Square","150x150x10"]
	British_Cold_Formed_Steel_Cold_Formed_Square_150x150x12 = ["British","Cold Formed Steel","Cold Formed Square","150x150x12"]
	British_Cold_Formed_Steel_Cold_Formed_Square_175x175x4 = ["British","Cold Formed Steel","Cold Formed Square","175x175x4"]
	British_Cold_Formed_Steel_Cold_Formed_Square_175x175x4_5 = ["British","Cold Formed Steel","Cold Formed Square","175x175x4.5"]
	British_Cold_Formed_Steel_Cold_Formed_Square_175x175x5 = ["British","Cold Formed Steel","Cold Formed Square","175x175x5"]
	British_Cold_Formed_Steel_Cold_Formed_Square_175x175x6 = ["British","Cold Formed Steel","Cold Formed Square","175x175x6"]
	British_Cold_Formed_Steel_Cold_Formed_Square_175x175x9 = ["British","Cold Formed Steel","Cold Formed Square","175x175x9"]
	British_Cold_Formed_Steel_Cold_Formed_Square_175x175x12_7 = ["British","Cold Formed Steel","Cold Formed Square","175x175x12.7"]
	British_Cold_Formed_Steel_Cold_Formed_Square_180x180x5 = ["British","Cold Formed Steel","Cold Formed Square","180x180x5"]
	British_Cold_Formed_Steel_Cold_Formed_Square_180x180x6 = ["British","Cold Formed Steel","Cold Formed Square","180x180x6"]
	British_Cold_Formed_Steel_Cold_Formed_Square_180x180x6_3 = ["British","Cold Formed Steel","Cold Formed Square","180x180x6.3"]
	British_Cold_Formed_Steel_Cold_Formed_Square_180x180x8 = ["British","Cold Formed Steel","Cold Formed Square","180x180x8"]
	British_Cold_Formed_Steel_Cold_Formed_Square_180x180x10 = ["British","Cold Formed Steel","Cold Formed Square","180x180x10"]
	British_Cold_Formed_Steel_Cold_Formed_Square_180x180x12 = ["British","Cold Formed Steel","Cold Formed Square","180x180x12"]
	British_Cold_Formed_Steel_Cold_Formed_Square_180x180x12_5 = ["British","Cold Formed Steel","Cold Formed Square","180x180x12.5"]
	British_Cold_Formed_Steel_Cold_Formed_Square_200x200x5 = ["British","Cold Formed Steel","Cold Formed Square","200x200x5"]
	British_Cold_Formed_Steel_Cold_Formed_Square_200x200x6 = ["British","Cold Formed Steel","Cold Formed Square","200x200x6"]
	British_Cold_Formed_Steel_Cold_Formed_Square_200x200x6_3 = ["British","Cold Formed Steel","Cold Formed Square","200x200x6.3"]
	British_Cold_Formed_Steel_Cold_Formed_Square_200x200x8 = ["British","Cold Formed Steel","Cold Formed Square","200x200x8"]
	British_Cold_Formed_Steel_Cold_Formed_Square_200x200x9 = ["British","Cold Formed Steel","Cold Formed Square","200x200x9"]
	British_Cold_Formed_Steel_Cold_Formed_Square_200x200x10 = ["British","Cold Formed Steel","Cold Formed Square","200x200x10"]
	British_Cold_Formed_Steel_Cold_Formed_Square_200x200x12 = ["British","Cold Formed Steel","Cold Formed Square","200x200x12"]
	British_Cold_Formed_Steel_Cold_Formed_Square_200x200x12_5 = ["British","Cold Formed Steel","Cold Formed Square","200x200x12.5"]
	British_Cold_Formed_Steel_Cold_Formed_Square_203x203x4_5 = ["British","Cold Formed Steel","Cold Formed Square","203x203x4.5"]
	British_Cold_Formed_Steel_Cold_Formed_Square_203x203x6_4 = ["British","Cold Formed Steel","Cold Formed Square","203x203x6.4"]
	British_Cold_Formed_Steel_Cold_Formed_Square_203x203x9_5 = ["British","Cold Formed Steel","Cold Formed Square","203x203x9.5"]
	British_Cold_Formed_Steel_Cold_Formed_Square_203x203x12_7 = ["British","Cold Formed Steel","Cold Formed Square","203x203x12.7"]
	British_Cold_Formed_Steel_Cold_Formed_Square_250x250x6 = ["British","Cold Formed Steel","Cold Formed Square","250x250x6"]
	British_Cold_Formed_Steel_Cold_Formed_Square_250x250x6_3 = ["British","Cold Formed Steel","Cold Formed Square","250x250x6.3"]
	British_Cold_Formed_Steel_Cold_Formed_Square_250x250x8 = ["British","Cold Formed Steel","Cold Formed Square","250x250x8"]
	British_Cold_Formed_Steel_Cold_Formed_Square_250x250x9 = ["British","Cold Formed Steel","Cold Formed Square","250x250x9"]
	British_Cold_Formed_Steel_Cold_Formed_Square_250x250x10 = ["British","Cold Formed Steel","Cold Formed Square","250x250x10"]
	British_Cold_Formed_Steel_Cold_Formed_Square_250x250x12 = ["British","Cold Formed Steel","Cold Formed Square","250x250x12"]
	British_Cold_Formed_Steel_Cold_Formed_Square_250x250x12_5 = ["British","Cold Formed Steel","Cold Formed Square","250x250x12.5"]
	British_Cold_Formed_Steel_Cold_Formed_Square_254x254x6_4 = ["British","Cold Formed Steel","Cold Formed Square","254x254x6.4"]
	British_Cold_Formed_Steel_Cold_Formed_Square_254x254x9_5 = ["British","Cold Formed Steel","Cold Formed Square","254x254x9.5"]
	British_Cold_Formed_Steel_Cold_Formed_Square_254x254x12_7 = ["British","Cold Formed Steel","Cold Formed Square","254x254x12.7"]
	British_Cold_Formed_Steel_Cold_Formed_Square_300x300x6 = ["British","Cold Formed Steel","Cold Formed Square","300x300x6"]
	British_Cold_Formed_Steel_Cold_Formed_Square_300x300x8 = ["British","Cold Formed Steel","Cold Formed Square","300x300x8"]
	British_Cold_Formed_Steel_Cold_Formed_Square_300x300x9 = ["British","Cold Formed Steel","Cold Formed Square","300x300x9"]
	British_Cold_Formed_Steel_Cold_Formed_Square_300x300x10 = ["British","Cold Formed Steel","Cold Formed Square","300x300x10"]
	British_Cold_Formed_Steel_Cold_Formed_Square_300x300x12 = ["British","Cold Formed Steel","Cold Formed Square","300x300x12"]
	British_Cold_Formed_Steel_Cold_Formed_Square_300x300x12_5 = ["British","Cold Formed Steel","Cold Formed Square","300x300x12.5"]
	British_Cold_Formed_Steel_Cold_Formed_Square_300x300x16 = ["British","Cold Formed Steel","Cold Formed Square","300x300x16"]
	British_Cold_Formed_Steel_Cold_Formed_Square_350x350x9 = ["British","Cold Formed Steel","Cold Formed Square","350x350x9"]
	British_Cold_Formed_Steel_Cold_Formed_Square_350x350x12 = ["British","Cold Formed Steel","Cold Formed Square","350x350x12"]
	British_Cold_Formed_Steel_Cold_Formed_Square_350x350x16 = ["British","Cold Formed Steel","Cold Formed Square","350x350x16"]
	British_Cold_Formed_Steel_Cold_Formed_Square_400x400x9 = ["British","Cold Formed Steel","Cold Formed Square","400x400x9"]
	British_Cold_Formed_Steel_Cold_Formed_Square_400x400x12 = ["British","Cold Formed Steel","Cold Formed Square","400x400x12"]
	British_Cold_Formed_Steel_Cold_Formed_Square_400x400x16 = ["British","Cold Formed Steel","Cold Formed Square","400x400x16"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_19x9x1 = ["British","Cold Formed Steel","Cold Formed Rectangular","19x9x1"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_19x9x1_2 = ["British","Cold Formed Steel","Cold Formed Rectangular","19x9x1.2"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_19x9x1_6 = ["British","Cold Formed Steel","Cold Formed Rectangular","19x9x1.6"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_25x12x1 = ["British","Cold Formed Steel","Cold Formed Rectangular","25x12x1"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_25x12x1_2 = ["British","Cold Formed Steel","Cold Formed Rectangular","25x12x1.2"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_25x12x1_6 = ["British","Cold Formed Steel","Cold Formed Rectangular","25x12x1.6"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_25x13x1_2 = ["British","Cold Formed Steel","Cold Formed Rectangular","25x13x1.2"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_25x13x1_6 = ["British","Cold Formed Steel","Cold Formed Rectangular","25x13x1.6"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_32x16x1 = ["British","Cold Formed Steel","Cold Formed Rectangular","32x16x1"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_32x16x1_2 = ["British","Cold Formed Steel","Cold Formed Rectangular","32x16x1.2"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_32x16x1_6 = ["British","Cold Formed Steel","Cold Formed Rectangular","32x16x1.6"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_38x19x1 = ["British","Cold Formed Steel","Cold Formed Rectangular","38x19x1"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_38x19x1_2 = ["British","Cold Formed Steel","Cold Formed Rectangular","38x19x1.2"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_38x19x1_6 = ["British","Cold Formed Steel","Cold Formed Rectangular","38x19x1.6"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_38x25x1 = ["British","Cold Formed Steel","Cold Formed Rectangular","38x25x1"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_38x25x1_2 = ["British","Cold Formed Steel","Cold Formed Rectangular","38x25x1.2"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_38x25x1_6 = ["British","Cold Formed Steel","Cold Formed Rectangular","38x25x1.6"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_50x25x1 = ["British","Cold Formed Steel","Cold Formed Rectangular","50x25x1"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_50x25x1_2 = ["British","Cold Formed Steel","Cold Formed Rectangular","50x25x1.2"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_50x25x1_6 = ["British","Cold Formed Steel","Cold Formed Rectangular","50x25x1.6"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_50x25x2 = ["British","Cold Formed Steel","Cold Formed Rectangular","50x25x2"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_50x25x2_3 = ["British","Cold Formed Steel","Cold Formed Rectangular","50x25x2.3"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_50x25x2_5 = ["British","Cold Formed Steel","Cold Formed Rectangular","50x25x2.5"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_50x25x3 = ["British","Cold Formed Steel","Cold Formed Rectangular","50x25x3"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_50x25x3_2 = ["British","Cold Formed Steel","Cold Formed Rectangular","50x25x3.2"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_50x30x2 = ["British","Cold Formed Steel","Cold Formed Rectangular","50x30x2"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_50x30x2_5 = ["British","Cold Formed Steel","Cold Formed Rectangular","50x30x2.5"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_50x30x3 = ["British","Cold Formed Steel","Cold Formed Rectangular","50x30x3"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_50x30x4 = ["British","Cold Formed Steel","Cold Formed Rectangular","50x30x4"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_60x40x1_6 = ["British","Cold Formed Steel","Cold Formed Rectangular","60x40x1.6"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_60x40x2_3 = ["British","Cold Formed Steel","Cold Formed Rectangular","60x40x2.3"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_60x40x2_5 = ["British","Cold Formed Steel","Cold Formed Rectangular","60x40x2.5"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_60x40x3 = ["British","Cold Formed Steel","Cold Formed Rectangular","60x40x3"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_60x40x4 = ["British","Cold Formed Steel","Cold Formed Rectangular","60x40x4"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_60x40x4_5 = ["British","Cold Formed Steel","Cold Formed Rectangular","60x40x4.5"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_65x38x1_6 = ["British","Cold Formed Steel","Cold Formed Rectangular","65x38x1.6"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_65x38x2_3 = ["British","Cold Formed Steel","Cold Formed Rectangular","65x38x2.3"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_65x38x3 = ["British","Cold Formed Steel","Cold Formed Rectangular","65x38x3"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_65x38x3_2 = ["British","Cold Formed Steel","Cold Formed Rectangular","65x38x3.2"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_65x38x4 = ["British","Cold Formed Steel","Cold Formed Rectangular","65x38x4"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_75x38x1_6 = ["British","Cold Formed Steel","Cold Formed Rectangular","75x38x1.6"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_75x38x1_9 = ["British","Cold Formed Steel","Cold Formed Rectangular","75x38x1.9"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_75x38x2_3 = ["British","Cold Formed Steel","Cold Formed Rectangular","75x38x2.3"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_75x38x3 = ["British","Cold Formed Steel","Cold Formed Rectangular","75x38x3"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_75x38x3_2 = ["British","Cold Formed Steel","Cold Formed Rectangular","75x38x3.2"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_75x38x4 = ["British","Cold Formed Steel","Cold Formed Rectangular","75x38x4"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_75x38x4_5 = ["British","Cold Formed Steel","Cold Formed Rectangular","75x38x4.5"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_75x50x1_9 = ["British","Cold Formed Steel","Cold Formed Rectangular","75x50x1.9"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_75x50x2_3 = ["British","Cold Formed Steel","Cold Formed Rectangular","75x50x2.3"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_75x50x3 = ["British","Cold Formed Steel","Cold Formed Rectangular","75x50x3"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_75x50x3_2 = ["British","Cold Formed Steel","Cold Formed Rectangular","75x50x3.2"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_75x50x4 = ["British","Cold Formed Steel","Cold Formed Rectangular","75x50x4"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_75x50x4_5 = ["British","Cold Formed Steel","Cold Formed Rectangular","75x50x4.5"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_75x50x4_6 = ["British","Cold Formed Steel","Cold Formed Rectangular","75x50x4.6"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_75x50x4_8 = ["British","Cold Formed Steel","Cold Formed Rectangular","75x50x4.8"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_75x50x5 = ["British","Cold Formed Steel","Cold Formed Rectangular","75x50x5"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_75x50x6 = ["British","Cold Formed Steel","Cold Formed Rectangular","75x50x6"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_80x40x3 = ["British","Cold Formed Steel","Cold Formed Rectangular","80x40x3"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_80x40x4 = ["British","Cold Formed Steel","Cold Formed Rectangular","80x40x4"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_90x50x3 = ["British","Cold Formed Steel","Cold Formed Rectangular","90x50x3"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_90x50x3_6 = ["British","Cold Formed Steel","Cold Formed Rectangular","90x50x3.6"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_90x50x4 = ["British","Cold Formed Steel","Cold Formed Rectangular","90x50x4"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_90x50x5 = ["British","Cold Formed Steel","Cold Formed Rectangular","90x50x5"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_100x50x1_9 = ["British","Cold Formed Steel","Cold Formed Rectangular","100x50x1.9"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_100x50x2_3 = ["British","Cold Formed Steel","Cold Formed Rectangular","100x50x2.3"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_100x50x3 = ["British","Cold Formed Steel","Cold Formed Rectangular","100x50x3"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_100x50x3_2 = ["British","Cold Formed Steel","Cold Formed Rectangular","100x50x3.2"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_100x50x4 = ["British","Cold Formed Steel","Cold Formed Rectangular","100x50x4"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_100x50x4_5 = ["British","Cold Formed Steel","Cold Formed Rectangular","100x50x4.5"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_100x50x5 = ["British","Cold Formed Steel","Cold Formed Rectangular","100x50x5"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_100x50x6 = ["British","Cold Formed Steel","Cold Formed Rectangular","100x50x6"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_100x50x6_3 = ["British","Cold Formed Steel","Cold Formed Rectangular","100x50x6.3"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_100x60x3 = ["British","Cold Formed Steel","Cold Formed Rectangular","100x60x3"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_100x60x3_6 = ["British","Cold Formed Steel","Cold Formed Rectangular","100x60x3.6"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_100x60x4 = ["British","Cold Formed Steel","Cold Formed Rectangular","100x60x4"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_100x60x5 = ["British","Cold Formed Steel","Cold Formed Rectangular","100x60x5"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_100x60x6 = ["British","Cold Formed Steel","Cold Formed Rectangular","100x60x6"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_100x60x6_3 = ["British","Cold Formed Steel","Cold Formed Rectangular","100x60x6.3"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_100x75x2_3 = ["British","Cold Formed Steel","Cold Formed Rectangular","100x75x2.3"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_100x75x3 = ["British","Cold Formed Steel","Cold Formed Rectangular","100x75x3"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_100x75x3_2 = ["British","Cold Formed Steel","Cold Formed Rectangular","100x75x3.2"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_100x75x4 = ["British","Cold Formed Steel","Cold Formed Rectangular","100x75x4"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_100x75x4_5 = ["British","Cold Formed Steel","Cold Formed Rectangular","100x75x4.5"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_100x75x4_6 = ["British","Cold Formed Steel","Cold Formed Rectangular","100x75x4.6"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_100x75x4_8 = ["British","Cold Formed Steel","Cold Formed Rectangular","100x75x4.8"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_100x75x5 = ["British","Cold Formed Steel","Cold Formed Rectangular","100x75x5"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_100x75x6 = ["British","Cold Formed Steel","Cold Formed Rectangular","100x75x6"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_120x60x3 = ["British","Cold Formed Steel","Cold Formed Rectangular","120x60x3"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_120x60x3_6 = ["British","Cold Formed Steel","Cold Formed Rectangular","120x60x3.6"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_120x60x4 = ["British","Cold Formed Steel","Cold Formed Rectangular","120x60x4"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_120x60x5 = ["British","Cold Formed Steel","Cold Formed Rectangular","120x60x5"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_120x60x6 = ["British","Cold Formed Steel","Cold Formed Rectangular","120x60x6"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_120x60x6_3 = ["British","Cold Formed Steel","Cold Formed Rectangular","120x60x6.3"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_120x80x4 = ["British","Cold Formed Steel","Cold Formed Rectangular","120x80x4"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_120x80x5 = ["British","Cold Formed Steel","Cold Formed Rectangular","120x80x5"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_120x80x6 = ["British","Cold Formed Steel","Cold Formed Rectangular","120x80x6"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_120x80x6_3 = ["British","Cold Formed Steel","Cold Formed Rectangular","120x80x6.3"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_120x80x8 = ["British","Cold Formed Steel","Cold Formed Rectangular","120x80x8"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_125x50x2_3 = ["British","Cold Formed Steel","Cold Formed Rectangular","125x50x2.3"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_125x50x3 = ["British","Cold Formed Steel","Cold Formed Rectangular","125x50x3"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_125x50x3_2 = ["British","Cold Formed Steel","Cold Formed Rectangular","125x50x3.2"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_125x50x4 = ["British","Cold Formed Steel","Cold Formed Rectangular","125x50x4"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_125x50x4_5 = ["British","Cold Formed Steel","Cold Formed Rectangular","125x50x4.5"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_125x50x4_6 = ["British","Cold Formed Steel","Cold Formed Rectangular","125x50x4.6"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_125x50x4_8 = ["British","Cold Formed Steel","Cold Formed Rectangular","125x50x4.8"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_125x50x5 = ["British","Cold Formed Steel","Cold Formed Rectangular","125x50x5"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_125x50x6 = ["British","Cold Formed Steel","Cold Formed Rectangular","125x50x6"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_125x50x6_4 = ["British","Cold Formed Steel","Cold Formed Rectangular","125x50x6.4"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_125x75x2_3 = ["British","Cold Formed Steel","Cold Formed Rectangular","125x75x2.3"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_125x75x3 = ["British","Cold Formed Steel","Cold Formed Rectangular","125x75x3"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_125x75x3_2 = ["British","Cold Formed Steel","Cold Formed Rectangular","125x75x3.2"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_125x75x4 = ["British","Cold Formed Steel","Cold Formed Rectangular","125x75x4"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_125x75x4_5 = ["British","Cold Formed Steel","Cold Formed Rectangular","125x75x4.5"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_125x75x5 = ["British","Cold Formed Steel","Cold Formed Rectangular","125x75x5"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_125x75x6 = ["British","Cold Formed Steel","Cold Formed Rectangular","125x75x6"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_125x75x6_4 = ["British","Cold Formed Steel","Cold Formed Rectangular","125x75x6.4"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_150x50x3 = ["British","Cold Formed Steel","Cold Formed Rectangular","150x50x3"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_150x50x3_2 = ["British","Cold Formed Steel","Cold Formed Rectangular","150x50x3.2"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_150x50x4 = ["British","Cold Formed Steel","Cold Formed Rectangular","150x50x4"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_150x50x4_5 = ["British","Cold Formed Steel","Cold Formed Rectangular","150x50x4.5"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_150x50x4_6 = ["British","Cold Formed Steel","Cold Formed Rectangular","150x50x4.6"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_150x50x4_8 = ["British","Cold Formed Steel","Cold Formed Rectangular","150x50x4.8"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_150x50x5 = ["British","Cold Formed Steel","Cold Formed Rectangular","150x50x5"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_150x50x6 = ["British","Cold Formed Steel","Cold Formed Rectangular","150x50x6"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_150x50x6_4 = ["British","Cold Formed Steel","Cold Formed Rectangular","150x50x6.4"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_150x75x3 = ["British","Cold Formed Steel","Cold Formed Rectangular","150x75x3"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_150x75x3_2 = ["British","Cold Formed Steel","Cold Formed Rectangular","150x75x3.2"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_150x75x4 = ["British","Cold Formed Steel","Cold Formed Rectangular","150x75x4"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_150x75x4_5 = ["British","Cold Formed Steel","Cold Formed Rectangular","150x75x4.5"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_150x75x4_6 = ["British","Cold Formed Steel","Cold Formed Rectangular","150x75x4.6"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_150x75x4_8 = ["British","Cold Formed Steel","Cold Formed Rectangular","150x75x4.8"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_150x75x5 = ["British","Cold Formed Steel","Cold Formed Rectangular","150x75x5"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_150x75x6 = ["British","Cold Formed Steel","Cold Formed Rectangular","150x75x6"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_150x75x6_4 = ["British","Cold Formed Steel","Cold Formed Rectangular","150x75x6.4"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_150x75x9 = ["British","Cold Formed Steel","Cold Formed Rectangular","150x75x9"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_150x100x3 = ["British","Cold Formed Steel","Cold Formed Rectangular","150x100x3"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_150x100x3_2 = ["British","Cold Formed Steel","Cold Formed Rectangular","150x100x3.2"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_150x100x4 = ["British","Cold Formed Steel","Cold Formed Rectangular","150x100x4"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_150x100x4_5 = ["British","Cold Formed Steel","Cold Formed Rectangular","150x100x4.5"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_150x100x4_6 = ["British","Cold Formed Steel","Cold Formed Rectangular","150x100x4.6"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_150x100x4_8 = ["British","Cold Formed Steel","Cold Formed Rectangular","150x100x4.8"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_150x100x5 = ["British","Cold Formed Steel","Cold Formed Rectangular","150x100x5"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_150x100x6 = ["British","Cold Formed Steel","Cold Formed Rectangular","150x100x6"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_150x100x6_3 = ["British","Cold Formed Steel","Cold Formed Rectangular","150x100x6.3"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_150x100x6_4 = ["British","Cold Formed Steel","Cold Formed Rectangular","150x100x6.4"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_150x100x8 = ["British","Cold Formed Steel","Cold Formed Rectangular","150x100x8"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_150x100x9 = ["British","Cold Formed Steel","Cold Formed Rectangular","150x100x9"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_150x100x9_5 = ["British","Cold Formed Steel","Cold Formed Rectangular","150x100x9.5"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_150x100x12_7 = ["British","Cold Formed Steel","Cold Formed Rectangular","150x100x12.7"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_160x80x5 = ["British","Cold Formed Steel","Cold Formed Rectangular","160x80x5"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_160x80x6 = ["British","Cold Formed Steel","Cold Formed Rectangular","160x80x6"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_160x80x8 = ["British","Cold Formed Steel","Cold Formed Rectangular","160x80x8"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_175x100x4_8 = ["British","Cold Formed Steel","Cold Formed Rectangular","175x100x4.8"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_175x100x6_4 = ["British","Cold Formed Steel","Cold Formed Rectangular","175x100x6.4"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_175x100x9_5 = ["British","Cold Formed Steel","Cold Formed Rectangular","175x100x9.5"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_175x100x12_7 = ["British","Cold Formed Steel","Cold Formed Rectangular","175x100x12.7"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_175x125x4_8 = ["British","Cold Formed Steel","Cold Formed Rectangular","175x125x4.8"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_175x125x6_4 = ["British","Cold Formed Steel","Cold Formed Rectangular","175x125x6.4"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_175x125x9_5 = ["British","Cold Formed Steel","Cold Formed Rectangular","175x125x9.5"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_175x125x12_7 = ["British","Cold Formed Steel","Cold Formed Rectangular","175x125x12.7"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_200x100x4 = ["British","Cold Formed Steel","Cold Formed Rectangular","200x100x4"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_200x100x4_5 = ["British","Cold Formed Steel","Cold Formed Rectangular","200x100x4.5"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_200x100x5 = ["British","Cold Formed Steel","Cold Formed Rectangular","200x100x5"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_200x100x6 = ["British","Cold Formed Steel","Cold Formed Rectangular","200x100x6"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_200x100x6_3 = ["British","Cold Formed Steel","Cold Formed Rectangular","200x100x6.3"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_200x100x8 = ["British","Cold Formed Steel","Cold Formed Rectangular","200x100x8"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_200x100x9 = ["British","Cold Formed Steel","Cold Formed Rectangular","200x100x9"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_200x100x9_5 = ["British","Cold Formed Steel","Cold Formed Rectangular","200x100x9.5"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_200x100x12 = ["British","Cold Formed Steel","Cold Formed Rectangular","200x100x12"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_200x100x12_7 = ["British","Cold Formed Steel","Cold Formed Rectangular","200x100x12.7"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_200x150x4_5 = ["British","Cold Formed Steel","Cold Formed Rectangular","200x150x4.5"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_200x150x6 = ["British","Cold Formed Steel","Cold Formed Rectangular","200x150x6"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_200x150x6_3 = ["British","Cold Formed Steel","Cold Formed Rectangular","200x150x6.3"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_200x150x9 = ["British","Cold Formed Steel","Cold Formed Rectangular","200x150x9"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_200x150x9_5 = ["British","Cold Formed Steel","Cold Formed Rectangular","200x150x9.5"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_200x150x12 = ["British","Cold Formed Steel","Cold Formed Rectangular","200x150x12"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_200x150x12_7 = ["British","Cold Formed Steel","Cold Formed Rectangular","200x150x12.7"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_250x150x5 = ["British","Cold Formed Steel","Cold Formed Rectangular","250x150x5"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_250x150x6 = ["British","Cold Formed Steel","Cold Formed Rectangular","250x150x6"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_250x150x6_3 = ["British","Cold Formed Steel","Cold Formed Rectangular","250x150x6.3"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_250x150x8 = ["British","Cold Formed Steel","Cold Formed Rectangular","250x150x8"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_250x150x9 = ["British","Cold Formed Steel","Cold Formed Rectangular","250x150x9"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_250x150x10 = ["British","Cold Formed Steel","Cold Formed Rectangular","250x150x10"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_250x150x12 = ["British","Cold Formed Steel","Cold Formed Rectangular","250x150x12"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_250x150x12_5 = ["British","Cold Formed Steel","Cold Formed Rectangular","250x150x12.5"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_300x100x6 = ["British","Cold Formed Steel","Cold Formed Rectangular","300x100x6"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_300x100x6_3 = ["British","Cold Formed Steel","Cold Formed Rectangular","300x100x6.3"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_300x100x10 = ["British","Cold Formed Steel","Cold Formed Rectangular","300x100x10"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_300x200x6 = ["British","Cold Formed Steel","Cold Formed Rectangular","300x200x6"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_300x200x6_3 = ["British","Cold Formed Steel","Cold Formed Rectangular","300x200x6.3"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_300x200x8 = ["British","Cold Formed Steel","Cold Formed Rectangular","300x200x8"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_300x200x9 = ["British","Cold Formed Steel","Cold Formed Rectangular","300x200x9"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_300x200x10 = ["British","Cold Formed Steel","Cold Formed Rectangular","300x200x10"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_300x200x12 = ["British","Cold Formed Steel","Cold Formed Rectangular","300x200x12"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_300x200x12_5 = ["British","Cold Formed Steel","Cold Formed Rectangular","300x200x12.5"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_400x200x6 = ["British","Cold Formed Steel","Cold Formed Rectangular","400x200x6"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_400x200x8 = ["British","Cold Formed Steel","Cold Formed Rectangular","400x200x8"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_400x200x9 = ["British","Cold Formed Steel","Cold Formed Rectangular","400x200x9"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_400x200x10 = ["British","Cold Formed Steel","Cold Formed Rectangular","400x200x10"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_400x200x12 = ["British","Cold Formed Steel","Cold Formed Rectangular","400x200x12"]
	British_Cold_Formed_Steel_Cold_Formed_Rectangular_400x200x12_5 = ["British","Cold Formed Steel","Cold Formed Rectangular","400x200x12.5"]
	British_Cold_Formed_Steel_Plain_Channels_60x30x1_6 = ["British","Cold Formed Steel","Plain Channels","60x30x1.6"]
	British_Cold_Formed_Steel_Plain_Channels_60x30x2_3 = ["British","Cold Formed Steel","Plain Channels","60x30x2.3"]
	British_Cold_Formed_Steel_Plain_Channels_75x45x1_6 = ["British","Cold Formed Steel","Plain Channels","75x45x1.6"]
	British_Cold_Formed_Steel_Plain_Channels_75x45x2_3 = ["British","Cold Formed Steel","Plain Channels","75x45x2.3"]
	British_Cold_Formed_Steel_Plain_Channels_75x45x3 = ["British","Cold Formed Steel","Plain Channels","75x45x3"]
	British_Cold_Formed_Steel_Plain_Channels_100x50x1_6 = ["British","Cold Formed Steel","Plain Channels","100x50x1.6"]
	British_Cold_Formed_Steel_Plain_Channels_100x50x2_3 = ["British","Cold Formed Steel","Plain Channels","100x50x2.3"]
	British_Cold_Formed_Steel_Plain_Channels_100x50x3 = ["British","Cold Formed Steel","Plain Channels","100x50x3"]
	British_Cold_Formed_Steel_Plain_Channels_100x50x4 = ["British","Cold Formed Steel","Plain Channels","100x50x4"]
	British_Cold_Formed_Steel_Plain_Channels_125x50x2_3 = ["British","Cold Formed Steel","Plain Channels","125x50x2.3"]
	British_Cold_Formed_Steel_Plain_Channels_125x50x3 = ["British","Cold Formed Steel","Plain Channels","125x50x3"]
	British_Cold_Formed_Steel_Plain_Channels_125x50x4 = ["British","Cold Formed Steel","Plain Channels","125x50x4"]
	British_Cold_Formed_Steel_Plain_Channels_125x50x4_5 = ["British","Cold Formed Steel","Plain Channels","125x50x4.5"]
	British_Cold_Formed_Steel_Plain_Channels_150x65x2_3 = ["British","Cold Formed Steel","Plain Channels","150x65x2.3"]
	British_Cold_Formed_Steel_Plain_Channels_150x65x3 = ["British","Cold Formed Steel","Plain Channels","150x65x3"]
	British_Cold_Formed_Steel_Plain_Channels_150x65x4 = ["British","Cold Formed Steel","Plain Channels","150x65x4"]
	British_Cold_Formed_Steel_Plain_Channels_150x65x4_5 = ["British","Cold Formed Steel","Plain Channels","150x65x4.5"]
	British_Cold_Formed_Steel_Plain_Channels_175x75x2_3 = ["British","Cold Formed Steel","Plain Channels","175x75x2.3"]
	British_Cold_Formed_Steel_Plain_Channels_175x75x3 = ["British","Cold Formed Steel","Plain Channels","175x75x3"]
	British_Cold_Formed_Steel_Plain_Channels_175x75x4 = ["British","Cold Formed Steel","Plain Channels","175x75x4"]
	British_Cold_Formed_Steel_Plain_Channels_175x75x4_5 = ["British","Cold Formed Steel","Plain Channels","175x75x4.5"]
	British_Cold_Formed_Steel_Plain_Channels_200x75x2_3 = ["British","Cold Formed Steel","Plain Channels","200x75x2.3"]
	British_Cold_Formed_Steel_Plain_Channels_200x75x3 = ["British","Cold Formed Steel","Plain Channels","200x75x3"]
	British_Cold_Formed_Steel_Plain_Channels_200x75x4 = ["British","Cold Formed Steel","Plain Channels","200x75x4"]
	British_Cold_Formed_Steel_Plain_Channels_200x75x4_5 = ["British","Cold Formed Steel","Plain Channels","200x75x4.5"]
	British_Cold_Formed_Steel_Plain_Channels_225x75x2_3 = ["British","Cold Formed Steel","Plain Channels","225x75x2.3"]
	British_Cold_Formed_Steel_Plain_Channels_225x75x3 = ["British","Cold Formed Steel","Plain Channels","225x75x3"]
	British_Cold_Formed_Steel_Plain_Channels_225x75x4 = ["British","Cold Formed Steel","Plain Channels","225x75x4"]
	British_Cold_Formed_Steel_Plain_Channels_225x75x4_5 = ["British","Cold Formed Steel","Plain Channels","225x75x4.5"]
	British_Cold_Formed_Steel_Plain_Channels_250x75x2_3 = ["British","Cold Formed Steel","Plain Channels","250x75x2.3"]
	British_Cold_Formed_Steel_Plain_Channels_250x75x3 = ["British","Cold Formed Steel","Plain Channels","250x75x3"]
	British_Cold_Formed_Steel_Plain_Channels_250x75x4 = ["British","Cold Formed Steel","Plain Channels","250x75x4"]
	British_Cold_Formed_Steel_Plain_Channels_250x75x4_5 = ["British","Cold Formed Steel","Plain Channels","250x75x4.5"]
	British_Cold_Formed_Steel_Lipped_Channels_60x30x10x1_6 = ["British","Cold Formed Steel","Lipped Channels","60x30x10x1.6"]
	British_Cold_Formed_Steel_Lipped_Channels_60x30x10x2 = ["British","Cold Formed Steel","Lipped Channels","60x30x10x2"]
	British_Cold_Formed_Steel_Lipped_Channels_60x30x10x2_3 = ["British","Cold Formed Steel","Lipped Channels","60x30x10x2.3"]
	British_Cold_Formed_Steel_Lipped_Channels_75x45x15x1_6 = ["British","Cold Formed Steel","Lipped Channels","75x45x15x1.6"]
	British_Cold_Formed_Steel_Lipped_Channels_75x45x15x2 = ["British","Cold Formed Steel","Lipped Channels","75x45x15x2"]
	British_Cold_Formed_Steel_Lipped_Channels_75x45x15x2_3 = ["British","Cold Formed Steel","Lipped Channels","75x45x15x2.3"]
	British_Cold_Formed_Steel_Lipped_Channels_75x45x15x3 = ["British","Cold Formed Steel","Lipped Channels","75x45x15x3"]
	British_Cold_Formed_Steel_Lipped_Channels_75x45x15x3_2 = ["British","Cold Formed Steel","Lipped Channels","75x45x15x3.2"]
	British_Cold_Formed_Steel_Lipped_Channels_100x50x20x1_6 = ["British","Cold Formed Steel","Lipped Channels","100x50x20x1.6"]
	British_Cold_Formed_Steel_Lipped_Channels_100x50x20x2 = ["British","Cold Formed Steel","Lipped Channels","100x50x20x2"]
	British_Cold_Formed_Steel_Lipped_Channels_100x50x20x2_3 = ["British","Cold Formed Steel","Lipped Channels","100x50x20x2.3"]
	British_Cold_Formed_Steel_Lipped_Channels_100x50x20x3 = ["British","Cold Formed Steel","Lipped Channels","100x50x20x3"]
	British_Cold_Formed_Steel_Lipped_Channels_100x50x20x3_2 = ["British","Cold Formed Steel","Lipped Channels","100x50x20x3.2"]
	British_Cold_Formed_Steel_Lipped_Channels_100x50x20x4 = ["British","Cold Formed Steel","Lipped Channels","100x50x20x4"]
	British_Cold_Formed_Steel_Lipped_Channels_100x50x20x4_5 = ["British","Cold Formed Steel","Lipped Channels","100x50x20x4.5"]
	British_Cold_Formed_Steel_Lipped_Channels_125x50x20x2 = ["British","Cold Formed Steel","Lipped Channels","125x50x20x2"]
	British_Cold_Formed_Steel_Lipped_Channels_125x50x20x2_3 = ["British","Cold Formed Steel","Lipped Channels","125x50x20x2.3"]
	British_Cold_Formed_Steel_Lipped_Channels_125x50x20x3 = ["British","Cold Formed Steel","Lipped Channels","125x50x20x3"]
	British_Cold_Formed_Steel_Lipped_Channels_125x50x20x3_2 = ["British","Cold Formed Steel","Lipped Channels","125x50x20x3.2"]
	British_Cold_Formed_Steel_Lipped_Channels_125x50x20x4 = ["British","Cold Formed Steel","Lipped Channels","125x50x20x4"]
	British_Cold_Formed_Steel_Lipped_Channels_125x50x20x4_5 = ["British","Cold Formed Steel","Lipped Channels","125x50x20x4.5"]
	British_Cold_Formed_Steel_Lipped_Channels_150x65x20x2_3 = ["British","Cold Formed Steel","Lipped Channels","150x65x20x2.3"]
	British_Cold_Formed_Steel_Lipped_Channels_150x65x20x3 = ["British","Cold Formed Steel","Lipped Channels","150x65x20x3"]
	British_Cold_Formed_Steel_Lipped_Channels_150x65x20x3_2 = ["British","Cold Formed Steel","Lipped Channels","150x65x20x3.2"]
	British_Cold_Formed_Steel_Lipped_Channels_150x65x20x4 = ["British","Cold Formed Steel","Lipped Channels","150x65x20x4"]
	British_Cold_Formed_Steel_Lipped_Channels_150x65x20x4_5 = ["British","Cold Formed Steel","Lipped Channels","150x65x20x4.5"]
	British_Cold_Formed_Steel_Lipped_Channels_175x75x20x2_3 = ["British","Cold Formed Steel","Lipped Channels","175x75x20x2.3"]
	British_Cold_Formed_Steel_Lipped_Channels_175x75x20x3 = ["British","Cold Formed Steel","Lipped Channels","175x75x20x3"]
	British_Cold_Formed_Steel_Lipped_Channels_175x75x20x3_2 = ["British","Cold Formed Steel","Lipped Channels","175x75x20x3.2"]
	British_Cold_Formed_Steel_Lipped_Channels_175x75x20x4 = ["British","Cold Formed Steel","Lipped Channels","175x75x20x4"]
	British_Cold_Formed_Steel_Lipped_Channels_175x75x20x4_5 = ["British","Cold Formed Steel","Lipped Channels","175x75x20x4.5"]
	British_Cold_Formed_Steel_Lipped_Channels_200x75x20x2_3 = ["British","Cold Formed Steel","Lipped Channels","200x75x20x2.3"]
	British_Cold_Formed_Steel_Lipped_Channels_200x75x20x3 = ["British","Cold Formed Steel","Lipped Channels","200x75x20x3"]
	British_Cold_Formed_Steel_Lipped_Channels_200x75x20x3_2 = ["British","Cold Formed Steel","Lipped Channels","200x75x20x3.2"]
	British_Cold_Formed_Steel_Lipped_Channels_200x75x20x4 = ["British","Cold Formed Steel","Lipped Channels","200x75x20x4"]
	British_Cold_Formed_Steel_Lipped_Channels_200x75x20x4_5 = ["British","Cold Formed Steel","Lipped Channels","200x75x20x4.5"]
	British_Cold_Formed_Steel_Lipped_Channels_200x75x25x2_3 = ["British","Cold Formed Steel","Lipped Channels","200x75x25x2.3"]
	British_Cold_Formed_Steel_Lipped_Channels_200x75x25x3 = ["British","Cold Formed Steel","Lipped Channels","200x75x25x3"]
	British_Cold_Formed_Steel_Lipped_Channels_200x75x25x3_2 = ["British","Cold Formed Steel","Lipped Channels","200x75x25x3.2"]
	British_Cold_Formed_Steel_Lipped_Channels_200x75x25x4 = ["British","Cold Formed Steel","Lipped Channels","200x75x25x4"]
	British_Cold_Formed_Steel_Lipped_Channels_200x75x25x4_5 = ["British","Cold Formed Steel","Lipped Channels","200x75x25x4.5"]
	British_Cold_Formed_Steel_Lipped_Channels_225x75x20x2_3 = ["British","Cold Formed Steel","Lipped Channels","225x75x20x2.3"]
	British_Cold_Formed_Steel_Lipped_Channels_225x75x20x3 = ["British","Cold Formed Steel","Lipped Channels","225x75x20x3"]
	British_Cold_Formed_Steel_Lipped_Channels_225x75x20x3_2 = ["British","Cold Formed Steel","Lipped Channels","225x75x20x3.2"]
	British_Cold_Formed_Steel_Lipped_Channels_225x75x20x4 = ["British","Cold Formed Steel","Lipped Channels","225x75x20x4"]
	British_Cold_Formed_Steel_Lipped_Channels_225x75x20x4_5 = ["British","Cold Formed Steel","Lipped Channels","225x75x20x4.5"]
	British_Cold_Formed_Steel_Lipped_Channels_225x75x25x2_3 = ["British","Cold Formed Steel","Lipped Channels","225x75x25x2.3"]
	British_Cold_Formed_Steel_Lipped_Channels_225x75x25x3 = ["British","Cold Formed Steel","Lipped Channels","225x75x25x3"]
	British_Cold_Formed_Steel_Lipped_Channels_225x75x25x3_2 = ["British","Cold Formed Steel","Lipped Channels","225x75x25x3.2"]
	British_Cold_Formed_Steel_Lipped_Channels_225x75x25x4 = ["British","Cold Formed Steel","Lipped Channels","225x75x25x4"]
	British_Cold_Formed_Steel_Lipped_Channels_225x75x25x4_5 = ["British","Cold Formed Steel","Lipped Channels","225x75x25x4.5"]
	British_Cold_Formed_Steel_Lipped_Channels_250x75x20x2_3 = ["British","Cold Formed Steel","Lipped Channels","250x75x20x2.3"]
	British_Cold_Formed_Steel_Lipped_Channels_250x75x20x3 = ["British","Cold Formed Steel","Lipped Channels","250x75x20x3"]
	British_Cold_Formed_Steel_Lipped_Channels_250x75x20x3_2 = ["British","Cold Formed Steel","Lipped Channels","250x75x20x3.2"]
	British_Cold_Formed_Steel_Lipped_Channels_250x75x20x4 = ["British","Cold Formed Steel","Lipped Channels","250x75x20x4"]
	British_Cold_Formed_Steel_Lipped_Channels_250x75x20x4_5 = ["British","Cold Formed Steel","Lipped Channels","250x75x20x4.5"]
	British_Cold_Formed_Steel_Lipped_Channels_250x75x25x2_3 = ["British","Cold Formed Steel","Lipped Channels","250x75x25x2.3"]
	British_Cold_Formed_Steel_Lipped_Channels_250x75x25x3 = ["British","Cold Formed Steel","Lipped Channels","250x75x25x3"]
	British_Cold_Formed_Steel_Lipped_Channels_250x75x25x3_2 = ["British","Cold Formed Steel","Lipped Channels","250x75x25x3.2"]
	British_Cold_Formed_Steel_Lipped_Channels_250x75x25x4 = ["British","Cold Formed Steel","Lipped Channels","250x75x25x4"]
	British_Cold_Formed_Steel_Lipped_Channels_250x75x25x4_5 = ["British","Cold Formed Steel","Lipped Channels","250x75x25x4.5"]
	British_Cold_Formed_Steel_HT_C_Purlins_C10010 = ["British","Cold Formed Steel","HT C Purlins","C10010"]
	British_Cold_Formed_Steel_HT_C_Purlins_C10012 = ["British","Cold Formed Steel","HT C Purlins","C10012"]
	British_Cold_Formed_Steel_HT_C_Purlins_C10015 = ["British","Cold Formed Steel","HT C Purlins","C10015"]
	British_Cold_Formed_Steel_HT_C_Purlins_C10019 = ["British","Cold Formed Steel","HT C Purlins","C10019"]
	British_Cold_Formed_Steel_HT_C_Purlins_C15012 = ["British","Cold Formed Steel","HT C Purlins","C15012"]
	British_Cold_Formed_Steel_HT_C_Purlins_C15015 = ["British","Cold Formed Steel","HT C Purlins","C15015"]
	British_Cold_Formed_Steel_HT_C_Purlins_C15019 = ["British","Cold Formed Steel","HT C Purlins","C15019"]
	British_Cold_Formed_Steel_HT_C_Purlins_C15024 = ["British","Cold Formed Steel","HT C Purlins","C15024"]
	British_Cold_Formed_Steel_HT_C_Purlins_C20015 = ["British","Cold Formed Steel","HT C Purlins","C20015"]
	British_Cold_Formed_Steel_HT_C_Purlins_C20019 = ["British","Cold Formed Steel","HT C Purlins","C20019"]
	British_Cold_Formed_Steel_HT_C_Purlins_C20024 = ["British","Cold Formed Steel","HT C Purlins","C20024"]
	British_Cold_Formed_Steel_HT_C_Purlins_C25019 = ["British","Cold Formed Steel","HT C Purlins","C25019"]
	British_Cold_Formed_Steel_HT_C_Purlins_C25024 = ["British","Cold Formed Steel","HT C Purlins","C25024"]
	British_Cold_Formed_Steel_HT_C_Purlins_C30024 = ["British","Cold Formed Steel","HT C Purlins","C30024"]
	British_Cold_Formed_Steel_HT_C_Purlins_C30030 = ["British","Cold Formed Steel","HT C Purlins","C30030"]
	British_Cold_Formed_Steel_HT_C_Purlins_C35030 = ["British","Cold Formed Steel","HT C Purlins","C35030"]
	British_Cold_Formed_Steel_HT_C_Purlins_LL06425 = ["British","Cold Formed Steel","HT C Purlins","LL06425"]
	British_Cold_Formed_Steel_HT_C_Purlins_LL07610 = ["British","Cold Formed Steel","HT C Purlins","LL07610"]
	British_Cold_Formed_Steel_HT_C_Purlins_LL07625 = ["British","Cold Formed Steel","HT C Purlins","LL07625"]
	British_Cold_Formed_Steel_HT_C_Purlins_LL10225 = ["British","Cold Formed Steel","HT C Purlins","LL10225"]
	British_Cold_Formed_Steel_HT_C_Purlins_LL10230 = ["British","Cold Formed Steel","HT C Purlins","LL10230"]
	British_Cold_Formed_Steel_HT_C_Purlins_LL12725 = ["British","Cold Formed Steel","HT C Purlins","LL12725"]
	British_Cold_Formed_Steel_HT_C_Purlins_LL12730 = ["British","Cold Formed Steel","HT C Purlins","LL12730"]
	British_Cold_Formed_Steel_HT_C_Purlins_LL15230 = ["British","Cold Formed Steel","HT C Purlins","LL15230"]
	British_Cold_Formed_Steel_HT_C_Purlins_LL20330 = ["British","Cold Formed Steel","HT C Purlins","LL20330"]
	British_Cold_Formed_Steel_HT_Z_Purlins_Z10010 = ["British","Cold Formed Steel","HT Z Purlins","Z10010"]
	British_Cold_Formed_Steel_HT_Z_Purlins_Z10012 = ["British","Cold Formed Steel","HT Z Purlins","Z10012"]
	British_Cold_Formed_Steel_HT_Z_Purlins_Z10015 = ["British","Cold Formed Steel","HT Z Purlins","Z10015"]
	British_Cold_Formed_Steel_HT_Z_Purlins_Z10019 = ["British","Cold Formed Steel","HT Z Purlins","Z10019"]
	British_Cold_Formed_Steel_HT_Z_Purlins_Z15012 = ["British","Cold Formed Steel","HT Z Purlins","Z15012"]
	British_Cold_Formed_Steel_HT_Z_Purlins_Z15015 = ["British","Cold Formed Steel","HT Z Purlins","Z15015"]
	British_Cold_Formed_Steel_HT_Z_Purlins_Z15019 = ["British","Cold Formed Steel","HT Z Purlins","Z15019"]
	British_Cold_Formed_Steel_HT_Z_Purlins_Z15024 = ["British","Cold Formed Steel","HT Z Purlins","Z15024"]
	British_Cold_Formed_Steel_HT_Z_Purlins_Z20015 = ["British","Cold Formed Steel","HT Z Purlins","Z20015"]
	British_Cold_Formed_Steel_HT_Z_Purlins_Z20019 = ["British","Cold Formed Steel","HT Z Purlins","Z20019"]
	British_Cold_Formed_Steel_HT_Z_Purlins_Z20024 = ["British","Cold Formed Steel","HT Z Purlins","Z20024"]
	British_Cold_Formed_Steel_HT_Z_Purlins_Z25019 = ["British","Cold Formed Steel","HT Z Purlins","Z25019"]
	British_Cold_Formed_Steel_HT_Z_Purlins_Z25024 = ["British","Cold Formed Steel","HT Z Purlins","Z25024"]
	British_Cold_Formed_Steel_HT_Z_Purlins_Z30024 = ["British","Cold Formed Steel","HT Z Purlins","Z30024"]
	British_Cold_Formed_Steel_HT_Z_Purlins_Z30030 = ["British","Cold Formed Steel","HT Z Purlins","Z30030"]
	British_Cold_Formed_Steel_HT_Z_Purlins_Z35030 = ["British","Cold Formed Steel","HT Z Purlins","Z35030"]
	Canadian_CISC_WRF_Welded_Reduced_Flange_WRF1000x210 = ["Canadian","CISC","WRF: Welded Reduced Flange","WRF1000x210"]
	Canadian_CISC_WRF_Welded_Reduced_Flange_WRF1000x275 = ["Canadian","CISC","WRF: Welded Reduced Flange","WRF1000x275"]
	Canadian_CISC_WRF_Welded_Reduced_Flange_WRF1000x340 = ["Canadian","CISC","WRF: Welded Reduced Flange","WRF1000x340"]
	Canadian_CISC_WRF_Welded_Reduced_Flange_WRF1200x244 = ["Canadian","CISC","WRF: Welded Reduced Flange","WRF1200x244"]
	Canadian_CISC_WRF_Welded_Reduced_Flange_WRF1200x309 = ["Canadian","CISC","WRF: Welded Reduced Flange","WRF1200x309"]
	Canadian_CISC_WRF_Welded_Reduced_Flange_WRF1200x373 = ["Canadian","CISC","WRF: Welded Reduced Flange","WRF1200x373"]
	Canadian_CISC_WRF_Welded_Reduced_Flange_WRF1400x284 = ["Canadian","CISC","WRF: Welded Reduced Flange","WRF1400x284"]
	Canadian_CISC_WRF_Welded_Reduced_Flange_WRF1400x348 = ["Canadian","CISC","WRF: Welded Reduced Flange","WRF1400x348"]
	Canadian_CISC_WRF_Welded_Reduced_Flange_WRF1400x413 = ["Canadian","CISC","WRF: Welded Reduced Flange","WRF1400x413"]
	Canadian_CISC_WRF_Welded_Reduced_Flange_WRF1600x362 = ["Canadian","CISC","WRF: Welded Reduced Flange","WRF1600x362"]
	Canadian_CISC_WRF_Welded_Reduced_Flange_WRF1600x427 = ["Canadian","CISC","WRF: Welded Reduced Flange","WRF1600x427"]
	Canadian_CISC_WRF_Welded_Reduced_Flange_WRF1600x491 = ["Canadian","CISC","WRF: Welded Reduced Flange","WRF1600x491"]
	Canadian_CISC_WRF_Welded_Reduced_Flange_WRF1800x416 = ["Canadian","CISC","WRF: Welded Reduced Flange","WRF1800x416"]
	Canadian_CISC_WRF_Welded_Reduced_Flange_WRF1800x480 = ["Canadian","CISC","WRF: Welded Reduced Flange","WRF1800x480"]
	Canadian_CISC_WRF_Welded_Reduced_Flange_WRF1800x543 = ["Canadian","CISC","WRF: Welded Reduced Flange","WRF1800x543"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF350x137 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF350x137"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF350x155 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF350x155"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF350x176 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF350x176"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF350x192 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF350x192"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF350x212 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF350x212"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF350x238 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF350x238"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF350x263 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF350x263"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF350x315 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF350x315"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF400x157 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF400x157"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF400x178 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF400x178"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF400x202 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF400x202"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF400x220 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF400x220"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF400x243 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF400x243"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF400x273 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF400x273"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF400x303 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF400x303"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF400x362 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF400x362"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF400x444 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF400x444"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF450x177 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF450x177"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF450x201 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF450x201"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF450x228 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF450x228"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF450x248 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF450x248"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF450x274 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF450x274"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF450x308 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF450x308"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF450x342 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF450x342"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF450x409 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF450x409"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF450x503 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF450x503"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF500x197 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF500x197"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF500x223 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF500x223"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF500x254 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF500x254"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF500x276 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF500x276"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF500x306 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF500x306"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF500x343 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF500x343"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF500x381 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF500x381"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF500x456 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF500x456"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF500x561 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF500x561"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF500x651 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF500x651"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF550x280 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF550x280"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF550x420 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF550x420"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF550x503 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF550x503"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF550x620 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF550x620"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF550x721 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF550x721"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF600x369 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF600x369"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF600x460 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF600x460"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF600x551 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF600x551"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF600x680 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF600x680"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF600x793 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF600x793"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF650x400 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF650x400"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF650x499 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF650x499"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF650x598 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF650x598"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF650x739 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF650x739"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF650x864 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF650x864"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF700x152 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF700x152"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF700x175 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF700x175"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF700x196 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF700x196"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF700x214 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF700x214"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF700x245 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF700x245"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF800x161 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF800x161"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF800x184 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF800x184"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF800x223 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF800x223"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF800x253 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF800x253"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF800x300 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF800x300"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF800x339 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF800x339"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF900x169 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF900x169"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF900x192 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF900x192"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF900x231 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF900x231"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF900x262 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF900x262"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF900x309 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF900x309"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF900x347 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF900x347"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF900x417 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF900x417"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF1000x200 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF1000x200"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF1000x223 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF1000x223"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF1000x262 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF1000x262"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF1000x293 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF1000x293"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF1000x340 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF1000x340"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF1000x377 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF1000x377"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF1000x447 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF1000x447"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF1100x234 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF1100x234"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF1100x273 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF1100x273"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF1100x304 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF1100x304"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF1100x351 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF1100x351"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF1100x388 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF1100x388"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF1100x458 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF1100x458"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF1200x263 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF1200x263"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF1200x302 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF1200x302"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF1200x333 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF1200x333"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF1200x380 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF1200x380"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF1200x418 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF1200x418"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF1200x487 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF1200x487"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF1400x358 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF1400x358"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF1400x405 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF1400x405"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF1400x471 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF1400x471"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF1400x513 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF1400x513"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF1400x597 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF1400x597"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF1600x431 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF1600x431"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF1600x496 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF1600x496"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF1600x538 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF1600x538"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF1600x580 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF1600x580"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF1600x622 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF1600x622"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF1800x510 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF1800x510"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF1800x575 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF1800x575"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF1800x617 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF1800x617"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF1800x659 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF1800x659"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF1800x700 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF1800x700"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF2000x542 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF2000x542"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF2000x607 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF2000x607"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF2000x648 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF2000x648"]
	Canadian_CISC_WWF_Welded_Wide_Flange_WWF2000x732 = ["Canadian","CISC","WWF: Welded Wide Flange","WWF2000x732"]
	Canadian_CISC_W_Wide_Flange_W100x19 = ["Canadian","CISC","W: Wide Flange","W100x19"]
	Canadian_CISC_W_Wide_Flange_W130x24 = ["Canadian","CISC","W: Wide Flange","W130x24"]
	Canadian_CISC_W_Wide_Flange_W130x28 = ["Canadian","CISC","W: Wide Flange","W130x28"]
	Canadian_CISC_W_Wide_Flange_W150x13 = ["Canadian","CISC","W: Wide Flange","W150x13"]
	Canadian_CISC_W_Wide_Flange_W150x14 = ["Canadian","CISC","W: Wide Flange","W150x14"]
	Canadian_CISC_W_Wide_Flange_W150x18 = ["Canadian","CISC","W: Wide Flange","W150x18"]
	Canadian_CISC_W_Wide_Flange_W150x22 = ["Canadian","CISC","W: Wide Flange","W150x22"]
	Canadian_CISC_W_Wide_Flange_W150x24 = ["Canadian","CISC","W: Wide Flange","W150x24"]
	Canadian_CISC_W_Wide_Flange_W150x30 = ["Canadian","CISC","W: Wide Flange","W150x30"]
	Canadian_CISC_W_Wide_Flange_W150x37 = ["Canadian","CISC","W: Wide Flange","W150x37"]
	Canadian_CISC_W_Wide_Flange_W200x15 = ["Canadian","CISC","W: Wide Flange","W200x15"]
	Canadian_CISC_W_Wide_Flange_W200x19 = ["Canadian","CISC","W: Wide Flange","W200x19"]
	Canadian_CISC_W_Wide_Flange_W200x21 = ["Canadian","CISC","W: Wide Flange","W200x21"]
	Canadian_CISC_W_Wide_Flange_W200x22 = ["Canadian","CISC","W: Wide Flange","W200x22"]
	Canadian_CISC_W_Wide_Flange_W200x27 = ["Canadian","CISC","W: Wide Flange","W200x27"]
	Canadian_CISC_W_Wide_Flange_W200x31 = ["Canadian","CISC","W: Wide Flange","W200x31"]
	Canadian_CISC_W_Wide_Flange_W200x36 = ["Canadian","CISC","W: Wide Flange","W200x36"]
	Canadian_CISC_W_Wide_Flange_W200x42 = ["Canadian","CISC","W: Wide Flange","W200x42"]
	Canadian_CISC_W_Wide_Flange_W200x46 = ["Canadian","CISC","W: Wide Flange","W200x46"]
	Canadian_CISC_W_Wide_Flange_W200x52 = ["Canadian","CISC","W: Wide Flange","W200x52"]
	Canadian_CISC_W_Wide_Flange_W200x59 = ["Canadian","CISC","W: Wide Flange","W200x59"]
	Canadian_CISC_W_Wide_Flange_W200x71 = ["Canadian","CISC","W: Wide Flange","W200x71"]
	Canadian_CISC_W_Wide_Flange_W200x86 = ["Canadian","CISC","W: Wide Flange","W200x86"]
	Canadian_CISC_W_Wide_Flange_W200x100 = ["Canadian","CISC","W: Wide Flange","W200x100"]
	Canadian_CISC_W_Wide_Flange_W250x18 = ["Canadian","CISC","W: Wide Flange","W250x18"]
	Canadian_CISC_W_Wide_Flange_W250x22 = ["Canadian","CISC","W: Wide Flange","W250x22"]
	Canadian_CISC_W_Wide_Flange_W250x24 = ["Canadian","CISC","W: Wide Flange","W250x24"]
	Canadian_CISC_W_Wide_Flange_W250x25 = ["Canadian","CISC","W: Wide Flange","W250x25"]
	Canadian_CISC_W_Wide_Flange_W250x28 = ["Canadian","CISC","W: Wide Flange","W250x28"]
	Canadian_CISC_W_Wide_Flange_W250x33 = ["Canadian","CISC","W: Wide Flange","W250x33"]
	Canadian_CISC_W_Wide_Flange_W250x39 = ["Canadian","CISC","W: Wide Flange","W250x39"]
	Canadian_CISC_W_Wide_Flange_W250x45 = ["Canadian","CISC","W: Wide Flange","W250x45"]
	Canadian_CISC_W_Wide_Flange_W250x49 = ["Canadian","CISC","W: Wide Flange","W250x49"]
	Canadian_CISC_W_Wide_Flange_W250x58 = ["Canadian","CISC","W: Wide Flange","W250x58"]
	Canadian_CISC_W_Wide_Flange_W250x67 = ["Canadian","CISC","W: Wide Flange","W250x67"]
	Canadian_CISC_W_Wide_Flange_W250x73 = ["Canadian","CISC","W: Wide Flange","W250x73"]
	Canadian_CISC_W_Wide_Flange_W250x80 = ["Canadian","CISC","W: Wide Flange","W250x80"]
	Canadian_CISC_W_Wide_Flange_W250x89 = ["Canadian","CISC","W: Wide Flange","W250x89"]
	Canadian_CISC_W_Wide_Flange_W250x101 = ["Canadian","CISC","W: Wide Flange","W250x101"]
	Canadian_CISC_W_Wide_Flange_W250x115 = ["Canadian","CISC","W: Wide Flange","W250x115"]
	Canadian_CISC_W_Wide_Flange_W250x131 = ["Canadian","CISC","W: Wide Flange","W250x131"]
	Canadian_CISC_W_Wide_Flange_W250x149 = ["Canadian","CISC","W: Wide Flange","W250x149"]
	Canadian_CISC_W_Wide_Flange_W250x167 = ["Canadian","CISC","W: Wide Flange","W250x167"]
	Canadian_CISC_W_Wide_Flange_W310x21 = ["Canadian","CISC","W: Wide Flange","W310x21"]
	Canadian_CISC_W_Wide_Flange_W310x24 = ["Canadian","CISC","W: Wide Flange","W310x24"]
	Canadian_CISC_W_Wide_Flange_W310x28 = ["Canadian","CISC","W: Wide Flange","W310x28"]
	Canadian_CISC_W_Wide_Flange_W310x31 = ["Canadian","CISC","W: Wide Flange","W310x31"]
	Canadian_CISC_W_Wide_Flange_W310x33 = ["Canadian","CISC","W: Wide Flange","W310x33"]
	Canadian_CISC_W_Wide_Flange_W310x39 = ["Canadian","CISC","W: Wide Flange","W310x39"]
	Canadian_CISC_W_Wide_Flange_W310x45 = ["Canadian","CISC","W: Wide Flange","W310x45"]
	Canadian_CISC_W_Wide_Flange_W310x52 = ["Canadian","CISC","W: Wide Flange","W310x52"]
	Canadian_CISC_W_Wide_Flange_W310x60 = ["Canadian","CISC","W: Wide Flange","W310x60"]
	Canadian_CISC_W_Wide_Flange_W310x67 = ["Canadian","CISC","W: Wide Flange","W310x67"]
	Canadian_CISC_W_Wide_Flange_W310x74 = ["Canadian","CISC","W: Wide Flange","W310x74"]
	Canadian_CISC_W_Wide_Flange_W310x79 = ["Canadian","CISC","W: Wide Flange","W310x79"]
	Canadian_CISC_W_Wide_Flange_W310x86 = ["Canadian","CISC","W: Wide Flange","W310x86"]
	Canadian_CISC_W_Wide_Flange_W310x97 = ["Canadian","CISC","W: Wide Flange","W310x97"]
	Canadian_CISC_W_Wide_Flange_W310x107 = ["Canadian","CISC","W: Wide Flange","W310x107"]
	Canadian_CISC_W_Wide_Flange_W310x118 = ["Canadian","CISC","W: Wide Flange","W310x118"]
	Canadian_CISC_W_Wide_Flange_W310x129 = ["Canadian","CISC","W: Wide Flange","W310x129"]
	Canadian_CISC_W_Wide_Flange_W310x143 = ["Canadian","CISC","W: Wide Flange","W310x143"]
	Canadian_CISC_W_Wide_Flange_W310x158 = ["Canadian","CISC","W: Wide Flange","W310x158"]
	Canadian_CISC_W_Wide_Flange_W310x179 = ["Canadian","CISC","W: Wide Flange","W310x179"]
	Canadian_CISC_W_Wide_Flange_W310x202 = ["Canadian","CISC","W: Wide Flange","W310x202"]
	Canadian_CISC_W_Wide_Flange_W310x226 = ["Canadian","CISC","W: Wide Flange","W310x226"]
	Canadian_CISC_W_Wide_Flange_W310x253 = ["Canadian","CISC","W: Wide Flange","W310x253"]
	Canadian_CISC_W_Wide_Flange_W310x283 = ["Canadian","CISC","W: Wide Flange","W310x283"]
	Canadian_CISC_W_Wide_Flange_W310x313 = ["Canadian","CISC","W: Wide Flange","W310x313"]
	Canadian_CISC_W_Wide_Flange_W310x342 = ["Canadian","CISC","W: Wide Flange","W310x342"]
	Canadian_CISC_W_Wide_Flange_W310x375 = ["Canadian","CISC","W: Wide Flange","W310x375"]
	Canadian_CISC_W_Wide_Flange_W310x415 = ["Canadian","CISC","W: Wide Flange","W310x415"]
	Canadian_CISC_W_Wide_Flange_W310x454 = ["Canadian","CISC","W: Wide Flange","W310x454"]
	Canadian_CISC_W_Wide_Flange_W310x500 = ["Canadian","CISC","W: Wide Flange","W310x500"]
	Canadian_CISC_W_Wide_Flange_W360x33 = ["Canadian","CISC","W: Wide Flange","W360x33"]
	Canadian_CISC_W_Wide_Flange_W360x39 = ["Canadian","CISC","W: Wide Flange","W360x39"]
	Canadian_CISC_W_Wide_Flange_W360x45 = ["Canadian","CISC","W: Wide Flange","W360x45"]
	Canadian_CISC_W_Wide_Flange_W360x51 = ["Canadian","CISC","W: Wide Flange","W360x51"]
	Canadian_CISC_W_Wide_Flange_W360x57 = ["Canadian","CISC","W: Wide Flange","W360x57"]
	Canadian_CISC_W_Wide_Flange_W360x64 = ["Canadian","CISC","W: Wide Flange","W360x64"]
	Canadian_CISC_W_Wide_Flange_W360x72 = ["Canadian","CISC","W: Wide Flange","W360x72"]
	Canadian_CISC_W_Wide_Flange_W360x79 = ["Canadian","CISC","W: Wide Flange","W360x79"]
	Canadian_CISC_W_Wide_Flange_W360x91 = ["Canadian","CISC","W: Wide Flange","W360x91"]
	Canadian_CISC_W_Wide_Flange_W360x101 = ["Canadian","CISC","W: Wide Flange","W360x101"]
	Canadian_CISC_W_Wide_Flange_W360x110 = ["Canadian","CISC","W: Wide Flange","W360x110"]
	Canadian_CISC_W_Wide_Flange_W360x122 = ["Canadian","CISC","W: Wide Flange","W360x122"]
	Canadian_CISC_W_Wide_Flange_W360x134 = ["Canadian","CISC","W: Wide Flange","W360x134"]
	Canadian_CISC_W_Wide_Flange_W360x147 = ["Canadian","CISC","W: Wide Flange","W360x147"]
	Canadian_CISC_W_Wide_Flange_W360x162 = ["Canadian","CISC","W: Wide Flange","W360x162"]
	Canadian_CISC_W_Wide_Flange_W360x179 = ["Canadian","CISC","W: Wide Flange","W360x179"]
	Canadian_CISC_W_Wide_Flange_W360x196 = ["Canadian","CISC","W: Wide Flange","W360x196"]
	Canadian_CISC_W_Wide_Flange_W360x216 = ["Canadian","CISC","W: Wide Flange","W360x216"]
	Canadian_CISC_W_Wide_Flange_W360x237 = ["Canadian","CISC","W: Wide Flange","W360x237"]
	Canadian_CISC_W_Wide_Flange_W360x262 = ["Canadian","CISC","W: Wide Flange","W360x262"]
	Canadian_CISC_W_Wide_Flange_W360x287 = ["Canadian","CISC","W: Wide Flange","W360x287"]
	Canadian_CISC_W_Wide_Flange_W360x314 = ["Canadian","CISC","W: Wide Flange","W360x314"]
	Canadian_CISC_W_Wide_Flange_W360x347 = ["Canadian","CISC","W: Wide Flange","W360x347"]
	Canadian_CISC_W_Wide_Flange_W360x382 = ["Canadian","CISC","W: Wide Flange","W360x382"]
	Canadian_CISC_W_Wide_Flange_W360x421 = ["Canadian","CISC","W: Wide Flange","W360x421"]
	Canadian_CISC_W_Wide_Flange_W360x463 = ["Canadian","CISC","W: Wide Flange","W360x463"]
	Canadian_CISC_W_Wide_Flange_W360x509 = ["Canadian","CISC","W: Wide Flange","W360x509"]
	Canadian_CISC_W_Wide_Flange_W360x551 = ["Canadian","CISC","W: Wide Flange","W360x551"]
	Canadian_CISC_W_Wide_Flange_W360x592 = ["Canadian","CISC","W: Wide Flange","W360x592"]
	Canadian_CISC_W_Wide_Flange_W360x634 = ["Canadian","CISC","W: Wide Flange","W360x634"]
	Canadian_CISC_W_Wide_Flange_W360x677 = ["Canadian","CISC","W: Wide Flange","W360x677"]
	Canadian_CISC_W_Wide_Flange_W360x744 = ["Canadian","CISC","W: Wide Flange","W360x744"]
	Canadian_CISC_W_Wide_Flange_W360x818 = ["Canadian","CISC","W: Wide Flange","W360x818"]
	Canadian_CISC_W_Wide_Flange_W360x900 = ["Canadian","CISC","W: Wide Flange","W360x900"]
	Canadian_CISC_W_Wide_Flange_W360x990 = ["Canadian","CISC","W: Wide Flange","W360x990"]
	Canadian_CISC_W_Wide_Flange_W360x1086 = ["Canadian","CISC","W: Wide Flange","W360x1086"]
	Canadian_CISC_W_Wide_Flange_W410x39 = ["Canadian","CISC","W: Wide Flange","W410x39"]
	Canadian_CISC_W_Wide_Flange_W410x46 = ["Canadian","CISC","W: Wide Flange","W410x46"]
	Canadian_CISC_W_Wide_Flange_W410x54 = ["Canadian","CISC","W: Wide Flange","W410x54"]
	Canadian_CISC_W_Wide_Flange_W410x60 = ["Canadian","CISC","W: Wide Flange","W410x60"]
	Canadian_CISC_W_Wide_Flange_W410x67 = ["Canadian","CISC","W: Wide Flange","W410x67"]
	Canadian_CISC_W_Wide_Flange_W410x74 = ["Canadian","CISC","W: Wide Flange","W410x74"]
	Canadian_CISC_W_Wide_Flange_W410x85 = ["Canadian","CISC","W: Wide Flange","W410x85"]
	Canadian_CISC_W_Wide_Flange_W410x100 = ["Canadian","CISC","W: Wide Flange","W410x100"]
	Canadian_CISC_W_Wide_Flange_W410x114 = ["Canadian","CISC","W: Wide Flange","W410x114"]
	Canadian_CISC_W_Wide_Flange_W410x132 = ["Canadian","CISC","W: Wide Flange","W410x132"]
	Canadian_CISC_W_Wide_Flange_W410x149 = ["Canadian","CISC","W: Wide Flange","W410x149"]
	Canadian_CISC_W_Wide_Flange_W460x52 = ["Canadian","CISC","W: Wide Flange","W460x52"]
	Canadian_CISC_W_Wide_Flange_W460x60 = ["Canadian","CISC","W: Wide Flange","W460x60"]
	Canadian_CISC_W_Wide_Flange_W460x61 = ["Canadian","CISC","W: Wide Flange","W460x61"]
	Canadian_CISC_W_Wide_Flange_W460x67 = ["Canadian","CISC","W: Wide Flange","W460x67"]
	Canadian_CISC_W_Wide_Flange_W460x68 = ["Canadian","CISC","W: Wide Flange","W460x68"]
	Canadian_CISC_W_Wide_Flange_W460x74 = ["Canadian","CISC","W: Wide Flange","W460x74"]
	Canadian_CISC_W_Wide_Flange_W460x82 = ["Canadian","CISC","W: Wide Flange","W460x82"]
	Canadian_CISC_W_Wide_Flange_W460x89 = ["Canadian","CISC","W: Wide Flange","W460x89"]
	Canadian_CISC_W_Wide_Flange_W460x97 = ["Canadian","CISC","W: Wide Flange","W460x97"]
	Canadian_CISC_W_Wide_Flange_W460x106 = ["Canadian","CISC","W: Wide Flange","W460x106"]
	Canadian_CISC_W_Wide_Flange_W460x113 = ["Canadian","CISC","W: Wide Flange","W460x113"]
	Canadian_CISC_W_Wide_Flange_W460x128 = ["Canadian","CISC","W: Wide Flange","W460x128"]
	Canadian_CISC_W_Wide_Flange_W460x144 = ["Canadian","CISC","W: Wide Flange","W460x144"]
	Canadian_CISC_W_Wide_Flange_W460x158 = ["Canadian","CISC","W: Wide Flange","W460x158"]
	Canadian_CISC_W_Wide_Flange_W460x177 = ["Canadian","CISC","W: Wide Flange","W460x177"]
	Canadian_CISC_W_Wide_Flange_W460x193 = ["Canadian","CISC","W: Wide Flange","W460x193"]
	Canadian_CISC_W_Wide_Flange_W460x213 = ["Canadian","CISC","W: Wide Flange","W460x213"]
	Canadian_CISC_W_Wide_Flange_W460x235 = ["Canadian","CISC","W: Wide Flange","W460x235"]
	Canadian_CISC_W_Wide_Flange_W460x260 = ["Canadian","CISC","W: Wide Flange","W460x260"]
	Canadian_CISC_W_Wide_Flange_W460x286 = ["Canadian","CISC","W: Wide Flange","W460x286"]
	Canadian_CISC_W_Wide_Flange_W460x315 = ["Canadian","CISC","W: Wide Flange","W460x315"]
	Canadian_CISC_W_Wide_Flange_W460x349 = ["Canadian","CISC","W: Wide Flange","W460x349"]
	Canadian_CISC_W_Wide_Flange_W460x384 = ["Canadian","CISC","W: Wide Flange","W460x384"]
	Canadian_CISC_W_Wide_Flange_W460x421 = ["Canadian","CISC","W: Wide Flange","W460x421"]
	Canadian_CISC_W_Wide_Flange_W460x464 = ["Canadian","CISC","W: Wide Flange","W460x464"]
	Canadian_CISC_W_Wide_Flange_W530x66 = ["Canadian","CISC","W: Wide Flange","W530x66"]
	Canadian_CISC_W_Wide_Flange_W530x72 = ["Canadian","CISC","W: Wide Flange","W530x72"]
	Canadian_CISC_W_Wide_Flange_W530x74 = ["Canadian","CISC","W: Wide Flange","W530x74"]
	Canadian_CISC_W_Wide_Flange_W530x82 = ["Canadian","CISC","W: Wide Flange","W530x82"]
	Canadian_CISC_W_Wide_Flange_W530x85 = ["Canadian","CISC","W: Wide Flange","W530x85"]
	Canadian_CISC_W_Wide_Flange_W530x92 = ["Canadian","CISC","W: Wide Flange","W530x92"]
	Canadian_CISC_W_Wide_Flange_W530x101 = ["Canadian","CISC","W: Wide Flange","W530x101"]
	Canadian_CISC_W_Wide_Flange_W530x109 = ["Canadian","CISC","W: Wide Flange","W530x109"]
	Canadian_CISC_W_Wide_Flange_W530x123 = ["Canadian","CISC","W: Wide Flange","W530x123"]
	Canadian_CISC_W_Wide_Flange_W530x138 = ["Canadian","CISC","W: Wide Flange","W530x138"]
	Canadian_CISC_W_Wide_Flange_W530x150 = ["Canadian","CISC","W: Wide Flange","W530x150"]
	Canadian_CISC_W_Wide_Flange_W530x165 = ["Canadian","CISC","W: Wide Flange","W530x165"]
	Canadian_CISC_W_Wide_Flange_W530x182 = ["Canadian","CISC","W: Wide Flange","W530x182"]
	Canadian_CISC_W_Wide_Flange_W530x196 = ["Canadian","CISC","W: Wide Flange","W530x196"]
	Canadian_CISC_W_Wide_Flange_W530x219 = ["Canadian","CISC","W: Wide Flange","W530x219"]
	Canadian_CISC_W_Wide_Flange_W530x248 = ["Canadian","CISC","W: Wide Flange","W530x248"]
	Canadian_CISC_W_Wide_Flange_W530x272 = ["Canadian","CISC","W: Wide Flange","W530x272"]
	Canadian_CISC_W_Wide_Flange_W530x300 = ["Canadian","CISC","W: Wide Flange","W530x300"]
	Canadian_CISC_W_Wide_Flange_W610x82 = ["Canadian","CISC","W: Wide Flange","W610x82"]
	Canadian_CISC_W_Wide_Flange_W610x84 = ["Canadian","CISC","W: Wide Flange","W610x84"]
	Canadian_CISC_W_Wide_Flange_W610x91 = ["Canadian","CISC","W: Wide Flange","W610x91"]
	Canadian_CISC_W_Wide_Flange_W610x92 = ["Canadian","CISC","W: Wide Flange","W610x92"]
	Canadian_CISC_W_Wide_Flange_W610x101 = ["Canadian","CISC","W: Wide Flange","W610x101"]
	Canadian_CISC_W_Wide_Flange_W610x113 = ["Canadian","CISC","W: Wide Flange","W610x113"]
	Canadian_CISC_W_Wide_Flange_W610x125 = ["Canadian","CISC","W: Wide Flange","W610x125"]
	Canadian_CISC_W_Wide_Flange_W610x140 = ["Canadian","CISC","W: Wide Flange","W610x140"]
	Canadian_CISC_W_Wide_Flange_W610x153 = ["Canadian","CISC","W: Wide Flange","W610x153"]
	Canadian_CISC_W_Wide_Flange_W610x155 = ["Canadian","CISC","W: Wide Flange","W610x155"]
	Canadian_CISC_W_Wide_Flange_W610x174 = ["Canadian","CISC","W: Wide Flange","W610x174"]
	Canadian_CISC_W_Wide_Flange_W610x195 = ["Canadian","CISC","W: Wide Flange","W610x195"]
	Canadian_CISC_W_Wide_Flange_W610x217 = ["Canadian","CISC","W: Wide Flange","W610x217"]
	Canadian_CISC_W_Wide_Flange_W610x241 = ["Canadian","CISC","W: Wide Flange","W610x241"]
	Canadian_CISC_W_Wide_Flange_W610x262 = ["Canadian","CISC","W: Wide Flange","W610x262"]
	Canadian_CISC_W_Wide_Flange_W610x285 = ["Canadian","CISC","W: Wide Flange","W610x285"]
	Canadian_CISC_W_Wide_Flange_W610x307 = ["Canadian","CISC","W: Wide Flange","W610x307"]
	Canadian_CISC_W_Wide_Flange_W610x341 = ["Canadian","CISC","W: Wide Flange","W610x341"]
	Canadian_CISC_W_Wide_Flange_W610x372 = ["Canadian","CISC","W: Wide Flange","W610x372"]
	Canadian_CISC_W_Wide_Flange_W610x415 = ["Canadian","CISC","W: Wide Flange","W610x415"]
	Canadian_CISC_W_Wide_Flange_W610x455 = ["Canadian","CISC","W: Wide Flange","W610x455"]
	Canadian_CISC_W_Wide_Flange_W610x498 = ["Canadian","CISC","W: Wide Flange","W610x498"]
	Canadian_CISC_W_Wide_Flange_W610x551 = ["Canadian","CISC","W: Wide Flange","W610x551"]
	Canadian_CISC_W_Wide_Flange_W690x125 = ["Canadian","CISC","W: Wide Flange","W690x125"]
	Canadian_CISC_W_Wide_Flange_W690x140 = ["Canadian","CISC","W: Wide Flange","W690x140"]
	Canadian_CISC_W_Wide_Flange_W690x152 = ["Canadian","CISC","W: Wide Flange","W690x152"]
	Canadian_CISC_W_Wide_Flange_W690x170 = ["Canadian","CISC","W: Wide Flange","W690x170"]
	Canadian_CISC_W_Wide_Flange_W690x192 = ["Canadian","CISC","W: Wide Flange","W690x192"]
	Canadian_CISC_W_Wide_Flange_W690x217 = ["Canadian","CISC","W: Wide Flange","W690x217"]
	Canadian_CISC_W_Wide_Flange_W690x240 = ["Canadian","CISC","W: Wide Flange","W690x240"]
	Canadian_CISC_W_Wide_Flange_W690x265 = ["Canadian","CISC","W: Wide Flange","W690x265"]
	Canadian_CISC_W_Wide_Flange_W690x289 = ["Canadian","CISC","W: Wide Flange","W690x289"]
	Canadian_CISC_W_Wide_Flange_W690x323 = ["Canadian","CISC","W: Wide Flange","W690x323"]
	Canadian_CISC_W_Wide_Flange_W690x350 = ["Canadian","CISC","W: Wide Flange","W690x350"]
	Canadian_CISC_W_Wide_Flange_W690x384 = ["Canadian","CISC","W: Wide Flange","W690x384"]
	Canadian_CISC_W_Wide_Flange_W690x419 = ["Canadian","CISC","W: Wide Flange","W690x419"]
	Canadian_CISC_W_Wide_Flange_W690x457 = ["Canadian","CISC","W: Wide Flange","W690x457"]
	Canadian_CISC_W_Wide_Flange_W690x500 = ["Canadian","CISC","W: Wide Flange","W690x500"]
	Canadian_CISC_W_Wide_Flange_W690x548 = ["Canadian","CISC","W: Wide Flange","W690x548"]
	Canadian_CISC_W_Wide_Flange_W690x802 = ["Canadian","CISC","W: Wide Flange","W690x802"]
	Canadian_CISC_W_Wide_Flange_W760x134 = ["Canadian","CISC","W: Wide Flange","W760x134"]
	Canadian_CISC_W_Wide_Flange_W760x147 = ["Canadian","CISC","W: Wide Flange","W760x147"]
	Canadian_CISC_W_Wide_Flange_W760x161 = ["Canadian","CISC","W: Wide Flange","W760x161"]
	Canadian_CISC_W_Wide_Flange_W760x173 = ["Canadian","CISC","W: Wide Flange","W760x173"]
	Canadian_CISC_W_Wide_Flange_W760x185 = ["Canadian","CISC","W: Wide Flange","W760x185"]
	Canadian_CISC_W_Wide_Flange_W760x196 = ["Canadian","CISC","W: Wide Flange","W760x196"]
	Canadian_CISC_W_Wide_Flange_W760x220 = ["Canadian","CISC","W: Wide Flange","W760x220"]
	Canadian_CISC_W_Wide_Flange_W760x257 = ["Canadian","CISC","W: Wide Flange","W760x257"]
	Canadian_CISC_W_Wide_Flange_W760x284 = ["Canadian","CISC","W: Wide Flange","W760x284"]
	Canadian_CISC_W_Wide_Flange_W760x314 = ["Canadian","CISC","W: Wide Flange","W760x314"]
	Canadian_CISC_W_Wide_Flange_W760x350 = ["Canadian","CISC","W: Wide Flange","W760x350"]
	Canadian_CISC_W_Wide_Flange_W760x389 = ["Canadian","CISC","W: Wide Flange","W760x389"]
	Canadian_CISC_W_Wide_Flange_W760x434 = ["Canadian","CISC","W: Wide Flange","W760x434"]
	Canadian_CISC_W_Wide_Flange_W760x484 = ["Canadian","CISC","W: Wide Flange","W760x484"]
	Canadian_CISC_W_Wide_Flange_W760x531 = ["Canadian","CISC","W: Wide Flange","W760x531"]
	Canadian_CISC_W_Wide_Flange_W760x582 = ["Canadian","CISC","W: Wide Flange","W760x582"]
	Canadian_CISC_W_Wide_Flange_W840x176 = ["Canadian","CISC","W: Wide Flange","W840x176"]
	Canadian_CISC_W_Wide_Flange_W840x193 = ["Canadian","CISC","W: Wide Flange","W840x193"]
	Canadian_CISC_W_Wide_Flange_W840x210 = ["Canadian","CISC","W: Wide Flange","W840x210"]
	Canadian_CISC_W_Wide_Flange_W840x226 = ["Canadian","CISC","W: Wide Flange","W840x226"]
	Canadian_CISC_W_Wide_Flange_W840x251 = ["Canadian","CISC","W: Wide Flange","W840x251"]
	Canadian_CISC_W_Wide_Flange_W840x299 = ["Canadian","CISC","W: Wide Flange","W840x299"]
	Canadian_CISC_W_Wide_Flange_W840x329 = ["Canadian","CISC","W: Wide Flange","W840x329"]
	Canadian_CISC_W_Wide_Flange_W840x359 = ["Canadian","CISC","W: Wide Flange","W840x359"]
	Canadian_CISC_W_Wide_Flange_W840x392 = ["Canadian","CISC","W: Wide Flange","W840x392"]
	Canadian_CISC_W_Wide_Flange_W840x433 = ["Canadian","CISC","W: Wide Flange","W840x433"]
	Canadian_CISC_W_Wide_Flange_W840x473 = ["Canadian","CISC","W: Wide Flange","W840x473"]
	Canadian_CISC_W_Wide_Flange_W840x527 = ["Canadian","CISC","W: Wide Flange","W840x527"]
	Canadian_CISC_W_Wide_Flange_W840x576 = ["Canadian","CISC","W: Wide Flange","W840x576"]
	Canadian_CISC_W_Wide_Flange_W920x201 = ["Canadian","CISC","W: Wide Flange","W920x201"]
	Canadian_CISC_W_Wide_Flange_W920x223 = ["Canadian","CISC","W: Wide Flange","W920x223"]
	Canadian_CISC_W_Wide_Flange_W920x238 = ["Canadian","CISC","W: Wide Flange","W920x238"]
	Canadian_CISC_W_Wide_Flange_W920x253 = ["Canadian","CISC","W: Wide Flange","W920x253"]
	Canadian_CISC_W_Wide_Flange_W920x271 = ["Canadian","CISC","W: Wide Flange","W920x271"]
	Canadian_CISC_W_Wide_Flange_W920x289 = ["Canadian","CISC","W: Wide Flange","W920x289"]
	Canadian_CISC_W_Wide_Flange_W920x313 = ["Canadian","CISC","W: Wide Flange","W920x313"]
	Canadian_CISC_W_Wide_Flange_W920x344 = ["Canadian","CISC","W: Wide Flange","W920x344"]
	Canadian_CISC_W_Wide_Flange_W920x345 = ["Canadian","CISC","W: Wide Flange","W920x345"]
	Canadian_CISC_W_Wide_Flange_W920x368 = ["Canadian","CISC","W: Wide Flange","W920x368"]
	Canadian_CISC_W_Wide_Flange_W920x381 = ["Canadian","CISC","W: Wide Flange","W920x381"]
	Canadian_CISC_W_Wide_Flange_W920x390 = ["Canadian","CISC","W: Wide Flange","W920x390"]
	Canadian_CISC_W_Wide_Flange_W920x420 = ["Canadian","CISC","W: Wide Flange","W920x420"]
	Canadian_CISC_W_Wide_Flange_W920x449 = ["Canadian","CISC","W: Wide Flange","W920x449"]
	Canadian_CISC_W_Wide_Flange_W920x491 = ["Canadian","CISC","W: Wide Flange","W920x491"]
	Canadian_CISC_W_Wide_Flange_W920x537 = ["Canadian","CISC","W: Wide Flange","W920x537"]
	Canadian_CISC_W_Wide_Flange_W920x588 = ["Canadian","CISC","W: Wide Flange","W920x588"]
	Canadian_CISC_W_Wide_Flange_W920x656 = ["Canadian","CISC","W: Wide Flange","W920x656"]
	Canadian_CISC_W_Wide_Flange_W920x725 = ["Canadian","CISC","W: Wide Flange","W920x725"]
	Canadian_CISC_W_Wide_Flange_W920x787 = ["Canadian","CISC","W: Wide Flange","W920x787"]
	Canadian_CISC_W_Wide_Flange_W920x970 = ["Canadian","CISC","W: Wide Flange","W920x970"]
	Canadian_CISC_W_Wide_Flange_W920x1191 = ["Canadian","CISC","W: Wide Flange","W920x1191"]
	Canadian_CISC_W_Wide_Flange_W1000x222 = ["Canadian","CISC","W: Wide Flange","W1000x222"]
	Canadian_CISC_W_Wide_Flange_W1000x249 = ["Canadian","CISC","W: Wide Flange","W1000x249"]
	Canadian_CISC_W_Wide_Flange_W1000x272 = ["Canadian","CISC","W: Wide Flange","W1000x272"]
	Canadian_CISC_W_Wide_Flange_W1000x296 = ["Canadian","CISC","W: Wide Flange","W1000x296"]
	Canadian_CISC_W_Wide_Flange_W1000x314 = ["Canadian","CISC","W: Wide Flange","W1000x314"]
	Canadian_CISC_W_Wide_Flange_W1000x321 = ["Canadian","CISC","W: Wide Flange","W1000x321"]
	Canadian_CISC_W_Wide_Flange_W1000x350 = ["Canadian","CISC","W: Wide Flange","W1000x350"]
	Canadian_CISC_W_Wide_Flange_W1000x371 = ["Canadian","CISC","W: Wide Flange","W1000x371"]
	Canadian_CISC_W_Wide_Flange_W1000x393 = ["Canadian","CISC","W: Wide Flange","W1000x393"]
	Canadian_CISC_W_Wide_Flange_W1000x412 = ["Canadian","CISC","W: Wide Flange","W1000x412"]
	Canadian_CISC_W_Wide_Flange_W1000x415 = ["Canadian","CISC","W: Wide Flange","W1000x415"]
	Canadian_CISC_W_Wide_Flange_W1000x438 = ["Canadian","CISC","W: Wide Flange","W1000x438"]
	Canadian_CISC_W_Wide_Flange_W1000x443 = ["Canadian","CISC","W: Wide Flange","W1000x443"]
	Canadian_CISC_W_Wide_Flange_W1000x483 = ["Canadian","CISC","W: Wide Flange","W1000x483"]
	Canadian_CISC_W_Wide_Flange_W1000x486 = ["Canadian","CISC","W: Wide Flange","W1000x486"]
	Canadian_CISC_W_Wide_Flange_W1000x494 = ["Canadian","CISC","W: Wide Flange","W1000x494"]
	Canadian_CISC_W_Wide_Flange_W1000x539 = ["Canadian","CISC","W: Wide Flange","W1000x539"]
	Canadian_CISC_W_Wide_Flange_W1000x554 = ["Canadian","CISC","W: Wide Flange","W1000x554"]
	Canadian_CISC_W_Wide_Flange_W1000x584 = ["Canadian","CISC","W: Wide Flange","W1000x584"]
	Canadian_CISC_W_Wide_Flange_W1000x591 = ["Canadian","CISC","W: Wide Flange","W1000x591"]
	Canadian_CISC_W_Wide_Flange_W1000x642 = ["Canadian","CISC","W: Wide Flange","W1000x642"]
	Canadian_CISC_W_Wide_Flange_W1000x748 = ["Canadian","CISC","W: Wide Flange","W1000x748"]
	Canadian_CISC_W_Wide_Flange_W1000x883 = ["Canadian","CISC","W: Wide Flange","W1000x883"]
	Canadian_CISC_W_Wide_Flange_W1100x343 = ["Canadian","CISC","W: Wide Flange","W1100x343"]
	Canadian_CISC_W_Wide_Flange_W1100x390 = ["Canadian","CISC","W: Wide Flange","W1100x390"]
	Canadian_CISC_W_Wide_Flange_W1100x433 = ["Canadian","CISC","W: Wide Flange","W1100x433"]
	Canadian_CISC_W_Wide_Flange_W1100x499 = ["Canadian","CISC","W: Wide Flange","W1100x499"]
	Canadian_CISC_HP_Shapes_HP200x54 = ["Canadian","CISC","HP Shapes","HP200x54"]
	Canadian_CISC_HP_Shapes_HP250x62 = ["Canadian","CISC","HP Shapes","HP250x62"]
	Canadian_CISC_HP_Shapes_HP250x85 = ["Canadian","CISC","HP Shapes","HP250x85"]
	Canadian_CISC_HP_Shapes_HP310x79 = ["Canadian","CISC","HP Shapes","HP310x79"]
	Canadian_CISC_HP_Shapes_HP310x94 = ["Canadian","CISC","HP Shapes","HP310x94"]
	Canadian_CISC_HP_Shapes_HP310x110 = ["Canadian","CISC","HP Shapes","HP310x110"]
	Canadian_CISC_HP_Shapes_HP310x125 = ["Canadian","CISC","HP Shapes","HP310x125"]
	Canadian_CISC_HP_Shapes_HP360x108 = ["Canadian","CISC","HP Shapes","HP360x108"]
	Canadian_CISC_HP_Shapes_HP360x132 = ["Canadian","CISC","HP Shapes","HP360x132"]
	Canadian_CISC_HP_Shapes_HP360x152 = ["Canadian","CISC","HP Shapes","HP360x152"]
	Canadian_CISC_HP_Shapes_HP360x174 = ["Canadian","CISC","HP Shapes","HP360x174"]
	Canadian_CISC_M_Shapes_M100x8_9 = ["Canadian","CISC","M Shapes","M100x8.9"]
	Canadian_CISC_M_Shapes_M130x28_1 = ["Canadian","CISC","M Shapes","M130x28.1"]
	Canadian_CISC_M_Shapes_M150x5_5 = ["Canadian","CISC","M Shapes","M150x5.5"]
	Canadian_CISC_M_Shapes_M150x6_6 = ["Canadian","CISC","M Shapes","M150x6.6"]
	Canadian_CISC_M_Shapes_M200x9_2 = ["Canadian","CISC","M Shapes","M200x9.2"]
	Canadian_CISC_M_Shapes_M200x9_7 = ["Canadian","CISC","M Shapes","M200x9.7"]
	Canadian_CISC_M_Shapes_M250x11_2 = ["Canadian","CISC","M Shapes","M250x11.2"]
	Canadian_CISC_M_Shapes_M250x11_9 = ["Canadian","CISC","M Shapes","M250x11.9"]
	Canadian_CISC_M_Shapes_M250x13_4 = ["Canadian","CISC","M Shapes","M250x13.4"]
	Canadian_CISC_M_Shapes_M310x14_9 = ["Canadian","CISC","M Shapes","M310x14.9"]
	Canadian_CISC_M_Shapes_M310x16_1 = ["Canadian","CISC","M Shapes","M310x16.1"]
	Canadian_CISC_M_Shapes_M310x17_6 = ["Canadian","CISC","M Shapes","M310x17.6"]
	Canadian_CISC_SLB_Super_Light_Beams_SLB55x6_4 = ["Canadian","CISC","SLB: Super-Light Beams","SLB55x6.4"]
	Canadian_CISC_SLB_Super_Light_Beams_SLB75x3_8 = ["Canadian","CISC","SLB: Super-Light Beams","SLB75x3.8"]
	Canadian_CISC_SLB_Super_Light_Beams_SLB75x4_3 = ["Canadian","CISC","SLB: Super-Light Beams","SLB75x4.3"]
	Canadian_CISC_SLB_Super_Light_Beams_SLB75x4_5 = ["Canadian","CISC","SLB: Super-Light Beams","SLB75x4.5"]
	Canadian_CISC_SLB_Super_Light_Beams_SLB75x5_6 = ["Canadian","CISC","SLB: Super-Light Beams","SLB75x5.6"]
	Canadian_CISC_SLB_Super_Light_Beams_SLB100x4_8 = ["Canadian","CISC","SLB: Super-Light Beams","SLB100x4.8"]
	Canadian_CISC_SLB_Super_Light_Beams_SLB100x5_1 = ["Canadian","CISC","SLB: Super-Light Beams","SLB100x5.1"]
	Canadian_CISC_SLB_Super_Light_Beams_SLB100x5_4 = ["Canadian","CISC","SLB: Super-Light Beams","SLB100x5.4"]
	Canadian_CISC_S_Shapes_S75x8 = ["Canadian","CISC","S Shapes","S75x8"]
	Canadian_CISC_S_Shapes_S75x11 = ["Canadian","CISC","S Shapes","S75x11"]
	Canadian_CISC_S_Shapes_S100x11 = ["Canadian","CISC","S Shapes","S100x11"]
	Canadian_CISC_S_Shapes_S100x14_1 = ["Canadian","CISC","S Shapes","S100x14.1"]
	Canadian_CISC_S_Shapes_S130x15 = ["Canadian","CISC","S Shapes","S130x15"]
	Canadian_CISC_S_Shapes_S150x19 = ["Canadian","CISC","S Shapes","S150x19"]
	Canadian_CISC_S_Shapes_S150x26 = ["Canadian","CISC","S Shapes","S150x26"]
	Canadian_CISC_S_Shapes_S200x27 = ["Canadian","CISC","S Shapes","S200x27"]
	Canadian_CISC_S_Shapes_S200x34 = ["Canadian","CISC","S Shapes","S200x34"]
	Canadian_CISC_S_Shapes_S250x38 = ["Canadian","CISC","S Shapes","S250x38"]
	Canadian_CISC_S_Shapes_S250x52 = ["Canadian","CISC","S Shapes","S250x52"]
	Canadian_CISC_S_Shapes_S310x47 = ["Canadian","CISC","S Shapes","S310x47"]
	Canadian_CISC_S_Shapes_S310x52 = ["Canadian","CISC","S Shapes","S310x52"]
	Canadian_CISC_S_Shapes_S310x60_7 = ["Canadian","CISC","S Shapes","S310x60.7"]
	Canadian_CISC_S_Shapes_S310x74 = ["Canadian","CISC","S Shapes","S310x74"]
	Canadian_CISC_S_Shapes_S380x64 = ["Canadian","CISC","S Shapes","S380x64"]
	Canadian_CISC_S_Shapes_S380x74 = ["Canadian","CISC","S Shapes","S380x74"]
	Canadian_CISC_S_Shapes_S460x81_4 = ["Canadian","CISC","S Shapes","S460x81.4"]
	Canadian_CISC_S_Shapes_S460x104 = ["Canadian","CISC","S Shapes","S460x104"]
	Canadian_CISC_S_Shapes_S510x98_2 = ["Canadian","CISC","S Shapes","S510x98.2"]
	Canadian_CISC_S_Shapes_S510x112 = ["Canadian","CISC","S Shapes","S510x112"]
	Canadian_CISC_S_Shapes_S510x128 = ["Canadian","CISC","S Shapes","S510x128"]
	Canadian_CISC_S_Shapes_S510x143 = ["Canadian","CISC","S Shapes","S510x143"]
	Canadian_CISC_S_Shapes_S610x119 = ["Canadian","CISC","S Shapes","S610x119"]
	Canadian_CISC_S_Shapes_S610x134 = ["Canadian","CISC","S Shapes","S610x134"]
	Canadian_CISC_S_Shapes_S610x149 = ["Canadian","CISC","S Shapes","S610x149"]
	Canadian_CISC_S_Shapes_S610x158 = ["Canadian","CISC","S Shapes","S610x158"]
	Canadian_CISC_S_Shapes_S610x180 = ["Canadian","CISC","S Shapes","S610x180"]
	Canadian_CISC_C_Shapes_C75x5 = ["Canadian","CISC","C Shapes","C75x5"]
	Canadian_CISC_C_Shapes_C75x6 = ["Canadian","CISC","C Shapes","C75x6"]
	Canadian_CISC_C_Shapes_C75x7 = ["Canadian","CISC","C Shapes","C75x7"]
	Canadian_CISC_C_Shapes_C75x9 = ["Canadian","CISC","C Shapes","C75x9"]
	Canadian_CISC_C_Shapes_C100x7 = ["Canadian","CISC","C Shapes","C100x7"]
	Canadian_CISC_C_Shapes_C100x8 = ["Canadian","CISC","C Shapes","C100x8"]
	Canadian_CISC_C_Shapes_C100x11 = ["Canadian","CISC","C Shapes","C100x11"]
	Canadian_CISC_C_Shapes_C130x10 = ["Canadian","CISC","C Shapes","C130x10"]
	Canadian_CISC_C_Shapes_C130x13 = ["Canadian","CISC","C Shapes","C130x13"]
	Canadian_CISC_C_Shapes_C150x12 = ["Canadian","CISC","C Shapes","C150x12"]
	Canadian_CISC_C_Shapes_C150x16 = ["Canadian","CISC","C Shapes","C150x16"]
	Canadian_CISC_C_Shapes_C150x19 = ["Canadian","CISC","C Shapes","C150x19"]
	Canadian_CISC_C_Shapes_C180x15 = ["Canadian","CISC","C Shapes","C180x15"]
	Canadian_CISC_C_Shapes_C180x18 = ["Canadian","CISC","C Shapes","C180x18"]
	Canadian_CISC_C_Shapes_C180x22 = ["Canadian","CISC","C Shapes","C180x22"]
	Canadian_CISC_C_Shapes_C200x17 = ["Canadian","CISC","C Shapes","C200x17"]
	Canadian_CISC_C_Shapes_C200x21 = ["Canadian","CISC","C Shapes","C200x21"]
	Canadian_CISC_C_Shapes_C200x28 = ["Canadian","CISC","C Shapes","C200x28"]
	Canadian_CISC_C_Shapes_C230x20 = ["Canadian","CISC","C Shapes","C230x20"]
	Canadian_CISC_C_Shapes_C230x22 = ["Canadian","CISC","C Shapes","C230x22"]
	Canadian_CISC_C_Shapes_C230x30 = ["Canadian","CISC","C Shapes","C230x30"]
	Canadian_CISC_C_Shapes_C250x23 = ["Canadian","CISC","C Shapes","C250x23"]
	Canadian_CISC_C_Shapes_C250x30 = ["Canadian","CISC","C Shapes","C250x30"]
	Canadian_CISC_C_Shapes_C250x37 = ["Canadian","CISC","C Shapes","C250x37"]
	Canadian_CISC_C_Shapes_C250x45 = ["Canadian","CISC","C Shapes","C250x45"]
	Canadian_CISC_C_Shapes_C310x31 = ["Canadian","CISC","C Shapes","C310x31"]
	Canadian_CISC_C_Shapes_C310x37 = ["Canadian","CISC","C Shapes","C310x37"]
	Canadian_CISC_C_Shapes_C310x45 = ["Canadian","CISC","C Shapes","C310x45"]
	Canadian_CISC_C_Shapes_C380x50 = ["Canadian","CISC","C Shapes","C380x50"]
	Canadian_CISC_C_Shapes_C380x60 = ["Canadian","CISC","C Shapes","C380x60"]
	Canadian_CISC_C_Shapes_C380x74 = ["Canadian","CISC","C Shapes","C380x74"]
	Canadian_CISC_MC_Misc_Channels_MC150x17_9 = ["Canadian","CISC","MC: Misc Channels","MC150x17.9"]
	Canadian_CISC_MC_Misc_Channels_MC150x22_5 = ["Canadian","CISC","MC: Misc Channels","MC150x22.5"]
	Canadian_CISC_MC_Misc_Channels_MC150x22_8 = ["Canadian","CISC","MC: Misc Channels","MC150x22.8"]
	Canadian_CISC_MC_Misc_Channels_MC150x24_3 = ["Canadian","CISC","MC: Misc Channels","MC150x24.3"]
	Canadian_CISC_MC_Misc_Channels_MC150x26_8 = ["Canadian","CISC","MC: Misc Channels","MC150x26.8"]
	Canadian_CISC_MC_Misc_Channels_MC180x28_4 = ["Canadian","CISC","MC: Misc Channels","MC180x28.4"]
	Canadian_CISC_MC_Misc_Channels_MC180x33_8 = ["Canadian","CISC","MC: Misc Channels","MC180x33.8"]
	Canadian_CISC_MC_Misc_Channels_MC200x12_6 = ["Canadian","CISC","MC: Misc Channels","MC200x12.6"]
	Canadian_CISC_MC_Misc_Channels_MC200x27_8 = ["Canadian","CISC","MC: Misc Channels","MC200x27.8"]
	Canadian_CISC_MC_Misc_Channels_MC200x29_8 = ["Canadian","CISC","MC: Misc Channels","MC200x29.8"]
	Canadian_CISC_MC_Misc_Channels_MC200x31_8 = ["Canadian","CISC","MC: Misc Channels","MC200x31.8"]
	Canadian_CISC_MC_Misc_Channels_MC200x33_9 = ["Canadian","CISC","MC: Misc Channels","MC200x33.9"]
	Canadian_CISC_MC_Misc_Channels_MC230x35_6 = ["Canadian","CISC","MC: Misc Channels","MC230x35.6"]
	Canadian_CISC_MC_Misc_Channels_MC230x37_8 = ["Canadian","CISC","MC: Misc Channels","MC230x37.8"]
	Canadian_CISC_MC_Misc_Channels_MC250x12_5 = ["Canadian","CISC","MC: Misc Channels","MC250x12.5"]
	Canadian_CISC_MC_Misc_Channels_MC250x33 = ["Canadian","CISC","MC: Misc Channels","MC250x33"]
	Canadian_CISC_MC_Misc_Channels_MC250x37 = ["Canadian","CISC","MC: Misc Channels","MC250x37"]
	Canadian_CISC_MC_Misc_Channels_MC250x42_4 = ["Canadian","CISC","MC: Misc Channels","MC250x42.4"]
	Canadian_CISC_MC_Misc_Channels_MC250x50 = ["Canadian","CISC","MC: Misc Channels","MC250x50"]
	Canadian_CISC_MC_Misc_Channels_MC250x61_2 = ["Canadian","CISC","MC: Misc Channels","MC250x61.2"]
	Canadian_CISC_MC_Misc_Channels_MC310x15_8 = ["Canadian","CISC","MC: Misc Channels","MC310x15.8"]
	Canadian_CISC_MC_Misc_Channels_MC310x46 = ["Canadian","CISC","MC: Misc Channels","MC310x46"]
	Canadian_CISC_MC_Misc_Channels_MC310x52 = ["Canadian","CISC","MC: Misc Channels","MC310x52"]
	Canadian_CISC_MC_Misc_Channels_MC310x60 = ["Canadian","CISC","MC: Misc Channels","MC310x60"]
	Canadian_CISC_MC_Misc_Channels_MC310x67 = ["Canadian","CISC","MC: Misc Channels","MC310x67"]
	Canadian_CISC_MC_Misc_Channels_MC310x74 = ["Canadian","CISC","MC: Misc Channels","MC310x74"]
	Canadian_CISC_MC_Misc_Channels_MC330x47_3 = ["Canadian","CISC","MC: Misc Channels","MC330x47.3"]
	Canadian_CISC_MC_Misc_Channels_MC330x52 = ["Canadian","CISC","MC: Misc Channels","MC330x52"]
	Canadian_CISC_MC_Misc_Channels_MC330x60 = ["Canadian","CISC","MC: Misc Channels","MC330x60"]
	Canadian_CISC_MC_Misc_Channels_MC330x74 = ["Canadian","CISC","MC: Misc Channels","MC330x74"]
	Canadian_CISC_MC_Misc_Channels_MC460x63_5 = ["Canadian","CISC","MC: Misc Channels","MC460x63.5"]
	Canadian_CISC_MC_Misc_Channels_MC460x68_2 = ["Canadian","CISC","MC: Misc Channels","MC460x68.2"]
	Canadian_CISC_MC_Misc_Channels_MC460x77_2 = ["Canadian","CISC","MC: Misc Channels","MC460x77.2"]
	Canadian_CISC_MC_Misc_Channels_MC460x86 = ["Canadian","CISC","MC: Misc Channels","MC460x86"]
	Canadian_CISC_Angles_Imperial_Series_L19x19x3_2 = ["Canadian","CISC","Angles Imperial Series","L19x19x3.2"]
	Canadian_CISC_Angles_Imperial_Series_L25x25x3_2 = ["Canadian","CISC","Angles Imperial Series","L25x25x3.2"]
	Canadian_CISC_Angles_Imperial_Series_L25x25x4_8 = ["Canadian","CISC","Angles Imperial Series","L25x25x4.8"]
	Canadian_CISC_Angles_Imperial_Series_L25x25x6_4 = ["Canadian","CISC","Angles Imperial Series","L25x25x6.4"]
	Canadian_CISC_Angles_Imperial_Series_L32x32x3_2 = ["Canadian","CISC","Angles Imperial Series","L32x32x3.2"]
	Canadian_CISC_Angles_Imperial_Series_L32x32x4_8 = ["Canadian","CISC","Angles Imperial Series","L32x32x4.8"]
	Canadian_CISC_Angles_Imperial_Series_L32x32x6_4 = ["Canadian","CISC","Angles Imperial Series","L32x32x6.4"]
	Canadian_CISC_Angles_Imperial_Series_L38x38x3_2 = ["Canadian","CISC","Angles Imperial Series","L38x38x3.2"]
	Canadian_CISC_Angles_Imperial_Series_L38x38x4_8 = ["Canadian","CISC","Angles Imperial Series","L38x38x4.8"]
	Canadian_CISC_Angles_Imperial_Series_L38x38x6_4 = ["Canadian","CISC","Angles Imperial Series","L38x38x6.4"]
	Canadian_CISC_Angles_Imperial_Series_L44x44x3_2 = ["Canadian","CISC","Angles Imperial Series","L44x44x3.2"]
	Canadian_CISC_Angles_Imperial_Series_L44x44x4_8 = ["Canadian","CISC","Angles Imperial Series","L44x44x4.8"]
	Canadian_CISC_Angles_Imperial_Series_L44x44x6_4 = ["Canadian","CISC","Angles Imperial Series","L44x44x6.4"]
	Canadian_CISC_Angles_Imperial_Series_L51x38x3_2 = ["Canadian","CISC","Angles Imperial Series","L51x38x3.2"]
	Canadian_CISC_Angles_Imperial_Series_L51x38x4_8 = ["Canadian","CISC","Angles Imperial Series","L51x38x4.8"]
	Canadian_CISC_Angles_Imperial_Series_L51x38x6_4 = ["Canadian","CISC","Angles Imperial Series","L51x38x6.4"]
	Canadian_CISC_Angles_Imperial_Series_L51x51x3_2 = ["Canadian","CISC","Angles Imperial Series","L51x51x3.2"]
	Canadian_CISC_Angles_Imperial_Series_L51x51x4_8 = ["Canadian","CISC","Angles Imperial Series","L51x51x4.8"]
	Canadian_CISC_Angles_Imperial_Series_L51x51x6_4 = ["Canadian","CISC","Angles Imperial Series","L51x51x6.4"]
	Canadian_CISC_Angles_Imperial_Series_L51x51x7_9 = ["Canadian","CISC","Angles Imperial Series","L51x51x7.9"]
	Canadian_CISC_Angles_Imperial_Series_L51x51x9_5 = ["Canadian","CISC","Angles Imperial Series","L51x51x9.5"]
	Canadian_CISC_Angles_Imperial_Series_L64x51x4_8 = ["Canadian","CISC","Angles Imperial Series","L64x51x4.8"]
	Canadian_CISC_Angles_Imperial_Series_L64x51x6_4 = ["Canadian","CISC","Angles Imperial Series","L64x51x6.4"]
	Canadian_CISC_Angles_Imperial_Series_L64x51x7_9 = ["Canadian","CISC","Angles Imperial Series","L64x51x7.9"]
	Canadian_CISC_Angles_Imperial_Series_L64x51x9_5 = ["Canadian","CISC","Angles Imperial Series","L64x51x9.5"]
	Canadian_CISC_Angles_Imperial_Series_L64x64x4_8 = ["Canadian","CISC","Angles Imperial Series","L64x64x4.8"]
	Canadian_CISC_Angles_Imperial_Series_L64x64x6_4 = ["Canadian","CISC","Angles Imperial Series","L64x64x6.4"]
	Canadian_CISC_Angles_Imperial_Series_L64x64x7_9 = ["Canadian","CISC","Angles Imperial Series","L64x64x7.9"]
	Canadian_CISC_Angles_Imperial_Series_L64x64x9_5 = ["Canadian","CISC","Angles Imperial Series","L64x64x9.5"]
	Canadian_CISC_Angles_Imperial_Series_L64x64x13 = ["Canadian","CISC","Angles Imperial Series","L64x64x13"]
	Canadian_CISC_Angles_Imperial_Series_L76x51x4_8 = ["Canadian","CISC","Angles Imperial Series","L76x51x4.8"]
	Canadian_CISC_Angles_Imperial_Series_L76x51x6_4 = ["Canadian","CISC","Angles Imperial Series","L76x51x6.4"]
	Canadian_CISC_Angles_Imperial_Series_L76x51x7_9 = ["Canadian","CISC","Angles Imperial Series","L76x51x7.9"]
	Canadian_CISC_Angles_Imperial_Series_L76x51x9_5 = ["Canadian","CISC","Angles Imperial Series","L76x51x9.5"]
	Canadian_CISC_Angles_Imperial_Series_L76x51x13 = ["Canadian","CISC","Angles Imperial Series","L76x51x13"]
	Canadian_CISC_Angles_Imperial_Series_L76x64x4_8 = ["Canadian","CISC","Angles Imperial Series","L76x64x4.8"]
	Canadian_CISC_Angles_Imperial_Series_L76x64x6_4 = ["Canadian","CISC","Angles Imperial Series","L76x64x6.4"]
	Canadian_CISC_Angles_Imperial_Series_L76x64x7_9 = ["Canadian","CISC","Angles Imperial Series","L76x64x7.9"]
	Canadian_CISC_Angles_Imperial_Series_L76x64x9_5 = ["Canadian","CISC","Angles Imperial Series","L76x64x9.5"]
	Canadian_CISC_Angles_Imperial_Series_L76x64x13 = ["Canadian","CISC","Angles Imperial Series","L76x64x13"]
	Canadian_CISC_Angles_Imperial_Series_L76x76x4_8 = ["Canadian","CISC","Angles Imperial Series","L76x76x4.8"]
	Canadian_CISC_Angles_Imperial_Series_L76x76x6_4 = ["Canadian","CISC","Angles Imperial Series","L76x76x6.4"]
	Canadian_CISC_Angles_Imperial_Series_L76x76x7_9 = ["Canadian","CISC","Angles Imperial Series","L76x76x7.9"]
	Canadian_CISC_Angles_Imperial_Series_L76x76x9_5 = ["Canadian","CISC","Angles Imperial Series","L76x76x9.5"]
	Canadian_CISC_Angles_Imperial_Series_L76x76x11 = ["Canadian","CISC","Angles Imperial Series","L76x76x11"]
	Canadian_CISC_Angles_Imperial_Series_L76x76x13 = ["Canadian","CISC","Angles Imperial Series","L76x76x13"]
	Canadian_CISC_Angles_Imperial_Series_L89x64x6_4 = ["Canadian","CISC","Angles Imperial Series","L89x64x6.4"]
	Canadian_CISC_Angles_Imperial_Series_L89x64x7_9 = ["Canadian","CISC","Angles Imperial Series","L89x64x7.9"]
	Canadian_CISC_Angles_Imperial_Series_L89x64x9_5 = ["Canadian","CISC","Angles Imperial Series","L89x64x9.5"]
	Canadian_CISC_Angles_Imperial_Series_L89x64x13 = ["Canadian","CISC","Angles Imperial Series","L89x64x13"]
	Canadian_CISC_Angles_Imperial_Series_L89x76x6_4 = ["Canadian","CISC","Angles Imperial Series","L89x76x6.4"]
	Canadian_CISC_Angles_Imperial_Series_L89x76x7_9 = ["Canadian","CISC","Angles Imperial Series","L89x76x7.9"]
	Canadian_CISC_Angles_Imperial_Series_L89x76x9_5 = ["Canadian","CISC","Angles Imperial Series","L89x76x9.5"]
	Canadian_CISC_Angles_Imperial_Series_L89x76x13 = ["Canadian","CISC","Angles Imperial Series","L89x76x13"]
	Canadian_CISC_Angles_Imperial_Series_L89x89x6_4 = ["Canadian","CISC","Angles Imperial Series","L89x89x6.4"]
	Canadian_CISC_Angles_Imperial_Series_L89x89x7_9 = ["Canadian","CISC","Angles Imperial Series","L89x89x7.9"]
	Canadian_CISC_Angles_Imperial_Series_L89x89x9_5 = ["Canadian","CISC","Angles Imperial Series","L89x89x9.5"]
	Canadian_CISC_Angles_Imperial_Series_L89x89x11 = ["Canadian","CISC","Angles Imperial Series","L89x89x11"]
	Canadian_CISC_Angles_Imperial_Series_L89x89x13 = ["Canadian","CISC","Angles Imperial Series","L89x89x13"]
	Canadian_CISC_Angles_Imperial_Series_L102x76x6_4 = ["Canadian","CISC","Angles Imperial Series","L102x76x6.4"]
	Canadian_CISC_Angles_Imperial_Series_L102x76x7_9 = ["Canadian","CISC","Angles Imperial Series","L102x76x7.9"]
	Canadian_CISC_Angles_Imperial_Series_L102x76x9_5 = ["Canadian","CISC","Angles Imperial Series","L102x76x9.5"]
	Canadian_CISC_Angles_Imperial_Series_L102x76x11 = ["Canadian","CISC","Angles Imperial Series","L102x76x11"]
	Canadian_CISC_Angles_Imperial_Series_L102x76x13 = ["Canadian","CISC","Angles Imperial Series","L102x76x13"]
	Canadian_CISC_Angles_Imperial_Series_L102x76x16 = ["Canadian","CISC","Angles Imperial Series","L102x76x16"]
	Canadian_CISC_Angles_Imperial_Series_L102x89x6_4 = ["Canadian","CISC","Angles Imperial Series","L102x89x6.4"]
	Canadian_CISC_Angles_Imperial_Series_L102x89x7_9 = ["Canadian","CISC","Angles Imperial Series","L102x89x7.9"]
	Canadian_CISC_Angles_Imperial_Series_L102x89x9_5 = ["Canadian","CISC","Angles Imperial Series","L102x89x9.5"]
	Canadian_CISC_Angles_Imperial_Series_L102x89x11 = ["Canadian","CISC","Angles Imperial Series","L102x89x11"]
	Canadian_CISC_Angles_Imperial_Series_L102x89x13 = ["Canadian","CISC","Angles Imperial Series","L102x89x13"]
	Canadian_CISC_Angles_Imperial_Series_L102x102x6_4 = ["Canadian","CISC","Angles Imperial Series","L102x102x6.4"]
	Canadian_CISC_Angles_Imperial_Series_L102x102x7_9 = ["Canadian","CISC","Angles Imperial Series","L102x102x7.9"]
	Canadian_CISC_Angles_Imperial_Series_L102x102x9_5 = ["Canadian","CISC","Angles Imperial Series","L102x102x9.5"]
	Canadian_CISC_Angles_Imperial_Series_L102x102x11 = ["Canadian","CISC","Angles Imperial Series","L102x102x11"]
	Canadian_CISC_Angles_Imperial_Series_L102x102x13 = ["Canadian","CISC","Angles Imperial Series","L102x102x13"]
	Canadian_CISC_Angles_Imperial_Series_L102x102x16 = ["Canadian","CISC","Angles Imperial Series","L102x102x16"]
	Canadian_CISC_Angles_Imperial_Series_L102x102x19 = ["Canadian","CISC","Angles Imperial Series","L102x102x19"]
	Canadian_CISC_Angles_Imperial_Series_L127x76x6_4 = ["Canadian","CISC","Angles Imperial Series","L127x76x6.4"]
	Canadian_CISC_Angles_Imperial_Series_L127x76x7_9 = ["Canadian","CISC","Angles Imperial Series","L127x76x7.9"]
	Canadian_CISC_Angles_Imperial_Series_L127x76x9_5 = ["Canadian","CISC","Angles Imperial Series","L127x76x9.5"]
	Canadian_CISC_Angles_Imperial_Series_L127x76x11 = ["Canadian","CISC","Angles Imperial Series","L127x76x11"]
	Canadian_CISC_Angles_Imperial_Series_L127x76x13 = ["Canadian","CISC","Angles Imperial Series","L127x76x13"]
	Canadian_CISC_Angles_Imperial_Series_L127x89x6_4 = ["Canadian","CISC","Angles Imperial Series","L127x89x6.4"]
	Canadian_CISC_Angles_Imperial_Series_L127x89x7_9 = ["Canadian","CISC","Angles Imperial Series","L127x89x7.9"]
	Canadian_CISC_Angles_Imperial_Series_L127x89x9_5 = ["Canadian","CISC","Angles Imperial Series","L127x89x9.5"]
	Canadian_CISC_Angles_Imperial_Series_L127x89x13 = ["Canadian","CISC","Angles Imperial Series","L127x89x13"]
	Canadian_CISC_Angles_Imperial_Series_L127x89x16 = ["Canadian","CISC","Angles Imperial Series","L127x89x16"]
	Canadian_CISC_Angles_Imperial_Series_L127x89x19 = ["Canadian","CISC","Angles Imperial Series","L127x89x19"]
	Canadian_CISC_Angles_Imperial_Series_L127x127x6_4 = ["Canadian","CISC","Angles Imperial Series","L127x127x6.4"]
	Canadian_CISC_Angles_Imperial_Series_L127x127x7_9 = ["Canadian","CISC","Angles Imperial Series","L127x127x7.9"]
	Canadian_CISC_Angles_Imperial_Series_L127x127x9_5 = ["Canadian","CISC","Angles Imperial Series","L127x127x9.5"]
	Canadian_CISC_Angles_Imperial_Series_L127x127x11 = ["Canadian","CISC","Angles Imperial Series","L127x127x11"]
	Canadian_CISC_Angles_Imperial_Series_L127x127x13 = ["Canadian","CISC","Angles Imperial Series","L127x127x13"]
	Canadian_CISC_Angles_Imperial_Series_L127x127x16 = ["Canadian","CISC","Angles Imperial Series","L127x127x16"]
	Canadian_CISC_Angles_Imperial_Series_L127x127x19 = ["Canadian","CISC","Angles Imperial Series","L127x127x19"]
	Canadian_CISC_Angles_Imperial_Series_L127x127x22 = ["Canadian","CISC","Angles Imperial Series","L127x127x22"]
	Canadian_CISC_Angles_Imperial_Series_L152x89x7_9 = ["Canadian","CISC","Angles Imperial Series","L152x89x7.9"]
	Canadian_CISC_Angles_Imperial_Series_L152x89x9_5 = ["Canadian","CISC","Angles Imperial Series","L152x89x9.5"]
	Canadian_CISC_Angles_Imperial_Series_L152x89x13 = ["Canadian","CISC","Angles Imperial Series","L152x89x13"]
	Canadian_CISC_Angles_Imperial_Series_L152x89x16 = ["Canadian","CISC","Angles Imperial Series","L152x89x16"]
	Canadian_CISC_Angles_Imperial_Series_L152x102x7_9 = ["Canadian","CISC","Angles Imperial Series","L152x102x7.9"]
	Canadian_CISC_Angles_Imperial_Series_L152x102x9_5 = ["Canadian","CISC","Angles Imperial Series","L152x102x9.5"]
	Canadian_CISC_Angles_Imperial_Series_L152x102x11 = ["Canadian","CISC","Angles Imperial Series","L152x102x11"]
	Canadian_CISC_Angles_Imperial_Series_L152x102x13 = ["Canadian","CISC","Angles Imperial Series","L152x102x13"]
	Canadian_CISC_Angles_Imperial_Series_L152x102x14 = ["Canadian","CISC","Angles Imperial Series","L152x102x14"]
	Canadian_CISC_Angles_Imperial_Series_L152x102x16 = ["Canadian","CISC","Angles Imperial Series","L152x102x16"]
	Canadian_CISC_Angles_Imperial_Series_L152x102x19 = ["Canadian","CISC","Angles Imperial Series","L152x102x19"]
	Canadian_CISC_Angles_Imperial_Series_L152x102x22 = ["Canadian","CISC","Angles Imperial Series","L152x102x22"]
	Canadian_CISC_Angles_Imperial_Series_L152x152x6_4 = ["Canadian","CISC","Angles Imperial Series","L152x152x6.4"]
	Canadian_CISC_Angles_Imperial_Series_L152x152x7_9 = ["Canadian","CISC","Angles Imperial Series","L152x152x7.9"]
	Canadian_CISC_Angles_Imperial_Series_L152x152x9_5 = ["Canadian","CISC","Angles Imperial Series","L152x152x9.5"]
	Canadian_CISC_Angles_Imperial_Series_L152x152x11 = ["Canadian","CISC","Angles Imperial Series","L152x152x11"]
	Canadian_CISC_Angles_Imperial_Series_L152x152x13 = ["Canadian","CISC","Angles Imperial Series","L152x152x13"]
	Canadian_CISC_Angles_Imperial_Series_L152x152x14 = ["Canadian","CISC","Angles Imperial Series","L152x152x14"]
	Canadian_CISC_Angles_Imperial_Series_L152x152x16 = ["Canadian","CISC","Angles Imperial Series","L152x152x16"]
	Canadian_CISC_Angles_Imperial_Series_L152x152x19 = ["Canadian","CISC","Angles Imperial Series","L152x152x19"]
	Canadian_CISC_Angles_Imperial_Series_L152x152x22 = ["Canadian","CISC","Angles Imperial Series","L152x152x22"]
	Canadian_CISC_Angles_Imperial_Series_L152x152x25 = ["Canadian","CISC","Angles Imperial Series","L152x152x25"]
	Canadian_CISC_Angles_Imperial_Series_L178x102x9_5 = ["Canadian","CISC","Angles Imperial Series","L178x102x9.5"]
	Canadian_CISC_Angles_Imperial_Series_L178x102x11 = ["Canadian","CISC","Angles Imperial Series","L178x102x11"]
	Canadian_CISC_Angles_Imperial_Series_L178x102x13 = ["Canadian","CISC","Angles Imperial Series","L178x102x13"]
	Canadian_CISC_Angles_Imperial_Series_L178x102x16 = ["Canadian","CISC","Angles Imperial Series","L178x102x16"]
	Canadian_CISC_Angles_Imperial_Series_L178x102x19 = ["Canadian","CISC","Angles Imperial Series","L178x102x19"]
	Canadian_CISC_Angles_Imperial_Series_L203x102x13 = ["Canadian","CISC","Angles Imperial Series","L203x102x13"]
	Canadian_CISC_Angles_Imperial_Series_L203x102x19 = ["Canadian","CISC","Angles Imperial Series","L203x102x19"]
	Canadian_CISC_Angles_Imperial_Series_L203x102x25 = ["Canadian","CISC","Angles Imperial Series","L203x102x25"]
	Canadian_CISC_Angles_Imperial_Series_L203x152x13 = ["Canadian","CISC","Angles Imperial Series","L203x152x13"]
	Canadian_CISC_Angles_Imperial_Series_L203x152x14 = ["Canadian","CISC","Angles Imperial Series","L203x152x14"]
	Canadian_CISC_Angles_Imperial_Series_L203x152x16 = ["Canadian","CISC","Angles Imperial Series","L203x152x16"]
	Canadian_CISC_Angles_Imperial_Series_L203x152x19 = ["Canadian","CISC","Angles Imperial Series","L203x152x19"]
	Canadian_CISC_Angles_Imperial_Series_L203x152x22 = ["Canadian","CISC","Angles Imperial Series","L203x152x22"]
	Canadian_CISC_Angles_Imperial_Series_L203x152x25 = ["Canadian","CISC","Angles Imperial Series","L203x152x25"]
	Canadian_CISC_Angles_Imperial_Series_L203x203x13 = ["Canadian","CISC","Angles Imperial Series","L203x203x13"]
	Canadian_CISC_Angles_Imperial_Series_L203x203x14 = ["Canadian","CISC","Angles Imperial Series","L203x203x14"]
	Canadian_CISC_Angles_Imperial_Series_L203x203x16 = ["Canadian","CISC","Angles Imperial Series","L203x203x16"]
	Canadian_CISC_Angles_Imperial_Series_L203x203x19 = ["Canadian","CISC","Angles Imperial Series","L203x203x19"]
	Canadian_CISC_Angles_Imperial_Series_L203x203x22 = ["Canadian","CISC","Angles Imperial Series","L203x203x22"]
	Canadian_CISC_Angles_Imperial_Series_L203x203x25 = ["Canadian","CISC","Angles Imperial Series","L203x203x25"]
	Canadian_CISC_Angles_Imperial_Series_L203x203x29 = ["Canadian","CISC","Angles Imperial Series","L203x203x29"]
	Canadian_CISC_WT_Structural_Tees_WT50x9_5 = ["Canadian","CISC","WT: Structural Tees","WT50x9.5"]
	Canadian_CISC_WT_Structural_Tees_WT65x12 = ["Canadian","CISC","WT: Structural Tees","WT65x12"]
	Canadian_CISC_WT_Structural_Tees_WT65x14 = ["Canadian","CISC","WT: Structural Tees","WT65x14"]
	Canadian_CISC_WT_Structural_Tees_WT75x7 = ["Canadian","CISC","WT: Structural Tees","WT75x7"]
	Canadian_CISC_WT_Structural_Tees_WT75x9 = ["Canadian","CISC","WT: Structural Tees","WT75x9"]
	Canadian_CISC_WT_Structural_Tees_WT75x11 = ["Canadian","CISC","WT: Structural Tees","WT75x11"]
	Canadian_CISC_WT_Structural_Tees_WT75x12 = ["Canadian","CISC","WT: Structural Tees","WT75x12"]
	Canadian_CISC_WT_Structural_Tees_WT75x15 = ["Canadian","CISC","WT: Structural Tees","WT75x15"]
	Canadian_CISC_WT_Structural_Tees_WT75x18_5 = ["Canadian","CISC","WT: Structural Tees","WT75x18.5"]
	Canadian_CISC_WT_Structural_Tees_WT100x7_5 = ["Canadian","CISC","WT: Structural Tees","WT100x7.5"]
	Canadian_CISC_WT_Structural_Tees_WT100x9_5 = ["Canadian","CISC","WT: Structural Tees","WT100x9.5"]
	Canadian_CISC_WT_Structural_Tees_WT100x11 = ["Canadian","CISC","WT: Structural Tees","WT100x11"]
	Canadian_CISC_WT_Structural_Tees_WT100x13_5 = ["Canadian","CISC","WT: Structural Tees","WT100x13.5"]
	Canadian_CISC_WT_Structural_Tees_WT100x15_5 = ["Canadian","CISC","WT: Structural Tees","WT100x15.5"]
	Canadian_CISC_WT_Structural_Tees_WT100x18 = ["Canadian","CISC","WT: Structural Tees","WT100x18"]
	Canadian_CISC_WT_Structural_Tees_WT100x21 = ["Canadian","CISC","WT: Structural Tees","WT100x21"]
	Canadian_CISC_WT_Structural_Tees_WT100x23 = ["Canadian","CISC","WT: Structural Tees","WT100x23"]
	Canadian_CISC_WT_Structural_Tees_WT100x26 = ["Canadian","CISC","WT: Structural Tees","WT100x26"]
	Canadian_CISC_WT_Structural_Tees_WT100x29_5 = ["Canadian","CISC","WT: Structural Tees","WT100x29.5"]
	Canadian_CISC_WT_Structural_Tees_WT100x35_5 = ["Canadian","CISC","WT: Structural Tees","WT100x35.5"]
	Canadian_CISC_WT_Structural_Tees_WT100x43 = ["Canadian","CISC","WT: Structural Tees","WT100x43"]
	Canadian_CISC_WT_Structural_Tees_WT100x50 = ["Canadian","CISC","WT: Structural Tees","WT100x50"]
	Canadian_CISC_WT_Structural_Tees_WT125x9 = ["Canadian","CISC","WT: Structural Tees","WT125x9"]
	Canadian_CISC_WT_Structural_Tees_WT125x11 = ["Canadian","CISC","WT: Structural Tees","WT125x11"]
	Canadian_CISC_WT_Structural_Tees_WT125x12_5 = ["Canadian","CISC","WT: Structural Tees","WT125x12.5"]
	Canadian_CISC_WT_Structural_Tees_WT125x14 = ["Canadian","CISC","WT: Structural Tees","WT125x14"]
	Canadian_CISC_WT_Structural_Tees_WT125x16_5 = ["Canadian","CISC","WT: Structural Tees","WT125x16.5"]
	Canadian_CISC_WT_Structural_Tees_WT125x19_5 = ["Canadian","CISC","WT: Structural Tees","WT125x19.5"]
	Canadian_CISC_WT_Structural_Tees_WT125x22_5 = ["Canadian","CISC","WT: Structural Tees","WT125x22.5"]
	Canadian_CISC_WT_Structural_Tees_WT125x24_5 = ["Canadian","CISC","WT: Structural Tees","WT125x24.5"]
	Canadian_CISC_WT_Structural_Tees_WT125x29 = ["Canadian","CISC","WT: Structural Tees","WT125x29"]
	Canadian_CISC_WT_Structural_Tees_WT125x33_5 = ["Canadian","CISC","WT: Structural Tees","WT125x33.5"]
	Canadian_CISC_WT_Structural_Tees_WT125x36_5 = ["Canadian","CISC","WT: Structural Tees","WT125x36.5"]
	Canadian_CISC_WT_Structural_Tees_WT125x40 = ["Canadian","CISC","WT: Structural Tees","WT125x40"]
	Canadian_CISC_WT_Structural_Tees_WT125x44_5 = ["Canadian","CISC","WT: Structural Tees","WT125x44.5"]
	Canadian_CISC_WT_Structural_Tees_WT125x50_5 = ["Canadian","CISC","WT: Structural Tees","WT125x50.5"]
	Canadian_CISC_WT_Structural_Tees_WT125x57_5 = ["Canadian","CISC","WT: Structural Tees","WT125x57.5"]
	Canadian_CISC_WT_Structural_Tees_WT125x65_5 = ["Canadian","CISC","WT: Structural Tees","WT125x65.5"]
	Canadian_CISC_WT_Structural_Tees_WT125x74_5 = ["Canadian","CISC","WT: Structural Tees","WT125x74.5"]
	Canadian_CISC_WT_Structural_Tees_WT125x83_5 = ["Canadian","CISC","WT: Structural Tees","WT125x83.5"]
	Canadian_CISC_WT_Structural_Tees_WT155x10_5 = ["Canadian","CISC","WT: Structural Tees","WT155x10.5"]
	Canadian_CISC_WT_Structural_Tees_WT155x12 = ["Canadian","CISC","WT: Structural Tees","WT155x12"]
	Canadian_CISC_WT_Structural_Tees_WT155x14 = ["Canadian","CISC","WT: Structural Tees","WT155x14"]
	Canadian_CISC_WT_Structural_Tees_WT155x16_5 = ["Canadian","CISC","WT: Structural Tees","WT155x16.5"]
	Canadian_CISC_WT_Structural_Tees_WT155x19_5 = ["Canadian","CISC","WT: Structural Tees","WT155x19.5"]
	Canadian_CISC_WT_Structural_Tees_WT155x22_5 = ["Canadian","CISC","WT: Structural Tees","WT155x22.5"]
	Canadian_CISC_WT_Structural_Tees_WT155x26 = ["Canadian","CISC","WT: Structural Tees","WT155x26"]
	Canadian_CISC_WT_Structural_Tees_WT155x30 = ["Canadian","CISC","WT: Structural Tees","WT155x30"]
	Canadian_CISC_WT_Structural_Tees_WT155x33_5 = ["Canadian","CISC","WT: Structural Tees","WT155x33.5"]
	Canadian_CISC_WT_Structural_Tees_WT155x37 = ["Canadian","CISC","WT: Structural Tees","WT155x37"]
	Canadian_CISC_WT_Structural_Tees_WT155x39_5 = ["Canadian","CISC","WT: Structural Tees","WT155x39.5"]
	Canadian_CISC_WT_Structural_Tees_WT155x43 = ["Canadian","CISC","WT: Structural Tees","WT155x43"]
	Canadian_CISC_WT_Structural_Tees_WT155x48_5 = ["Canadian","CISC","WT: Structural Tees","WT155x48.5"]
	Canadian_CISC_WT_Structural_Tees_WT155x53_5 = ["Canadian","CISC","WT: Structural Tees","WT155x53.5"]
	Canadian_CISC_WT_Structural_Tees_WT155x59 = ["Canadian","CISC","WT: Structural Tees","WT155x59"]
	Canadian_CISC_WT_Structural_Tees_WT155x64_5 = ["Canadian","CISC","WT: Structural Tees","WT155x64.5"]
	Canadian_CISC_WT_Structural_Tees_WT155x71_5 = ["Canadian","CISC","WT: Structural Tees","WT155x71.5"]
	Canadian_CISC_WT_Structural_Tees_WT155x79 = ["Canadian","CISC","WT: Structural Tees","WT155x79"]
	Canadian_CISC_WT_Structural_Tees_WT155x89_5 = ["Canadian","CISC","WT: Structural Tees","WT155x89.5"]
	Canadian_CISC_WT_Structural_Tees_WT155x101 = ["Canadian","CISC","WT: Structural Tees","WT155x101"]
	Canadian_CISC_WT_Structural_Tees_WT155x113 = ["Canadian","CISC","WT: Structural Tees","WT155x113"]
	Canadian_CISC_WT_Structural_Tees_WT155x126_5 = ["Canadian","CISC","WT: Structural Tees","WT155x126.5"]
	Canadian_CISC_WT_Structural_Tees_WT155x141_5 = ["Canadian","CISC","WT: Structural Tees","WT155x141.5"]
	Canadian_CISC_WT_Structural_Tees_WT155x156_5 = ["Canadian","CISC","WT: Structural Tees","WT155x156.5"]
	Canadian_CISC_WT_Structural_Tees_WT155x171 = ["Canadian","CISC","WT: Structural Tees","WT155x171"]
	Canadian_CISC_WT_Structural_Tees_WT155x187_5 = ["Canadian","CISC","WT: Structural Tees","WT155x187.5"]
	Canadian_CISC_WT_Structural_Tees_WT155x207_5 = ["Canadian","CISC","WT: Structural Tees","WT155x207.5"]
	Canadian_CISC_WT_Structural_Tees_WT155x227 = ["Canadian","CISC","WT: Structural Tees","WT155x227"]
	Canadian_CISC_WT_Structural_Tees_WT155x250 = ["Canadian","CISC","WT: Structural Tees","WT155x250"]
	Canadian_CISC_WT_Structural_Tees_WT180x16_5 = ["Canadian","CISC","WT: Structural Tees","WT180x16.5"]
	Canadian_CISC_WT_Structural_Tees_WT180x19_5 = ["Canadian","CISC","WT: Structural Tees","WT180x19.5"]
	Canadian_CISC_WT_Structural_Tees_WT180x22_5 = ["Canadian","CISC","WT: Structural Tees","WT180x22.5"]
	Canadian_CISC_WT_Structural_Tees_WT180x25_5 = ["Canadian","CISC","WT: Structural Tees","WT180x25.5"]
	Canadian_CISC_WT_Structural_Tees_WT180x28_5 = ["Canadian","CISC","WT: Structural Tees","WT180x28.5"]
	Canadian_CISC_WT_Structural_Tees_WT180x32 = ["Canadian","CISC","WT: Structural Tees","WT180x32"]
	Canadian_CISC_WT_Structural_Tees_WT180x36 = ["Canadian","CISC","WT: Structural Tees","WT180x36"]
	Canadian_CISC_WT_Structural_Tees_WT180x39_5 = ["Canadian","CISC","WT: Structural Tees","WT180x39.5"]
	Canadian_CISC_WT_Structural_Tees_WT180x45_5 = ["Canadian","CISC","WT: Structural Tees","WT180x45.5"]
	Canadian_CISC_WT_Structural_Tees_WT180x50_5 = ["Canadian","CISC","WT: Structural Tees","WT180x50.5"]
	Canadian_CISC_WT_Structural_Tees_WT180x55 = ["Canadian","CISC","WT: Structural Tees","WT180x55"]
	Canadian_CISC_WT_Structural_Tees_WT180x61 = ["Canadian","CISC","WT: Structural Tees","WT180x61"]
	Canadian_CISC_WT_Structural_Tees_WT180x67 = ["Canadian","CISC","WT: Structural Tees","WT180x67"]
	Canadian_CISC_WT_Structural_Tees_WT180x73_5 = ["Canadian","CISC","WT: Structural Tees","WT180x73.5"]
	Canadian_CISC_WT_Structural_Tees_WT180x81 = ["Canadian","CISC","WT: Structural Tees","WT180x81"]
	Canadian_CISC_WT_Structural_Tees_WT180x89_5 = ["Canadian","CISC","WT: Structural Tees","WT180x89.5"]
	Canadian_CISC_WT_Structural_Tees_WT180x98 = ["Canadian","CISC","WT: Structural Tees","WT180x98"]
	Canadian_CISC_WT_Structural_Tees_WT180x108 = ["Canadian","CISC","WT: Structural Tees","WT180x108"]
	Canadian_CISC_WT_Structural_Tees_WT180x118_5 = ["Canadian","CISC","WT: Structural Tees","WT180x118.5"]
	Canadian_CISC_WT_Structural_Tees_WT180x131 = ["Canadian","CISC","WT: Structural Tees","WT180x131"]
	Canadian_CISC_WT_Structural_Tees_WT180x143_5 = ["Canadian","CISC","WT: Structural Tees","WT180x143.5"]
	Canadian_CISC_WT_Structural_Tees_WT180x157 = ["Canadian","CISC","WT: Structural Tees","WT180x157"]
	Canadian_CISC_WT_Structural_Tees_WT180x173_5 = ["Canadian","CISC","WT: Structural Tees","WT180x173.5"]
	Canadian_CISC_WT_Structural_Tees_WT180x191 = ["Canadian","CISC","WT: Structural Tees","WT180x191"]
	Canadian_CISC_WT_Structural_Tees_WT180x210_5 = ["Canadian","CISC","WT: Structural Tees","WT180x210.5"]
	Canadian_CISC_WT_Structural_Tees_WT180x231_5 = ["Canadian","CISC","WT: Structural Tees","WT180x231.5"]
	Canadian_CISC_WT_Structural_Tees_WT180x254_5 = ["Canadian","CISC","WT: Structural Tees","WT180x254.5"]
	Canadian_CISC_WT_Structural_Tees_WT180x275_5 = ["Canadian","CISC","WT: Structural Tees","WT180x275.5"]
	Canadian_CISC_WT_Structural_Tees_WT180x296 = ["Canadian","CISC","WT: Structural Tees","WT180x296"]
	Canadian_CISC_WT_Structural_Tees_WT180x317 = ["Canadian","CISC","WT: Structural Tees","WT180x317"]
	Canadian_CISC_WT_Structural_Tees_WT180x338_5 = ["Canadian","CISC","WT: Structural Tees","WT180x338.5"]
	Canadian_CISC_WT_Structural_Tees_WT180x372 = ["Canadian","CISC","WT: Structural Tees","WT180x372"]
	Canadian_CISC_WT_Structural_Tees_WT180x409 = ["Canadian","CISC","WT: Structural Tees","WT180x409"]
	Canadian_CISC_WT_Structural_Tees_WT180x450 = ["Canadian","CISC","WT: Structural Tees","WT180x450"]
	Canadian_CISC_WT_Structural_Tees_WT180x495 = ["Canadian","CISC","WT: Structural Tees","WT180x495"]
	Canadian_CISC_WT_Structural_Tees_WT180x543 = ["Canadian","CISC","WT: Structural Tees","WT180x543"]
	Canadian_CISC_WT_Structural_Tees_WT205x19_5 = ["Canadian","CISC","WT: Structural Tees","WT205x19.5"]
	Canadian_CISC_WT_Structural_Tees_WT205x23 = ["Canadian","CISC","WT: Structural Tees","WT205x23"]
	Canadian_CISC_WT_Structural_Tees_WT205x27 = ["Canadian","CISC","WT: Structural Tees","WT205x27"]
	Canadian_CISC_WT_Structural_Tees_WT205x30 = ["Canadian","CISC","WT: Structural Tees","WT205x30"]
	Canadian_CISC_WT_Structural_Tees_WT205x33_5 = ["Canadian","CISC","WT: Structural Tees","WT205x33.5"]
	Canadian_CISC_WT_Structural_Tees_WT205x37 = ["Canadian","CISC","WT: Structural Tees","WT205x37"]
	Canadian_CISC_WT_Structural_Tees_WT205x42_5 = ["Canadian","CISC","WT: Structural Tees","WT205x42.5"]
	Canadian_CISC_WT_Structural_Tees_WT205x50 = ["Canadian","CISC","WT: Structural Tees","WT205x50"]
	Canadian_CISC_WT_Structural_Tees_WT205x57 = ["Canadian","CISC","WT: Structural Tees","WT205x57"]
	Canadian_CISC_WT_Structural_Tees_WT205x66 = ["Canadian","CISC","WT: Structural Tees","WT205x66"]
	Canadian_CISC_WT_Structural_Tees_WT205x74_5 = ["Canadian","CISC","WT: Structural Tees","WT205x74.5"]
	Canadian_CISC_WT_Structural_Tees_WT230x26 = ["Canadian","CISC","WT: Structural Tees","WT230x26"]
	Canadian_CISC_WT_Structural_Tees_WT230x30 = ["Canadian","CISC","WT: Structural Tees","WT230x30"]
	Canadian_CISC_WT_Structural_Tees_WT230x34 = ["Canadian","CISC","WT: Structural Tees","WT230x34"]
	Canadian_CISC_WT_Structural_Tees_WT230x37 = ["Canadian","CISC","WT: Structural Tees","WT230x37"]
	Canadian_CISC_WT_Structural_Tees_WT230x41 = ["Canadian","CISC","WT: Structural Tees","WT230x41"]
	Canadian_CISC_WT_Structural_Tees_WT230x44_5 = ["Canadian","CISC","WT: Structural Tees","WT230x44.5"]
	Canadian_CISC_WT_Structural_Tees_WT230x48_5 = ["Canadian","CISC","WT: Structural Tees","WT230x48.5"]
	Canadian_CISC_WT_Structural_Tees_WT230x53 = ["Canadian","CISC","WT: Structural Tees","WT230x53"]
	Canadian_CISC_WT_Structural_Tees_WT230x56_5 = ["Canadian","CISC","WT: Structural Tees","WT230x56.5"]
	Canadian_CISC_WT_Structural_Tees_WT230x64 = ["Canadian","CISC","WT: Structural Tees","WT230x64"]
	Canadian_CISC_WT_Structural_Tees_WT230x72 = ["Canadian","CISC","WT: Structural Tees","WT230x72"]
	Canadian_CISC_WT_Structural_Tees_WT230x79 = ["Canadian","CISC","WT: Structural Tees","WT230x79"]
	Canadian_CISC_WT_Structural_Tees_WT230x88_5 = ["Canadian","CISC","WT: Structural Tees","WT230x88.5"]
	Canadian_CISC_WT_Structural_Tees_WT265x33 = ["Canadian","CISC","WT: Structural Tees","WT265x33"]
	Canadian_CISC_WT_Structural_Tees_WT265x37 = ["Canadian","CISC","WT: Structural Tees","WT265x37"]
	Canadian_CISC_WT_Structural_Tees_WT265x41 = ["Canadian","CISC","WT: Structural Tees","WT265x41"]
	Canadian_CISC_WT_Structural_Tees_WT265x42_5 = ["Canadian","CISC","WT: Structural Tees","WT265x42.5"]
	Canadian_CISC_WT_Structural_Tees_WT265x46 = ["Canadian","CISC","WT: Structural Tees","WT265x46"]
	Canadian_CISC_WT_Structural_Tees_WT265x50_5 = ["Canadian","CISC","WT: Structural Tees","WT265x50.5"]
	Canadian_CISC_WT_Structural_Tees_WT265x54_5 = ["Canadian","CISC","WT: Structural Tees","WT265x54.5"]
	Canadian_CISC_WT_Structural_Tees_WT265x61_5 = ["Canadian","CISC","WT: Structural Tees","WT265x61.5"]
	Canadian_CISC_WT_Structural_Tees_WT265x69 = ["Canadian","CISC","WT: Structural Tees","WT265x69"]
	Canadian_CISC_WT_Structural_Tees_WT265x75 = ["Canadian","CISC","WT: Structural Tees","WT265x75"]
	Canadian_CISC_WT_Structural_Tees_WT265x82_5 = ["Canadian","CISC","WT: Structural Tees","WT265x82.5"]
	Canadian_CISC_WT_Structural_Tees_WT265x91 = ["Canadian","CISC","WT: Structural Tees","WT265x91"]
	Canadian_CISC_WT_Structural_Tees_WT265x98 = ["Canadian","CISC","WT: Structural Tees","WT265x98"]
	Canadian_CISC_WT_Structural_Tees_WT265x109_5 = ["Canadian","CISC","WT: Structural Tees","WT265x109.5"]
	Canadian_CISC_WT_Structural_Tees_WT305x41 = ["Canadian","CISC","WT: Structural Tees","WT305x41"]
	Canadian_CISC_WT_Structural_Tees_WT305x46 = ["Canadian","CISC","WT: Structural Tees","WT305x46"]
	Canadian_CISC_WT_Structural_Tees_WT305x50_5 = ["Canadian","CISC","WT: Structural Tees","WT305x50.5"]
	Canadian_CISC_WT_Structural_Tees_WT305x56_5 = ["Canadian","CISC","WT: Structural Tees","WT305x56.5"]
	Canadian_CISC_WT_Structural_Tees_WT305x62_5 = ["Canadian","CISC","WT: Structural Tees","WT305x62.5"]
	Canadian_CISC_WT_Structural_Tees_WT305x70 = ["Canadian","CISC","WT: Structural Tees","WT305x70"]
	Canadian_CISC_WT_Structural_Tees_WT305x77_5 = ["Canadian","CISC","WT: Structural Tees","WT305x77.5"]
	Canadian_CISC_WT_Structural_Tees_WT305x87 = ["Canadian","CISC","WT: Structural Tees","WT305x87"]
	Canadian_CISC_WT_Structural_Tees_WT305x97_5 = ["Canadian","CISC","WT: Structural Tees","WT305x97.5"]
	Canadian_CISC_WT_Structural_Tees_WT305x108_5 = ["Canadian","CISC","WT: Structural Tees","WT305x108.5"]
	Canadian_CISC_WT_Structural_Tees_WT305x120_5 = ["Canadian","CISC","WT: Structural Tees","WT305x120.5"]
	Canadian_CISC_WT_Structural_Tees_WT345x62_5 = ["Canadian","CISC","WT: Structural Tees","WT345x62.5"]
	Canadian_CISC_WT_Structural_Tees_WT345x70 = ["Canadian","CISC","WT: Structural Tees","WT345x70"]
	Canadian_CISC_WT_Structural_Tees_WT345x76 = ["Canadian","CISC","WT: Structural Tees","WT345x76"]
	Canadian_CISC_WT_Structural_Tees_WT345x85 = ["Canadian","CISC","WT: Structural Tees","WT345x85"]
	Canadian_CISC_WT_Structural_Tees_WT345x108_5 = ["Canadian","CISC","WT: Structural Tees","WT345x108.5"]
	Canadian_CISC_WT_Structural_Tees_WT345x120 = ["Canadian","CISC","WT: Structural Tees","WT345x120"]
	Canadian_CISC_WT_Structural_Tees_WT345x132_5 = ["Canadian","CISC","WT: Structural Tees","WT345x132.5"]
	Canadian_CISC_WT_Structural_Tees_WT380x73_5 = ["Canadian","CISC","WT: Structural Tees","WT380x73.5"]
	Canadian_CISC_WT_Structural_Tees_WT380x80_5 = ["Canadian","CISC","WT: Structural Tees","WT380x80.5"]
	Canadian_CISC_WT_Structural_Tees_WT380x86_5 = ["Canadian","CISC","WT: Structural Tees","WT380x86.5"]
	Canadian_CISC_WT_Structural_Tees_WT380x92_5 = ["Canadian","CISC","WT: Structural Tees","WT380x92.5"]
	Canadian_CISC_WT_Structural_Tees_WT380x98 = ["Canadian","CISC","WT: Structural Tees","WT380x98"]
	Canadian_CISC_WT_Structural_Tees_WT380x128_5 = ["Canadian","CISC","WT: Structural Tees","WT380x128.5"]
	Canadian_CISC_WT_Structural_Tees_WT380x142 = ["Canadian","CISC","WT: Structural Tees","WT380x142"]
	Canadian_CISC_WT_Structural_Tees_WT380x157 = ["Canadian","CISC","WT: Structural Tees","WT380x157"]
	Canadian_CISC_WT_Structural_Tees_WT420x88 = ["Canadian","CISC","WT: Structural Tees","WT420x88"]
	Canadian_CISC_WT_Structural_Tees_WT420x96_5 = ["Canadian","CISC","WT: Structural Tees","WT420x96.5"]
	Canadian_CISC_WT_Structural_Tees_WT420x105 = ["Canadian","CISC","WT: Structural Tees","WT420x105"]
	Canadian_CISC_WT_Structural_Tees_WT420x113 = ["Canadian","CISC","WT: Structural Tees","WT420x113"]
	Canadian_CISC_WT_Structural_Tees_WT420x149_5 = ["Canadian","CISC","WT: Structural Tees","WT420x149.5"]
	Canadian_CISC_WT_Structural_Tees_WT420x164_5 = ["Canadian","CISC","WT: Structural Tees","WT420x164.5"]
	Canadian_CISC_WT_Structural_Tees_WT420x179_5 = ["Canadian","CISC","WT: Structural Tees","WT420x179.5"]
	Canadian_CISC_WT_Structural_Tees_WT460x100_5 = ["Canadian","CISC","WT: Structural Tees","WT460x100.5"]
	Canadian_CISC_WT_Structural_Tees_WT460x111_5 = ["Canadian","CISC","WT: Structural Tees","WT460x111.5"]
	Canadian_CISC_WT_Structural_Tees_WT460x119 = ["Canadian","CISC","WT: Structural Tees","WT460x119"]
	Canadian_CISC_WT_Structural_Tees_WT460x126_5 = ["Canadian","CISC","WT: Structural Tees","WT460x126.5"]
	Canadian_CISC_WT_Structural_Tees_WT460x135_5 = ["Canadian","CISC","WT: Structural Tees","WT460x135.5"]
	Canadian_CISC_WT_Structural_Tees_WT460x144_5 = ["Canadian","CISC","WT: Structural Tees","WT460x144.5"]
	Canadian_CISC_WT_Structural_Tees_WT460x156_5 = ["Canadian","CISC","WT: Structural Tees","WT460x156.5"]
	Canadian_CISC_WT_Structural_Tees_WT460x171 = ["Canadian","CISC","WT: Structural Tees","WT460x171"]
	Canadian_CISC_WT_Structural_Tees_WT460x182_5 = ["Canadian","CISC","WT: Structural Tees","WT460x182.5"]
	Canadian_CISC_WT_Structural_Tees_WT460x193_5 = ["Canadian","CISC","WT: Structural Tees","WT460x193.5"]
	Canadian_CISC_WT_Structural_Tees_WT460x208_5 = ["Canadian","CISC","WT: Structural Tees","WT460x208.5"]
	Canadian_CISC_WT_Structural_Tees_WT460x223 = ["Canadian","CISC","WT: Structural Tees","WT460x223"]
	Canadian_CISC_WWT_Structural_Tees_WWT175x68_5 = ["Canadian","CISC","WWT: Structural Tees","WWT175x68.5"]
	Canadian_CISC_WWT_Structural_Tees_WWT175x77_5 = ["Canadian","CISC","WWT: Structural Tees","WWT175x77.5"]
	Canadian_CISC_WWT_Structural_Tees_WWT175x88 = ["Canadian","CISC","WWT: Structural Tees","WWT175x88"]
	Canadian_CISC_WWT_Structural_Tees_WWT175x96 = ["Canadian","CISC","WWT: Structural Tees","WWT175x96"]
	Canadian_CISC_WWT_Structural_Tees_WWT175x106 = ["Canadian","CISC","WWT: Structural Tees","WWT175x106"]
	Canadian_CISC_WWT_Structural_Tees_WWT175x119 = ["Canadian","CISC","WWT: Structural Tees","WWT175x119"]
	Canadian_CISC_WWT_Structural_Tees_WWT175x131_5 = ["Canadian","CISC","WWT: Structural Tees","WWT175x131.5"]
	Canadian_CISC_WWT_Structural_Tees_WWT175x157_5 = ["Canadian","CISC","WWT: Structural Tees","WWT175x157.5"]
	Canadian_CISC_WWT_Structural_Tees_WWT200x78_5 = ["Canadian","CISC","WWT: Structural Tees","WWT200x78.5"]
	Canadian_CISC_WWT_Structural_Tees_WWT200x89 = ["Canadian","CISC","WWT: Structural Tees","WWT200x89"]
	Canadian_CISC_WWT_Structural_Tees_WWT200x101 = ["Canadian","CISC","WWT: Structural Tees","WWT200x101"]
	Canadian_CISC_WWT_Structural_Tees_WWT200x110 = ["Canadian","CISC","WWT: Structural Tees","WWT200x110"]
	Canadian_CISC_WWT_Structural_Tees_WWT200x121_5 = ["Canadian","CISC","WWT: Structural Tees","WWT200x121.5"]
	Canadian_CISC_WWT_Structural_Tees_WWT200x136_5 = ["Canadian","CISC","WWT: Structural Tees","WWT200x136.5"]
	Canadian_CISC_WWT_Structural_Tees_WWT200x151_5 = ["Canadian","CISC","WWT: Structural Tees","WWT200x151.5"]
	Canadian_CISC_WWT_Structural_Tees_WWT200x181 = ["Canadian","CISC","WWT: Structural Tees","WWT200x181"]
	Canadian_CISC_WWT_Structural_Tees_WWT200x222 = ["Canadian","CISC","WWT: Structural Tees","WWT200x222"]
	Canadian_CISC_WWT_Structural_Tees_WWT225x88_5 = ["Canadian","CISC","WWT: Structural Tees","WWT225x88.5"]
	Canadian_CISC_WWT_Structural_Tees_WWT225x100_5 = ["Canadian","CISC","WWT: Structural Tees","WWT225x100.5"]
	Canadian_CISC_WWT_Structural_Tees_WWT225x114 = ["Canadian","CISC","WWT: Structural Tees","WWT225x114"]
	Canadian_CISC_WWT_Structural_Tees_WWT225x124 = ["Canadian","CISC","WWT: Structural Tees","WWT225x124"]
	Canadian_CISC_WWT_Structural_Tees_WWT225x137 = ["Canadian","CISC","WWT: Structural Tees","WWT225x137"]
	Canadian_CISC_WWT_Structural_Tees_WWT225x154 = ["Canadian","CISC","WWT: Structural Tees","WWT225x154"]
	Canadian_CISC_WWT_Structural_Tees_WWT225x171 = ["Canadian","CISC","WWT: Structural Tees","WWT225x171"]
	Canadian_CISC_WWT_Structural_Tees_WWT225x204_5 = ["Canadian","CISC","WWT: Structural Tees","WWT225x204.5"]
	Canadian_CISC_WWT_Structural_Tees_WWT225x251_5 = ["Canadian","CISC","WWT: Structural Tees","WWT225x251.5"]
	Canadian_CISC_WWT_Structural_Tees_WWT250x98_5 = ["Canadian","CISC","WWT: Structural Tees","WWT250x98.5"]
	Canadian_CISC_WWT_Structural_Tees_WWT250x111_5 = ["Canadian","CISC","WWT: Structural Tees","WWT250x111.5"]
	Canadian_CISC_WWT_Structural_Tees_WWT250x127 = ["Canadian","CISC","WWT: Structural Tees","WWT250x127"]
	Canadian_CISC_WWT_Structural_Tees_WWT250x138 = ["Canadian","CISC","WWT: Structural Tees","WWT250x138"]
	Canadian_CISC_WWT_Structural_Tees_WWT250x153 = ["Canadian","CISC","WWT: Structural Tees","WWT250x153"]
	Canadian_CISC_WWT_Structural_Tees_WWT250x171_5 = ["Canadian","CISC","WWT: Structural Tees","WWT250x171.5"]
	Canadian_CISC_WWT_Structural_Tees_WWT250x190_5 = ["Canadian","CISC","WWT: Structural Tees","WWT250x190.5"]
	Canadian_CISC_WWT_Structural_Tees_WWT250x228 = ["Canadian","CISC","WWT: Structural Tees","WWT250x228"]
	Canadian_CISC_WWT_Structural_Tees_WWT250x280_5 = ["Canadian","CISC","WWT: Structural Tees","WWT250x280.5"]
	Canadian_CISC_WWT_Structural_Tees_WWT250x325_5 = ["Canadian","CISC","WWT: Structural Tees","WWT250x325.5"]
	Canadian_CISC_WWT_Structural_Tees_WWT275x140 = ["Canadian","CISC","WWT: Structural Tees","WWT275x140"]
	Canadian_CISC_WWT_Structural_Tees_WWT275x210 = ["Canadian","CISC","WWT: Structural Tees","WWT275x210"]
	Canadian_CISC_WWT_Structural_Tees_WWT275x251_5 = ["Canadian","CISC","WWT: Structural Tees","WWT275x251.5"]
	Canadian_CISC_WWT_Structural_Tees_WWT275x310 = ["Canadian","CISC","WWT: Structural Tees","WWT275x310"]
	Canadian_CISC_WWT_Structural_Tees_WWT275x360_5 = ["Canadian","CISC","WWT: Structural Tees","WWT275x360.5"]
	Canadian_CISC_HSS_Rectangular_HS51x25x3_2 = ["Canadian","CISC","HSS: Rectangular","HS51x25x3.2"]
	Canadian_CISC_HSS_Rectangular_HS51x25x4_8 = ["Canadian","CISC","HSS: Rectangular","HS51x25x4.8"]
	Canadian_CISC_HSS_Rectangular_HS76x51x3_2 = ["Canadian","CISC","HSS: Rectangular","HS76x51x3.2"]
	Canadian_CISC_HSS_Rectangular_HS76x51x4_8 = ["Canadian","CISC","HSS: Rectangular","HS76x51x4.8"]
	Canadian_CISC_HSS_Rectangular_HS76x51x6_4 = ["Canadian","CISC","HSS: Rectangular","HS76x51x6.4"]
	Canadian_CISC_HSS_Rectangular_HS76x51x8_0 = ["Canadian","CISC","HSS: Rectangular","HS76x51x8.0"]
	Canadian_CISC_HSS_Rectangular_HS89x64x3_2 = ["Canadian","CISC","HSS: Rectangular","HS89x64x3.2"]
	Canadian_CISC_HSS_Rectangular_HS89x64x4_8 = ["Canadian","CISC","HSS: Rectangular","HS89x64x4.8"]
	Canadian_CISC_HSS_Rectangular_HS89x64x6_4 = ["Canadian","CISC","HSS: Rectangular","HS89x64x6.4"]
	Canadian_CISC_HSS_Rectangular_HS89x64x8_0 = ["Canadian","CISC","HSS: Rectangular","HS89x64x8.0"]
	Canadian_CISC_HSS_Rectangular_HS102x51x3_2 = ["Canadian","CISC","HSS: Rectangular","HS102x51x3.2"]
	Canadian_CISC_HSS_Rectangular_HS102x51x4_8 = ["Canadian","CISC","HSS: Rectangular","HS102x51x4.8"]
	Canadian_CISC_HSS_Rectangular_HS102x51x6_4 = ["Canadian","CISC","HSS: Rectangular","HS102x51x6.4"]
	Canadian_CISC_HSS_Rectangular_HS102x51x8_0 = ["Canadian","CISC","HSS: Rectangular","HS102x51x8.0"]
	Canadian_CISC_HSS_Rectangular_HS102x51x9_5 = ["Canadian","CISC","HSS: Rectangular","HS102x51x9.5"]
	Canadian_CISC_HSS_Rectangular_HS102x76x3_2 = ["Canadian","CISC","HSS: Rectangular","HS102x76x3.2"]
	Canadian_CISC_HSS_Rectangular_HS102x76x4_8 = ["Canadian","CISC","HSS: Rectangular","HS102x76x4.8"]
	Canadian_CISC_HSS_Rectangular_HS102x76x6_4 = ["Canadian","CISC","HSS: Rectangular","HS102x76x6.4"]
	Canadian_CISC_HSS_Rectangular_HS102x76x8_0 = ["Canadian","CISC","HSS: Rectangular","HS102x76x8.0"]
	Canadian_CISC_HSS_Rectangular_HS102x76x9_5 = ["Canadian","CISC","HSS: Rectangular","HS102x76x9.5"]
	Canadian_CISC_HSS_Rectangular_HS127x76x4_8 = ["Canadian","CISC","HSS: Rectangular","HS127x76x4.8"]
	Canadian_CISC_HSS_Rectangular_HS127x76x6_4 = ["Canadian","CISC","HSS: Rectangular","HS127x76x6.4"]
	Canadian_CISC_HSS_Rectangular_HS127x76x8_0 = ["Canadian","CISC","HSS: Rectangular","HS127x76x8.0"]
	Canadian_CISC_HSS_Rectangular_HS127x76x9_5 = ["Canadian","CISC","HSS: Rectangular","HS127x76x9.5"]
	Canadian_CISC_HSS_Rectangular_HS152x76x4_8 = ["Canadian","CISC","HSS: Rectangular","HS152x76x4.8"]
	Canadian_CISC_HSS_Rectangular_HS152x76x6_4 = ["Canadian","CISC","HSS: Rectangular","HS152x76x6.4"]
	Canadian_CISC_HSS_Rectangular_HS152x76x8_0 = ["Canadian","CISC","HSS: Rectangular","HS152x76x8.0"]
	Canadian_CISC_HSS_Rectangular_HS152x76x9_5 = ["Canadian","CISC","HSS: Rectangular","HS152x76x9.5"]
	Canadian_CISC_HSS_Rectangular_HS152x76x13 = ["Canadian","CISC","HSS: Rectangular","HS152x76x13"]
	Canadian_CISC_HSS_Rectangular_HS152x102x4_8 = ["Canadian","CISC","HSS: Rectangular","HS152x102x4.8"]
	Canadian_CISC_HSS_Rectangular_HS152x102x6_4 = ["Canadian","CISC","HSS: Rectangular","HS152x102x6.4"]
	Canadian_CISC_HSS_Rectangular_HS152x102x8_0 = ["Canadian","CISC","HSS: Rectangular","HS152x102x8.0"]
	Canadian_CISC_HSS_Rectangular_HS152x102x9_5 = ["Canadian","CISC","HSS: Rectangular","HS152x102x9.5"]
	Canadian_CISC_HSS_Rectangular_HS152x102x13 = ["Canadian","CISC","HSS: Rectangular","HS152x102x13"]
	Canadian_CISC_HSS_Rectangular_HS178x127x4_8 = ["Canadian","CISC","HSS: Rectangular","HS178x127x4.8"]
	Canadian_CISC_HSS_Rectangular_HS178x127x6_4 = ["Canadian","CISC","HSS: Rectangular","HS178x127x6.4"]
	Canadian_CISC_HSS_Rectangular_HS178x127x8_0 = ["Canadian","CISC","HSS: Rectangular","HS178x127x8.0"]
	Canadian_CISC_HSS_Rectangular_HS178x127x9_5 = ["Canadian","CISC","HSS: Rectangular","HS178x127x9.5"]
	Canadian_CISC_HSS_Rectangular_HS178x127x13 = ["Canadian","CISC","HSS: Rectangular","HS178x127x13"]
	Canadian_CISC_HSS_Rectangular_HS203x102x4_8 = ["Canadian","CISC","HSS: Rectangular","HS203x102x4.8"]
	Canadian_CISC_HSS_Rectangular_HS203x102x6_4 = ["Canadian","CISC","HSS: Rectangular","HS203x102x6.4"]
	Canadian_CISC_HSS_Rectangular_HS203x102x8_0 = ["Canadian","CISC","HSS: Rectangular","HS203x102x8.0"]
	Canadian_CISC_HSS_Rectangular_HS203x102x9_5 = ["Canadian","CISC","HSS: Rectangular","HS203x102x9.5"]
	Canadian_CISC_HSS_Rectangular_HS203x102x13 = ["Canadian","CISC","HSS: Rectangular","HS203x102x13"]
	Canadian_CISC_HSS_Rectangular_HS203x152x4_8 = ["Canadian","CISC","HSS: Rectangular","HS203x152x4.8"]
	Canadian_CISC_HSS_Rectangular_HS203x152x6_4 = ["Canadian","CISC","HSS: Rectangular","HS203x152x6.4"]
	Canadian_CISC_HSS_Rectangular_HS203x152x8_0 = ["Canadian","CISC","HSS: Rectangular","HS203x152x8.0"]
	Canadian_CISC_HSS_Rectangular_HS203x152x9_5 = ["Canadian","CISC","HSS: Rectangular","HS203x152x9.5"]
	Canadian_CISC_HSS_Rectangular_HS203x152x13 = ["Canadian","CISC","HSS: Rectangular","HS203x152x13"]
	Canadian_CISC_HSS_Rectangular_HS254x152x6_4 = ["Canadian","CISC","HSS: Rectangular","HS254x152x6.4"]
	Canadian_CISC_HSS_Rectangular_HS254x152x8_0 = ["Canadian","CISC","HSS: Rectangular","HS254x152x8.0"]
	Canadian_CISC_HSS_Rectangular_HS254x152x9_5 = ["Canadian","CISC","HSS: Rectangular","HS254x152x9.5"]
	Canadian_CISC_HSS_Rectangular_HS254x152x13 = ["Canadian","CISC","HSS: Rectangular","HS254x152x13"]
	Canadian_CISC_HSS_Rectangular_HS254x152x16 = ["Canadian","CISC","HSS: Rectangular","HS254x152x16"]
	Canadian_CISC_HSS_Rectangular_HS305x203x6_4 = ["Canadian","CISC","HSS: Rectangular","HS305x203x6.4"]
	Canadian_CISC_HSS_Rectangular_HS305x203x8_0 = ["Canadian","CISC","HSS: Rectangular","HS305x203x8.0"]
	Canadian_CISC_HSS_Rectangular_HS305x203x9_5 = ["Canadian","CISC","HSS: Rectangular","HS305x203x9.5"]
	Canadian_CISC_HSS_Rectangular_HS305x203x13 = ["Canadian","CISC","HSS: Rectangular","HS305x203x13"]
	Canadian_CISC_HSS_Rectangular_HS305x203x16 = ["Canadian","CISC","HSS: Rectangular","HS305x203x16"]
	Canadian_CISC_HSS_Rectangular_HS356x254x9_5 = ["Canadian","CISC","HSS: Rectangular","HS356x254x9.5"]
	Canadian_CISC_HSS_Rectangular_HS356x254x13 = ["Canadian","CISC","HSS: Rectangular","HS356x254x13"]
	Canadian_CISC_HSS_Rectangular_HS356x254x16 = ["Canadian","CISC","HSS: Rectangular","HS356x254x16"]
	Canadian_CISC_HSS_Square_HS38x38x3_2 = ["Canadian","CISC","HSS: Square","HS38x38x3.2"]
	Canadian_CISC_HSS_Square_HS38x38x4_8 = ["Canadian","CISC","HSS: Square","HS38x38x4.8"]
	Canadian_CISC_HSS_Square_HS51x51x3_2 = ["Canadian","CISC","HSS: Square","HS51x51x3.2"]
	Canadian_CISC_HSS_Square_HS51x51x4_8 = ["Canadian","CISC","HSS: Square","HS51x51x4.8"]
	Canadian_CISC_HSS_Square_HS51x51x6_4 = ["Canadian","CISC","HSS: Square","HS51x51x6.4"]
	Canadian_CISC_HSS_Square_HS64x64x3_2 = ["Canadian","CISC","HSS: Square","HS64x64x3.2"]
	Canadian_CISC_HSS_Square_HS64x64x4_8 = ["Canadian","CISC","HSS: Square","HS64x64x4.8"]
	Canadian_CISC_HSS_Square_HS64x64x6_4 = ["Canadian","CISC","HSS: Square","HS64x64x6.4"]
	Canadian_CISC_HSS_Square_HS64x64x8_0 = ["Canadian","CISC","HSS: Square","HS64x64x8.0"]
	Canadian_CISC_HSS_Square_HS76x76x3_2 = ["Canadian","CISC","HSS: Square","HS76x76x3.2"]
	Canadian_CISC_HSS_Square_HS76x76x4_8 = ["Canadian","CISC","HSS: Square","HS76x76x4.8"]
	Canadian_CISC_HSS_Square_HS76x76x6_4 = ["Canadian","CISC","HSS: Square","HS76x76x6.4"]
	Canadian_CISC_HSS_Square_HS76x76x8_0 = ["Canadian","CISC","HSS: Square","HS76x76x8.0"]
	Canadian_CISC_HSS_Square_HS76x76x9_5 = ["Canadian","CISC","HSS: Square","HS76x76x9.5"]
	Canadian_CISC_HSS_Square_HS89x89x3_2 = ["Canadian","CISC","HSS: Square","HS89x89x3.2"]
	Canadian_CISC_HSS_Square_HS89x89x4_8 = ["Canadian","CISC","HSS: Square","HS89x89x4.8"]
	Canadian_CISC_HSS_Square_HS89x89x6_4 = ["Canadian","CISC","HSS: Square","HS89x89x6.4"]
	Canadian_CISC_HSS_Square_HS89x89x8_0 = ["Canadian","CISC","HSS: Square","HS89x89x8.0"]
	Canadian_CISC_HSS_Square_HS89x89x9_5 = ["Canadian","CISC","HSS: Square","HS89x89x9.5"]
	Canadian_CISC_HSS_Square_HS102x102x3_2 = ["Canadian","CISC","HSS: Square","HS102x102x3.2"]
	Canadian_CISC_HSS_Square_HS102x102x4_8 = ["Canadian","CISC","HSS: Square","HS102x102x4.8"]
	Canadian_CISC_HSS_Square_HS102x102x6_4 = ["Canadian","CISC","HSS: Square","HS102x102x6.4"]
	Canadian_CISC_HSS_Square_HS102x102x8_0 = ["Canadian","CISC","HSS: Square","HS102x102x8.0"]
	Canadian_CISC_HSS_Square_HS102x102x9_5 = ["Canadian","CISC","HSS: Square","HS102x102x9.5"]
	Canadian_CISC_HSS_Square_HS102x102x13 = ["Canadian","CISC","HSS: Square","HS102x102x13"]
	Canadian_CISC_HSS_Square_HS114x114x3_2 = ["Canadian","CISC","HSS: Square","HS114x114x3.2"]
	Canadian_CISC_HSS_Square_HS114x114x4_8 = ["Canadian","CISC","HSS: Square","HS114x114x4.8"]
	Canadian_CISC_HSS_Square_HS114x114x6_4 = ["Canadian","CISC","HSS: Square","HS114x114x6.4"]
	Canadian_CISC_HSS_Square_HS114x114x8_0 = ["Canadian","CISC","HSS: Square","HS114x114x8.0"]
	Canadian_CISC_HSS_Square_HS114x114x9_5 = ["Canadian","CISC","HSS: Square","HS114x114x9.5"]
	Canadian_CISC_HSS_Square_HS114x114x13 = ["Canadian","CISC","HSS: Square","HS114x114x13"]
	Canadian_CISC_HSS_Square_HS127x127x4_8 = ["Canadian","CISC","HSS: Square","HS127x127x4.8"]
	Canadian_CISC_HSS_Square_HS127x127x6_4 = ["Canadian","CISC","HSS: Square","HS127x127x6.4"]
	Canadian_CISC_HSS_Square_HS127x127x8_0 = ["Canadian","CISC","HSS: Square","HS127x127x8.0"]
	Canadian_CISC_HSS_Square_HS127x127x9_5 = ["Canadian","CISC","HSS: Square","HS127x127x9.5"]
	Canadian_CISC_HSS_Square_HS127x127x13 = ["Canadian","CISC","HSS: Square","HS127x127x13"]
	Canadian_CISC_HSS_Square_HS152x152x4_8 = ["Canadian","CISC","HSS: Square","HS152x152x4.8"]
	Canadian_CISC_HSS_Square_HS152x152x6_4 = ["Canadian","CISC","HSS: Square","HS152x152x6.4"]
	Canadian_CISC_HSS_Square_HS152x152x8_0 = ["Canadian","CISC","HSS: Square","HS152x152x8.0"]
	Canadian_CISC_HSS_Square_HS152x152x9_5 = ["Canadian","CISC","HSS: Square","HS152x152x9.5"]
	Canadian_CISC_HSS_Square_HS152x152x13 = ["Canadian","CISC","HSS: Square","HS152x152x13"]
	Canadian_CISC_HSS_Square_HS178x178x4_8 = ["Canadian","CISC","HSS: Square","HS178x178x4.8"]
	Canadian_CISC_HSS_Square_HS178x178x6_4 = ["Canadian","CISC","HSS: Square","HS178x178x6.4"]
	Canadian_CISC_HSS_Square_HS178x178x8_0 = ["Canadian","CISC","HSS: Square","HS178x178x8.0"]
	Canadian_CISC_HSS_Square_HS178x178x9_5 = ["Canadian","CISC","HSS: Square","HS178x178x9.5"]
	Canadian_CISC_HSS_Square_HS178x178x13 = ["Canadian","CISC","HSS: Square","HS178x178x13"]
	Canadian_CISC_HSS_Square_HS178x178x16 = ["Canadian","CISC","HSS: Square","HS178x178x16"]
	Canadian_CISC_HSS_Square_HS203x203x6_4 = ["Canadian","CISC","HSS: Square","HS203x203x6.4"]
	Canadian_CISC_HSS_Square_HS203x203x8_0 = ["Canadian","CISC","HSS: Square","HS203x203x8.0"]
	Canadian_CISC_HSS_Square_HS203x203x9_5 = ["Canadian","CISC","HSS: Square","HS203x203x9.5"]
	Canadian_CISC_HSS_Square_HS203x203x13 = ["Canadian","CISC","HSS: Square","HS203x203x13"]
	Canadian_CISC_HSS_Square_HS203x203x16 = ["Canadian","CISC","HSS: Square","HS203x203x16"]
	Canadian_CISC_HSS_Square_HS254x254x6_4 = ["Canadian","CISC","HSS: Square","HS254x254x6.4"]
	Canadian_CISC_HSS_Square_HS254x254x8_0 = ["Canadian","CISC","HSS: Square","HS254x254x8.0"]
	Canadian_CISC_HSS_Square_HS254x254x9_5 = ["Canadian","CISC","HSS: Square","HS254x254x9.5"]
	Canadian_CISC_HSS_Square_HS254x254x13 = ["Canadian","CISC","HSS: Square","HS254x254x13"]
	Canadian_CISC_HSS_Square_HS254x254x16 = ["Canadian","CISC","HSS: Square","HS254x254x16"]
	Canadian_CISC_HSS_Square_HS305x305x6_4 = ["Canadian","CISC","HSS: Square","HS305x305x6.4"]
	Canadian_CISC_HSS_Square_HS305x305x8_0 = ["Canadian","CISC","HSS: Square","HS305x305x8.0"]
	Canadian_CISC_HSS_Square_HS305x305x9_5 = ["Canadian","CISC","HSS: Square","HS305x305x9.5"]
	Canadian_CISC_HSS_Square_HS305x305x13 = ["Canadian","CISC","HSS: Square","HS305x305x13"]
	Canadian_CISC_HSS_Square_HS305x305x16 = ["Canadian","CISC","HSS: Square","HS305x305x16"]
	Canadian_CISC_HSS_Round_HS48x3_2 = ["Canadian","CISC","HSS: Round","HS48x3.2"]
	Canadian_CISC_HSS_Round_HS48x4_8 = ["Canadian","CISC","HSS: Round","HS48x4.8"]
	Canadian_CISC_HSS_Round_HS60x3_2 = ["Canadian","CISC","HSS: Round","HS60x3.2"]
	Canadian_CISC_HSS_Round_HS60x4_8 = ["Canadian","CISC","HSS: Round","HS60x4.8"]
	Canadian_CISC_HSS_Round_HS60x6_4 = ["Canadian","CISC","HSS: Round","HS60x6.4"]
	Canadian_CISC_HSS_Round_HS64x3_2 = ["Canadian","CISC","HSS: Round","HS64x3.2"]
	Canadian_CISC_HSS_Round_HS64x4_8 = ["Canadian","CISC","HSS: Round","HS64x4.8"]
	Canadian_CISC_HSS_Round_HS64x6_4 = ["Canadian","CISC","HSS: Round","HS64x6.4"]
	Canadian_CISC_HSS_Round_HS73x3_2 = ["Canadian","CISC","HSS: Round","HS73x3.2"]
	Canadian_CISC_HSS_Round_HS73x4_8 = ["Canadian","CISC","HSS: Round","HS73x4.8"]
	Canadian_CISC_HSS_Round_HS73x6_4 = ["Canadian","CISC","HSS: Round","HS73x6.4"]
	Canadian_CISC_HSS_Round_HS76x4_8 = ["Canadian","CISC","HSS: Round","HS76x4.8"]
	Canadian_CISC_HSS_Round_HS76x6_4 = ["Canadian","CISC","HSS: Round","HS76x6.4"]
	Canadian_CISC_HSS_Round_HS89x3_2 = ["Canadian","CISC","HSS: Round","HS89x3.2"]
	Canadian_CISC_HSS_Round_HS89x4_8 = ["Canadian","CISC","HSS: Round","HS89x4.8"]
	Canadian_CISC_HSS_Round_HS89x6_4 = ["Canadian","CISC","HSS: Round","HS89x6.4"]
	Canadian_CISC_HSS_Round_HS89x8_0 = ["Canadian","CISC","HSS: Round","HS89x8.0"]
	Canadian_CISC_HSS_Round_HS102x3_2 = ["Canadian","CISC","HSS: Round","HS102x3.2"]
	Canadian_CISC_HSS_Round_HS102x4_8 = ["Canadian","CISC","HSS: Round","HS102x4.8"]
	Canadian_CISC_HSS_Round_HS102x6_4 = ["Canadian","CISC","HSS: Round","HS102x6.4"]
	Canadian_CISC_HSS_Round_HS102x8_0 = ["Canadian","CISC","HSS: Round","HS102x8.0"]
	Canadian_CISC_HSS_Round_HS114x3_2 = ["Canadian","CISC","HSS: Round","HS114x3.2"]
	Canadian_CISC_HSS_Round_HS114x4_8 = ["Canadian","CISC","HSS: Round","HS114x4.8"]
	Canadian_CISC_HSS_Round_HS114x9_5 = ["Canadian","CISC","HSS: Round","HS114x9.5"]
	Canadian_CISC_HSS_Round_HS127x3_2 = ["Canadian","CISC","HSS: Round","HS127x3.2"]
	Canadian_CISC_HSS_Round_HS127x4_8 = ["Canadian","CISC","HSS: Round","HS127x4.8"]
	Canadian_CISC_HSS_Round_HS127x6_4 = ["Canadian","CISC","HSS: Round","HS127x6.4"]
	Canadian_CISC_HSS_Round_HS127x8_0 = ["Canadian","CISC","HSS: Round","HS127x8.0"]
	Canadian_CISC_HSS_Round_HS127x9_5 = ["Canadian","CISC","HSS: Round","HS127x9.5"]
	Canadian_CISC_HSS_Round_HS127x13 = ["Canadian","CISC","HSS: Round","HS127x13"]
	Canadian_CISC_HSS_Round_HS141x4_8 = ["Canadian","CISC","HSS: Round","HS141x4.8"]
	Canadian_CISC_HSS_Round_HS141x6_4 = ["Canadian","CISC","HSS: Round","HS141x6.4"]
	Canadian_CISC_HSS_Round_HS141x9_5 = ["Canadian","CISC","HSS: Round","HS141x9.5"]
	Canadian_CISC_HSS_Round_HS152x3_2 = ["Canadian","CISC","HSS: Round","HS152x3.2"]
	Canadian_CISC_HSS_Round_HS152x4_8 = ["Canadian","CISC","HSS: Round","HS152x4.8"]
	Canadian_CISC_HSS_Round_HS152x6_4 = ["Canadian","CISC","HSS: Round","HS152x6.4"]
	Canadian_CISC_HSS_Round_HS152x8_0 = ["Canadian","CISC","HSS: Round","HS152x8.0"]
	Canadian_CISC_HSS_Round_HS152x9_5 = ["Canadian","CISC","HSS: Round","HS152x9.5"]
	Canadian_CISC_HSS_Round_HS168x3_2 = ["Canadian","CISC","HSS: Round","HS168x3.2"]
	Canadian_CISC_HSS_Round_HS168x4_8 = ["Canadian","CISC","HSS: Round","HS168x4.8"]
	Canadian_CISC_HSS_Round_HS168x6_4 = ["Canadian","CISC","HSS: Round","HS168x6.4"]
	Canadian_CISC_HSS_Round_HS168x8_0 = ["Canadian","CISC","HSS: Round","HS168x8.0"]
	Canadian_CISC_HSS_Round_HS168x9_5 = ["Canadian","CISC","HSS: Round","HS168x9.5"]
	Canadian_CISC_HSS_Round_HS168x13 = ["Canadian","CISC","HSS: Round","HS168x13"]
	Canadian_CISC_HSS_Round_HS178x4_8 = ["Canadian","CISC","HSS: Round","HS178x4.8"]
	Canadian_CISC_HSS_Round_HS178x6_4 = ["Canadian","CISC","HSS: Round","HS178x6.4"]
	Canadian_CISC_HSS_Round_HS178x8_0 = ["Canadian","CISC","HSS: Round","HS178x8.0"]
	Canadian_CISC_HSS_Round_HS178x9_5 = ["Canadian","CISC","HSS: Round","HS178x9.5"]
	Canadian_CISC_HSS_Round_HS178x13 = ["Canadian","CISC","HSS: Round","HS178x13"]
	Canadian_CISC_HSS_Round_HS219x4_8 = ["Canadian","CISC","HSS: Round","HS219x4.8"]
	Canadian_CISC_HSS_Round_HS219x6_4 = ["Canadian","CISC","HSS: Round","HS219x6.4"]
	Canadian_CISC_HSS_Round_HS219x9_5 = ["Canadian","CISC","HSS: Round","HS219x9.5"]
	Canadian_CISC_HSS_Round_HS219x13 = ["Canadian","CISC","HSS: Round","HS219x13"]
	Canadian_CISC_HSS_Round_HS219x16 = ["Canadian","CISC","HSS: Round","HS219x16"]
	Canadian_CISC_HSS_Round_HS273x4_8 = ["Canadian","CISC","HSS: Round","HS273x4.8"]
	Canadian_CISC_HSS_Round_HS273x6_4 = ["Canadian","CISC","HSS: Round","HS273x6.4"]
	Canadian_CISC_HSS_Round_HS273x13 = ["Canadian","CISC","HSS: Round","HS273x13"]
	Canadian_CISC_HSS_Round_HS324x6_4 = ["Canadian","CISC","HSS: Round","HS324x6.4"]
	Canadian_CISC_HSS_Round_HS324x9_5 = ["Canadian","CISC","HSS: Round","HS324x9.5"]
	Canadian_CISC_HSS_Round_HS324x13 = ["Canadian","CISC","HSS: Round","HS324x13"]
	Canadian_CISC_HSS_Round_HS356x6_4 = ["Canadian","CISC","HSS: Round","HS356x6.4"]
	Canadian_CISC_HSS_Round_HS356x9_5 = ["Canadian","CISC","HSS: Round","HS356x9.5"]
	Canadian_CISC_HSS_Round_HS356x13 = ["Canadian","CISC","HSS: Round","HS356x13"]
	Canadian_CISC_HSS_Round_HS356x16 = ["Canadian","CISC","HSS: Round","HS356x16"]
	Canadian_CISC_HSS_Round_HS406x6_4 = ["Canadian","CISC","HSS: Round","HS406x6.4"]
	Canadian_CISC_HSS_Round_HS406x9_5 = ["Canadian","CISC","HSS: Round","HS406x9.5"]
	Canadian_CISC_HSS_Round_HS406x13 = ["Canadian","CISC","HSS: Round","HS406x13"]
	Canadian_CISC_2L_Short_Legs_2L51x38x3_2SLBB = ["Canadian","CISC","2L: Short Legs","2L51x38x3.2SLBB"]
	Canadian_CISC_2L_Short_Legs_2L51x38x4_8SLBB = ["Canadian","CISC","2L: Short Legs","2L51x38x4.8SLBB"]
	Canadian_CISC_2L_Short_Legs_2L51x38x6_4SLBB = ["Canadian","CISC","2L: Short Legs","2L51x38x6.4SLBB"]
	Canadian_CISC_2L_Short_Legs_2L64x51x4_8SLBB = ["Canadian","CISC","2L: Short Legs","2L64x51x4.8SLBB"]
	Canadian_CISC_2L_Short_Legs_2L64x51x6_4SLBB = ["Canadian","CISC","2L: Short Legs","2L64x51x6.4SLBB"]
	Canadian_CISC_2L_Short_Legs_2L64x51x7_9SLBB = ["Canadian","CISC","2L: Short Legs","2L64x51x7.9SLBB"]
	Canadian_CISC_2L_Short_Legs_2L64x51x9_5SLBB = ["Canadian","CISC","2L: Short Legs","2L64x51x9.5SLBB"]
	Canadian_CISC_2L_Short_Legs_2L76x51x4_8SLBB = ["Canadian","CISC","2L: Short Legs","2L76x51x4.8SLBB"]
	Canadian_CISC_2L_Short_Legs_2L76x51x6_4SLBB = ["Canadian","CISC","2L: Short Legs","2L76x51x6.4SLBB"]
	Canadian_CISC_2L_Short_Legs_2L76x51x7_9SLBB = ["Canadian","CISC","2L: Short Legs","2L76x51x7.9SLBB"]
	Canadian_CISC_2L_Short_Legs_2L76x51x9_5SLBB = ["Canadian","CISC","2L: Short Legs","2L76x51x9.5SLBB"]
	Canadian_CISC_2L_Short_Legs_2L76x51x13SLBB = ["Canadian","CISC","2L: Short Legs","2L76x51x13SLBB"]
	Canadian_CISC_2L_Short_Legs_2L76x64x4_8SLBB = ["Canadian","CISC","2L: Short Legs","2L76x64x4.8SLBB"]
	Canadian_CISC_2L_Short_Legs_2L76x64x6_4SLBB = ["Canadian","CISC","2L: Short Legs","2L76x64x6.4SLBB"]
	Canadian_CISC_2L_Short_Legs_2L76x64x7_9SLBB = ["Canadian","CISC","2L: Short Legs","2L76x64x7.9SLBB"]
	Canadian_CISC_2L_Short_Legs_2L76x64x9_5SLBB = ["Canadian","CISC","2L: Short Legs","2L76x64x9.5SLBB"]
	Canadian_CISC_2L_Short_Legs_2L76x64x13SLBB = ["Canadian","CISC","2L: Short Legs","2L76x64x13SLBB"]
	Canadian_CISC_2L_Short_Legs_2L89x64x6_4SLBB = ["Canadian","CISC","2L: Short Legs","2L89x64x6.4SLBB"]
	Canadian_CISC_2L_Short_Legs_2L89x64x7_9SLBB = ["Canadian","CISC","2L: Short Legs","2L89x64x7.9SLBB"]
	Canadian_CISC_2L_Short_Legs_2L89x64x9_5SLBB = ["Canadian","CISC","2L: Short Legs","2L89x64x9.5SLBB"]
	Canadian_CISC_2L_Short_Legs_2L89x64x13SLBB = ["Canadian","CISC","2L: Short Legs","2L89x64x13SLBB"]
	Canadian_CISC_2L_Short_Legs_2L89x76x6_4SLBB = ["Canadian","CISC","2L: Short Legs","2L89x76x6.4SLBB"]
	Canadian_CISC_2L_Short_Legs_2L89x76x7_9SLBB = ["Canadian","CISC","2L: Short Legs","2L89x76x7.9SLBB"]
	Canadian_CISC_2L_Short_Legs_2L89x76x9_5SLBB = ["Canadian","CISC","2L: Short Legs","2L89x76x9.5SLBB"]
	Canadian_CISC_2L_Short_Legs_2L89x76x13SLBB = ["Canadian","CISC","2L: Short Legs","2L89x76x13SLBB"]
	Canadian_CISC_2L_Short_Legs_2L102x76x6_4SLBB = ["Canadian","CISC","2L: Short Legs","2L102x76x6.4SLBB"]
	Canadian_CISC_2L_Short_Legs_2L102x76x7_9SLBB = ["Canadian","CISC","2L: Short Legs","2L102x76x7.9SLBB"]
	Canadian_CISC_2L_Short_Legs_2L102x76x9_5SLBB = ["Canadian","CISC","2L: Short Legs","2L102x76x9.5SLBB"]
	Canadian_CISC_2L_Short_Legs_2L102x76x11SLBB = ["Canadian","CISC","2L: Short Legs","2L102x76x11SLBB"]
	Canadian_CISC_2L_Short_Legs_2L102x76x13SLBB = ["Canadian","CISC","2L: Short Legs","2L102x76x13SLBB"]
	Canadian_CISC_2L_Short_Legs_2L102x76x16SLBB = ["Canadian","CISC","2L: Short Legs","2L102x76x16SLBB"]
	Canadian_CISC_2L_Short_Legs_2L102x89x6_4SLBB = ["Canadian","CISC","2L: Short Legs","2L102x89x6.4SLBB"]
	Canadian_CISC_2L_Short_Legs_2L102x89x7_9SLBB = ["Canadian","CISC","2L: Short Legs","2L102x89x7.9SLBB"]
	Canadian_CISC_2L_Short_Legs_2L102x89x9_5SLBB = ["Canadian","CISC","2L: Short Legs","2L102x89x9.5SLBB"]
	Canadian_CISC_2L_Short_Legs_2L102x89x11SLBB = ["Canadian","CISC","2L: Short Legs","2L102x89x11SLBB"]
	Canadian_CISC_2L_Short_Legs_2L102x89x13SLBB = ["Canadian","CISC","2L: Short Legs","2L102x89x13SLBB"]
	Canadian_CISC_2L_Short_Legs_2L127x76x6_4SLBB = ["Canadian","CISC","2L: Short Legs","2L127x76x6.4SLBB"]
	Canadian_CISC_2L_Short_Legs_2L127x76x7_9SLBB = ["Canadian","CISC","2L: Short Legs","2L127x76x7.9SLBB"]
	Canadian_CISC_2L_Short_Legs_2L127x76x9_5SLBB = ["Canadian","CISC","2L: Short Legs","2L127x76x9.5SLBB"]
	Canadian_CISC_2L_Short_Legs_2L127x76x11SLBB = ["Canadian","CISC","2L: Short Legs","2L127x76x11SLBB"]
	Canadian_CISC_2L_Short_Legs_2L127x76x13SLBB = ["Canadian","CISC","2L: Short Legs","2L127x76x13SLBB"]
	Canadian_CISC_2L_Short_Legs_2L127x89x6_4SLBB = ["Canadian","CISC","2L: Short Legs","2L127x89x6.4SLBB"]
	Canadian_CISC_2L_Short_Legs_2L127x89x7_9SLBB = ["Canadian","CISC","2L: Short Legs","2L127x89x7.9SLBB"]
	Canadian_CISC_2L_Short_Legs_2L127x89x9_5SLBB = ["Canadian","CISC","2L: Short Legs","2L127x89x9.5SLBB"]
	Canadian_CISC_2L_Short_Legs_2L127x89x13SLBB = ["Canadian","CISC","2L: Short Legs","2L127x89x13SLBB"]
	Canadian_CISC_2L_Short_Legs_2L127x89x16SLBB = ["Canadian","CISC","2L: Short Legs","2L127x89x16SLBB"]
	Canadian_CISC_2L_Short_Legs_2L127x89x19SLBB = ["Canadian","CISC","2L: Short Legs","2L127x89x19SLBB"]
	Canadian_CISC_2L_Short_Legs_2L152x89x7_9SLBB = ["Canadian","CISC","2L: Short Legs","2L152x89x7.9SLBB"]
	Canadian_CISC_2L_Short_Legs_2L152x89x9_5SLBB = ["Canadian","CISC","2L: Short Legs","2L152x89x9.5SLBB"]
	Canadian_CISC_2L_Short_Legs_2L152x89x13SLBB = ["Canadian","CISC","2L: Short Legs","2L152x89x13SLBB"]
	Canadian_CISC_2L_Short_Legs_2L152x89x16SLBB = ["Canadian","CISC","2L: Short Legs","2L152x89x16SLBB"]
	Canadian_CISC_2L_Short_Legs_2L152x102x7_9SLBB = ["Canadian","CISC","2L: Short Legs","2L152x102x7.9SLBB"]
	Canadian_CISC_2L_Short_Legs_2L152x102x9_5SLBB = ["Canadian","CISC","2L: Short Legs","2L152x102x9.5SLBB"]
	Canadian_CISC_2L_Short_Legs_2L152x102x11SLBB = ["Canadian","CISC","2L: Short Legs","2L152x102x11SLBB"]
	Canadian_CISC_2L_Short_Legs_2L152x102x13SLBB = ["Canadian","CISC","2L: Short Legs","2L152x102x13SLBB"]
	Canadian_CISC_2L_Short_Legs_2L152x102x14SLBB = ["Canadian","CISC","2L: Short Legs","2L152x102x14SLBB"]
	Canadian_CISC_2L_Short_Legs_2L152x102x16SLBB = ["Canadian","CISC","2L: Short Legs","2L152x102x16SLBB"]
	Canadian_CISC_2L_Short_Legs_2L152x102x19SLBB = ["Canadian","CISC","2L: Short Legs","2L152x102x19SLBB"]
	Canadian_CISC_2L_Short_Legs_2L152x102x22SLBB = ["Canadian","CISC","2L: Short Legs","2L152x102x22SLBB"]
	Canadian_CISC_2L_Short_Legs_2L178x102x9_5SLBB = ["Canadian","CISC","2L: Short Legs","2L178x102x9.5SLBB"]
	Canadian_CISC_2L_Short_Legs_2L178x102x11SLBB = ["Canadian","CISC","2L: Short Legs","2L178x102x11SLBB"]
	Canadian_CISC_2L_Short_Legs_2L178x102x13SLBB = ["Canadian","CISC","2L: Short Legs","2L178x102x13SLBB"]
	Canadian_CISC_2L_Short_Legs_2L178x102x16SLBB = ["Canadian","CISC","2L: Short Legs","2L178x102x16SLBB"]
	Canadian_CISC_2L_Short_Legs_2L178x102x19SLBB = ["Canadian","CISC","2L: Short Legs","2L178x102x19SLBB"]
	Canadian_CISC_2L_Short_Legs_2L203x102x13SLBB = ["Canadian","CISC","2L: Short Legs","2L203x102x13SLBB"]
	Canadian_CISC_2L_Short_Legs_2L203x102x19SLBB = ["Canadian","CISC","2L: Short Legs","2L203x102x19SLBB"]
	Canadian_CISC_2L_Short_Legs_2L203x102x25SLBB = ["Canadian","CISC","2L: Short Legs","2L203x102x25SLBB"]
	Canadian_CISC_2L_Short_Legs_2L203x152x13SLB = ["Canadian","CISC","2L: Short Legs","2L203x152x13SLB"]
	Canadian_CISC_2L_Short_Legs_2L203x152x14SLBB = ["Canadian","CISC","2L: Short Legs","2L203x152x14SLBB"]
	Canadian_CISC_2L_Short_Legs_2L203x152x16SLBB = ["Canadian","CISC","2L: Short Legs","2L203x152x16SLBB"]
	Canadian_CISC_2L_Short_Legs_2L203x152x19SLBB = ["Canadian","CISC","2L: Short Legs","2L203x152x19SLBB"]
	Canadian_CISC_2L_Short_Legs_2L203x152x22SLBB = ["Canadian","CISC","2L: Short Legs","2L203x152x22SLBB"]
	Canadian_CISC_2L_Short_Legs_2L203x152x25SLBB = ["Canadian","CISC","2L: Short Legs","2L203x152x25SLBB"]
	Canadian_CISC_2L_Long_Legs_2L51x38x3_2LLBB = ["Canadian","CISC","2L: Long Legs","2L51x38x3.2LLBB"]
	Canadian_CISC_2L_Long_Legs_2L51x38x4_8LLBB = ["Canadian","CISC","2L: Long Legs","2L51x38x4.8LLBB"]
	Canadian_CISC_2L_Long_Legs_2L51x38x6_4LLBB = ["Canadian","CISC","2L: Long Legs","2L51x38x6.4LLBB"]
	Canadian_CISC_2L_Long_Legs_2L64x51x4_8LLBB = ["Canadian","CISC","2L: Long Legs","2L64x51x4.8LLBB"]
	Canadian_CISC_2L_Long_Legs_2L64x51x6_4LLBB = ["Canadian","CISC","2L: Long Legs","2L64x51x6.4LLBB"]
	Canadian_CISC_2L_Long_Legs_2L64x51x7_9LLBB = ["Canadian","CISC","2L: Long Legs","2L64x51x7.9LLBB"]
	Canadian_CISC_2L_Long_Legs_2L64x51x9_5LLBB = ["Canadian","CISC","2L: Long Legs","2L64x51x9.5LLBB"]
	Canadian_CISC_2L_Long_Legs_2L76x51x4_8LLBB = ["Canadian","CISC","2L: Long Legs","2L76x51x4.8LLBB"]
	Canadian_CISC_2L_Long_Legs_2L76x51x6_4LLBB = ["Canadian","CISC","2L: Long Legs","2L76x51x6.4LLBB"]
	Canadian_CISC_2L_Long_Legs_2L76x51x7_9LLBB = ["Canadian","CISC","2L: Long Legs","2L76x51x7.9LLBB"]
	Canadian_CISC_2L_Long_Legs_2L76x51x9_5LLBB = ["Canadian","CISC","2L: Long Legs","2L76x51x9.5LLBB"]
	Canadian_CISC_2L_Long_Legs_2L76x51x13LLBB = ["Canadian","CISC","2L: Long Legs","2L76x51x13LLBB"]
	Canadian_CISC_2L_Long_Legs_2L76x64x4_8LLBB = ["Canadian","CISC","2L: Long Legs","2L76x64x4.8LLBB"]
	Canadian_CISC_2L_Long_Legs_2L76x64x6_4LLBB = ["Canadian","CISC","2L: Long Legs","2L76x64x6.4LLBB"]
	Canadian_CISC_2L_Long_Legs_2L76x64x7_9LLBB = ["Canadian","CISC","2L: Long Legs","2L76x64x7.9LLBB"]
	Canadian_CISC_2L_Long_Legs_2L76x64x9_5LLBB = ["Canadian","CISC","2L: Long Legs","2L76x64x9.5LLBB"]
	Canadian_CISC_2L_Long_Legs_2L76x64x13LLBB = ["Canadian","CISC","2L: Long Legs","2L76x64x13LLBB"]
	Canadian_CISC_2L_Long_Legs_2L89x64x6_4LLBB = ["Canadian","CISC","2L: Long Legs","2L89x64x6.4LLBB"]
	Canadian_CISC_2L_Long_Legs_2L89x64x7_9LLBB = ["Canadian","CISC","2L: Long Legs","2L89x64x7.9LLBB"]
	Canadian_CISC_2L_Long_Legs_2L89x64x9_5LLBB = ["Canadian","CISC","2L: Long Legs","2L89x64x9.5LLBB"]
	Canadian_CISC_2L_Long_Legs_2L89x64x13LLBB = ["Canadian","CISC","2L: Long Legs","2L89x64x13LLBB"]
	Canadian_CISC_2L_Long_Legs_2L89x76x6_4LLBB = ["Canadian","CISC","2L: Long Legs","2L89x76x6.4LLBB"]
	Canadian_CISC_2L_Long_Legs_2L89x76x7_9LLBB = ["Canadian","CISC","2L: Long Legs","2L89x76x7.9LLBB"]
	Canadian_CISC_2L_Long_Legs_2L89x76x9_5LLBB = ["Canadian","CISC","2L: Long Legs","2L89x76x9.5LLBB"]
	Canadian_CISC_2L_Long_Legs_2L89x76x13LLBB = ["Canadian","CISC","2L: Long Legs","2L89x76x13LLBB"]
	Canadian_CISC_2L_Long_Legs_2L102x76x6_4LLBB = ["Canadian","CISC","2L: Long Legs","2L102x76x6.4LLBB"]
	Canadian_CISC_2L_Long_Legs_2L102x76x7_9LLBB = ["Canadian","CISC","2L: Long Legs","2L102x76x7.9LLBB"]
	Canadian_CISC_2L_Long_Legs_2L102x76x9_5LLBB = ["Canadian","CISC","2L: Long Legs","2L102x76x9.5LLBB"]
	Canadian_CISC_2L_Long_Legs_2L102x76x11LLBB = ["Canadian","CISC","2L: Long Legs","2L102x76x11LLBB"]
	Canadian_CISC_2L_Long_Legs_2L102x76x13LLBB = ["Canadian","CISC","2L: Long Legs","2L102x76x13LLBB"]
	Canadian_CISC_2L_Long_Legs_2L102x76x16LLBB = ["Canadian","CISC","2L: Long Legs","2L102x76x16LLBB"]
	Canadian_CISC_2L_Long_Legs_2L102x89x6_4LLBB = ["Canadian","CISC","2L: Long Legs","2L102x89x6.4LLBB"]
	Canadian_CISC_2L_Long_Legs_2L102x89x7_9LLBB = ["Canadian","CISC","2L: Long Legs","2L102x89x7.9LLBB"]
	Canadian_CISC_2L_Long_Legs_2L102x89x9_5LLBB = ["Canadian","CISC","2L: Long Legs","2L102x89x9.5LLBB"]
	Canadian_CISC_2L_Long_Legs_2L102x89x11LLBB = ["Canadian","CISC","2L: Long Legs","2L102x89x11LLBB"]
	Canadian_CISC_2L_Long_Legs_2L102x89x13LLBB = ["Canadian","CISC","2L: Long Legs","2L102x89x13LLBB"]
	Canadian_CISC_2L_Long_Legs_2L127x76x6_4LLBB = ["Canadian","CISC","2L: Long Legs","2L127x76x6.4LLBB"]
	Canadian_CISC_2L_Long_Legs_2L127x76x7_9LLBB = ["Canadian","CISC","2L: Long Legs","2L127x76x7.9LLBB"]
	Canadian_CISC_2L_Long_Legs_2L127x76x9_5LLBB = ["Canadian","CISC","2L: Long Legs","2L127x76x9.5LLBB"]
	Canadian_CISC_2L_Long_Legs_2L127x76x11LLBB = ["Canadian","CISC","2L: Long Legs","2L127x76x11LLBB"]
	Canadian_CISC_2L_Long_Legs_2L127x76x13LLBB = ["Canadian","CISC","2L: Long Legs","2L127x76x13LLBB"]
	Canadian_CISC_2L_Long_Legs_2L127x89x6_4LLBB = ["Canadian","CISC","2L: Long Legs","2L127x89x6.4LLBB"]
	Canadian_CISC_2L_Long_Legs_2L127x89x7_9LLBB = ["Canadian","CISC","2L: Long Legs","2L127x89x7.9LLBB"]
	Canadian_CISC_2L_Long_Legs_2L127x89x9_5LLBB = ["Canadian","CISC","2L: Long Legs","2L127x89x9.5LLBB"]
	Canadian_CISC_2L_Long_Legs_2L127x89x13LLBB = ["Canadian","CISC","2L: Long Legs","2L127x89x13LLBB"]
	Canadian_CISC_2L_Long_Legs_2L127x89x16LLBB = ["Canadian","CISC","2L: Long Legs","2L127x89x16LLBB"]
	Canadian_CISC_2L_Long_Legs_2L127x89x19LLBB = ["Canadian","CISC","2L: Long Legs","2L127x89x19LLBB"]
	Canadian_CISC_2L_Long_Legs_2L152x89x7_9LLBB = ["Canadian","CISC","2L: Long Legs","2L152x89x7.9LLBB"]
	Canadian_CISC_2L_Long_Legs_2L152x89x9_5LLBB = ["Canadian","CISC","2L: Long Legs","2L152x89x9.5LLBB"]
	Canadian_CISC_2L_Long_Legs_2L152x89x13LLBB = ["Canadian","CISC","2L: Long Legs","2L152x89x13LLBB"]
	Canadian_CISC_2L_Long_Legs_2L152x89x16LLBB = ["Canadian","CISC","2L: Long Legs","2L152x89x16LLBB"]
	Canadian_CISC_2L_Long_Legs_2L152x102x7_9LLBB = ["Canadian","CISC","2L: Long Legs","2L152x102x7.9LLBB"]
	Canadian_CISC_2L_Long_Legs_2L152x102x9_5LLBB = ["Canadian","CISC","2L: Long Legs","2L152x102x9.5LLBB"]
	Canadian_CISC_2L_Long_Legs_2L152x102x11LLBB = ["Canadian","CISC","2L: Long Legs","2L152x102x11LLBB"]
	Canadian_CISC_2L_Long_Legs_2L152x102x13LLBB = ["Canadian","CISC","2L: Long Legs","2L152x102x13LLBB"]
	Canadian_CISC_2L_Long_Legs_2L152x102x14LLBB = ["Canadian","CISC","2L: Long Legs","2L152x102x14LLBB"]
	Canadian_CISC_2L_Long_Legs_2L152x102x16LLBB = ["Canadian","CISC","2L: Long Legs","2L152x102x16LLBB"]
	Canadian_CISC_2L_Long_Legs_2L152x102x19LLBB = ["Canadian","CISC","2L: Long Legs","2L152x102x19LLBB"]
	Canadian_CISC_2L_Long_Legs_2L152x102x22LLBB = ["Canadian","CISC","2L: Long Legs","2L152x102x22LLBB"]
	Canadian_CISC_2L_Long_Legs_2L178x102x9_5LLBB = ["Canadian","CISC","2L: Long Legs","2L178x102x9.5LLBB"]
	Canadian_CISC_2L_Long_Legs_2L178x102x11LLBB = ["Canadian","CISC","2L: Long Legs","2L178x102x11LLBB"]
	Canadian_CISC_2L_Long_Legs_2L178x102x13LLBB = ["Canadian","CISC","2L: Long Legs","2L178x102x13LLBB"]
	Canadian_CISC_2L_Long_Legs_2L178x102x16LLBB = ["Canadian","CISC","2L: Long Legs","2L178x102x16LLBB"]
	Canadian_CISC_2L_Long_Legs_2L178x102x19LLBB = ["Canadian","CISC","2L: Long Legs","2L178x102x19LLBB"]
	Canadian_CISC_2L_Long_Legs_2L203x102x13LLBB = ["Canadian","CISC","2L: Long Legs","2L203x102x13LLBB"]
	Canadian_CISC_2L_Long_Legs_2L203x102x19LLBB = ["Canadian","CISC","2L: Long Legs","2L203x102x19LLBB"]
	Canadian_CISC_2L_Long_Legs_2L203x102x25LLBB = ["Canadian","CISC","2L: Long Legs","2L203x102x25LLBB"]
	Canadian_CISC_2L_Long_Legs_2L203x152x13LLBB = ["Canadian","CISC","2L: Long Legs","2L203x152x13LLBB"]
	Canadian_CISC_2L_Long_Legs_2L203x152x14LLBB = ["Canadian","CISC","2L: Long Legs","2L203x152x14LLBB"]
	Canadian_CISC_2L_Long_Legs_2L203x152x16LLBB = ["Canadian","CISC","2L: Long Legs","2L203x152x16LLBB"]
	Canadian_CISC_2L_Long_Legs_2L203x152x19LLBB = ["Canadian","CISC","2L: Long Legs","2L203x152x19LLBB"]
	Canadian_CISC_2L_Long_Legs_2L203x152x22LLBB = ["Canadian","CISC","2L: Long Legs","2L203x152x22LLBB"]
	Canadian_CISC_2L_Long_Legs_2L203x152x25LLBB = ["Canadian","CISC","2L: Long Legs","2L203x152x25LLBB"]
	Canadian_CISC_2L_Equal_Legs_2L19x19x3_2ELBB = ["Canadian","CISC","2L: Equal Legs","2L19x19x3.2ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L25x25x3_2ELBB = ["Canadian","CISC","2L: Equal Legs","2L25x25x3.2ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L25x25x4_8ELBB = ["Canadian","CISC","2L: Equal Legs","2L25x25x4.8ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L25x25x6_4ELBB = ["Canadian","CISC","2L: Equal Legs","2L25x25x6.4ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L32x32x3_2ELBB = ["Canadian","CISC","2L: Equal Legs","2L32x32x3.2ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L32x32x4_8ELBB = ["Canadian","CISC","2L: Equal Legs","2L32x32x4.8ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L32x32x6_4ELBB = ["Canadian","CISC","2L: Equal Legs","2L32x32x6.4ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L38x38x3_2ELBB = ["Canadian","CISC","2L: Equal Legs","2L38x38x3.2ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L38x38x4_8ELBB = ["Canadian","CISC","2L: Equal Legs","2L38x38x4.8ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L38x38x6_4ELBB = ["Canadian","CISC","2L: Equal Legs","2L38x38x6.4ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L44x44x3_2ELBB = ["Canadian","CISC","2L: Equal Legs","2L44x44x3.2ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L44x44x4_8ELBB = ["Canadian","CISC","2L: Equal Legs","2L44x44x4.8ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L44x44x6_4ELBB = ["Canadian","CISC","2L: Equal Legs","2L44x44x6.4ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L51x51x3_2ELBB = ["Canadian","CISC","2L: Equal Legs","2L51x51x3.2ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L51x51x4_8ELBB = ["Canadian","CISC","2L: Equal Legs","2L51x51x4.8ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L51x51x6_4ELBB = ["Canadian","CISC","2L: Equal Legs","2L51x51x6.4ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L51x51x7_9ELBB = ["Canadian","CISC","2L: Equal Legs","2L51x51x7.9ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L51x51x9_5ELBB = ["Canadian","CISC","2L: Equal Legs","2L51x51x9.5ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L64x64x4_8ELBB = ["Canadian","CISC","2L: Equal Legs","2L64x64x4.8ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L64x64x6_4ELBB = ["Canadian","CISC","2L: Equal Legs","2L64x64x6.4ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L64x64x7_9ELBB = ["Canadian","CISC","2L: Equal Legs","2L64x64x7.9ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L64x64x9_5ELBB = ["Canadian","CISC","2L: Equal Legs","2L64x64x9.5ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L64x64x13ELBB = ["Canadian","CISC","2L: Equal Legs","2L64x64x13ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L76x76x4_8ELBB = ["Canadian","CISC","2L: Equal Legs","2L76x76x4.8ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L76x76x6_4ELBB = ["Canadian","CISC","2L: Equal Legs","2L76x76x6.4ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L76x76x7_9ELBB = ["Canadian","CISC","2L: Equal Legs","2L76x76x7.9ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L76x76x9_5ELBB = ["Canadian","CISC","2L: Equal Legs","2L76x76x9.5ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L76x76x11ELBB = ["Canadian","CISC","2L: Equal Legs","2L76x76x11ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L76x76x13ELBB = ["Canadian","CISC","2L: Equal Legs","2L76x76x13ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L89x89x6_4ELBB = ["Canadian","CISC","2L: Equal Legs","2L89x89x6.4ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L89x89x7_9ELBB = ["Canadian","CISC","2L: Equal Legs","2L89x89x7.9ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L89x89x9_5ELBB = ["Canadian","CISC","2L: Equal Legs","2L89x89x9.5ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L89x89x11ELBB = ["Canadian","CISC","2L: Equal Legs","2L89x89x11ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L89x89x13ELBB = ["Canadian","CISC","2L: Equal Legs","2L89x89x13ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L102x102x6_4ELBB = ["Canadian","CISC","2L: Equal Legs","2L102x102x6.4ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L102x102x7_9ELBB = ["Canadian","CISC","2L: Equal Legs","2L102x102x7.9ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L102x102x9_5ELBB = ["Canadian","CISC","2L: Equal Legs","2L102x102x9.5ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L102x102x11ELBB = ["Canadian","CISC","2L: Equal Legs","2L102x102x11ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L102x102x13ELBB = ["Canadian","CISC","2L: Equal Legs","2L102x102x13ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L102x102x16ELBB = ["Canadian","CISC","2L: Equal Legs","2L102x102x16ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L102x102x19ELBB = ["Canadian","CISC","2L: Equal Legs","2L102x102x19ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L127x127x6_4ELBB = ["Canadian","CISC","2L: Equal Legs","2L127x127x6.4ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L127x127x7_9ELBB = ["Canadian","CISC","2L: Equal Legs","2L127x127x7.9ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L127x127x9_5ELBB = ["Canadian","CISC","2L: Equal Legs","2L127x127x9.5ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L127x127x11ELBB = ["Canadian","CISC","2L: Equal Legs","2L127x127x11ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L127x127x13ELBB = ["Canadian","CISC","2L: Equal Legs","2L127x127x13ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L127x127x16ELBB = ["Canadian","CISC","2L: Equal Legs","2L127x127x16ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L127x127x19ELBB = ["Canadian","CISC","2L: Equal Legs","2L127x127x19ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L127x127x22ELBB = ["Canadian","CISC","2L: Equal Legs","2L127x127x22ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L152x152x6_4ELBB = ["Canadian","CISC","2L: Equal Legs","2L152x152x6.4ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L152x152x7_9ELBB = ["Canadian","CISC","2L: Equal Legs","2L152x152x7.9ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L152x152x9_5ELBB = ["Canadian","CISC","2L: Equal Legs","2L152x152x9.5ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L152x152x11ELBB = ["Canadian","CISC","2L: Equal Legs","2L152x152x11ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L152x152x13ELBB = ["Canadian","CISC","2L: Equal Legs","2L152x152x13ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L152x152x14ELBB = ["Canadian","CISC","2L: Equal Legs","2L152x152x14ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L152x152x16ELBB = ["Canadian","CISC","2L: Equal Legs","2L152x152x16ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L152x152x19ELBB = ["Canadian","CISC","2L: Equal Legs","2L152x152x19ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L152x152x22ELBB = ["Canadian","CISC","2L: Equal Legs","2L152x152x22ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L152x152x25ELBB = ["Canadian","CISC","2L: Equal Legs","2L152x152x25ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L203x203x13ELBB = ["Canadian","CISC","2L: Equal Legs","2L203x203x13ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L203x203x14ELBB = ["Canadian","CISC","2L: Equal Legs","2L203x203x14ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L203x203x16ELBB = ["Canadian","CISC","2L: Equal Legs","2L203x203x16ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L203x203x19ELBB = ["Canadian","CISC","2L: Equal Legs","2L203x203x19ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L203x203x22ELBB = ["Canadian","CISC","2L: Equal Legs","2L203x203x22ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L203x203x25ELBB = ["Canadian","CISC","2L: Equal Legs","2L203x203x25ELBB"]
	Canadian_CISC_2L_Equal_Legs_2L203x203x29ELBB = ["Canadian","CISC","2L: Equal Legs","2L203x203x29ELBB"]
	Canadian_CSSBI_Unperforated_Studs_Lipped_Channel_362S125_33 = ["Canadian","CSSBI","Unperforated Studs (Lipped Channel)","362S125-33"]
	Canadian_CSSBI_Unperforated_Studs_Lipped_Channel_362S125_43 = ["Canadian","CSSBI","Unperforated Studs (Lipped Channel)","362S125-43"]
	Canadian_CSSBI_Unperforated_Studs_Lipped_Channel_362S125_54 = ["Canadian","CSSBI","Unperforated Studs (Lipped Channel)","362S125-54"]
	Canadian_CSSBI_Unperforated_Studs_Lipped_Channel_362S162_33 = ["Canadian","CSSBI","Unperforated Studs (Lipped Channel)","362S162-33"]
	Canadian_CSSBI_Unperforated_Studs_Lipped_Channel_362S162_43 = ["Canadian","CSSBI","Unperforated Studs (Lipped Channel)","362S162-43"]
	Canadian_CSSBI_Unperforated_Studs_Lipped_Channel_362S162_54 = ["Canadian","CSSBI","Unperforated Studs (Lipped Channel)","362S162-54"]
	Canadian_CSSBI_Unperforated_Studs_Lipped_Channel_362S162_68 = ["Canadian","CSSBI","Unperforated Studs (Lipped Channel)","362S162-68"]
	Canadian_CSSBI_Unperforated_Studs_Lipped_Channel_362S162_97 = ["Canadian","CSSBI","Unperforated Studs (Lipped Channel)","362S162-97"]
	Canadian_CSSBI_Unperforated_Studs_Lipped_Channel_400S125_33 = ["Canadian","CSSBI","Unperforated Studs (Lipped Channel)","400S125-33"]
	Canadian_CSSBI_Unperforated_Studs_Lipped_Channel_400S125_43 = ["Canadian","CSSBI","Unperforated Studs (Lipped Channel)","400S125-43"]
	Canadian_CSSBI_Unperforated_Studs_Lipped_Channel_400S125_54 = ["Canadian","CSSBI","Unperforated Studs (Lipped Channel)","400S125-54"]
	Canadian_CSSBI_Unperforated_Studs_Lipped_Channel_400S162_33 = ["Canadian","CSSBI","Unperforated Studs (Lipped Channel)","400S162-33"]
	Canadian_CSSBI_Unperforated_Studs_Lipped_Channel_400S162_43 = ["Canadian","CSSBI","Unperforated Studs (Lipped Channel)","400S162-43"]
	Canadian_CSSBI_Unperforated_Studs_Lipped_Channel_400S162_54 = ["Canadian","CSSBI","Unperforated Studs (Lipped Channel)","400S162-54"]
	Canadian_CSSBI_Unperforated_Studs_Lipped_Channel_400S162_68 = ["Canadian","CSSBI","Unperforated Studs (Lipped Channel)","400S162-68"]
	Canadian_CSSBI_Unperforated_Studs_Lipped_Channel_400S162_97 = ["Canadian","CSSBI","Unperforated Studs (Lipped Channel)","400S162-97"]
	Canadian_CSSBI_Unperforated_Studs_Lipped_Channel_600S125_33 = ["Canadian","CSSBI","Unperforated Studs (Lipped Channel)","600S125-33"]
	Canadian_CSSBI_Unperforated_Studs_Lipped_Channel_600S125_43 = ["Canadian","CSSBI","Unperforated Studs (Lipped Channel)","600S125-43"]
	Canadian_CSSBI_Unperforated_Studs_Lipped_Channel_600S125_54 = ["Canadian","CSSBI","Unperforated Studs (Lipped Channel)","600S125-54"]
	Canadian_CSSBI_Unperforated_Studs_Lipped_Channel_600S162_33 = ["Canadian","CSSBI","Unperforated Studs (Lipped Channel)","600S162-33"]
	Canadian_CSSBI_Unperforated_Studs_Lipped_Channel_600S162_43 = ["Canadian","CSSBI","Unperforated Studs (Lipped Channel)","600S162-43"]
	Canadian_CSSBI_Unperforated_Studs_Lipped_Channel_600S162_54 = ["Canadian","CSSBI","Unperforated Studs (Lipped Channel)","600S162-54"]
	Canadian_CSSBI_Unperforated_Studs_Lipped_Channel_600S162_68 = ["Canadian","CSSBI","Unperforated Studs (Lipped Channel)","600S162-68"]
	Canadian_CSSBI_Unperforated_Studs_Lipped_Channel_600S162_97 = ["Canadian","CSSBI","Unperforated Studs (Lipped Channel)","600S162-97"]
	Canadian_CSSBI_Unperforated_Studs_Lipped_Channel_600S200_33 = ["Canadian","CSSBI","Unperforated Studs (Lipped Channel)","600S200-33"]
	Canadian_CSSBI_Unperforated_Studs_Lipped_Channel_600S200_43 = ["Canadian","CSSBI","Unperforated Studs (Lipped Channel)","600S200-43"]
	Canadian_CSSBI_Unperforated_Studs_Lipped_Channel_600S200_54 = ["Canadian","CSSBI","Unperforated Studs (Lipped Channel)","600S200-54"]
	Canadian_CSSBI_Unperforated_Studs_Lipped_Channel_600S200_68 = ["Canadian","CSSBI","Unperforated Studs (Lipped Channel)","600S200-68"]
	Canadian_CSSBI_Unperforated_Studs_Lipped_Channel_600S200_97 = ["Canadian","CSSBI","Unperforated Studs (Lipped Channel)","600S200-97"]
	Canadian_CSSBI_Unperforated_Studs_Lipped_Channel_800S162_43 = ["Canadian","CSSBI","Unperforated Studs (Lipped Channel)","800S162-43"]
	Canadian_CSSBI_Unperforated_Studs_Lipped_Channel_800S162_54 = ["Canadian","CSSBI","Unperforated Studs (Lipped Channel)","800S162-54"]
	Canadian_CSSBI_Unperforated_Studs_Lipped_Channel_800S162_68 = ["Canadian","CSSBI","Unperforated Studs (Lipped Channel)","800S162-68"]
	Canadian_CSSBI_Unperforated_Studs_Lipped_Channel_800S162_97 = ["Canadian","CSSBI","Unperforated Studs (Lipped Channel)","800S162-97"]
	Canadian_CSSBI_Unperforated_Studs_Lipped_Channel_800S200_43 = ["Canadian","CSSBI","Unperforated Studs (Lipped Channel)","800S200-43"]
	Canadian_CSSBI_Unperforated_Studs_Lipped_Channel_800S200_54 = ["Canadian","CSSBI","Unperforated Studs (Lipped Channel)","800S200-54"]
	Canadian_CSSBI_Unperforated_Studs_Lipped_Channel_800S200_68 = ["Canadian","CSSBI","Unperforated Studs (Lipped Channel)","800S200-68"]
	Canadian_CSSBI_Unperforated_Studs_Lipped_Channel_800S200_97 = ["Canadian","CSSBI","Unperforated Studs (Lipped Channel)","800S200-97"]
	Canadian_CSSBI_Perforated_Studs_Lipped_Channel_362S125_33 = ["Canadian","CSSBI","Perforated Studs (Lipped Channel)","362S125-33"]
	Canadian_CSSBI_Perforated_Studs_Lipped_Channel_362S125_43 = ["Canadian","CSSBI","Perforated Studs (Lipped Channel)","362S125-43"]
	Canadian_CSSBI_Perforated_Studs_Lipped_Channel_362S125_54 = ["Canadian","CSSBI","Perforated Studs (Lipped Channel)","362S125-54"]
	Canadian_CSSBI_Perforated_Studs_Lipped_Channel_362S162_33 = ["Canadian","CSSBI","Perforated Studs (Lipped Channel)","362S162-33"]
	Canadian_CSSBI_Perforated_Studs_Lipped_Channel_362S162_43 = ["Canadian","CSSBI","Perforated Studs (Lipped Channel)","362S162-43"]
	Canadian_CSSBI_Perforated_Studs_Lipped_Channel_362S162_54 = ["Canadian","CSSBI","Perforated Studs (Lipped Channel)","362S162-54"]
	Canadian_CSSBI_Perforated_Studs_Lipped_Channel_362S162_68 = ["Canadian","CSSBI","Perforated Studs (Lipped Channel)","362S162-68"]
	Canadian_CSSBI_Perforated_Studs_Lipped_Channel_362S162_97 = ["Canadian","CSSBI","Perforated Studs (Lipped Channel)","362S162-97"]
	Canadian_CSSBI_Perforated_Studs_Lipped_Channel_400S125_33 = ["Canadian","CSSBI","Perforated Studs (Lipped Channel)","400S125-33"]
	Canadian_CSSBI_Perforated_Studs_Lipped_Channel_400S125_43 = ["Canadian","CSSBI","Perforated Studs (Lipped Channel)","400S125-43"]
	Canadian_CSSBI_Perforated_Studs_Lipped_Channel_400S125_54 = ["Canadian","CSSBI","Perforated Studs (Lipped Channel)","400S125-54"]
	Canadian_CSSBI_Perforated_Studs_Lipped_Channel_400S162_33 = ["Canadian","CSSBI","Perforated Studs (Lipped Channel)","400S162-33"]
	Canadian_CSSBI_Perforated_Studs_Lipped_Channel_400S162_43 = ["Canadian","CSSBI","Perforated Studs (Lipped Channel)","400S162-43"]
	Canadian_CSSBI_Perforated_Studs_Lipped_Channel_400S162_54 = ["Canadian","CSSBI","Perforated Studs (Lipped Channel)","400S162-54"]
	Canadian_CSSBI_Perforated_Studs_Lipped_Channel_400S162_68 = ["Canadian","CSSBI","Perforated Studs (Lipped Channel)","400S162-68"]
	Canadian_CSSBI_Perforated_Studs_Lipped_Channel_400S162_97 = ["Canadian","CSSBI","Perforated Studs (Lipped Channel)","400S162-97"]
	Canadian_CSSBI_Perforated_Studs_Lipped_Channel_600S125_33 = ["Canadian","CSSBI","Perforated Studs (Lipped Channel)","600S125-33"]
	Canadian_CSSBI_Perforated_Studs_Lipped_Channel_600S125_43 = ["Canadian","CSSBI","Perforated Studs (Lipped Channel)","600S125-43"]
	Canadian_CSSBI_Perforated_Studs_Lipped_Channel_600S125_54 = ["Canadian","CSSBI","Perforated Studs (Lipped Channel)","600S125-54"]
	Canadian_CSSBI_Perforated_Studs_Lipped_Channel_600S162_33 = ["Canadian","CSSBI","Perforated Studs (Lipped Channel)","600S162-33"]
	Canadian_CSSBI_Perforated_Studs_Lipped_Channel_600S162_43 = ["Canadian","CSSBI","Perforated Studs (Lipped Channel)","600S162-43"]
	Canadian_CSSBI_Perforated_Studs_Lipped_Channel_600S162_54 = ["Canadian","CSSBI","Perforated Studs (Lipped Channel)","600S162-54"]
	Canadian_CSSBI_Perforated_Studs_Lipped_Channel_600S162_68 = ["Canadian","CSSBI","Perforated Studs (Lipped Channel)","600S162-68"]
	Canadian_CSSBI_Perforated_Studs_Lipped_Channel_600S162_97 = ["Canadian","CSSBI","Perforated Studs (Lipped Channel)","600S162-97"]
	Canadian_CSSBI_Perforated_Studs_Lipped_Channel_600S200_33 = ["Canadian","CSSBI","Perforated Studs (Lipped Channel)","600S200-33"]
	Canadian_CSSBI_Perforated_Studs_Lipped_Channel_600S200_43 = ["Canadian","CSSBI","Perforated Studs (Lipped Channel)","600S200-43"]
	Canadian_CSSBI_Perforated_Studs_Lipped_Channel_600S200_54 = ["Canadian","CSSBI","Perforated Studs (Lipped Channel)","600S200-54"]
	Canadian_CSSBI_Perforated_Studs_Lipped_Channel_600S200_68 = ["Canadian","CSSBI","Perforated Studs (Lipped Channel)","600S200-68"]
	Canadian_CSSBI_Perforated_Studs_Lipped_Channel_600S200_97 = ["Canadian","CSSBI","Perforated Studs (Lipped Channel)","600S200-97"]
	Canadian_CSSBI_Perforated_Studs_Lipped_Channel_800S162_43 = ["Canadian","CSSBI","Perforated Studs (Lipped Channel)","800S162-43"]
	Canadian_CSSBI_Perforated_Studs_Lipped_Channel_800S162_54 = ["Canadian","CSSBI","Perforated Studs (Lipped Channel)","800S162-54"]
	Canadian_CSSBI_Perforated_Studs_Lipped_Channel_800S162_68 = ["Canadian","CSSBI","Perforated Studs (Lipped Channel)","800S162-68"]
	Canadian_CSSBI_Perforated_Studs_Lipped_Channel_800S162_97 = ["Canadian","CSSBI","Perforated Studs (Lipped Channel)","800S162-97"]
	Canadian_CSSBI_Perforated_Studs_Lipped_Channel_800S200_43 = ["Canadian","CSSBI","Perforated Studs (Lipped Channel)","800S200-43"]
	Canadian_CSSBI_Perforated_Studs_Lipped_Channel_800S200_54 = ["Canadian","CSSBI","Perforated Studs (Lipped Channel)","800S200-54"]
	Canadian_CSSBI_Perforated_Studs_Lipped_Channel_800S200_68 = ["Canadian","CSSBI","Perforated Studs (Lipped Channel)","800S200-68"]
	Canadian_CSSBI_Perforated_Studs_Lipped_Channel_800S200_97 = ["Canadian","CSSBI","Perforated Studs (Lipped Channel)","800S200-97"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_600S162_43 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","600S162-43"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_600S162_54 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","600S162-54"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_600S162_68 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","600S162-68"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_600S162_97 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","600S162-97"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_600S200_43 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","600S200-43"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_600S200_54 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","600S200-54"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_600S200_68 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","600S200-68"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_600S200_97 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","600S200-97"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_800S162_43 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","800S162-43"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_800S162_54 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","800S162-54"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_800S162_68 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","800S162-68"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_800S162_97 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","800S162-97"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_800S200_43 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","800S200-43"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_800S200_54 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","800S200-54"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_800S200_68 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","800S200-68"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_800S200_97 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","800S200-97"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_800S250_43 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","800S250-43"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_800S250_54 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","800S250-54"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_800S250_68 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","800S250-68"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_800S250_97 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","800S250-97"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_1000S162_54 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","1000S162-54"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_1000S162_68 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","1000S162-68"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_1000S162_97 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","1000S162-97"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_1000S200_54 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","1000S200-54"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_1000S200_68 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","1000S200-68"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_1000S200_97 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","1000S200-97"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_1000S250_54 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","1000S250-54"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_1000S250_68 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","1000S250-68"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_1000S250_97 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","1000S250-97"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_1000S300_54 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","1000S300-54"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_1000S300_68 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","1000S300-68"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_1000S300_97 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","1000S300-97"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_1200S162_68 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","1200S162-68"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_1200S162_97 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","1200S162-97"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_1200S200_68 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","1200S200-68"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_1200S200_97 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","1200S200-97"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_1200S250_68 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","1200S250-68"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_1200S250_97 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","1200S250-97"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_1200S300_68 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","1200S300-68"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_1200S300_97 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","1200S300-97"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_1400S162_68 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","1400S162-68"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_1400S162_97 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","1400S162-97"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_1400S200_68 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","1400S200-68"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_1400S200_97 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","1400S200-97"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_1400S250_68 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","1400S250-68"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_1400S250_97 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","1400S250-97"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_1400S300_68 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","1400S300-68"]
	Canadian_CSSBI_Unperforated_Joists_Lipped_Channel_1400S300_97 = ["Canadian","CSSBI","Unperforated Joists (Lipped Channel)","1400S300-97"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_600S162_43 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","600S162-43"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_600S162_54 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","600S162-54"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_600S162_68 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","600S162-68"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_600S162_97 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","600S162-97"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_600S200_43 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","600S200-43"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_600S200_54 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","600S200-54"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_600S200_68 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","600S200-68"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_600S200_97 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","600S200-97"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_800S162_43 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","800S162-43"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_800S162_54 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","800S162-54"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_800S162_68 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","800S162-68"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_800S162_97 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","800S162-97"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_800S200_43 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","800S200-43"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_800S200_54 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","800S200-54"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_800S200_68 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","800S200-68"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_800S200_97 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","800S200-97"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_800S250_43 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","800S250-43"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_800S250_54 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","800S250-54"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_800S250_68 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","800S250-68"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_800S250_97 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","800S250-97"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_1000S162_54 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","1000S162-54"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_1000S162_68 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","1000S162-68"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_1000S162_97 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","1000S162-97"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_1000S200_54 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","1000S200-54"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_1000S200_68 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","1000S200-68"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_1000S200_97 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","1000S200-97"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_1000S250_54 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","1000S250-54"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_1000S250_68 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","1000S250-68"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_1000S250_97 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","1000S250-97"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_1000S300_54 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","1000S300-54"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_1000S300_68 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","1000S300-68"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_1000S300_97 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","1000S300-97"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_1200S162_68 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","1200S162-68"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_1200S162_97 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","1200S162-97"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_1200S200_68 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","1200S200-68"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_1200S200_97 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","1200S200-97"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_1200S250_68 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","1200S250-68"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_1200S250_97 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","1200S250-97"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_1200S300_68 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","1200S300-68"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_1200S300_97 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","1200S300-97"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_1400S162_68 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","1400S162-68"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_1400S162_97 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","1400S162-97"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_1400S200_68 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","1400S200-68"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_1400S200_97 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","1400S200-97"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_1400S250_68 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","1400S250-68"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_1400S250_97 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","1400S250-97"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_1400S300_68 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","1400S300-68"]
	Canadian_CSSBI_Perforated_Joists_Lipped_Channel_1400S300_97 = ["Canadian","CSSBI","Perforated Joists (Lipped Channel)","1400S300-97"]
	Canadian_CSSBI_Tracks_Channel_362T125_33 = ["Canadian","CSSBI","Tracks (Channel)","362T125-33"]
	Canadian_CSSBI_Tracks_Channel_362T125_43 = ["Canadian","CSSBI","Tracks (Channel)","362T125-43"]
	Canadian_CSSBI_Tracks_Channel_362T125_54 = ["Canadian","CSSBI","Tracks (Channel)","362T125-54"]
	Canadian_CSSBI_Tracks_Channel_362T125_68 = ["Canadian","CSSBI","Tracks (Channel)","362T125-68"]
	Canadian_CSSBI_Tracks_Channel_362T125_97 = ["Canadian","CSSBI","Tracks (Channel)","362T125-97"]
	Canadian_CSSBI_Tracks_Channel_362T150_33 = ["Canadian","CSSBI","Tracks (Channel)","362T150-33"]
	Canadian_CSSBI_Tracks_Channel_362T150_43 = ["Canadian","CSSBI","Tracks (Channel)","362T150-43"]
	Canadian_CSSBI_Tracks_Channel_362T150_54 = ["Canadian","CSSBI","Tracks (Channel)","362T150-54"]
	Canadian_CSSBI_Tracks_Channel_362T150_68 = ["Canadian","CSSBI","Tracks (Channel)","362T150-68"]
	Canadian_CSSBI_Tracks_Channel_362T150_97 = ["Canadian","CSSBI","Tracks (Channel)","362T150-97"]
	Canadian_CSSBI_Tracks_Channel_362T200_33 = ["Canadian","CSSBI","Tracks (Channel)","362T200-33"]
	Canadian_CSSBI_Tracks_Channel_362T200_43 = ["Canadian","CSSBI","Tracks (Channel)","362T200-43"]
	Canadian_CSSBI_Tracks_Channel_362T200_54 = ["Canadian","CSSBI","Tracks (Channel)","362T200-54"]
	Canadian_CSSBI_Tracks_Channel_362T200_68 = ["Canadian","CSSBI","Tracks (Channel)","362T200-68"]
	Canadian_CSSBI_Tracks_Channel_362T200_97 = ["Canadian","CSSBI","Tracks (Channel)","362T200-97"]
	Canadian_CSSBI_Tracks_Channel_400T125_33 = ["Canadian","CSSBI","Tracks (Channel)","400T125-33"]
	Canadian_CSSBI_Tracks_Channel_400T125_43 = ["Canadian","CSSBI","Tracks (Channel)","400T125-43"]
	Canadian_CSSBI_Tracks_Channel_400T125_54 = ["Canadian","CSSBI","Tracks (Channel)","400T125-54"]
	Canadian_CSSBI_Tracks_Channel_400T125_68 = ["Canadian","CSSBI","Tracks (Channel)","400T125-68"]
	Canadian_CSSBI_Tracks_Channel_400T125_97 = ["Canadian","CSSBI","Tracks (Channel)","400T125-97"]
	Canadian_CSSBI_Tracks_Channel_400T150_33 = ["Canadian","CSSBI","Tracks (Channel)","400T150-33"]
	Canadian_CSSBI_Tracks_Channel_400T150_43 = ["Canadian","CSSBI","Tracks (Channel)","400T150-43"]
	Canadian_CSSBI_Tracks_Channel_400T150_54 = ["Canadian","CSSBI","Tracks (Channel)","400T150-54"]
	Canadian_CSSBI_Tracks_Channel_400T150_68 = ["Canadian","CSSBI","Tracks (Channel)","400T150-68"]
	Canadian_CSSBI_Tracks_Channel_400T150_97 = ["Canadian","CSSBI","Tracks (Channel)","400T150-97"]
	Canadian_CSSBI_Tracks_Channel_400T200_33 = ["Canadian","CSSBI","Tracks (Channel)","400T200-33"]
	Canadian_CSSBI_Tracks_Channel_400T200_43 = ["Canadian","CSSBI","Tracks (Channel)","400T200-43"]
	Canadian_CSSBI_Tracks_Channel_400T200_54 = ["Canadian","CSSBI","Tracks (Channel)","400T200-54"]
	Canadian_CSSBI_Tracks_Channel_400T200_68 = ["Canadian","CSSBI","Tracks (Channel)","400T200-68"]
	Canadian_CSSBI_Tracks_Channel_400T200_97 = ["Canadian","CSSBI","Tracks (Channel)","400T200-97"]
	Canadian_CSSBI_Tracks_Channel_600T125_33 = ["Canadian","CSSBI","Tracks (Channel)","600T125-33"]
	Canadian_CSSBI_Tracks_Channel_600T125_43 = ["Canadian","CSSBI","Tracks (Channel)","600T125-43"]
	Canadian_CSSBI_Tracks_Channel_600T125_54 = ["Canadian","CSSBI","Tracks (Channel)","600T125-54"]
	Canadian_CSSBI_Tracks_Channel_600T125_68 = ["Canadian","CSSBI","Tracks (Channel)","600T125-68"]
	Canadian_CSSBI_Tracks_Channel_600T125_97 = ["Canadian","CSSBI","Tracks (Channel)","600T125-97"]
	Canadian_CSSBI_Tracks_Channel_600T150_33 = ["Canadian","CSSBI","Tracks (Channel)","600T150-33"]
	Canadian_CSSBI_Tracks_Channel_600T150_43 = ["Canadian","CSSBI","Tracks (Channel)","600T150-43"]
	Canadian_CSSBI_Tracks_Channel_600T150_54 = ["Canadian","CSSBI","Tracks (Channel)","600T150-54"]
	Canadian_CSSBI_Tracks_Channel_600T150_68 = ["Canadian","CSSBI","Tracks (Channel)","600T150-68"]
	Canadian_CSSBI_Tracks_Channel_600T150_97 = ["Canadian","CSSBI","Tracks (Channel)","600T150-97"]
	Canadian_CSSBI_Tracks_Channel_600T200_33 = ["Canadian","CSSBI","Tracks (Channel)","600T200-33"]
	Canadian_CSSBI_Tracks_Channel_600T200_43 = ["Canadian","CSSBI","Tracks (Channel)","600T200-43"]
	Canadian_CSSBI_Tracks_Channel_600T200_54 = ["Canadian","CSSBI","Tracks (Channel)","600T200-54"]
	Canadian_CSSBI_Tracks_Channel_600T200_68 = ["Canadian","CSSBI","Tracks (Channel)","600T200-68"]
	Canadian_CSSBI_Tracks_Channel_600T200_97 = ["Canadian","CSSBI","Tracks (Channel)","600T200-97"]
	Canadian_CSSBI_Tracks_Channel_800T125_43 = ["Canadian","CSSBI","Tracks (Channel)","800T125-43"]
	Canadian_CSSBI_Tracks_Channel_800T125_54 = ["Canadian","CSSBI","Tracks (Channel)","800T125-54"]
	Canadian_CSSBI_Tracks_Channel_800T125_68 = ["Canadian","CSSBI","Tracks (Channel)","800T125-68"]
	Canadian_CSSBI_Tracks_Channel_800T125_97 = ["Canadian","CSSBI","Tracks (Channel)","800T125-97"]
	Canadian_CSSBI_Tracks_Channel_800T150_43 = ["Canadian","CSSBI","Tracks (Channel)","800T150-43"]
	Canadian_CSSBI_Tracks_Channel_800T150_54 = ["Canadian","CSSBI","Tracks (Channel)","800T150-54"]
	Canadian_CSSBI_Tracks_Channel_800T150_68 = ["Canadian","CSSBI","Tracks (Channel)","800T150-68"]
	Canadian_CSSBI_Tracks_Channel_800T150_97 = ["Canadian","CSSBI","Tracks (Channel)","800T150-97"]
	Canadian_CSSBI_Tracks_Channel_800T200_43 = ["Canadian","CSSBI","Tracks (Channel)","800T200-43"]
	Canadian_CSSBI_Tracks_Channel_800T200_54 = ["Canadian","CSSBI","Tracks (Channel)","800T200-54"]
	Canadian_CSSBI_Tracks_Channel_800T200_68 = ["Canadian","CSSBI","Tracks (Channel)","800T200-68"]
	Canadian_CSSBI_Tracks_Channel_800T200_97 = ["Canadian","CSSBI","Tracks (Channel)","800T200-97"]
	Canadian_CSSBI_Tracks_Channel_1000T125_54 = ["Canadian","CSSBI","Tracks (Channel)","1000T125-54"]
	Canadian_CSSBI_Tracks_Channel_1000T125_68 = ["Canadian","CSSBI","Tracks (Channel)","1000T125-68"]
	Canadian_CSSBI_Tracks_Channel_1000T125_97 = ["Canadian","CSSBI","Tracks (Channel)","1000T125-97"]
	Canadian_CSSBI_Tracks_Channel_1000T150_54 = ["Canadian","CSSBI","Tracks (Channel)","1000T150-54"]
	Canadian_CSSBI_Tracks_Channel_1000T150_68 = ["Canadian","CSSBI","Tracks (Channel)","1000T150-68"]
	Canadian_CSSBI_Tracks_Channel_1000T150_97 = ["Canadian","CSSBI","Tracks (Channel)","1000T150-97"]
	Canadian_CSSBI_Tracks_Channel_1000T200_54 = ["Canadian","CSSBI","Tracks (Channel)","1000T200-54"]
	Canadian_CSSBI_Tracks_Channel_1000T200_68 = ["Canadian","CSSBI","Tracks (Channel)","1000T200-68"]
	Canadian_CSSBI_Tracks_Channel_1000T200_97 = ["Canadian","CSSBI","Tracks (Channel)","1000T200-97"]
	Canadian_CSSBI_Tracks_Channel_1200T125_68 = ["Canadian","CSSBI","Tracks (Channel)","1200T125-68"]
	Canadian_CSSBI_Tracks_Channel_1200T125_97 = ["Canadian","CSSBI","Tracks (Channel)","1200T125-97"]
	Canadian_CSSBI_Tracks_Channel_1200T150_68 = ["Canadian","CSSBI","Tracks (Channel)","1200T150-68"]
	Canadian_CSSBI_Tracks_Channel_1200T150_97 = ["Canadian","CSSBI","Tracks (Channel)","1200T150-97"]
	Canadian_CSSBI_Tracks_Channel_1200T200_68 = ["Canadian","CSSBI","Tracks (Channel)","1200T200-68"]
	Canadian_CSSBI_Tracks_Channel_1200T200_97 = ["Canadian","CSSBI","Tracks (Channel)","1200T200-97"]
	Canadian_CSSBI_Tracks_Channel_1400T125_68 = ["Canadian","CSSBI","Tracks (Channel)","1400T125-68"]
	Canadian_CSSBI_Tracks_Channel_1400T125_97 = ["Canadian","CSSBI","Tracks (Channel)","1400T125-97"]
	Canadian_CSSBI_Tracks_Channel_1400T150_68 = ["Canadian","CSSBI","Tracks (Channel)","1400T150-68"]
	Canadian_CSSBI_Tracks_Channel_1400T150_97 = ["Canadian","CSSBI","Tracks (Channel)","1400T150-97"]
	Canadian_CSSBI_Tracks_Channel_1400T200_68 = ["Canadian","CSSBI","Tracks (Channel)","1400T200-68"]
	Canadian_CSSBI_Tracks_Channel_1400T200_97 = ["Canadian","CSSBI","Tracks (Channel)","1400T200-97"]
	Canadian_CSSBI_Bridging_Channels_75U50_54_Fy_equals_230_MPa = ["Canadian","CSSBI","Bridging Channels","75U50-54 (Fy = 230 MPa)"]
	Canadian_CSSBI_Bridging_Channels_75U50_54_Fy_equals_345_MPa = ["Canadian","CSSBI","Bridging Channels","75U50-54 (Fy = 345 MPa)"]
	Canadian_CSSBI_Bridging_Channels_150U50_43_Fy_equals_230_MPa = ["Canadian","CSSBI","Bridging Channels","150U50-43 (Fy = 230 MPa)"]
	Canadian_CSSBI_Bridging_Channels_150U50_43_Fy_equals_345_MPa = ["Canadian","CSSBI","Bridging Channels","150U50-43 (Fy = 345 MPa)"]
	Canadian_CSSBI_Bridging_Channels_150U50_54_Fy_equals_230_MPa = ["Canadian","CSSBI","Bridging Channels","150U50-54 (Fy = 230 MPa)"]
	Canadian_CSSBI_Bridging_Channels_150U50_54_Fy_equals_345_MPa = ["Canadian","CSSBI","Bridging Channels","150U50-54 (Fy = 345 MPa)"]
	Canadian_CSSBI_Bridging_Channels_150U75_54_Fy_equals_230_MPa = ["Canadian","CSSBI","Bridging Channels","150U75-54 (Fy = 230 MPa)"]
	Canadian_CSSBI_Bridging_Channels_150U75_54_Fy_equals_345_MPa = ["Canadian","CSSBI","Bridging Channels","150U75-54 (Fy = 345 MPa)"]
	China_Steel_Beam_Tees_TM241x300 = ["China","Steel","Beam Tees","TM241x300"]
	China_Steel_Beam_Tees_TM291x300 = ["China","Steel","Beam Tees","TM291x300"]
	China_Steel_Beam_Tees_TM294x300 = ["China","Steel","Beam Tees","TM294x300"]
	China_Steel_Beam_Tees_TM297x302 = ["China","Steel","Beam Tees","TM297x302"]
	China_Steel_Beam_Tees_TN50x50 = ["China","Steel","Beam Tees","TN50x50"]
	China_Steel_Beam_Tees_TN62_5x60 = ["China","Steel","Beam Tees","TN62.5x60"]
	China_Steel_Beam_Tees_TN75x75 = ["China","Steel","Beam Tees","TN75x75"]
	China_Steel_Beam_Tees_TN85_5x89 = ["China","Steel","Beam Tees","TN85.5x89"]
	China_Steel_Beam_Tees_TN87_5x90 = ["China","Steel","Beam Tees","TN87.5x90"]
	China_Steel_Beam_Tees_TN99x99 = ["China","Steel","Beam Tees","TN99x99"]
	China_Steel_Beam_Tees_TN100x100 = ["China","Steel","Beam Tees","TN100x100"]
	China_Steel_Beam_Tees_TN124x124 = ["China","Steel","Beam Tees","TN124x124"]
	China_Steel_Beam_Tees_TN125x125 = ["China","Steel","Beam Tees","TN125x125"]
	China_Steel_Beam_Tees_TN149x149 = ["China","Steel","Beam Tees","TN149x149"]
	China_Steel_Beam_Tees_TN150x150 = ["China","Steel","Beam Tees","TN150x150"]
	China_Steel_Beam_Tees_TN173x174 = ["China","Steel","Beam Tees","TN173x174"]
	China_Steel_Beam_Tees_TN175x175 = ["China","Steel","Beam Tees","TN175x175"]
	China_Steel_Beam_Tees_TN198x199 = ["China","Steel","Beam Tees","TN198x199"]
	China_Steel_Beam_Tees_TN200x200 = ["China","Steel","Beam Tees","TN200x200"]
	China_Steel_Beam_Tees_TN223x150 = ["China","Steel","Beam Tees","TN223x150"]
	China_Steel_Beam_Tees_TN223x199 = ["China","Steel","Beam Tees","TN223x199"]
	China_Steel_Beam_Tees_TN225x151 = ["China","Steel","Beam Tees","TN225x151"]
	China_Steel_Beam_Tees_TN225x200 = ["China","Steel","Beam Tees","TN225x200"]
	China_Steel_Beam_Tees_TN235x150 = ["China","Steel","Beam Tees","TN235x150"]
	China_Steel_Beam_Tees_TN237_5x151_5 = ["China","Steel","Beam Tees","TN237.5x151.5"]
	China_Steel_Beam_Tees_TN241x153_5 = ["China","Steel","Beam Tees","TN241x153.5"]
	China_Steel_Beam_Tees_TN246x150 = ["China","Steel","Beam Tees","TN246x150"]
	China_Steel_Beam_Tees_TN248x199 = ["China","Steel","Beam Tees","TN248x199"]
	China_Steel_Beam_Tees_TN250x152 = ["China","Steel","Beam Tees","TN250x152"]
	China_Steel_Beam_Tees_TN250x200 = ["China","Steel","Beam Tees","TN250x200"]
	China_Steel_Beam_Tees_TN252x153 = ["China","Steel","Beam Tees","TN252x153"]
	China_Steel_Beam_Tees_TN253x201 = ["China","Steel","Beam Tees","TN253x201"]
	China_Steel_Beam_Tees_TN273x199 = ["China","Steel","Beam Tees","TN273x199"]
	China_Steel_Beam_Tees_TN275x200 = ["China","Steel","Beam Tees","TN275x200"]
	China_Steel_Beam_Tees_TN298x199 = ["China","Steel","Beam Tees","TN298x199"]
	China_Steel_Beam_Tees_TN300x200 = ["China","Steel","Beam Tees","TN300x200"]
	China_Steel_Beam_Tees_TN303x201 = ["China","Steel","Beam Tees","TN303x201"]
	China_Steel_Beam_Tees_TN312_5x198_5 = ["China","Steel","Beam Tees","TN312.5x198.5"]
	China_Steel_Beam_Tees_TN315x200 = ["China","Steel","Beam Tees","TN315x200"]
	China_Steel_Beam_Tees_TN319x202 = ["China","Steel","Beam Tees","TN319x202"]
	China_Steel_Beam_Tees_TN323x299 = ["China","Steel","Beam Tees","TN323x299"]
	China_Steel_Beam_Tees_TN325x300 = ["China","Steel","Beam Tees","TN325x300"]
	China_Steel_Beam_Tees_TN328x301 = ["China","Steel","Beam Tees","TN328x301"]
	China_Steel_Beam_Tees_TN346x300 = ["China","Steel","Beam Tees","TN346x300"]
	China_Steel_Beam_Tees_TN350x300 = ["China","Steel","Beam Tees","TN350x300"]
	China_Steel_Beam_Tees_TN396xx300 = ["China","Steel","Beam Tees","TN396xx300"]
	China_Steel_Beam_Tees_TN400x300 = ["China","Steel","Beam Tees","TN400x300"]
	China_Steel_Beam_Tees_TN445x299 = ["China","Steel","Beam Tees","TN445x299"]
	China_Steel_Beam_Tees_TN450x300 = ["China","Steel","Beam Tees","TN450x300"]
	China_Steel_Beam_Tees_TN456x302 = ["China","Steel","Beam Tees","TN456x302"]
	China_Steel_Channels_CH50x37 = ["China","Steel","Channels","CH50x37"]
	China_Steel_Channels_CH63x40 = ["China","Steel","Channels","CH63x40"]
	China_Steel_Channels_CH65x40 = ["China","Steel","Channels","CH65x40"]
	China_Steel_Channels_CH80x43 = ["China","Steel","Channels","CH80x43"]
	China_Steel_Channels_CH100x48 = ["China","Steel","Channels","CH100x48"]
	China_Steel_Channels_CH120x53 = ["China","Steel","Channels","CH120x53"]
	China_Steel_Channels_CH126x53 = ["China","Steel","Channels","CH126x53"]
	China_Steel_Channels_CH140x58 = ["China","Steel","Channels","CH140x58"]
	China_Steel_Channels_CH140x60 = ["China","Steel","Channels","CH140x60"]
	China_Steel_Channels_CH160x63 = ["China","Steel","Channels","CH160x63"]
	China_Steel_Channels_CH160x65 = ["China","Steel","Channels","CH160x65"]
	China_Steel_Channels_CH180x68 = ["China","Steel","Channels","CH180x68"]
	China_Steel_Channels_CH180x70 = ["China","Steel","Channels","CH180x70"]
	China_Steel_Channels_CH200x73 = ["China","Steel","Channels","CH200x73"]
	China_Steel_Channels_CH200x75 = ["China","Steel","Channels","CH200x75"]
	China_Steel_Channels_CH220x77 = ["China","Steel","Channels","CH220x77"]
	China_Steel_Channels_CH220x79 = ["China","Steel","Channels","CH220x79"]
	China_Steel_Channels_CH240x78 = ["China","Steel","Channels","CH240x78"]
	China_Steel_Channels_CH240x80 = ["China","Steel","Channels","CH240x80"]
	China_Steel_Channels_CH240x82 = ["China","Steel","Channels","CH240x82"]
	China_Steel_Channels_CH250x78 = ["China","Steel","Channels","CH250x78"]
	China_Steel_Channels_CH250x80 = ["China","Steel","Channels","CH250x80"]
	China_Steel_Channels_CH250x82 = ["China","Steel","Channels","CH250x82"]
	China_Steel_Channels_CH270x82 = ["China","Steel","Channels","CH270x82"]
	China_Steel_Channels_CH270x84 = ["China","Steel","Channels","CH270x84"]
	China_Steel_Channels_CH270x86 = ["China","Steel","Channels","CH270x86"]
	China_Steel_Channels_CH280x82 = ["China","Steel","Channels","CH280x82"]
	China_Steel_Channels_CH280x84 = ["China","Steel","Channels","CH280x84"]
	China_Steel_Channels_CH280x86 = ["China","Steel","Channels","CH280x86"]
	China_Steel_Channels_CH300x85 = ["China","Steel","Channels","CH300x85"]
	China_Steel_Channels_CH300x87 = ["China","Steel","Channels","CH300x87"]
	China_Steel_Channels_CH300x89 = ["China","Steel","Channels","CH300x89"]
	China_Steel_Channels_CH320x88 = ["China","Steel","Channels","CH320x88"]
	China_Steel_Channels_CH320x90 = ["China","Steel","Channels","CH320x90"]
	China_Steel_Channels_CH320x92 = ["China","Steel","Channels","CH320x92"]
	China_Steel_Channels_CH360x96 = ["China","Steel","Channels","CH360x96"]
	China_Steel_Channels_CH360x98 = ["China","Steel","Channels","CH360x98"]
	China_Steel_Channels_CH360x100 = ["China","Steel","Channels","CH360x100"]
	China_Steel_Channels_CH400x100 = ["China","Steel","Channels","CH400x100"]
	China_Steel_Channels_CH400x102 = ["China","Steel","Channels","CH400x102"]
	China_Steel_Channels_CH400x104 = ["China","Steel","Channels","CH400x104"]
	China_Steel_Circular_hollow_sections_CHS21_3x1_2 = ["China","Steel","Circular hollow sections","CHS21.3x1.2"]
	China_Steel_Circular_hollow_sections_CHS21_3x1_5 = ["China","Steel","Circular hollow sections","CHS21.3x1.5"]
	China_Steel_Circular_hollow_sections_CHS21_3x1_8 = ["China","Steel","Circular hollow sections","CHS21.3x1.8"]
	China_Steel_Circular_hollow_sections_CHS21_3x2 = ["China","Steel","Circular hollow sections","CHS21.3x2"]
	China_Steel_Circular_hollow_sections_CHS21_3x2_5 = ["China","Steel","Circular hollow sections","CHS21.3x2.5"]
	China_Steel_Circular_hollow_sections_CHS21_3x3 = ["China","Steel","Circular hollow sections","CHS21.3x3"]
	China_Steel_Circular_hollow_sections_CHS26_8x1_2 = ["China","Steel","Circular hollow sections","CHS26.8x1.2"]
	China_Steel_Circular_hollow_sections_CHS26_8x1_5 = ["China","Steel","Circular hollow sections","CHS26.8x1.5"]
	China_Steel_Circular_hollow_sections_CHS26_8x1_8 = ["China","Steel","Circular hollow sections","CHS26.8x1.8"]
	China_Steel_Circular_hollow_sections_CHS26_8x2 = ["China","Steel","Circular hollow sections","CHS26.8x2"]
	China_Steel_Circular_hollow_sections_CHS26_8x2_5 = ["China","Steel","Circular hollow sections","CHS26.8x2.5"]
	China_Steel_Circular_hollow_sections_CHS26_8x3 = ["China","Steel","Circular hollow sections","CHS26.8x3"]
	China_Steel_Circular_hollow_sections_CHS32x3 = ["China","Steel","Circular hollow sections","CHS32x3"]
	China_Steel_Circular_hollow_sections_CHS32x4 = ["China","Steel","Circular hollow sections","CHS32x4"]
	China_Steel_Circular_hollow_sections_CHS33_5x1_5 = ["China","Steel","Circular hollow sections","CHS33.5x1.5"]
	China_Steel_Circular_hollow_sections_CHS33_5x2 = ["China","Steel","Circular hollow sections","CHS33.5x2"]
	China_Steel_Circular_hollow_sections_CHS33_5x2_5 = ["China","Steel","Circular hollow sections","CHS33.5x2.5"]
	China_Steel_Circular_hollow_sections_CHS33_5x3 = ["China","Steel","Circular hollow sections","CHS33.5x3"]
	China_Steel_Circular_hollow_sections_CHS33_5x3_5 = ["China","Steel","Circular hollow sections","CHS33.5x3.5"]
	China_Steel_Circular_hollow_sections_CHS33_5x4 = ["China","Steel","Circular hollow sections","CHS33.5x4"]
	China_Steel_Circular_hollow_sections_CHS42_3x1_5 = ["China","Steel","Circular hollow sections","CHS42.3x1.5"]
	China_Steel_Circular_hollow_sections_CHS42_3x2 = ["China","Steel","Circular hollow sections","CHS42.3x2"]
	China_Steel_Circular_hollow_sections_CHS42_3x2_5 = ["China","Steel","Circular hollow sections","CHS42.3x2.5"]
	China_Steel_Circular_hollow_sections_CHS42_3x3 = ["China","Steel","Circular hollow sections","CHS42.3x3"]
	China_Steel_Circular_hollow_sections_CHS42_3x4 = ["China","Steel","Circular hollow sections","CHS42.3x4"]
	China_Steel_Circular_hollow_sections_CHS42x3 = ["China","Steel","Circular hollow sections","CHS42x3"]
	China_Steel_Circular_hollow_sections_CHS42x4 = ["China","Steel","Circular hollow sections","CHS42x4"]
	China_Steel_Circular_hollow_sections_CHS48x1_5 = ["China","Steel","Circular hollow sections","CHS48x1.5"]
	China_Steel_Circular_hollow_sections_CHS48x2 = ["China","Steel","Circular hollow sections","CHS48x2"]
	China_Steel_Circular_hollow_sections_CHS48x2_5 = ["China","Steel","Circular hollow sections","CHS48x2.5"]
	China_Steel_Circular_hollow_sections_CHS48x3 = ["China","Steel","Circular hollow sections","CHS48x3"]
	China_Steel_Circular_hollow_sections_CHS48x4_5 = ["China","Steel","Circular hollow sections","CHS48x4.5"]
	China_Steel_Circular_hollow_sections_CHS48x5 = ["China","Steel","Circular hollow sections","CHS48x5"]
	China_Steel_Circular_hollow_sections_CHS50x3 = ["China","Steel","Circular hollow sections","CHS50x3"]
	China_Steel_Circular_hollow_sections_CHS50x4 = ["China","Steel","Circular hollow sections","CHS50x4"]
	China_Steel_Circular_hollow_sections_CHS50x5 = ["China","Steel","Circular hollow sections","CHS50x5"]
	China_Steel_Circular_hollow_sections_CHS60x2 = ["China","Steel","Circular hollow sections","CHS60x2"]
	China_Steel_Circular_hollow_sections_CHS60x2_5 = ["China","Steel","Circular hollow sections","CHS60x2.5"]
	China_Steel_Circular_hollow_sections_CHS60x3 = ["China","Steel","Circular hollow sections","CHS60x3"]
	China_Steel_Circular_hollow_sections_CHS60x4 = ["China","Steel","Circular hollow sections","CHS60x4"]
	China_Steel_Circular_hollow_sections_CHS60x5 = ["China","Steel","Circular hollow sections","CHS60x5"]
	China_Steel_Circular_hollow_sections_CHS75_5x2_5 = ["China","Steel","Circular hollow sections","CHS75.5x2.5"]
	China_Steel_Circular_hollow_sections_CHS75_5x3 = ["China","Steel","Circular hollow sections","CHS75.5x3"]
	China_Steel_Circular_hollow_sections_CHS75_5x4 = ["China","Steel","Circular hollow sections","CHS75.5x4"]
	China_Steel_Circular_hollow_sections_CHS75_5x5 = ["China","Steel","Circular hollow sections","CHS75.5x5"]
	China_Steel_Circular_hollow_sections_CHS76x4 = ["China","Steel","Circular hollow sections","CHS76x4"]
	China_Steel_Circular_hollow_sections_CHS76x6 = ["China","Steel","Circular hollow sections","CHS76x6"]
	China_Steel_Circular_hollow_sections_CHS88_5x3 = ["China","Steel","Circular hollow sections","CHS88.5x3"]
	China_Steel_Circular_hollow_sections_CHS88_5x4 = ["China","Steel","Circular hollow sections","CHS88.5x4"]
	China_Steel_Circular_hollow_sections_CHS88_5x5 = ["China","Steel","Circular hollow sections","CHS88.5x5"]
	China_Steel_Circular_hollow_sections_CHS88_5x6 = ["China","Steel","Circular hollow sections","CHS88.5x6"]
	China_Steel_Circular_hollow_sections_CHS89x4 = ["China","Steel","Circular hollow sections","CHS89x4"]
	China_Steel_Circular_hollow_sections_CHS89x6 = ["China","Steel","Circular hollow sections","CHS89x6"]
	China_Steel_Circular_hollow_sections_CHS102x4 = ["China","Steel","Circular hollow sections","CHS102x4"]
	China_Steel_Circular_hollow_sections_CHS102x6 = ["China","Steel","Circular hollow sections","CHS102x6"]
	China_Steel_Circular_hollow_sections_CHS114x4 = ["China","Steel","Circular hollow sections","CHS114x4"]
	China_Steel_Circular_hollow_sections_CHS114x5 = ["China","Steel","Circular hollow sections","CHS114x5"]
	China_Steel_Circular_hollow_sections_CHS114x6 = ["China","Steel","Circular hollow sections","CHS114x6"]
	China_Steel_Circular_hollow_sections_CHS140x4 = ["China","Steel","Circular hollow sections","CHS140x4"]
	China_Steel_Circular_hollow_sections_CHS140x5 = ["China","Steel","Circular hollow sections","CHS140x5"]
	China_Steel_Circular_hollow_sections_CHS140x6 = ["China","Steel","Circular hollow sections","CHS140x6"]
	China_Steel_Circular_hollow_sections_CHS152x5 = ["China","Steel","Circular hollow sections","CHS152x5"]
	China_Steel_Circular_hollow_sections_CHS152x6 = ["China","Steel","Circular hollow sections","CHS152x6"]
	China_Steel_Circular_hollow_sections_CHS152x8 = ["China","Steel","Circular hollow sections","CHS152x8"]
	China_Steel_Circular_hollow_sections_CHS165x4 = ["China","Steel","Circular hollow sections","CHS165x4"]
	China_Steel_Circular_hollow_sections_CHS165x5 = ["China","Steel","Circular hollow sections","CHS165x5"]
	China_Steel_Circular_hollow_sections_CHS165x6 = ["China","Steel","Circular hollow sections","CHS165x6"]
	China_Steel_Circular_hollow_sections_CHS165x8 = ["China","Steel","Circular hollow sections","CHS165x8"]
	China_Steel_Circular_hollow_sections_CHS168x5 = ["China","Steel","Circular hollow sections","CHS168x5"]
	China_Steel_Circular_hollow_sections_CHS168x6 = ["China","Steel","Circular hollow sections","CHS168x6"]
	China_Steel_Circular_hollow_sections_CHS168x8 = ["China","Steel","Circular hollow sections","CHS168x8"]
	China_Steel_Circular_hollow_sections_CHS194x6 = ["China","Steel","Circular hollow sections","CHS194x6"]
	China_Steel_Circular_hollow_sections_CHS194x8 = ["China","Steel","Circular hollow sections","CHS194x8"]
	China_Steel_Circular_hollow_sections_CHS194x10 = ["China","Steel","Circular hollow sections","CHS194x10"]
	China_Steel_Circular_hollow_sections_CHS219_1x5 = ["China","Steel","Circular hollow sections","CHS219.1x5"]
	China_Steel_Circular_hollow_sections_CHS219_1x6 = ["China","Steel","Circular hollow sections","CHS219.1x6"]
	China_Steel_Circular_hollow_sections_CHS219_1x8 = ["China","Steel","Circular hollow sections","CHS219.1x8"]
	China_Steel_Circular_hollow_sections_CHS219_1x10 = ["China","Steel","Circular hollow sections","CHS219.1x10"]
	China_Steel_Circular_hollow_sections_CHS219x6 = ["China","Steel","Circular hollow sections","CHS219x6"]
	China_Steel_Circular_hollow_sections_CHS219x8 = ["China","Steel","Circular hollow sections","CHS219x8"]
	China_Steel_Circular_hollow_sections_CHS219x10 = ["China","Steel","Circular hollow sections","CHS219x10"]
	China_Steel_Circular_hollow_sections_CHS273x5 = ["China","Steel","Circular hollow sections","CHS273x5"]
	China_Steel_Circular_hollow_sections_CHS273x6 = ["China","Steel","Circular hollow sections","CHS273x6"]
	China_Steel_Circular_hollow_sections_CHS273x7 = ["China","Steel","Circular hollow sections","CHS273x7"]
	China_Steel_Circular_hollow_sections_CHS273x8 = ["China","Steel","Circular hollow sections","CHS273x8"]
	China_Steel_Circular_hollow_sections_CHS273x10 = ["China","Steel","Circular hollow sections","CHS273x10"]
	China_Steel_Circular_hollow_sections_CHS325x5 = ["China","Steel","Circular hollow sections","CHS325x5"]
	China_Steel_Circular_hollow_sections_CHS325x6 = ["China","Steel","Circular hollow sections","CHS325x6"]
	China_Steel_Circular_hollow_sections_CHS325x8 = ["China","Steel","Circular hollow sections","CHS325x8"]
	China_Steel_Circular_hollow_sections_CHS325x10 = ["China","Steel","Circular hollow sections","CHS325x10"]
	China_Steel_Circular_hollow_sections_CHS325x12 = ["China","Steel","Circular hollow sections","CHS325x12"]
	China_Steel_Circular_hollow_sections_CHS351x8 = ["China","Steel","Circular hollow sections","CHS351x8"]
	China_Steel_Circular_hollow_sections_CHS351x10 = ["China","Steel","Circular hollow sections","CHS351x10"]
	China_Steel_Circular_hollow_sections_CHS351x12 = ["China","Steel","Circular hollow sections","CHS351x12"]
	China_Steel_Circular_hollow_sections_CHS355_6x6 = ["China","Steel","Circular hollow sections","CHS355.6x6"]
	China_Steel_Circular_hollow_sections_CHS355_6x8 = ["China","Steel","Circular hollow sections","CHS355.6x8"]
	China_Steel_Circular_hollow_sections_CHS355_6x10 = ["China","Steel","Circular hollow sections","CHS355.6x10"]
	China_Steel_Circular_hollow_sections_CHS355_6x12 = ["China","Steel","Circular hollow sections","CHS355.6x12"]
	China_Steel_Circular_hollow_sections_CHS402x10 = ["China","Steel","Circular hollow sections","CHS402x10"]
	China_Steel_Circular_hollow_sections_CHS402x12 = ["China","Steel","Circular hollow sections","CHS402x12"]
	China_Steel_Circular_hollow_sections_CHS402x14 = ["China","Steel","Circular hollow sections","CHS402x14"]
	China_Steel_Circular_hollow_sections_CHS402x16 = ["China","Steel","Circular hollow sections","CHS402x16"]
	China_Steel_Circular_hollow_sections_CHS406_4x8 = ["China","Steel","Circular hollow sections","CHS406.4x8"]
	China_Steel_Circular_hollow_sections_CHS406_4x10 = ["China","Steel","Circular hollow sections","CHS406.4x10"]
	China_Steel_Circular_hollow_sections_CHS406_4x12 = ["China","Steel","Circular hollow sections","CHS406.4x12"]
	China_Steel_Circular_hollow_sections_CHS450x10 = ["China","Steel","Circular hollow sections","CHS450x10"]
	China_Steel_Circular_hollow_sections_CHS450x12 = ["China","Steel","Circular hollow sections","CHS450x12"]
	China_Steel_Circular_hollow_sections_CHS450x14 = ["China","Steel","Circular hollow sections","CHS450x14"]
	China_Steel_Circular_hollow_sections_CHS450x16 = ["China","Steel","Circular hollow sections","CHS450x16"]
	China_Steel_Circular_hollow_sections_CHS457x8 = ["China","Steel","Circular hollow sections","CHS457x8"]
	China_Steel_Circular_hollow_sections_CHS457x10 = ["China","Steel","Circular hollow sections","CHS457x10"]
	China_Steel_Circular_hollow_sections_CHS457x12 = ["China","Steel","Circular hollow sections","CHS457x12"]
	China_Steel_Circular_hollow_sections_CHS500x10 = ["China","Steel","Circular hollow sections","CHS500x10"]
	China_Steel_Circular_hollow_sections_CHS500x12 = ["China","Steel","Circular hollow sections","CHS500x12"]
	China_Steel_Circular_hollow_sections_CHS500x14 = ["China","Steel","Circular hollow sections","CHS500x14"]
	China_Steel_Circular_hollow_sections_CHS500x16 = ["China","Steel","Circular hollow sections","CHS500x16"]
	China_Steel_Circular_hollow_sections_CHS508x8 = ["China","Steel","Circular hollow sections","CHS508x8"]
	China_Steel_Circular_hollow_sections_CHS508x10 = ["China","Steel","Circular hollow sections","CHS508x10"]
	China_Steel_Circular_hollow_sections_CHS508x12 = ["China","Steel","Circular hollow sections","CHS508x12"]
	China_Steel_Circular_hollow_sections_CHS550x10 = ["China","Steel","Circular hollow sections","CHS550x10"]
	China_Steel_Circular_hollow_sections_CHS550x12 = ["China","Steel","Circular hollow sections","CHS550x12"]
	China_Steel_Circular_hollow_sections_CHS550x14 = ["China","Steel","Circular hollow sections","CHS550x14"]
	China_Steel_Circular_hollow_sections_CHS550x16 = ["China","Steel","Circular hollow sections","CHS550x16"]
	China_Steel_Circular_hollow_sections_CHS600x10 = ["China","Steel","Circular hollow sections","CHS600x10"]
	China_Steel_Circular_hollow_sections_CHS600x12 = ["China","Steel","Circular hollow sections","CHS600x12"]
	China_Steel_Circular_hollow_sections_CHS600x14 = ["China","Steel","Circular hollow sections","CHS600x14"]
	China_Steel_Circular_hollow_sections_CHS600x16 = ["China","Steel","Circular hollow sections","CHS600x16"]
	China_Steel_Circular_hollow_sections_CHS610x8 = ["China","Steel","Circular hollow sections","CHS610x8"]
	China_Steel_Circular_hollow_sections_CHS610x10 = ["China","Steel","Circular hollow sections","CHS610x10"]
	China_Steel_Circular_hollow_sections_CHS610x12_5 = ["China","Steel","Circular hollow sections","CHS610x12.5"]
	China_Steel_Circular_hollow_sections_CHS610x16 = ["China","Steel","Circular hollow sections","CHS610x16"]
	China_Steel_Circular_hollow_sections_CHS630x10 = ["China","Steel","Circular hollow sections","CHS630x10"]
	China_Steel_Circular_hollow_sections_CHS630x12 = ["China","Steel","Circular hollow sections","CHS630x12"]
	China_Steel_Circular_hollow_sections_CHS630x14 = ["China","Steel","Circular hollow sections","CHS630x14"]
	China_Steel_Circular_hollow_sections_CHS630x16 = ["China","Steel","Circular hollow sections","CHS630x16"]
	China_Steel_Column_Tees_TM74x100 = ["China","Steel","Column Tees","TM74x100"]
	China_Steel_Column_Tees_TM97x150 = ["China","Steel","Column Tees","TM97x150"]
	China_Steel_Column_Tees_TM122x175 = ["China","Steel","Column Tees","TM122x175"]
	China_Steel_Column_Tees_TM147x200 = ["China","Steel","Column Tees","TM147x200"]
	China_Steel_Column_Tees_TM149x201 = ["China","Steel","Column Tees","TM149x201"]
	China_Steel_Column_Tees_TM170x250 = ["China","Steel","Column Tees","TM170x250"]
	China_Steel_Column_Tees_TM195x300 = ["China","Steel","Column Tees","TM195x300"]
	China_Steel_Column_Tees_TM200x300 = ["China","Steel","Column Tees","TM200x300"]
	China_Steel_Column_Tees_TM220x300 = ["China","Steel","Column Tees","TM220x300"]
	China_Steel_Column_Tees_TM244x300 = ["China","Steel","Column Tees","TM244x300"]
	China_Steel_Column_Tees_TM272x300 = ["China","Steel","Column Tees","TM272x300"]
	China_Steel_Column_Tees_TM275x300 = ["China","Steel","Column Tees","TM275x300"]
	China_Steel_Column_Tees_TW50x100 = ["China","Steel","Column Tees","TW50x100"]
	China_Steel_Column_Tees_TW62_5x125 = ["China","Steel","Column Tees","TW62.5x125"]
	China_Steel_Column_Tees_TW75x150 = ["China","Steel","Column Tees","TW75x150"]
	China_Steel_Column_Tees_TW87_5x175 = ["China","Steel","Column Tees","TW87.5x175"]
	China_Steel_Column_Tees_TW100x200 = ["China","Steel","Column Tees","TW100x200"]
	China_Steel_Column_Tees_TW100x204 = ["China","Steel","Column Tees","TW100x204"]
	China_Steel_Column_Tees_TW125x250 = ["China","Steel","Column Tees","TW125x250"]
	China_Steel_Column_Tees_TW125x255 = ["China","Steel","Column Tees","TW125x255"]
	China_Steel_Column_Tees_TW147x302 = ["China","Steel","Column Tees","TW147x302"]
	China_Steel_Column_Tees_TW150x300 = ["China","Steel","Column Tees","TW150x300"]
	China_Steel_Column_Tees_TW150x305 = ["China","Steel","Column Tees","TW150x305"]
	China_Steel_Column_Tees_TW172x348 = ["China","Steel","Column Tees","TW172x348"]
	China_Steel_Column_Tees_TW175x350 = ["China","Steel","Column Tees","TW175x350"]
	China_Steel_Column_Tees_TW194x402 = ["China","Steel","Column Tees","TW194x402"]
	China_Steel_Column_Tees_TW197x398 = ["China","Steel","Column Tees","TW197x398"]
	China_Steel_Column_Tees_TW200x400 = ["China","Steel","Column Tees","TW200x400"]
	China_Steel_Column_Tees_TW200x408 = ["China","Steel","Column Tees","TW200x408"]
	China_Steel_Column_Tees_TW207x405 = ["China","Steel","Column Tees","TW207x405"]
	China_Steel_Column_Tees_TW214x407 = ["China","Steel","Column Tees","TW214x407"]
	China_Steel_Equal_angles_EA20x3 = ["China","Steel","Equal angles","EA20x3"]
	China_Steel_Equal_angles_EA20x4 = ["China","Steel","Equal angles","EA20x4"]
	China_Steel_Equal_angles_EA25x3 = ["China","Steel","Equal angles","EA25x3"]
	China_Steel_Equal_angles_EA25x4 = ["China","Steel","Equal angles","EA25x4"]
	China_Steel_Equal_angles_EA30x3 = ["China","Steel","Equal angles","EA30x3"]
	China_Steel_Equal_angles_EA30x4 = ["China","Steel","Equal angles","EA30x4"]
	China_Steel_Equal_angles_EA36x3 = ["China","Steel","Equal angles","EA36x3"]
	China_Steel_Equal_angles_EA36x4 = ["China","Steel","Equal angles","EA36x4"]
	China_Steel_Equal_angles_EA36x5 = ["China","Steel","Equal angles","EA36x5"]
	China_Steel_Equal_angles_EA40x3 = ["China","Steel","Equal angles","EA40x3"]
	China_Steel_Equal_angles_EA40x4 = ["China","Steel","Equal angles","EA40x4"]
	China_Steel_Equal_angles_EA40x5 = ["China","Steel","Equal angles","EA40x5"]
	China_Steel_Equal_angles_EA45x3 = ["China","Steel","Equal angles","EA45x3"]
	China_Steel_Equal_angles_EA45x4 = ["China","Steel","Equal angles","EA45x4"]
	China_Steel_Equal_angles_EA45x5 = ["China","Steel","Equal angles","EA45x5"]
	China_Steel_Equal_angles_EA45x6 = ["China","Steel","Equal angles","EA45x6"]
	China_Steel_Equal_angles_EA50x3 = ["China","Steel","Equal angles","EA50x3"]
	China_Steel_Equal_angles_EA50x4 = ["China","Steel","Equal angles","EA50x4"]
	China_Steel_Equal_angles_EA50x5 = ["China","Steel","Equal angles","EA50x5"]
	China_Steel_Equal_angles_EA50x6 = ["China","Steel","Equal angles","EA50x6"]
	China_Steel_Equal_angles_EA56x3 = ["China","Steel","Equal angles","EA56x3"]
	China_Steel_Equal_angles_EA56x4 = ["China","Steel","Equal angles","EA56x4"]
	China_Steel_Equal_angles_EA56x5 = ["China","Steel","Equal angles","EA56x5"]
	China_Steel_Equal_angles_EA56x6 = ["China","Steel","Equal angles","EA56x6"]
	China_Steel_Equal_angles_EA56x7 = ["China","Steel","Equal angles","EA56x7"]
	China_Steel_Equal_angles_EA56x8 = ["China","Steel","Equal angles","EA56x8"]
	China_Steel_Equal_angles_EA60x5 = ["China","Steel","Equal angles","EA60x5"]
	China_Steel_Equal_angles_EA60x6 = ["China","Steel","Equal angles","EA60x6"]
	China_Steel_Equal_angles_EA60x7 = ["China","Steel","Equal angles","EA60x7"]
	China_Steel_Equal_angles_EA60x8 = ["China","Steel","Equal angles","EA60x8"]
	China_Steel_Equal_angles_EA63x4 = ["China","Steel","Equal angles","EA63x4"]
	China_Steel_Equal_angles_EA63x5 = ["China","Steel","Equal angles","EA63x5"]
	China_Steel_Equal_angles_EA63x6 = ["China","Steel","Equal angles","EA63x6"]
	China_Steel_Equal_angles_EA63x7 = ["China","Steel","Equal angles","EA63x7"]
	China_Steel_Equal_angles_EA63x8 = ["China","Steel","Equal angles","EA63x8"]
	China_Steel_Equal_angles_EA63x10 = ["China","Steel","Equal angles","EA63x10"]
	China_Steel_Equal_angles_EA70x4 = ["China","Steel","Equal angles","EA70x4"]
	China_Steel_Equal_angles_EA70x5 = ["China","Steel","Equal angles","EA70x5"]
	China_Steel_Equal_angles_EA70x6 = ["China","Steel","Equal angles","EA70x6"]
	China_Steel_Equal_angles_EA70x7 = ["China","Steel","Equal angles","EA70x7"]
	China_Steel_Equal_angles_EA70x8 = ["China","Steel","Equal angles","EA70x8"]
	China_Steel_Equal_angles_EA75x5 = ["China","Steel","Equal angles","EA75x5"]
	China_Steel_Equal_angles_EA75x6 = ["China","Steel","Equal angles","EA75x6"]
	China_Steel_Equal_angles_EA75x7 = ["China","Steel","Equal angles","EA75x7"]
	China_Steel_Equal_angles_EA75x8 = ["China","Steel","Equal angles","EA75x8"]
	China_Steel_Equal_angles_EA75x9 = ["China","Steel","Equal angles","EA75x9"]
	China_Steel_Equal_angles_EA75x10 = ["China","Steel","Equal angles","EA75x10"]
	China_Steel_Equal_angles_EA80x5 = ["China","Steel","Equal angles","EA80x5"]
	China_Steel_Equal_angles_EA80x6 = ["China","Steel","Equal angles","EA80x6"]
	China_Steel_Equal_angles_EA80x7 = ["China","Steel","Equal angles","EA80x7"]
	China_Steel_Equal_angles_EA80x8 = ["China","Steel","Equal angles","EA80x8"]
	China_Steel_Equal_angles_EA80x9 = ["China","Steel","Equal angles","EA80x9"]
	China_Steel_Equal_angles_EA80x10 = ["China","Steel","Equal angles","EA80x10"]
	China_Steel_Equal_angles_EA90x6 = ["China","Steel","Equal angles","EA90x6"]
	China_Steel_Equal_angles_EA90x7 = ["China","Steel","Equal angles","EA90x7"]
	China_Steel_Equal_angles_EA90x8 = ["China","Steel","Equal angles","EA90x8"]
	China_Steel_Equal_angles_EA90x9 = ["China","Steel","Equal angles","EA90x9"]
	China_Steel_Equal_angles_EA90x10 = ["China","Steel","Equal angles","EA90x10"]
	China_Steel_Equal_angles_EA90x12 = ["China","Steel","Equal angles","EA90x12"]
	China_Steel_Equal_angles_EA100x6 = ["China","Steel","Equal angles","EA100x6"]
	China_Steel_Equal_angles_EA100x7 = ["China","Steel","Equal angles","EA100x7"]
	China_Steel_Equal_angles_EA100x8 = ["China","Steel","Equal angles","EA100x8"]
	China_Steel_Equal_angles_EA100x9 = ["China","Steel","Equal angles","EA100x9"]
	China_Steel_Equal_angles_EA100x10 = ["China","Steel","Equal angles","EA100x10"]
	China_Steel_Equal_angles_EA100x12 = ["China","Steel","Equal angles","EA100x12"]
	China_Steel_Equal_angles_EA100x14 = ["China","Steel","Equal angles","EA100x14"]
	China_Steel_Equal_angles_EA100x16 = ["China","Steel","Equal angles","EA100x16"]
	China_Steel_Equal_angles_EA110x7 = ["China","Steel","Equal angles","EA110x7"]
	China_Steel_Equal_angles_EA110x8 = ["China","Steel","Equal angles","EA110x8"]
	China_Steel_Equal_angles_EA110x10 = ["China","Steel","Equal angles","EA110x10"]
	China_Steel_Equal_angles_EA110x12 = ["China","Steel","Equal angles","EA110x12"]
	China_Steel_Equal_angles_EA110x14 = ["China","Steel","Equal angles","EA110x14"]
	China_Steel_Equal_angles_EA125x8 = ["China","Steel","Equal angles","EA125x8"]
	China_Steel_Equal_angles_EA125x10 = ["China","Steel","Equal angles","EA125x10"]
	China_Steel_Equal_angles_EA125x12 = ["China","Steel","Equal angles","EA125x12"]
	China_Steel_Equal_angles_EA125x14 = ["China","Steel","Equal angles","EA125x14"]
	China_Steel_Equal_angles_EA125x16 = ["China","Steel","Equal angles","EA125x16"]
	China_Steel_Equal_angles_EA140x10 = ["China","Steel","Equal angles","EA140x10"]
	China_Steel_Equal_angles_EA140x12 = ["China","Steel","Equal angles","EA140x12"]
	China_Steel_Equal_angles_EA140x14 = ["China","Steel","Equal angles","EA140x14"]
	China_Steel_Equal_angles_EA140x16 = ["China","Steel","Equal angles","EA140x16"]
	China_Steel_Equal_angles_EA150x8 = ["China","Steel","Equal angles","EA150x8"]
	China_Steel_Equal_angles_EA150x10 = ["China","Steel","Equal angles","EA150x10"]
	China_Steel_Equal_angles_EA150x12 = ["China","Steel","Equal angles","EA150x12"]
	China_Steel_Equal_angles_EA150x14 = ["China","Steel","Equal angles","EA150x14"]
	China_Steel_Equal_angles_EA150x15 = ["China","Steel","Equal angles","EA150x15"]
	China_Steel_Equal_angles_EA150x16 = ["China","Steel","Equal angles","EA150x16"]
	China_Steel_Equal_angles_EA160x10 = ["China","Steel","Equal angles","EA160x10"]
	China_Steel_Equal_angles_EA160x12 = ["China","Steel","Equal angles","EA160x12"]
	China_Steel_Equal_angles_EA160x14 = ["China","Steel","Equal angles","EA160x14"]
	China_Steel_Equal_angles_EA160x16 = ["China","Steel","Equal angles","EA160x16"]
	China_Steel_Equal_angles_EA180x12 = ["China","Steel","Equal angles","EA180x12"]
	China_Steel_Equal_angles_EA180x14 = ["China","Steel","Equal angles","EA180x14"]
	China_Steel_Equal_angles_EA180x16 = ["China","Steel","Equal angles","EA180x16"]
	China_Steel_Equal_angles_EA180x18 = ["China","Steel","Equal angles","EA180x18"]
	China_Steel_Equal_angles_EA200x14 = ["China","Steel","Equal angles","EA200x14"]
	China_Steel_Equal_angles_EA200x16 = ["China","Steel","Equal angles","EA200x16"]
	China_Steel_Equal_angles_EA200x18 = ["China","Steel","Equal angles","EA200x18"]
	China_Steel_Equal_angles_EA200x20 = ["China","Steel","Equal angles","EA200x20"]
	China_Steel_Equal_angles_EA200x24 = ["China","Steel","Equal angles","EA200x24"]
	China_Steel_Equal_angles_EA220x16 = ["China","Steel","Equal angles","EA220x16"]
	China_Steel_Equal_angles_EA220x18 = ["China","Steel","Equal angles","EA220x18"]
	China_Steel_Equal_angles_EA220x20 = ["China","Steel","Equal angles","EA220x20"]
	China_Steel_Equal_angles_EA220x22 = ["China","Steel","Equal angles","EA220x22"]
	China_Steel_Equal_angles_EA220x24 = ["China","Steel","Equal angles","EA220x24"]
	China_Steel_Equal_angles_EA220x26 = ["China","Steel","Equal angles","EA220x26"]
	China_Steel_Equal_angles_EA250x18 = ["China","Steel","Equal angles","EA250x18"]
	China_Steel_Equal_angles_EA250x20 = ["China","Steel","Equal angles","EA250x20"]
	China_Steel_Equal_angles_EA250x24 = ["China","Steel","Equal angles","EA250x24"]
	China_Steel_Equal_angles_EA250x26 = ["China","Steel","Equal angles","EA250x26"]
	China_Steel_Equal_angles_EA250x28 = ["China","Steel","Equal angles","EA250x28"]
	China_Steel_Equal_angles_EA250x30 = ["China","Steel","Equal angles","EA250x30"]
	China_Steel_Equal_angles_EA250x32 = ["China","Steel","Equal angles","EA250x32"]
	China_Steel_Equal_angles_EA250x35 = ["China","Steel","Equal angles","EA250x35"]
	China_Steel_HM_beams_HM148x100 = ["China","Steel","HM beams","HM148x100"]
	China_Steel_HM_beams_HM194x150 = ["China","Steel","HM beams","HM194x150"]
	China_Steel_HM_beams_HM244x175 = ["China","Steel","HM beams","HM244x175"]
	China_Steel_HM_beams_HM294x200 = ["China","Steel","HM beams","HM294x200"]
	China_Steel_HM_beams_HM340x250 = ["China","Steel","HM beams","HM340x250"]
	China_Steel_HM_beams_HM390x300 = ["China","Steel","HM beams","HM390x300"]
	China_Steel_HM_beams_HM440x300 = ["China","Steel","HM beams","HM440x300"]
	China_Steel_HM_beams_HM482x300 = ["China","Steel","HM beams","HM482x300"]
	China_Steel_HM_beams_HM488x300 = ["China","Steel","HM beams","HM488x300"]
	China_Steel_HM_beams_HM544x300 = ["China","Steel","HM beams","HM544x300"]
	China_Steel_HM_beams_HM550x300 = ["China","Steel","HM beams","HM550x300"]
	China_Steel_HM_beams_HM582x300 = ["China","Steel","HM beams","HM582x300"]
	China_Steel_HM_beams_HM588x300 = ["China","Steel","HM beams","HM588x300"]
	China_Steel_HM_beams_HM594x302 = ["China","Steel","HM beams","HM594x302"]
	China_Steel_HM_beams_MH298x201 = ["China","Steel","HM beams","MH298x201"]
	China_Steel_HN_beams_HN100x50 = ["China","Steel","HN beams","HN100x50"]
	China_Steel_HN_beams_HN125x60 = ["China","Steel","HN beams","HN125x60"]
	China_Steel_HN_beams_HN150x75 = ["China","Steel","HN beams","HN150x75"]
	China_Steel_HN_beams_HN175x90 = ["China","Steel","HN beams","HN175x90"]
	China_Steel_HN_beams_HN198x99 = ["China","Steel","HN beams","HN198x99"]
	China_Steel_HN_beams_HN200x100 = ["China","Steel","HN beams","HN200x100"]
	China_Steel_HN_beams_HN248x124 = ["China","Steel","HN beams","HN248x124"]
	China_Steel_HN_beams_HN250x125 = ["China","Steel","HN beams","HN250x125"]
	China_Steel_HN_beams_HN298x149 = ["China","Steel","HN beams","HN298x149"]
	China_Steel_HN_beams_HN300x150 = ["China","Steel","HN beams","HN300x150"]
	China_Steel_HN_beams_HN346x174 = ["China","Steel","HN beams","HN346x174"]
	China_Steel_HN_beams_HN350x175 = ["China","Steel","HN beams","HN350x175"]
	China_Steel_HN_beams_HN396x199 = ["China","Steel","HN beams","HN396x199"]
	China_Steel_HN_beams_HN400x150 = ["China","Steel","HN beams","HN400x150"]
	China_Steel_HN_beams_HN400x200 = ["China","Steel","HN beams","HN400x200"]
	China_Steel_HN_beams_HN446x150 = ["China","Steel","HN beams","HN446x150"]
	China_Steel_HN_beams_HN446x199 = ["China","Steel","HN beams","HN446x199"]
	China_Steel_HN_beams_HN450x151 = ["China","Steel","HN beams","HN450x151"]
	China_Steel_HN_beams_HN450x200 = ["China","Steel","HN beams","HN450x200"]
	China_Steel_HN_beams_HN470x150 = ["China","Steel","HN beams","HN470x150"]
	China_Steel_HN_beams_HN475x151_5 = ["China","Steel","HN beams","HN475x151.5"]
	China_Steel_HN_beams_HN482x153_5 = ["China","Steel","HN beams","HN482x153.5"]
	China_Steel_HN_beams_HN492x150 = ["China","Steel","HN beams","HN492x150"]
	China_Steel_HN_beams_HN496x199 = ["China","Steel","HN beams","HN496x199"]
	China_Steel_HN_beams_HN500x150 = ["China","Steel","HN beams","HN500x150"]
	China_Steel_HN_beams_HN500x152 = ["China","Steel","HN beams","HN500x152"]
	China_Steel_HN_beams_HN500x200 = ["China","Steel","HN beams","HN500x200"]
	China_Steel_HN_beams_HN504x153 = ["China","Steel","HN beams","HN504x153"]
	China_Steel_HN_beams_HN506x201 = ["China","Steel","HN beams","HN506x201"]
	China_Steel_HN_beams_HN546x199 = ["China","Steel","HN beams","HN546x199"]
	China_Steel_HN_beams_HN550x200 = ["China","Steel","HN beams","HN550x200"]
	China_Steel_HN_beams_HN596x199 = ["China","Steel","HN beams","HN596x199"]
	China_Steel_HN_beams_HN600x200 = ["China","Steel","HN beams","HN600x200"]
	China_Steel_HN_beams_HN606x201 = ["China","Steel","HN beams","HN606x201"]
	China_Steel_HN_beams_HN625x198_5 = ["China","Steel","HN beams","HN625x198.5"]
	China_Steel_HN_beams_HN630x200 = ["China","Steel","HN beams","HN630x200"]
	China_Steel_HN_beams_HN638x202 = ["China","Steel","HN beams","HN638x202"]
	China_Steel_HN_beams_HN646x299 = ["China","Steel","HN beams","HN646x299"]
	China_Steel_HN_beams_HN650x300 = ["China","Steel","HN beams","HN650x300"]
	China_Steel_HN_beams_HN656x301 = ["China","Steel","HN beams","HN656x301"]
	China_Steel_HN_beams_HN692x300 = ["China","Steel","HN beams","HN692x300"]
	China_Steel_HN_beams_HN700x300 = ["China","Steel","HN beams","HN700x300"]
	China_Steel_HN_beams_HN734x299 = ["China","Steel","HN beams","HN734x299"]
	China_Steel_HN_beams_HN742x300 = ["China","Steel","HN beams","HN742x300"]
	China_Steel_HN_beams_HN750x300 = ["China","Steel","HN beams","HN750x300"]
	China_Steel_HN_beams_HN758x303 = ["China","Steel","HN beams","HN758x303"]
	China_Steel_HN_beams_HN792x300 = ["China","Steel","HN beams","HN792x300"]
	China_Steel_HN_beams_HN800x300 = ["China","Steel","HN beams","HN800x300"]
	China_Steel_HN_beams_HN834x298 = ["China","Steel","HN beams","HN834x298"]
	China_Steel_HN_beams_HN842x299 = ["China","Steel","HN beams","HN842x299"]
	China_Steel_HN_beams_HN850x300 = ["China","Steel","HN beams","HN850x300"]
	China_Steel_HN_beams_HN858x301 = ["China","Steel","HN beams","HN858x301"]
	China_Steel_HN_beams_HN890x299 = ["China","Steel","HN beams","HN890x299"]
	China_Steel_HN_beams_HN900x300 = ["China","Steel","HN beams","HN900x300"]
	China_Steel_HN_beams_HN912x302 = ["China","Steel","HN beams","HN912x302"]
	China_Steel_HN_beams_HN970x297 = ["China","Steel","HN beams","HN970x297"]
	China_Steel_HN_beams_HN980x298 = ["China","Steel","HN beams","HN980x298"]
	China_Steel_HN_beams_HN990x298 = ["China","Steel","HN beams","HN990x298"]
	China_Steel_HN_beams_HN1000x300 = ["China","Steel","HN beams","HN1000x300"]
	China_Steel_HN_beams_HN1008x302 = ["China","Steel","HN beams","HN1008x302"]
	China_Steel_HP_columns_HP200x200 = ["China","Steel","HP columns","HP200x200"]
	China_Steel_HP_columns_HP200x204 = ["China","Steel","HP columns","HP200x204"]
	China_Steel_HP_columns_HP244x252 = ["China","Steel","HP columns","HP244x252"]
	China_Steel_HP_columns_HP250x250 = ["China","Steel","HP columns","HP250x250"]
	China_Steel_HP_columns_HP250x255 = ["China","Steel","HP columns","HP250x255"]
	China_Steel_HP_columns_HP294x302 = ["China","Steel","HP columns","HP294x302"]
	China_Steel_HP_columns_HP300x300 = ["China","Steel","HP columns","HP300x300"]
	China_Steel_HP_columns_HP300x305 = ["China","Steel","HP columns","HP300x305"]
	China_Steel_HP_columns_HP338x351 = ["China","Steel","HP columns","HP338x351"]
	China_Steel_HP_columns_HP344x348 = ["China","Steel","HP columns","HP344x348"]
	China_Steel_HP_columns_HP344x354 = ["China","Steel","HP columns","HP344x354"]
	China_Steel_HP_columns_HP350x350 = ["China","Steel","HP columns","HP350x350"]
	China_Steel_HP_columns_HP350x357 = ["China","Steel","HP columns","HP350x357"]
	China_Steel_HP_columns_HP388x402 = ["China","Steel","HP columns","HP388x402"]
	China_Steel_HP_columns_HP394x405 = ["China","Steel","HP columns","HP394x405"]
	China_Steel_HP_columns_HP400x400 = ["China","Steel","HP columns","HP400x400"]
	China_Steel_HP_columns_HP400x408 = ["China","Steel","HP columns","HP400x408"]
	China_Steel_HP_columns_HP414x405 = ["China","Steel","HP columns","HP414x405"]
	China_Steel_HP_columns_HP428x407 = ["China","Steel","HP columns","HP428x407"]
	China_Steel_HP_columns_HP458x417 = ["China","Steel","HP columns","HP458x417"]
	China_Steel_HP_columns_HP492x465 = ["China","Steel","HP columns","HP492x465"]
	China_Steel_HP_columns_HP498x432 = ["China","Steel","HP columns","HP498x432"]
	China_Steel_HP_columns_HP502x465 = ["China","Steel","HP columns","HP502x465"]
	China_Steel_HP_columns_HP502x470 = ["China","Steel","HP columns","HP502x470"]
	China_Steel_HT_beams_HT95x48 = ["China","Steel","HT beams","HT95x48"]
	China_Steel_HT_beams_HT96x99 = ["China","Steel","HT beams","HT96x99"]
	China_Steel_HT_beams_HT97x49 = ["China","Steel","HT beams","HT97x49"]
	China_Steel_HT_beams_HT118x58 = ["China","Steel","HT beams","HT118x58"]
	China_Steel_HT_beams_HT119x123 = ["China","Steel","HT beams","HT119x123"]
	China_Steel_HT_beams_HT120x59 = ["China","Steel","HT beams","HT120x59"]
	China_Steel_HT_beams_HT139x97 = ["China","Steel","HT beams","HT139x97"]
	China_Steel_HT_beams_HT142x99 = ["China","Steel","HT beams","HT142x99"]
	China_Steel_HT_beams_HT144x148 = ["China","Steel","HT beams","HT144x148"]
	China_Steel_HT_beams_HT145x73 = ["China","Steel","HT beams","HT145x73"]
	China_Steel_HT_beams_HT147x74 = ["China","Steel","HT beams","HT147x74"]
	China_Steel_HT_beams_HT147x149 = ["China","Steel","HT beams","HT147x149"]
	China_Steel_HT_beams_HT167x173 = ["China","Steel","HT beams","HT167x173"]
	China_Steel_HT_beams_HT168x88 = ["China","Steel","HT beams","HT168x88"]
	China_Steel_HT_beams_HT171x89 = ["China","Steel","HT beams","HT171x89"]
	China_Steel_HT_beams_HT172x175 = ["China","Steel","HT beams","HT172x175"]
	China_Steel_HT_beams_HT188x149 = ["China","Steel","HT beams","HT188x149"]
	China_Steel_HT_beams_HT192x198 = ["China","Steel","HT beams","HT192x198"]
	China_Steel_HT_beams_HT193x98 = ["China","Steel","HT beams","HT193x98"]
	China_Steel_HT_beams_HT196x99 = ["China","Steel","HT beams","HT196x99"]
	China_Steel_HT_beams_HT238x173 = ["China","Steel","HT beams","HT238x173"]
	China_Steel_HT_beams_HT244x124 = ["China","Steel","HT beams","HT244x124"]
	China_Steel_HT_beams_HT286x198 = ["China","Steel","HT beams","HT286x198"]
	China_Steel_HT_beams_HT294x148 = ["China","Steel","HT beams","HT294x148"]
	China_Steel_HT_beams_HT340x173 = ["China","Steel","HT beams","HT340x173"]
	China_Steel_HT_beams_HT390x148 = ["China","Steel","HT beams","HT390x148"]
	China_Steel_HT_beams_HT390x198 = ["China","Steel","HT beams","HT390x198"]
	China_Steel_HW_columns_HW100x100 = ["China","Steel","HW columns","HW100x100"]
	China_Steel_HW_columns_HW125x125 = ["China","Steel","HW columns","HW125x125"]
	China_Steel_HW_columns_HW150x150 = ["China","Steel","HW columns","HW150x150"]
	China_Steel_HW_columns_HW175x175 = ["China","Steel","HW columns","HW175x175"]
	China_Steel_HW_columns_HW200x200 = ["China","Steel","HW columns","HW200x200"]
	China_Steel_HW_columns_HW200x204 = ["China","Steel","HW columns","HW200x204"]
	China_Steel_HW_columns_HW244x252 = ["China","Steel","HW columns","HW244x252"]
	China_Steel_HW_columns_HW250x250 = ["China","Steel","HW columns","HW250x250"]
	China_Steel_HW_columns_HW250x255 = ["China","Steel","HW columns","HW250x255"]
	China_Steel_HW_columns_HW294x302 = ["China","Steel","HW columns","HW294x302"]
	China_Steel_HW_columns_HW300x300 = ["China","Steel","HW columns","HW300x300"]
	China_Steel_HW_columns_HW300x305 = ["China","Steel","HW columns","HW300x305"]
	China_Steel_HW_columns_HW338x351 = ["China","Steel","HW columns","HW338x351"]
	China_Steel_HW_columns_HW344x348 = ["China","Steel","HW columns","HW344x348"]
	China_Steel_HW_columns_HW344x354 = ["China","Steel","HW columns","HW344x354"]
	China_Steel_HW_columns_HW350x350 = ["China","Steel","HW columns","HW350x350"]
	China_Steel_HW_columns_HW350x357 = ["China","Steel","HW columns","HW350x357"]
	China_Steel_HW_columns_HW388x402 = ["China","Steel","HW columns","HW388x402"]
	China_Steel_HW_columns_HW394x398 = ["China","Steel","HW columns","HW394x398"]
	China_Steel_HW_columns_HW394x405 = ["China","Steel","HW columns","HW394x405"]
	China_Steel_HW_columns_HW400x400 = ["China","Steel","HW columns","HW400x400"]
	China_Steel_HW_columns_HW400x408 = ["China","Steel","HW columns","HW400x408"]
	China_Steel_HW_columns_HW414x405 = ["China","Steel","HW columns","HW414x405"]
	China_Steel_HW_columns_HW428x407 = ["China","Steel","HW columns","HW428x407"]
	China_Steel_HW_columns_HW458x417 = ["China","Steel","HW columns","HW458x417"]
	China_Steel_HW_columns_HW492x465 = ["China","Steel","HW columns","HW492x465"]
	China_Steel_HW_columns_HW498x432 = ["China","Steel","HW columns","HW498x432"]
	China_Steel_HW_columns_HW502x465 = ["China","Steel","HW columns","HW502x465"]
	China_Steel_HW_columns_HW502x470 = ["China","Steel","HW columns","HW502x470"]
	China_Steel_I_Shape_I10 = ["China","Steel","I Shape","I10"]
	China_Steel_I_Shape_I12 = ["China","Steel","I Shape","I12"]
	China_Steel_I_Shape_I12_6 = ["China","Steel","I Shape","I12.6"]
	China_Steel_I_Shape_I14 = ["China","Steel","I Shape","I14"]
	China_Steel_I_Shape_I16 = ["China","Steel","I Shape","I16"]
	China_Steel_I_Shape_I18 = ["China","Steel","I Shape","I18"]
	China_Steel_I_Shape_I20a = ["China","Steel","I Shape","I20a"]
	China_Steel_I_Shape_I20b = ["China","Steel","I Shape","I20b"]
	China_Steel_I_Shape_I22a = ["China","Steel","I Shape","I22a"]
	China_Steel_I_Shape_I22b = ["China","Steel","I Shape","I22b"]
	China_Steel_I_Shape_I24a = ["China","Steel","I Shape","I24a"]
	China_Steel_I_Shape_I24b = ["China","Steel","I Shape","I24b"]
	China_Steel_I_Shape_I25a = ["China","Steel","I Shape","I25a"]
	China_Steel_I_Shape_I25b = ["China","Steel","I Shape","I25b"]
	China_Steel_I_Shape_I27a = ["China","Steel","I Shape","I27a"]
	China_Steel_I_Shape_I27b = ["China","Steel","I Shape","I27b"]
	China_Steel_I_Shape_I28a = ["China","Steel","I Shape","I28a"]
	China_Steel_I_Shape_I28b = ["China","Steel","I Shape","I28b"]
	China_Steel_I_Shape_I30a = ["China","Steel","I Shape","I30a"]
	China_Steel_I_Shape_I30b = ["China","Steel","I Shape","I30b"]
	China_Steel_I_Shape_I30c = ["China","Steel","I Shape","I30c"]
	China_Steel_I_Shape_I32a = ["China","Steel","I Shape","I32a"]
	China_Steel_I_Shape_I32b = ["China","Steel","I Shape","I32b"]
	China_Steel_I_Shape_I32c = ["China","Steel","I Shape","I32c"]
	China_Steel_I_Shape_I36a = ["China","Steel","I Shape","I36a"]
	China_Steel_I_Shape_I36b = ["China","Steel","I Shape","I36b"]
	China_Steel_I_Shape_I36c = ["China","Steel","I Shape","I36c"]
	China_Steel_I_Shape_I40a = ["China","Steel","I Shape","I40a"]
	China_Steel_I_Shape_I40b = ["China","Steel","I Shape","I40b"]
	China_Steel_I_Shape_I40c = ["China","Steel","I Shape","I40c"]
	China_Steel_I_Shape_I45a = ["China","Steel","I Shape","I45a"]
	China_Steel_I_Shape_I45b = ["China","Steel","I Shape","I45b"]
	China_Steel_I_Shape_I45c = ["China","Steel","I Shape","I45c"]
	China_Steel_I_Shape_I50a = ["China","Steel","I Shape","I50a"]
	China_Steel_I_Shape_I50b = ["China","Steel","I Shape","I50b"]
	China_Steel_I_Shape_I50c = ["China","Steel","I Shape","I50c"]
	China_Steel_I_Shape_I55a = ["China","Steel","I Shape","I55a"]
	China_Steel_I_Shape_I55b = ["China","Steel","I Shape","I55b"]
	China_Steel_I_Shape_I55c = ["China","Steel","I Shape","I55c"]
	China_Steel_I_Shape_I56a = ["China","Steel","I Shape","I56a"]
	China_Steel_I_Shape_I56b = ["China","Steel","I Shape","I56b"]
	China_Steel_I_Shape_I56c = ["China","Steel","I Shape","I56c"]
	China_Steel_I_Shape_I63a = ["China","Steel","I Shape","I63a"]
	China_Steel_I_Shape_I63b = ["China","Steel","I Shape","I63b"]
	China_Steel_I_Shape_I63c = ["China","Steel","I Shape","I63c"]
	China_Steel_Rectangular_tubes_RT30x20x1_5 = ["China","Steel","Rectangular tubes","RT30x20x1.5"]
	China_Steel_Rectangular_tubes_RT30x20x1_75 = ["China","Steel","Rectangular tubes","RT30x20x1.75"]
	China_Steel_Rectangular_tubes_RT30x20x2 = ["China","Steel","Rectangular tubes","RT30x20x2"]
	China_Steel_Rectangular_tubes_RT30x20x2_5 = ["China","Steel","Rectangular tubes","RT30x20x2.5"]
	China_Steel_Rectangular_tubes_RT40x20x1_5 = ["China","Steel","Rectangular tubes","RT40x20x1.5"]
	China_Steel_Rectangular_tubes_RT40x20x1_75 = ["China","Steel","Rectangular tubes","RT40x20x1.75"]
	China_Steel_Rectangular_tubes_RT40x20x2 = ["China","Steel","Rectangular tubes","RT40x20x2"]
	China_Steel_Rectangular_tubes_RT40x20x2_5 = ["China","Steel","Rectangular tubes","RT40x20x2.5"]
	China_Steel_Rectangular_tubes_RT40x20x3 = ["China","Steel","Rectangular tubes","RT40x20x3"]
	China_Steel_Rectangular_tubes_RT40x25x1_5 = ["China","Steel","Rectangular tubes","RT40x25x1.5"]
	China_Steel_Rectangular_tubes_RT40x25x1_75 = ["China","Steel","Rectangular tubes","RT40x25x1.75"]
	China_Steel_Rectangular_tubes_RT40x25x2 = ["China","Steel","Rectangular tubes","RT40x25x2"]
	China_Steel_Rectangular_tubes_RT40x25x2_5 = ["China","Steel","Rectangular tubes","RT40x25x2.5"]
	China_Steel_Rectangular_tubes_RT40x25x3 = ["China","Steel","Rectangular tubes","RT40x25x3"]
	China_Steel_Rectangular_tubes_RT40x30x1_5 = ["China","Steel","Rectangular tubes","RT40x30x1.5"]
	China_Steel_Rectangular_tubes_RT40x30x1_75 = ["China","Steel","Rectangular tubes","RT40x30x1.75"]
	China_Steel_Rectangular_tubes_RT40x30x2 = ["China","Steel","Rectangular tubes","RT40x30x2"]
	China_Steel_Rectangular_tubes_RT40x30x2_5 = ["China","Steel","Rectangular tubes","RT40x30x2.5"]
	China_Steel_Rectangular_tubes_RT40x30x3 = ["China","Steel","Rectangular tubes","RT40x30x3"]
	China_Steel_Rectangular_tubes_RT50x25x1_5 = ["China","Steel","Rectangular tubes","RT50x25x1.5"]
	China_Steel_Rectangular_tubes_RT50x25x1_75 = ["China","Steel","Rectangular tubes","RT50x25x1.75"]
	China_Steel_Rectangular_tubes_RT50x25x2 = ["China","Steel","Rectangular tubes","RT50x25x2"]
	China_Steel_Rectangular_tubes_RT50x25x2_5 = ["China","Steel","Rectangular tubes","RT50x25x2.5"]
	China_Steel_Rectangular_tubes_RT50x25x3 = ["China","Steel","Rectangular tubes","RT50x25x3"]
	China_Steel_Rectangular_tubes_RT50x30x1_5 = ["China","Steel","Rectangular tubes","RT50x30x1.5"]
	China_Steel_Rectangular_tubes_RT50x30x1_75 = ["China","Steel","Rectangular tubes","RT50x30x1.75"]
	China_Steel_Rectangular_tubes_RT50x30x2 = ["China","Steel","Rectangular tubes","RT50x30x2"]
	China_Steel_Rectangular_tubes_RT50x30x2_5 = ["China","Steel","Rectangular tubes","RT50x30x2.5"]
	China_Steel_Rectangular_tubes_RT50x30x3 = ["China","Steel","Rectangular tubes","RT50x30x3"]
	China_Steel_Rectangular_tubes_RT50x30x4 = ["China","Steel","Rectangular tubes","RT50x30x4"]
	China_Steel_Rectangular_tubes_RT50x40x1_5 = ["China","Steel","Rectangular tubes","RT50x40x1.5"]
	China_Steel_Rectangular_tubes_RT50x40x1_75 = ["China","Steel","Rectangular tubes","RT50x40x1.75"]
	China_Steel_Rectangular_tubes_RT50x40x2 = ["China","Steel","Rectangular tubes","RT50x40x2"]
	China_Steel_Rectangular_tubes_RT50x40x2_5 = ["China","Steel","Rectangular tubes","RT50x40x2.5"]
	China_Steel_Rectangular_tubes_RT50x40x3 = ["China","Steel","Rectangular tubes","RT50x40x3"]
	China_Steel_Rectangular_tubes_RT50x40x4 = ["China","Steel","Rectangular tubes","RT50x40x4"]
	China_Steel_Rectangular_tubes_RT55x25x1_5 = ["China","Steel","Rectangular tubes","RT55x25x1.5"]
	China_Steel_Rectangular_tubes_RT55x25x1_75 = ["China","Steel","Rectangular tubes","RT55x25x1.75"]
	China_Steel_Rectangular_tubes_RT55x25x2 = ["China","Steel","Rectangular tubes","RT55x25x2"]
	China_Steel_Rectangular_tubes_RT55x40x1_5 = ["China","Steel","Rectangular tubes","RT55x40x1.5"]
	China_Steel_Rectangular_tubes_RT55x40x1_75 = ["China","Steel","Rectangular tubes","RT55x40x1.75"]
	China_Steel_Rectangular_tubes_RT55x40x2 = ["China","Steel","Rectangular tubes","RT55x40x2"]
	China_Steel_Rectangular_tubes_RT55x50x1_75 = ["China","Steel","Rectangular tubes","RT55x50x1.75"]
	China_Steel_Rectangular_tubes_RT55x50x2 = ["China","Steel","Rectangular tubes","RT55x50x2"]
	China_Steel_Rectangular_tubes_RT60x30x2 = ["China","Steel","Rectangular tubes","RT60x30x2"]
	China_Steel_Rectangular_tubes_RT60x30x2_5 = ["China","Steel","Rectangular tubes","RT60x30x2.5"]
	China_Steel_Rectangular_tubes_RT60x30x3 = ["China","Steel","Rectangular tubes","RT60x30x3"]
	China_Steel_Rectangular_tubes_RT60x30x4 = ["China","Steel","Rectangular tubes","RT60x30x4"]
	China_Steel_Rectangular_tubes_RT60x40x2 = ["China","Steel","Rectangular tubes","RT60x40x2"]
	China_Steel_Rectangular_tubes_RT60x40x2_5 = ["China","Steel","Rectangular tubes","RT60x40x2.5"]
	China_Steel_Rectangular_tubes_RT60x40x3 = ["China","Steel","Rectangular tubes","RT60x40x3"]
	China_Steel_Rectangular_tubes_RT60x40x4 = ["China","Steel","Rectangular tubes","RT60x40x4"]
	China_Steel_Rectangular_tubes_RT70x50x2 = ["China","Steel","Rectangular tubes","RT70x50x2"]
	China_Steel_Rectangular_tubes_RT70x50x3 = ["China","Steel","Rectangular tubes","RT70x50x3"]
	China_Steel_Rectangular_tubes_RT70x50x4 = ["China","Steel","Rectangular tubes","RT70x50x4"]
	China_Steel_Rectangular_tubes_RT70x50x5 = ["China","Steel","Rectangular tubes","RT70x50x5"]
	China_Steel_Rectangular_tubes_RT80x40x2 = ["China","Steel","Rectangular tubes","RT80x40x2"]
	China_Steel_Rectangular_tubes_RT80x40x2_5 = ["China","Steel","Rectangular tubes","RT80x40x2.5"]
	China_Steel_Rectangular_tubes_RT80x40x3 = ["China","Steel","Rectangular tubes","RT80x40x3"]
	China_Steel_Rectangular_tubes_RT80x40x4 = ["China","Steel","Rectangular tubes","RT80x40x4"]
	China_Steel_Rectangular_tubes_RT80x40x5 = ["China","Steel","Rectangular tubes","RT80x40x5"]
	China_Steel_Rectangular_tubes_RT80x60x3 = ["China","Steel","Rectangular tubes","RT80x60x3"]
	China_Steel_Rectangular_tubes_RT80x60x4 = ["China","Steel","Rectangular tubes","RT80x60x4"]
	China_Steel_Rectangular_tubes_RT80x60x5 = ["China","Steel","Rectangular tubes","RT80x60x5"]
	China_Steel_Rectangular_tubes_RT90x40x3 = ["China","Steel","Rectangular tubes","RT90x40x3"]
	China_Steel_Rectangular_tubes_RT90x40x4 = ["China","Steel","Rectangular tubes","RT90x40x4"]
	China_Steel_Rectangular_tubes_RT90x40x5 = ["China","Steel","Rectangular tubes","RT90x40x5"]
	China_Steel_Rectangular_tubes_RT90x50x2 = ["China","Steel","Rectangular tubes","RT90x50x2"]
	China_Steel_Rectangular_tubes_RT90x50x2_5 = ["China","Steel","Rectangular tubes","RT90x50x2.5"]
	China_Steel_Rectangular_tubes_RT90x50x3 = ["China","Steel","Rectangular tubes","RT90x50x3"]
	China_Steel_Rectangular_tubes_RT90x50x4 = ["China","Steel","Rectangular tubes","RT90x50x4"]
	China_Steel_Rectangular_tubes_RT90x50x5 = ["China","Steel","Rectangular tubes","RT90x50x5"]
	China_Steel_Rectangular_tubes_RT90x55x2 = ["China","Steel","Rectangular tubes","RT90x55x2"]
	China_Steel_Rectangular_tubes_RT90x55x2_5 = ["China","Steel","Rectangular tubes","RT90x55x2.5"]
	China_Steel_Rectangular_tubes_RT90x60x3 = ["China","Steel","Rectangular tubes","RT90x60x3"]
	China_Steel_Rectangular_tubes_RT90x60x4 = ["China","Steel","Rectangular tubes","RT90x60x4"]
	China_Steel_Rectangular_tubes_RT90x60x5 = ["China","Steel","Rectangular tubes","RT90x60x5"]
	China_Steel_Rectangular_tubes_RT95x50x2 = ["China","Steel","Rectangular tubes","RT95x50x2"]
	China_Steel_Rectangular_tubes_RT95x50x2_5 = ["China","Steel","Rectangular tubes","RT95x50x2.5"]
	China_Steel_Rectangular_tubes_RT100x50x3 = ["China","Steel","Rectangular tubes","RT100x50x3"]
	China_Steel_Rectangular_tubes_RT100x50x4 = ["China","Steel","Rectangular tubes","RT100x50x4"]
	China_Steel_Rectangular_tubes_RT100x50x5 = ["China","Steel","Rectangular tubes","RT100x50x5"]
	China_Steel_Rectangular_tubes_RT120x50x2_5 = ["China","Steel","Rectangular tubes","RT120x50x2.5"]
	China_Steel_Rectangular_tubes_RT120x50x3 = ["China","Steel","Rectangular tubes","RT120x50x3"]
	China_Steel_Rectangular_tubes_RT120x60x3 = ["China","Steel","Rectangular tubes","RT120x60x3"]
	China_Steel_Rectangular_tubes_RT120x60x4 = ["China","Steel","Rectangular tubes","RT120x60x4"]
	China_Steel_Rectangular_tubes_RT120x60x5 = ["China","Steel","Rectangular tubes","RT120x60x5"]
	China_Steel_Rectangular_tubes_RT120x60x6 = ["China","Steel","Rectangular tubes","RT120x60x6"]
	China_Steel_Rectangular_tubes_RT120x80x3 = ["China","Steel","Rectangular tubes","RT120x80x3"]
	China_Steel_Rectangular_tubes_RT120x80x4 = ["China","Steel","Rectangular tubes","RT120x80x4"]
	China_Steel_Rectangular_tubes_RT120x80x5 = ["China","Steel","Rectangular tubes","RT120x80x5"]
	China_Steel_Rectangular_tubes_RT120x80x6 = ["China","Steel","Rectangular tubes","RT120x80x6"]
	China_Steel_Rectangular_tubes_RT140x80x4 = ["China","Steel","Rectangular tubes","RT140x80x4"]
	China_Steel_Rectangular_tubes_RT140x80x5 = ["China","Steel","Rectangular tubes","RT140x80x5"]
	China_Steel_Rectangular_tubes_RT140x80x6 = ["China","Steel","Rectangular tubes","RT140x80x6"]
	China_Steel_Rectangular_tubes_RT150x100x4 = ["China","Steel","Rectangular tubes","RT150x100x4"]
	China_Steel_Rectangular_tubes_RT150x100x5 = ["China","Steel","Rectangular tubes","RT150x100x5"]
	China_Steel_Rectangular_tubes_RT150x100x6 = ["China","Steel","Rectangular tubes","RT150x100x6"]
	China_Steel_Rectangular_tubes_RT150x100x8 = ["China","Steel","Rectangular tubes","RT150x100x8"]
	China_Steel_Rectangular_tubes_RT160x60x3 = ["China","Steel","Rectangular tubes","RT160x60x3"]
	China_Steel_Rectangular_tubes_RT160x60x4_5 = ["China","Steel","Rectangular tubes","RT160x60x4.5"]
	China_Steel_Rectangular_tubes_RT160x80x4 = ["China","Steel","Rectangular tubes","RT160x80x4"]
	China_Steel_Rectangular_tubes_RT160x80x5 = ["China","Steel","Rectangular tubes","RT160x80x5"]
	China_Steel_Rectangular_tubes_RT160x80x6 = ["China","Steel","Rectangular tubes","RT160x80x6"]
	China_Steel_Rectangular_tubes_RT160x80x8 = ["China","Steel","Rectangular tubes","RT160x80x8"]
	China_Steel_Rectangular_tubes_RT180x65x3 = ["China","Steel","Rectangular tubes","RT180x65x3"]
	China_Steel_Rectangular_tubes_RT180x65x4_5 = ["China","Steel","Rectangular tubes","RT180x65x4.5"]
	China_Steel_Rectangular_tubes_RT180x100x4 = ["China","Steel","Rectangular tubes","RT180x100x4"]
	China_Steel_Rectangular_tubes_RT180x100x5 = ["China","Steel","Rectangular tubes","RT180x100x5"]
	China_Steel_Rectangular_tubes_RT180x100x6 = ["China","Steel","Rectangular tubes","RT180x100x6"]
	China_Steel_Rectangular_tubes_RT180x100x8 = ["China","Steel","Rectangular tubes","RT180x100x8"]
	China_Steel_Rectangular_tubes_RT200x100x4 = ["China","Steel","Rectangular tubes","RT200x100x4"]
	China_Steel_Rectangular_tubes_RT200x100x5 = ["China","Steel","Rectangular tubes","RT200x100x5"]
	China_Steel_Rectangular_tubes_RT200x100x6 = ["China","Steel","Rectangular tubes","RT200x100x6"]
	China_Steel_Rectangular_tubes_RT200x100x8 = ["China","Steel","Rectangular tubes","RT200x100x8"]
	China_Steel_Rectangular_tubes_RT200x120x4 = ["China","Steel","Rectangular tubes","RT200x120x4"]
	China_Steel_Rectangular_tubes_RT200x120x5 = ["China","Steel","Rectangular tubes","RT200x120x5"]
	China_Steel_Rectangular_tubes_RT200x120x6 = ["China","Steel","Rectangular tubes","RT200x120x6"]
	China_Steel_Rectangular_tubes_RT200x120x8 = ["China","Steel","Rectangular tubes","RT200x120x8"]
	China_Steel_Rectangular_tubes_RT200x150x4 = ["China","Steel","Rectangular tubes","RT200x150x4"]
	China_Steel_Rectangular_tubes_RT200x150x5 = ["China","Steel","Rectangular tubes","RT200x150x5"]
	China_Steel_Rectangular_tubes_RT200x150x6 = ["China","Steel","Rectangular tubes","RT200x150x6"]
	China_Steel_Rectangular_tubes_RT200x150x8 = ["China","Steel","Rectangular tubes","RT200x150x8"]
	China_Steel_Rectangular_tubes_RT220x140x4 = ["China","Steel","Rectangular tubes","RT220x140x4"]
	China_Steel_Rectangular_tubes_RT220x140x5 = ["China","Steel","Rectangular tubes","RT220x140x5"]
	China_Steel_Rectangular_tubes_RT220x140x6 = ["China","Steel","Rectangular tubes","RT220x140x6"]
	China_Steel_Rectangular_tubes_RT220x140x8 = ["China","Steel","Rectangular tubes","RT220x140x8"]
	China_Steel_Rectangular_tubes_RT250x150x4 = ["China","Steel","Rectangular tubes","RT250x150x4"]
	China_Steel_Rectangular_tubes_RT250x150x5 = ["China","Steel","Rectangular tubes","RT250x150x5"]
	China_Steel_Rectangular_tubes_RT250x150x6 = ["China","Steel","Rectangular tubes","RT250x150x6"]
	China_Steel_Rectangular_tubes_RT250x150x8 = ["China","Steel","Rectangular tubes","RT250x150x8"]
	China_Steel_Rectangular_tubes_RT260x180x5 = ["China","Steel","Rectangular tubes","RT260x180x5"]
	China_Steel_Rectangular_tubes_RT260x180x6 = ["China","Steel","Rectangular tubes","RT260x180x6"]
	China_Steel_Rectangular_tubes_RT260x180x8 = ["China","Steel","Rectangular tubes","RT260x180x8"]
	China_Steel_Rectangular_tubes_RT260x180x10 = ["China","Steel","Rectangular tubes","RT260x180x10"]
	China_Steel_Rectangular_tubes_RT300x200x5 = ["China","Steel","Rectangular tubes","RT300x200x5"]
	China_Steel_Rectangular_tubes_RT300x200x6 = ["China","Steel","Rectangular tubes","RT300x200x6"]
	China_Steel_Rectangular_tubes_RT300x200x8 = ["China","Steel","Rectangular tubes","RT300x200x8"]
	China_Steel_Rectangular_tubes_RT300x200x10 = ["China","Steel","Rectangular tubes","RT300x200x10"]
	China_Steel_Rectangular_tubes_RT350x250x5 = ["China","Steel","Rectangular tubes","RT350x250x5"]
	China_Steel_Rectangular_tubes_RT350x250x6 = ["China","Steel","Rectangular tubes","RT350x250x6"]
	China_Steel_Rectangular_tubes_RT350x250x8 = ["China","Steel","Rectangular tubes","RT350x250x8"]
	China_Steel_Rectangular_tubes_RT350x250x10 = ["China","Steel","Rectangular tubes","RT350x250x10"]
	China_Steel_Rectangular_tubes_RT400x200x5 = ["China","Steel","Rectangular tubes","RT400x200x5"]
	China_Steel_Rectangular_tubes_RT400x200x6 = ["China","Steel","Rectangular tubes","RT400x200x6"]
	China_Steel_Rectangular_tubes_RT400x200x8 = ["China","Steel","Rectangular tubes","RT400x200x8"]
	China_Steel_Rectangular_tubes_RT400x200x10 = ["China","Steel","Rectangular tubes","RT400x200x10"]
	China_Steel_Rectangular_tubes_RT400x200x12 = ["China","Steel","Rectangular tubes","RT400x200x12"]
	China_Steel_Rectangular_tubes_RT400x250x5 = ["China","Steel","Rectangular tubes","RT400x250x5"]
	China_Steel_Rectangular_tubes_RT400x250x6 = ["China","Steel","Rectangular tubes","RT400x250x6"]
	China_Steel_Rectangular_tubes_RT400x250x8 = ["China","Steel","Rectangular tubes","RT400x250x8"]
	China_Steel_Rectangular_tubes_RT400x250x10 = ["China","Steel","Rectangular tubes","RT400x250x10"]
	China_Steel_Rectangular_tubes_RT400x250x12 = ["China","Steel","Rectangular tubes","RT400x250x12"]
	China_Steel_Rectangular_tubes_RT450x250x6 = ["China","Steel","Rectangular tubes","RT450x250x6"]
	China_Steel_Rectangular_tubes_RT450x250x8 = ["China","Steel","Rectangular tubes","RT450x250x8"]
	China_Steel_Rectangular_tubes_RT450x250x10 = ["China","Steel","Rectangular tubes","RT450x250x10"]
	China_Steel_Rectangular_tubes_RT450x250x12 = ["China","Steel","Rectangular tubes","RT450x250x12"]
	China_Steel_Rectangular_tubes_RT500x300x6 = ["China","Steel","Rectangular tubes","RT500x300x6"]
	China_Steel_Rectangular_tubes_RT500x300x8 = ["China","Steel","Rectangular tubes","RT500x300x8"]
	China_Steel_Rectangular_tubes_RT500x300x10 = ["China","Steel","Rectangular tubes","RT500x300x10"]
	China_Steel_Rectangular_tubes_RT500x300x12 = ["China","Steel","Rectangular tubes","RT500x300x12"]
	China_Steel_Rectangular_tubes_RT550x350x8 = ["China","Steel","Rectangular tubes","RT550x350x8"]
	China_Steel_Rectangular_tubes_RT550x350x10 = ["China","Steel","Rectangular tubes","RT550x350x10"]
	China_Steel_Rectangular_tubes_RT550x350x12 = ["China","Steel","Rectangular tubes","RT550x350x12"]
	China_Steel_Rectangular_tubes_RT550x350x14 = ["China","Steel","Rectangular tubes","RT550x350x14"]
	China_Steel_Rectangular_tubes_RT600x400x8 = ["China","Steel","Rectangular tubes","RT600x400x8"]
	China_Steel_Rectangular_tubes_RT600x400x10 = ["China","Steel","Rectangular tubes","RT600x400x10"]
	China_Steel_Rectangular_tubes_RT600x400x12 = ["China","Steel","Rectangular tubes","RT600x400x12"]
	China_Steel_Rectangular_tubes_RT600x400x14 = ["China","Steel","Rectangular tubes","RT600x400x14"]
	China_Steel_Rectangular_tubes_RT600x400x16 = ["China","Steel","Rectangular tubes","RT600x400x16"]
	China_Steel_Square_tubes_ST20x20x1_2 = ["China","Steel","Square tubes","ST20x20x1.2"]
	China_Steel_Square_tubes_ST20x20x1_5 = ["China","Steel","Square tubes","ST20x20x1.5"]
	China_Steel_Square_tubes_ST20x20x1_75 = ["China","Steel","Square tubes","ST20x20x1.75"]
	China_Steel_Square_tubes_ST20x20x2_0 = ["China","Steel","Square tubes","ST20x20x2.0"]
	China_Steel_Square_tubes_ST25x25x1_2 = ["China","Steel","Square tubes","ST25x25x1.2"]
	China_Steel_Square_tubes_ST25x25x1_5 = ["China","Steel","Square tubes","ST25x25x1.5"]
	China_Steel_Square_tubes_ST25x25x1_75 = ["China","Steel","Square tubes","ST25x25x1.75"]
	China_Steel_Square_tubes_ST25x25x2 = ["China","Steel","Square tubes","ST25x25x2"]
	China_Steel_Square_tubes_ST30x30x1_5 = ["China","Steel","Square tubes","ST30x30x1.5"]
	China_Steel_Square_tubes_ST30x30x1_75 = ["China","Steel","Square tubes","ST30x30x1.75"]
	China_Steel_Square_tubes_ST30x30x2 = ["China","Steel","Square tubes","ST30x30x2"]
	China_Steel_Square_tubes_ST30x30x2_5 = ["China","Steel","Square tubes","ST30x30x2.5"]
	China_Steel_Square_tubes_ST30x30x3 = ["China","Steel","Square tubes","ST30x30x3"]
	China_Steel_Square_tubes_ST40x40x1_5 = ["China","Steel","Square tubes","ST40x40x1.5"]
	China_Steel_Square_tubes_ST40x40x1_75 = ["China","Steel","Square tubes","ST40x40x1.75"]
	China_Steel_Square_tubes_ST40x40x2 = ["China","Steel","Square tubes","ST40x40x2"]
	China_Steel_Square_tubes_ST40x40x2_5 = ["China","Steel","Square tubes","ST40x40x2.5"]
	China_Steel_Square_tubes_ST40x40x3 = ["China","Steel","Square tubes","ST40x40x3"]
	China_Steel_Square_tubes_ST40x40x4 = ["China","Steel","Square tubes","ST40x40x4"]
	China_Steel_Square_tubes_ST50x50x1_5 = ["China","Steel","Square tubes","ST50x50x1.5"]
	China_Steel_Square_tubes_ST50x50x1_75 = ["China","Steel","Square tubes","ST50x50x1.75"]
	China_Steel_Square_tubes_ST50x50x2 = ["China","Steel","Square tubes","ST50x50x2"]
	China_Steel_Square_tubes_ST50x50x2_5 = ["China","Steel","Square tubes","ST50x50x2.5"]
	China_Steel_Square_tubes_ST50x50x3 = ["China","Steel","Square tubes","ST50x50x3"]
	China_Steel_Square_tubes_ST50x50x4 = ["China","Steel","Square tubes","ST50x50x4"]
	China_Steel_Square_tubes_ST60x60x2 = ["China","Steel","Square tubes","ST60x60x2"]
	China_Steel_Square_tubes_ST60x60x2_5 = ["China","Steel","Square tubes","ST60x60x2.5"]
	China_Steel_Square_tubes_ST60x60x3 = ["China","Steel","Square tubes","ST60x60x3"]
	China_Steel_Square_tubes_ST60x60x4 = ["China","Steel","Square tubes","ST60x60x4"]
	China_Steel_Square_tubes_ST60x60x5 = ["China","Steel","Square tubes","ST60x60x5"]
	China_Steel_Square_tubes_ST70x70x2_5 = ["China","Steel","Square tubes","ST70x70x2.5"]
	China_Steel_Square_tubes_ST70x70x3 = ["China","Steel","Square tubes","ST70x70x3"]
	China_Steel_Square_tubes_ST70x70x4 = ["China","Steel","Square tubes","ST70x70x4"]
	China_Steel_Square_tubes_ST70x70x5 = ["China","Steel","Square tubes","ST70x70x5"]
	China_Steel_Square_tubes_ST80x80x2_5 = ["China","Steel","Square tubes","ST80x80x2.5"]
	China_Steel_Square_tubes_ST80x80x3 = ["China","Steel","Square tubes","ST80x80x3"]
	China_Steel_Square_tubes_ST80x80x4 = ["China","Steel","Square tubes","ST80x80x4"]
	China_Steel_Square_tubes_ST80x80x5 = ["China","Steel","Square tubes","ST80x80x5"]
	China_Steel_Square_tubes_ST90x90x3 = ["China","Steel","Square tubes","ST90x90x3"]
	China_Steel_Square_tubes_ST90x90x4 = ["China","Steel","Square tubes","ST90x90x4"]
	China_Steel_Square_tubes_ST90x90x5 = ["China","Steel","Square tubes","ST90x90x5"]
	China_Steel_Square_tubes_ST90x90x6 = ["China","Steel","Square tubes","ST90x90x6"]
	China_Steel_Square_tubes_ST100x100x4 = ["China","Steel","Square tubes","ST100x100x4"]
	China_Steel_Square_tubes_ST100x100x5 = ["China","Steel","Square tubes","ST100x100x5"]
	China_Steel_Square_tubes_ST100x100x6 = ["China","Steel","Square tubes","ST100x100x6"]
	China_Steel_Square_tubes_ST110x110x4 = ["China","Steel","Square tubes","ST110x110x4"]
	China_Steel_Square_tubes_ST110x110x5 = ["China","Steel","Square tubes","ST110x110x5"]
	China_Steel_Square_tubes_ST110x110x6 = ["China","Steel","Square tubes","ST110x110x6"]
	China_Steel_Square_tubes_ST120x120x4 = ["China","Steel","Square tubes","ST120x120x4"]
	China_Steel_Square_tubes_ST120x120x5 = ["China","Steel","Square tubes","ST120x120x5"]
	China_Steel_Square_tubes_ST120x120x6 = ["China","Steel","Square tubes","ST120x120x6"]
	China_Steel_Square_tubes_ST120x120x8 = ["China","Steel","Square tubes","ST120x120x8"]
	China_Steel_Square_tubes_ST130x130x4 = ["China","Steel","Square tubes","ST130x130x4"]
	China_Steel_Square_tubes_ST130x130x5 = ["China","Steel","Square tubes","ST130x130x5"]
	China_Steel_Square_tubes_ST130x130x6 = ["China","Steel","Square tubes","ST130x130x6"]
	China_Steel_Square_tubes_ST130x130x8 = ["China","Steel","Square tubes","ST130x130x8"]
	China_Steel_Square_tubes_ST140x140x4 = ["China","Steel","Square tubes","ST140x140x4"]
	China_Steel_Square_tubes_ST140x140x5 = ["China","Steel","Square tubes","ST140x140x5"]
	China_Steel_Square_tubes_ST140x140x6 = ["China","Steel","Square tubes","ST140x140x6"]
	China_Steel_Square_tubes_ST140x140x8 = ["China","Steel","Square tubes","ST140x140x8"]
	China_Steel_Square_tubes_ST150x150x4 = ["China","Steel","Square tubes","ST150x150x4"]
	China_Steel_Square_tubes_ST150x150x5 = ["China","Steel","Square tubes","ST150x150x5"]
	China_Steel_Square_tubes_ST150x150x6 = ["China","Steel","Square tubes","ST150x150x6"]
	China_Steel_Square_tubes_ST150x150x8 = ["China","Steel","Square tubes","ST150x150x8"]
	China_Steel_Square_tubes_ST160x160x4 = ["China","Steel","Square tubes","ST160x160x4"]
	China_Steel_Square_tubes_ST160x160x5 = ["China","Steel","Square tubes","ST160x160x5"]
	China_Steel_Square_tubes_ST160x160x6 = ["China","Steel","Square tubes","ST160x160x6"]
	China_Steel_Square_tubes_ST160x160x8 = ["China","Steel","Square tubes","ST160x160x8"]
	China_Steel_Square_tubes_ST170x170x4 = ["China","Steel","Square tubes","ST170x170x4"]
	China_Steel_Square_tubes_ST170x170x5 = ["China","Steel","Square tubes","ST170x170x5"]
	China_Steel_Square_tubes_ST170x170x6 = ["China","Steel","Square tubes","ST170x170x6"]
	China_Steel_Square_tubes_ST170x170x8 = ["China","Steel","Square tubes","ST170x170x8"]
	China_Steel_Square_tubes_ST180x180x4 = ["China","Steel","Square tubes","ST180x180x4"]
	China_Steel_Square_tubes_ST180x180x5 = ["China","Steel","Square tubes","ST180x180x5"]
	China_Steel_Square_tubes_ST180x180x6 = ["China","Steel","Square tubes","ST180x180x6"]
	China_Steel_Square_tubes_ST180x180x8 = ["China","Steel","Square tubes","ST180x180x8"]
	China_Steel_Square_tubes_ST190x190x4 = ["China","Steel","Square tubes","ST190x190x4"]
	China_Steel_Square_tubes_ST190x190x5 = ["China","Steel","Square tubes","ST190x190x5"]
	China_Steel_Square_tubes_ST190x190x6 = ["China","Steel","Square tubes","ST190x190x6"]
	China_Steel_Square_tubes_ST190x190x8 = ["China","Steel","Square tubes","ST190x190x8"]
	China_Steel_Square_tubes_ST200x200x4 = ["China","Steel","Square tubes","ST200x200x4"]
	China_Steel_Square_tubes_ST200x200x5 = ["China","Steel","Square tubes","ST200x200x5"]
	China_Steel_Square_tubes_ST200x200x6 = ["China","Steel","Square tubes","ST200x200x6"]
	China_Steel_Square_tubes_ST200x200x8 = ["China","Steel","Square tubes","ST200x200x8"]
	China_Steel_Square_tubes_ST200x200x10 = ["China","Steel","Square tubes","ST200x200x10"]
	China_Steel_Square_tubes_ST220x220x5 = ["China","Steel","Square tubes","ST220x220x5"]
	China_Steel_Square_tubes_ST220x220x6 = ["China","Steel","Square tubes","ST220x220x6"]
	China_Steel_Square_tubes_ST220x220x8 = ["China","Steel","Square tubes","ST220x220x8"]
	China_Steel_Square_tubes_ST220x220x10 = ["China","Steel","Square tubes","ST220x220x10"]
	China_Steel_Square_tubes_ST220x220x12 = ["China","Steel","Square tubes","ST220x220x12"]
	China_Steel_Square_tubes_ST250x250x5 = ["China","Steel","Square tubes","ST250x250x5"]
	China_Steel_Square_tubes_ST250x250x6 = ["China","Steel","Square tubes","ST250x250x6"]
	China_Steel_Square_tubes_ST250x250x8 = ["China","Steel","Square tubes","ST250x250x8"]
	China_Steel_Square_tubes_ST250x250x10 = ["China","Steel","Square tubes","ST250x250x10"]
	China_Steel_Square_tubes_ST250x250x12 = ["China","Steel","Square tubes","ST250x250x12"]
	China_Steel_Square_tubes_ST280x280x5 = ["China","Steel","Square tubes","ST280x280x5"]
	China_Steel_Square_tubes_ST280x280x6 = ["China","Steel","Square tubes","ST280x280x6"]
	China_Steel_Square_tubes_ST280x280x8 = ["China","Steel","Square tubes","ST280x280x8"]
	China_Steel_Square_tubes_ST280x280x10 = ["China","Steel","Square tubes","ST280x280x10"]
	China_Steel_Square_tubes_ST280x280x12 = ["China","Steel","Square tubes","ST280x280x12"]
	China_Steel_Square_tubes_ST300x300x6 = ["China","Steel","Square tubes","ST300x300x6"]
	China_Steel_Square_tubes_ST300x300x8 = ["China","Steel","Square tubes","ST300x300x8"]
	China_Steel_Square_tubes_ST300x300x10 = ["China","Steel","Square tubes","ST300x300x10"]
	China_Steel_Square_tubes_ST300x300x12 = ["China","Steel","Square tubes","ST300x300x12"]
	China_Steel_Square_tubes_ST350x350x6 = ["China","Steel","Square tubes","ST350x350x6"]
	China_Steel_Square_tubes_ST350x350x8 = ["China","Steel","Square tubes","ST350x350x8"]
	China_Steel_Square_tubes_ST350x350x10 = ["China","Steel","Square tubes","ST350x350x10"]
	China_Steel_Square_tubes_ST350x350x12 = ["China","Steel","Square tubes","ST350x350x12"]
	China_Steel_Square_tubes_ST400x400x8 = ["China","Steel","Square tubes","ST400x400x8"]
	China_Steel_Square_tubes_ST400x400x10 = ["China","Steel","Square tubes","ST400x400x10"]
	China_Steel_Square_tubes_ST400x400x12 = ["China","Steel","Square tubes","ST400x400x12"]
	China_Steel_Square_tubes_ST400x400x14 = ["China","Steel","Square tubes","ST400x400x14"]
	China_Steel_Square_tubes_ST450x450x8 = ["China","Steel","Square tubes","ST450x450x8"]
	China_Steel_Square_tubes_ST450x450x10 = ["China","Steel","Square tubes","ST450x450x10"]
	China_Steel_Square_tubes_ST450x450x12 = ["China","Steel","Square tubes","ST450x450x12"]
	China_Steel_Square_tubes_ST450x450x14 = ["China","Steel","Square tubes","ST450x450x14"]
	China_Steel_Square_tubes_ST500x500x8 = ["China","Steel","Square tubes","ST500x500x8"]
	China_Steel_Square_tubes_ST500x500x10 = ["China","Steel","Square tubes","ST500x500x10"]
	China_Steel_Square_tubes_ST500x500x12 = ["China","Steel","Square tubes","ST500x500x12"]
	China_Steel_Square_tubes_ST500x500x14 = ["China","Steel","Square tubes","ST500x500x14"]
	China_Steel_Square_tubes_ST500x500x16 = ["China","Steel","Square tubes","ST500x500x16"]
	China_Steel_Unequal_angles_UA25x16x3 = ["China","Steel","Unequal angles","UA25x16x3"]
	China_Steel_Unequal_angles_UA25x16x4 = ["China","Steel","Unequal angles","UA25x16x4"]
	China_Steel_Unequal_angles_UA32x20x3 = ["China","Steel","Unequal angles","UA32x20x3"]
	China_Steel_Unequal_angles_UA32x20x4 = ["China","Steel","Unequal angles","UA32x20x4"]
	China_Steel_Unequal_angles_UA40x25x3 = ["China","Steel","Unequal angles","UA40x25x3"]
	China_Steel_Unequal_angles_UA40x25x4 = ["China","Steel","Unequal angles","UA40x25x4"]
	China_Steel_Unequal_angles_UA45x28x3 = ["China","Steel","Unequal angles","UA45x28x3"]
	China_Steel_Unequal_angles_UA45x28x4 = ["China","Steel","Unequal angles","UA45x28x4"]
	China_Steel_Unequal_angles_UA50x32x3 = ["China","Steel","Unequal angles","UA50x32x3"]
	China_Steel_Unequal_angles_UA50x32x4 = ["China","Steel","Unequal angles","UA50x32x4"]
	China_Steel_Unequal_angles_UA56x36x3 = ["China","Steel","Unequal angles","UA56x36x3"]
	China_Steel_Unequal_angles_UA56x36x4 = ["China","Steel","Unequal angles","UA56x36x4"]
	China_Steel_Unequal_angles_UA56x36x5 = ["China","Steel","Unequal angles","UA56x36x5"]
	China_Steel_Unequal_angles_UA63x40x4 = ["China","Steel","Unequal angles","UA63x40x4"]
	China_Steel_Unequal_angles_UA63x40x5 = ["China","Steel","Unequal angles","UA63x40x5"]
	China_Steel_Unequal_angles_UA63x40x6 = ["China","Steel","Unequal angles","UA63x40x6"]
	China_Steel_Unequal_angles_UA63x40x7 = ["China","Steel","Unequal angles","UA63x40x7"]
	China_Steel_Unequal_angles_UA70x45x4 = ["China","Steel","Unequal angles","UA70x45x4"]
	China_Steel_Unequal_angles_UA70x45x5 = ["China","Steel","Unequal angles","UA70x45x5"]
	China_Steel_Unequal_angles_UA70x45x6 = ["China","Steel","Unequal angles","UA70x45x6"]
	China_Steel_Unequal_angles_UA70x45x7 = ["China","Steel","Unequal angles","UA70x45x7"]
	China_Steel_Unequal_angles_UA75x50x5 = ["China","Steel","Unequal angles","UA75x50x5"]
	China_Steel_Unequal_angles_UA75x50x6 = ["China","Steel","Unequal angles","UA75x50x6"]
	China_Steel_Unequal_angles_UA75x50x8 = ["China","Steel","Unequal angles","UA75x50x8"]
	China_Steel_Unequal_angles_UA75x50x10 = ["China","Steel","Unequal angles","UA75x50x10"]
	China_Steel_Unequal_angles_UA80x50x5 = ["China","Steel","Unequal angles","UA80x50x5"]
	China_Steel_Unequal_angles_UA80x50x6 = ["China","Steel","Unequal angles","UA80x50x6"]
	China_Steel_Unequal_angles_UA80x50x7 = ["China","Steel","Unequal angles","UA80x50x7"]
	China_Steel_Unequal_angles_UA80x50x8 = ["China","Steel","Unequal angles","UA80x50x8"]
	China_Steel_Unequal_angles_UA90x56x5 = ["China","Steel","Unequal angles","UA90x56x5"]
	China_Steel_Unequal_angles_UA90x56x6 = ["China","Steel","Unequal angles","UA90x56x6"]
	China_Steel_Unequal_angles_UA90x56x7 = ["China","Steel","Unequal angles","UA90x56x7"]
	China_Steel_Unequal_angles_UA90x56x8 = ["China","Steel","Unequal angles","UA90x56x8"]
	China_Steel_Unequal_angles_UA100x63x6 = ["China","Steel","Unequal angles","UA100x63x6"]
	China_Steel_Unequal_angles_UA100x63x7 = ["China","Steel","Unequal angles","UA100x63x7"]
	China_Steel_Unequal_angles_UA100x63x8 = ["China","Steel","Unequal angles","UA100x63x8"]
	China_Steel_Unequal_angles_UA100x63x10 = ["China","Steel","Unequal angles","UA100x63x10"]
	China_Steel_Unequal_angles_UA100x80x6 = ["China","Steel","Unequal angles","UA100x80x6"]
	China_Steel_Unequal_angles_UA100x80x7 = ["China","Steel","Unequal angles","UA100x80x7"]
	China_Steel_Unequal_angles_UA100x80x8 = ["China","Steel","Unequal angles","UA100x80x8"]
	China_Steel_Unequal_angles_UA100x80x10 = ["China","Steel","Unequal angles","UA100x80x10"]
	China_Steel_Unequal_angles_UA110x70x6 = ["China","Steel","Unequal angles","UA110x70x6"]
	China_Steel_Unequal_angles_UA110x70x7 = ["China","Steel","Unequal angles","UA110x70x7"]
	China_Steel_Unequal_angles_UA110x70x8 = ["China","Steel","Unequal angles","UA110x70x8"]
	China_Steel_Unequal_angles_UA110x70x10 = ["China","Steel","Unequal angles","UA110x70x10"]
	China_Steel_Unequal_angles_UA125x80x7 = ["China","Steel","Unequal angles","UA125x80x7"]
	China_Steel_Unequal_angles_UA125x80x8 = ["China","Steel","Unequal angles","UA125x80x8"]
	China_Steel_Unequal_angles_UA125x80x10 = ["China","Steel","Unequal angles","UA125x80x10"]
	China_Steel_Unequal_angles_UA125x80x12 = ["China","Steel","Unequal angles","UA125x80x12"]
	China_Steel_Unequal_angles_UA140x90x8 = ["China","Steel","Unequal angles","UA140x90x8"]
	China_Steel_Unequal_angles_UA140x90x10 = ["China","Steel","Unequal angles","UA140x90x10"]
	China_Steel_Unequal_angles_UA140x90x12 = ["China","Steel","Unequal angles","UA140x90x12"]
	China_Steel_Unequal_angles_UA140x90x14 = ["China","Steel","Unequal angles","UA140x90x14"]
	China_Steel_Unequal_angles_UA150x90x8 = ["China","Steel","Unequal angles","UA150x90x8"]
	China_Steel_Unequal_angles_UA150x90x10 = ["China","Steel","Unequal angles","UA150x90x10"]
	China_Steel_Unequal_angles_UA150x90x12 = ["China","Steel","Unequal angles","UA150x90x12"]
	China_Steel_Unequal_angles_UA150x90x14 = ["China","Steel","Unequal angles","UA150x90x14"]
	China_Steel_Unequal_angles_UA150x90x15 = ["China","Steel","Unequal angles","UA150x90x15"]
	China_Steel_Unequal_angles_UA150x90x16 = ["China","Steel","Unequal angles","UA150x90x16"]
	China_Steel_Unequal_angles_UA160x100x10 = ["China","Steel","Unequal angles","UA160x100x10"]
	China_Steel_Unequal_angles_UA160x100x12 = ["China","Steel","Unequal angles","UA160x100x12"]
	China_Steel_Unequal_angles_UA160x100x14 = ["China","Steel","Unequal angles","UA160x100x14"]
	China_Steel_Unequal_angles_UA160x100x16 = ["China","Steel","Unequal angles","UA160x100x16"]
	China_Steel_Unequal_angles_UA180x110x10 = ["China","Steel","Unequal angles","UA180x110x10"]
	China_Steel_Unequal_angles_UA180x110x12 = ["China","Steel","Unequal angles","UA180x110x12"]
	China_Steel_Unequal_angles_UA180x110x14 = ["China","Steel","Unequal angles","UA180x110x14"]
	China_Steel_Unequal_angles_UA180x110x16 = ["China","Steel","Unequal angles","UA180x110x16"]
	China_Steel_Unequal_angles_UA200x125x12 = ["China","Steel","Unequal angles","UA200x125x12"]
	China_Steel_Unequal_angles_UA200x125x14 = ["China","Steel","Unequal angles","UA200x125x14"]
	China_Steel_Unequal_angles_UA200x125x16 = ["China","Steel","Unequal angles","UA200x125x16"]
	China_Steel_Unequal_angles_UA200x125x18 = ["China","Steel","Unequal angles","UA200x125x18"]
	China_Steel_W_shape_W375x394 = ["China","Steel","W shape","W375x394"]
	China_Steel_W_shape_W380x395 = ["China","Steel","W shape","W380x395"]
	China_Steel_W_shape_W387x398 = ["China","Steel","W shape","W387x398"]
	China_Steel_W_shape_W393x399 = ["China","Steel","W shape","W393x399"]
	China_Steel_W_shape_W399x401 = ["China","Steel","W shape","W399x401"]
	China_Steel_W_shape_W407x404 = ["China","Steel","W shape","W407x404"]
	China_Steel_W_shape_W416x406 = ["China","Steel","W shape","W416x406"]
	China_Steel_W_shape_W425x409 = ["China","Steel","W shape","W425x409"]
	China_Steel_W_shape_W435x412 = ["China","Steel","W shape","W435x412"]
	China_Steel_W_shape_W446x416 = ["China","Steel","W shape","W446x416"]
	China_Steel_W_shape_W455x418 = ["China","Steel","W shape","W455x418"]
	China_Steel_W_shape_W465x421 = ["China","Steel","W shape","W465x421"]
	China_Steel_W_shape_W474x424 = ["China","Steel","W shape","W474x424"]
	China_Steel_W_shape_W483x428 = ["China","Steel","W shape","W483x428"]
	China_Steel_W_shape_W498x432 = ["China","Steel","W shape","W498x432"]
	China_Steel_W_shape_W514x437 = ["China","Steel","W shape","W514x437"]
	China_Steel_W_shape_W531x442 = ["China","Steel","W shape","W531x442"]
	China_Steel_W_shape_W550x448 = ["China","Steel","W shape","W550x448"]
	China_Steel_W_shape_W569x454 = ["China","Steel","W shape","W569x454"]
	China_Steel_W_shape_W635x329 = ["China","Steel","W shape","W635x329"]
	China_Steel_W_shape_W641x327 = ["China","Steel","W shape","W641x327"]
	China_Steel_W_shape_W647x329 = ["China","Steel","W shape","W647x329"]
	China_Steel_W_shape_W661x333 = ["China","Steel","W shape","W661x333"]
	China_Steel_W_shape_W679x338 = ["China","Steel","W shape","W679x338"]
	China_Steel_W_shape_W689x340 = ["China","Steel","W shape","W689x340"]
	China_Steel_W_shape_W699x343 = ["China","Steel","W shape","W699x343"]
	China_Steel_W_shape_W711x347 = ["China","Steel","W shape","W711x347"]
	China_Steel_W_shape_W903x304 = ["China","Steel","W shape","W903x304"]
	China_Steel_W_shape_W911x304 = ["China","Steel","W shape","W911x304"]
	China_Steel_W_shape_W912x418 = ["China","Steel","W shape","W912x418"]
	China_Steel_W_shape_W915x305 = ["China","Steel","W shape","W915x305"]
	China_Steel_W_shape_W916x419 = ["China","Steel","W shape","W916x419"]
	China_Steel_W_shape_W919x306 = ["China","Steel","W shape","W919x306"]
	China_Steel_W_shape_W921x420 = ["China","Steel","W shape","W921x420"]
	China_Steel_W_shape_W923x307 = ["China","Steel","W shape","W923x307"]
	China_Steel_W_shape_W927x308 = ["China","Steel","W shape","W927x308"]
	China_Steel_W_shape_W928x422 = ["China","Steel","W shape","W928x422"]
	China_Steel_W_shape_W932x309 = ["China","Steel","W shape","W932x309"]
	China_Steel_W_shape_W933x423 = ["China","Steel","W shape","W933x423"]
	China_Steel_W_shape_W942x422 = ["China","Steel","W shape","W942x422"]
	China_Steel_W_shape_W950x425 = ["China","Steel","W shape","W950x425"]
	China_Steel_W_shape_W960x427 = ["China","Steel","W shape","W960x427"]
	China_Steel_W_shape_W970x300 = ["China","Steel","W shape","W970x300"]
	China_Steel_W_shape_W972x431 = ["China","Steel","W shape","W972x431"]
	China_Steel_W_shape_W980x300 = ["China","Steel","W shape","W980x300"]
	China_Steel_W_shape_W982x400 = ["China","Steel","W shape","W982x400"]
	China_Steel_W_shape_W990x300 = ["China","Steel","W shape","W990x300"]
	China_Steel_W_shape_W990x400 = ["China","Steel","W shape","W990x400"]
	China_Steel_W_shape_W996x437 = ["China","Steel","W shape","W996x437"]
	China_Steel_W_shape_W1000x300 = ["China","Steel","W shape","W1000x300"]
	China_Steel_W_shape_W1000x400 = ["China","Steel","W shape","W1000x400"]
	China_Steel_W_shape_W1008x302 = ["China","Steel","W shape","W1008x302"]
	China_Steel_W_shape_W1008x402 = ["China","Steel","W shape","W1008x402"]
	China_Steel_W_shape_W1012x402 = ["China","Steel","W shape","W1012x402"]
	China_Steel_W_shape_W1016x303 = ["China","Steel","W shape","W1016x303"]
	China_Steel_W_shape_W1020x304 = ["China","Steel","W shape","W1020x304"]
	China_Steel_W_shape_W1020x404 = ["China","Steel","W shape","W1020x404"]
	China_Steel_W_shape_W1028x446 = ["China","Steel","W shape","W1028x446"]
	China_Steel_W_shape_W1030x407 = ["China","Steel","W shape","W1030x407"]
	China_Steel_W_shape_W1036x309 = ["China","Steel","W shape","W1036x309"]
	China_Steel_W_shape_W1040x409 = ["China","Steel","W shape","W1040x409"]
	China_Steel_W_shape_W1048x412 = ["China","Steel","W shape","W1048x412"]
	China_Steel_W_shape_W1056x314 = ["China","Steel","W shape","W1056x314"]
	China_Steel_W_shape_W1068x417 = ["China","Steel","W shape","W1068x417"]
	China_Steel_W_shape_W1090x400 = ["China","Steel","W shape","W1090x400"]
	China_Steel_W_shape_W1092x424 = ["China","Steel","W shape","W1092x424"]
	China_Steel_W_shape_W1100x400 = ["China","Steel","W shape","W1100x400"]
	China_Steel_W_shape_W1108x402 = ["China","Steel","W shape","W1108x402"]
	China_Steel_W_shape_W1118x405 = ["China","Steel","W shape","W1118x405"]
	European_Steel_EN_10210_2_CHC_CHS21_3x2_3 = ["European","Steel","EN 10210-2 CHC","CHS21.3x2.3"]
	European_Steel_EN_10210_2_CHC_CHS21_3x2_6 = ["European","Steel","EN 10210-2 CHC","CHS21.3x2.6"]
	European_Steel_EN_10210_2_CHC_CHS21_3x3_2 = ["European","Steel","EN 10210-2 CHC","CHS21.3x3.2"]
	European_Steel_EN_10210_2_CHC_CHS26_9x2_3 = ["European","Steel","EN 10210-2 CHC","CHS26.9x2.3"]
	European_Steel_EN_10210_2_CHC_CHS26_9x2_6 = ["European","Steel","EN 10210-2 CHC","CHS26.9x2.6"]
	European_Steel_EN_10210_2_CHC_CHS26_9x3_2 = ["European","Steel","EN 10210-2 CHC","CHS26.9x3.2"]
	European_Steel_EN_10210_2_CHC_CHS33_7x2_6 = ["European","Steel","EN 10210-2 CHC","CHS33.7x2.6"]
	European_Steel_EN_10210_2_CHC_CHS33_7x3_2 = ["European","Steel","EN 10210-2 CHC","CHS33.7x3.2"]
	European_Steel_EN_10210_2_CHC_CHS33_7x4 = ["European","Steel","EN 10210-2 CHC","CHS33.7x4"]
	European_Steel_EN_10210_2_CHC_CHS42_4x2_6 = ["European","Steel","EN 10210-2 CHC","CHS42.4x2.6"]
	European_Steel_EN_10210_2_CHC_CHS42_4x3_2 = ["European","Steel","EN 10210-2 CHC","CHS42.4x3.2"]
	European_Steel_EN_10210_2_CHC_CHS42_4x4 = ["European","Steel","EN 10210-2 CHC","CHS42.4x4"]
	European_Steel_EN_10210_2_CHC_CHS48_3x2_6 = ["European","Steel","EN 10210-2 CHC","CHS48.3x2.6"]
	European_Steel_EN_10210_2_CHC_CHS48_3x3_2 = ["European","Steel","EN 10210-2 CHC","CHS48.3x3.2"]
	European_Steel_EN_10210_2_CHC_CHS48_3x4 = ["European","Steel","EN 10210-2 CHC","CHS48.3x4"]
	European_Steel_EN_10210_2_CHC_CHS48_3x5 = ["European","Steel","EN 10210-2 CHC","CHS48.3x5"]
	European_Steel_EN_10210_2_CHC_CHS60_3x2_6 = ["European","Steel","EN 10210-2 CHC","CHS60.3x2.6"]
	European_Steel_EN_10210_2_CHC_CHS60_3x3_2 = ["European","Steel","EN 10210-2 CHC","CHS60.3x3.2"]
	European_Steel_EN_10210_2_CHC_CHS60_3x4 = ["European","Steel","EN 10210-2 CHC","CHS60.3x4"]
	European_Steel_EN_10210_2_CHC_CHS60_3x5 = ["European","Steel","EN 10210-2 CHC","CHS60.3x5"]
	European_Steel_EN_10210_2_CHC_CHS76_1x2_6 = ["European","Steel","EN 10210-2 CHC","CHS76.1x2.6"]
	European_Steel_EN_10210_2_CHC_CHS76_1x3_2 = ["European","Steel","EN 10210-2 CHC","CHS76.1x3.2"]
	European_Steel_EN_10210_2_CHC_CHS76_1x4 = ["European","Steel","EN 10210-2 CHC","CHS76.1x4"]
	European_Steel_EN_10210_2_CHC_CHS76_1x5 = ["European","Steel","EN 10210-2 CHC","CHS76.1x5"]
	European_Steel_EN_10210_2_CHC_CHS88_9x3_2 = ["European","Steel","EN 10210-2 CHC","CHS88.9x3.2"]
	European_Steel_EN_10210_2_CHC_CHS88_9x4 = ["European","Steel","EN 10210-2 CHC","CHS88.9x4"]
	European_Steel_EN_10210_2_CHC_CHS88_9x5 = ["European","Steel","EN 10210-2 CHC","CHS88.9x5"]
	European_Steel_EN_10210_2_CHC_CHS88_9x6_3 = ["European","Steel","EN 10210-2 CHC","CHS88.9x6.3"]
	European_Steel_EN_10210_2_CHC_CHS101_6x3_2 = ["European","Steel","EN 10210-2 CHC","CHS101.6x3.2"]
	European_Steel_EN_10210_2_CHC_CHS101_6x4 = ["European","Steel","EN 10210-2 CHC","CHS101.6x4"]
	European_Steel_EN_10210_2_CHC_CHS101_6x5 = ["European","Steel","EN 10210-2 CHC","CHS101.6x5"]
	European_Steel_EN_10210_2_CHC_CHS101_6x6_3 = ["European","Steel","EN 10210-2 CHC","CHS101.6x6.3"]
	European_Steel_EN_10210_2_CHC_CHS101_6x8 = ["European","Steel","EN 10210-2 CHC","CHS101.6x8"]
	European_Steel_EN_10210_2_CHC_CHS101_6x10 = ["European","Steel","EN 10210-2 CHC","CHS101.6x10"]
	European_Steel_EN_10210_2_CHC_CHS114_3x3_2 = ["European","Steel","EN 10210-2 CHC","CHS114.3x3.2"]
	European_Steel_EN_10210_2_CHC_CHS114_3x4 = ["European","Steel","EN 10210-2 CHC","CHS114.3x4"]
	European_Steel_EN_10210_2_CHC_CHS114_3x5 = ["European","Steel","EN 10210-2 CHC","CHS114.3x5"]
	European_Steel_EN_10210_2_CHC_CHS114_3x6_3 = ["European","Steel","EN 10210-2 CHC","CHS114.3x6.3"]
	European_Steel_EN_10210_2_CHC_CHS114_3x8 = ["European","Steel","EN 10210-2 CHC","CHS114.3x8"]
	European_Steel_EN_10210_2_CHC_CHS114_3x10 = ["European","Steel","EN 10210-2 CHC","CHS114.3x10"]
	European_Steel_EN_10210_2_CHC_CHS139_7x4 = ["European","Steel","EN 10210-2 CHC","CHS139.7x4"]
	European_Steel_EN_10210_2_CHC_CHS139_7x5 = ["European","Steel","EN 10210-2 CHC","CHS139.7x5"]
	European_Steel_EN_10210_2_CHC_CHS139_7x6_3 = ["European","Steel","EN 10210-2 CHC","CHS139.7x6.3"]
	European_Steel_EN_10210_2_CHC_CHS139_7x8 = ["European","Steel","EN 10210-2 CHC","CHS139.7x8"]
	European_Steel_EN_10210_2_CHC_CHS139_7x10 = ["European","Steel","EN 10210-2 CHC","CHS139.7x10"]
	European_Steel_EN_10210_2_CHC_CHS139_7x12_5 = ["European","Steel","EN 10210-2 CHC","CHS139.7x12.5"]
	European_Steel_EN_10210_2_CHC_CHS168_3x4 = ["European","Steel","EN 10210-2 CHC","CHS168.3x4"]
	European_Steel_EN_10210_2_CHC_CHS168_3x5 = ["European","Steel","EN 10210-2 CHC","CHS168.3x5"]
	European_Steel_EN_10210_2_CHC_CHS168_3x6_3 = ["European","Steel","EN 10210-2 CHC","CHS168.3x6.3"]
	European_Steel_EN_10210_2_CHC_CHS168_3x8 = ["European","Steel","EN 10210-2 CHC","CHS168.3x8"]
	European_Steel_EN_10210_2_CHC_CHS168_3x10 = ["European","Steel","EN 10210-2 CHC","CHS168.3x10"]
	European_Steel_EN_10210_2_CHC_CHS168_3x12_5 = ["European","Steel","EN 10210-2 CHC","CHS168.3x12.5"]
	European_Steel_EN_10210_2_CHC_CHS177_8x5 = ["European","Steel","EN 10210-2 CHC","CHS177.8x5"]
	European_Steel_EN_10210_2_CHC_CHS177_8x6_3 = ["European","Steel","EN 10210-2 CHC","CHS177.8x6.3"]
	European_Steel_EN_10210_2_CHC_CHS177_8x8 = ["European","Steel","EN 10210-2 CHC","CHS177.8x8"]
	European_Steel_EN_10210_2_CHC_CHS177_8x10 = ["European","Steel","EN 10210-2 CHC","CHS177.8x10"]
	European_Steel_EN_10210_2_CHC_CHS177_8x12_5 = ["European","Steel","EN 10210-2 CHC","CHS177.8x12.5"]
	European_Steel_EN_10210_2_CHC_CHS193_7x5 = ["European","Steel","EN 10210-2 CHC","CHS193.7x5"]
	European_Steel_EN_10210_2_CHC_CHS193_7x6_3 = ["European","Steel","EN 10210-2 CHC","CHS193.7x6.3"]
	European_Steel_EN_10210_2_CHC_CHS193_7x8 = ["European","Steel","EN 10210-2 CHC","CHS193.7x8"]
	European_Steel_EN_10210_2_CHC_CHS193_7x10 = ["European","Steel","EN 10210-2 CHC","CHS193.7x10"]
	European_Steel_EN_10210_2_CHC_CHS193_7x12_5 = ["European","Steel","EN 10210-2 CHC","CHS193.7x12.5"]
	European_Steel_EN_10210_2_CHC_CHS193_7x14_2 = ["European","Steel","EN 10210-2 CHC","CHS193.7x14.2"]
	European_Steel_EN_10210_2_CHC_CHS193_7x16 = ["European","Steel","EN 10210-2 CHC","CHS193.7x16"]
	European_Steel_EN_10210_2_CHC_CHS219_1x5 = ["European","Steel","EN 10210-2 CHC","CHS219.1x5"]
	European_Steel_EN_10210_2_CHC_CHS219_1x6_3 = ["European","Steel","EN 10210-2 CHC","CHS219.1x6.3"]
	European_Steel_EN_10210_2_CHC_CHS219_1x8 = ["European","Steel","EN 10210-2 CHC","CHS219.1x8"]
	European_Steel_EN_10210_2_CHC_CHS219_1x10 = ["European","Steel","EN 10210-2 CHC","CHS219.1x10"]
	European_Steel_EN_10210_2_CHC_CHS219_1x12_5 = ["European","Steel","EN 10210-2 CHC","CHS219.1x12.5"]
	European_Steel_EN_10210_2_CHC_CHS219_1x14_2 = ["European","Steel","EN 10210-2 CHC","CHS219.1x14.2"]
	European_Steel_EN_10210_2_CHC_CHS219_1x16 = ["European","Steel","EN 10210-2 CHC","CHS219.1x16"]
	European_Steel_EN_10210_2_CHC_CHS219_1x20 = ["European","Steel","EN 10210-2 CHC","CHS219.1x20"]
	European_Steel_EN_10210_2_CHC_CHS244_5x5 = ["European","Steel","EN 10210-2 CHC","CHS244.5x5"]
	European_Steel_EN_10210_2_CHC_CHS244_5x6_3 = ["European","Steel","EN 10210-2 CHC","CHS244.5x6.3"]
	European_Steel_EN_10210_2_CHC_CHS244_5x8 = ["European","Steel","EN 10210-2 CHC","CHS244.5x8"]
	European_Steel_EN_10210_2_CHC_CHS244_5x10 = ["European","Steel","EN 10210-2 CHC","CHS244.5x10"]
	European_Steel_EN_10210_2_CHC_CHS244_5x12_5 = ["European","Steel","EN 10210-2 CHC","CHS244.5x12.5"]
	European_Steel_EN_10210_2_CHC_CHS244_5x14_2 = ["European","Steel","EN 10210-2 CHC","CHS244.5x14.2"]
	European_Steel_EN_10210_2_CHC_CHS244_5x16 = ["European","Steel","EN 10210-2 CHC","CHS244.5x16"]
	European_Steel_EN_10210_2_CHC_CHS244_5x20 = ["European","Steel","EN 10210-2 CHC","CHS244.5x20"]
	European_Steel_EN_10210_2_CHC_CHS244_5x25 = ["European","Steel","EN 10210-2 CHC","CHS244.5x25"]
	European_Steel_EN_10210_2_CHC_CHS273x5 = ["European","Steel","EN 10210-2 CHC","CHS273x5"]
	European_Steel_EN_10210_2_CHC_CHS273x6_3 = ["European","Steel","EN 10210-2 CHC","CHS273x6.3"]
	European_Steel_EN_10210_2_CHC_CHS273x8 = ["European","Steel","EN 10210-2 CHC","CHS273x8"]
	European_Steel_EN_10210_2_CHC_CHS273x10 = ["European","Steel","EN 10210-2 CHC","CHS273x10"]
	European_Steel_EN_10210_2_CHC_CHS273x12_5 = ["European","Steel","EN 10210-2 CHC","CHS273x12.5"]
	European_Steel_EN_10210_2_CHC_CHS273x14_2 = ["European","Steel","EN 10210-2 CHC","CHS273x14.2"]
	European_Steel_EN_10210_2_CHC_CHS273x16 = ["European","Steel","EN 10210-2 CHC","CHS273x16"]
	European_Steel_EN_10210_2_CHC_CHS273x20 = ["European","Steel","EN 10210-2 CHC","CHS273x20"]
	European_Steel_EN_10210_2_CHC_CHS273x25 = ["European","Steel","EN 10210-2 CHC","CHS273x25"]
	European_Steel_EN_10210_2_CHC_CHS323_9x5 = ["European","Steel","EN 10210-2 CHC","CHS323.9x5"]
	European_Steel_EN_10210_2_CHC_CHS323_9x6_3 = ["European","Steel","EN 10210-2 CHC","CHS323.9x6.3"]
	European_Steel_EN_10210_2_CHC_CHS323_9x8 = ["European","Steel","EN 10210-2 CHC","CHS323.9x8"]
	European_Steel_EN_10210_2_CHC_CHS323_9x10 = ["European","Steel","EN 10210-2 CHC","CHS323.9x10"]
	European_Steel_EN_10210_2_CHC_CHS323_9x12_5 = ["European","Steel","EN 10210-2 CHC","CHS323.9x12.5"]
	European_Steel_EN_10210_2_CHC_CHS323_9x14_2 = ["European","Steel","EN 10210-2 CHC","CHS323.9x14.2"]
	European_Steel_EN_10210_2_CHC_CHS323_9x16 = ["European","Steel","EN 10210-2 CHC","CHS323.9x16"]
	European_Steel_EN_10210_2_CHC_CHS323_9x20 = ["European","Steel","EN 10210-2 CHC","CHS323.9x20"]
	European_Steel_EN_10210_2_CHC_CHS323_9x25 = ["European","Steel","EN 10210-2 CHC","CHS323.9x25"]
	European_Steel_EN_10210_2_CHC_CHS355_6x6_3 = ["European","Steel","EN 10210-2 CHC","CHS355.6x6.3"]
	European_Steel_EN_10210_2_CHC_CHS355_6x8 = ["European","Steel","EN 10210-2 CHC","CHS355.6x8"]
	European_Steel_EN_10210_2_CHC_CHS355_6x10 = ["European","Steel","EN 10210-2 CHC","CHS355.6x10"]
	European_Steel_EN_10210_2_CHC_CHS355_6x12_5 = ["European","Steel","EN 10210-2 CHC","CHS355.6x12.5"]
	European_Steel_EN_10210_2_CHC_CHS355_6x14_2 = ["European","Steel","EN 10210-2 CHC","CHS355.6x14.2"]
	European_Steel_EN_10210_2_CHC_CHS355_6x16 = ["European","Steel","EN 10210-2 CHC","CHS355.6x16"]
	European_Steel_EN_10210_2_CHC_CHS355_6x20 = ["European","Steel","EN 10210-2 CHC","CHS355.6x20"]
	European_Steel_EN_10210_2_CHC_CHS355_6x25 = ["European","Steel","EN 10210-2 CHC","CHS355.6x25"]
	European_Steel_EN_10210_2_CHC_CHS406_4x6_3 = ["European","Steel","EN 10210-2 CHC","CHS406.4x6.3"]
	European_Steel_EN_10210_2_CHC_CHS406_4x8 = ["European","Steel","EN 10210-2 CHC","CHS406.4x8"]
	European_Steel_EN_10210_2_CHC_CHS406_4x10 = ["European","Steel","EN 10210-2 CHC","CHS406.4x10"]
	European_Steel_EN_10210_2_CHC_CHS406_4x12_5 = ["European","Steel","EN 10210-2 CHC","CHS406.4x12.5"]
	European_Steel_EN_10210_2_CHC_CHS406_4x14_2 = ["European","Steel","EN 10210-2 CHC","CHS406.4x14.2"]
	European_Steel_EN_10210_2_CHC_CHS406_4x16 = ["European","Steel","EN 10210-2 CHC","CHS406.4x16"]
	European_Steel_EN_10210_2_CHC_CHS406_4x20 = ["European","Steel","EN 10210-2 CHC","CHS406.4x20"]
	European_Steel_EN_10210_2_CHC_CHS406_4x25 = ["European","Steel","EN 10210-2 CHC","CHS406.4x25"]
	European_Steel_EN_10210_2_CHC_CHS406_4x30 = ["European","Steel","EN 10210-2 CHC","CHS406.4x30"]
	European_Steel_EN_10210_2_CHC_CHS406_4x40 = ["European","Steel","EN 10210-2 CHC","CHS406.4x40"]
	European_Steel_EN_10210_2_CHC_CHS457x6_3 = ["European","Steel","EN 10210-2 CHC","CHS457x6.3"]
	European_Steel_EN_10210_2_CHC_CHS457x8 = ["European","Steel","EN 10210-2 CHC","CHS457x8"]
	European_Steel_EN_10210_2_CHC_CHS457x10 = ["European","Steel","EN 10210-2 CHC","CHS457x10"]
	European_Steel_EN_10210_2_CHC_CHS457x12_5 = ["European","Steel","EN 10210-2 CHC","CHS457x12.5"]
	European_Steel_EN_10210_2_CHC_CHS457x14_2 = ["European","Steel","EN 10210-2 CHC","CHS457x14.2"]
	European_Steel_EN_10210_2_CHC_CHS457x16 = ["European","Steel","EN 10210-2 CHC","CHS457x16"]
	European_Steel_EN_10210_2_CHC_CHS457x20 = ["European","Steel","EN 10210-2 CHC","CHS457x20"]
	European_Steel_EN_10210_2_CHC_CHS457x25 = ["European","Steel","EN 10210-2 CHC","CHS457x25"]
	European_Steel_EN_10210_2_CHC_CHS457x30 = ["European","Steel","EN 10210-2 CHC","CHS457x30"]
	European_Steel_EN_10210_2_CHC_CHS457x40 = ["European","Steel","EN 10210-2 CHC","CHS457x40"]
	European_Steel_EN_10210_2_CHC_CHS508x6_3 = ["European","Steel","EN 10210-2 CHC","CHS508x6.3"]
	European_Steel_EN_10210_2_CHC_CHS508x8 = ["European","Steel","EN 10210-2 CHC","CHS508x8"]
	European_Steel_EN_10210_2_CHC_CHS508x10 = ["European","Steel","EN 10210-2 CHC","CHS508x10"]
	European_Steel_EN_10210_2_CHC_CHS508x12_5 = ["European","Steel","EN 10210-2 CHC","CHS508x12.5"]
	European_Steel_EN_10210_2_CHC_CHS508x14_2 = ["European","Steel","EN 10210-2 CHC","CHS508x14.2"]
	European_Steel_EN_10210_2_CHC_CHS508x16 = ["European","Steel","EN 10210-2 CHC","CHS508x16"]
	European_Steel_EN_10210_2_CHC_CHS508x20 = ["European","Steel","EN 10210-2 CHC","CHS508x20"]
	European_Steel_EN_10210_2_CHC_CHS508x25 = ["European","Steel","EN 10210-2 CHC","CHS508x25"]
	European_Steel_EN_10210_2_CHC_CHS508x30 = ["European","Steel","EN 10210-2 CHC","CHS508x30"]
	European_Steel_EN_10210_2_CHC_CHS508x40 = ["European","Steel","EN 10210-2 CHC","CHS508x40"]
	European_Steel_EN_10210_2_CHC_CHS508x50 = ["European","Steel","EN 10210-2 CHC","CHS508x50"]
	European_Steel_EN_10210_2_CHC_CHS610x6_3 = ["European","Steel","EN 10210-2 CHC","CHS610x6.3"]
	European_Steel_EN_10210_2_CHC_CHS610x8 = ["European","Steel","EN 10210-2 CHC","CHS610x8"]
	European_Steel_EN_10210_2_CHC_CHS610x10 = ["European","Steel","EN 10210-2 CHC","CHS610x10"]
	European_Steel_EN_10210_2_CHC_CHS610x12_5 = ["European","Steel","EN 10210-2 CHC","CHS610x12.5"]
	European_Steel_EN_10210_2_CHC_CHS610x14_2 = ["European","Steel","EN 10210-2 CHC","CHS610x14.2"]
	European_Steel_EN_10210_2_CHC_CHS610x16 = ["European","Steel","EN 10210-2 CHC","CHS610x16"]
	European_Steel_EN_10210_2_CHC_CHS610x20 = ["European","Steel","EN 10210-2 CHC","CHS610x20"]
	European_Steel_EN_10210_2_CHC_CHS610x25 = ["European","Steel","EN 10210-2 CHC","CHS610x25"]
	European_Steel_EN_10210_2_CHC_CHS610x30 = ["European","Steel","EN 10210-2 CHC","CHS610x30"]
	European_Steel_EN_10210_2_CHC_CHS610x40 = ["European","Steel","EN 10210-2 CHC","CHS610x40"]
	European_Steel_EN_10210_2_CHC_CHS610x50 = ["European","Steel","EN 10210-2 CHC","CHS610x50"]
	European_Steel_EN_10210_2_CHC_CHS711x6_3 = ["European","Steel","EN 10210-2 CHC","CHS711x6.3"]
	European_Steel_EN_10210_2_CHC_CHS711x8 = ["European","Steel","EN 10210-2 CHC","CHS711x8"]
	European_Steel_EN_10210_2_CHC_CHS711x10 = ["European","Steel","EN 10210-2 CHC","CHS711x10"]
	European_Steel_EN_10210_2_CHC_CHS711x12_5 = ["European","Steel","EN 10210-2 CHC","CHS711x12.5"]
	European_Steel_EN_10210_2_CHC_CHS711x14_2 = ["European","Steel","EN 10210-2 CHC","CHS711x14.2"]
	European_Steel_EN_10210_2_CHC_CHS711x16 = ["European","Steel","EN 10210-2 CHC","CHS711x16"]
	European_Steel_EN_10210_2_CHC_CHS711x20 = ["European","Steel","EN 10210-2 CHC","CHS711x20"]
	European_Steel_EN_10210_2_CHC_CHS711x25 = ["European","Steel","EN 10210-2 CHC","CHS711x25"]
	European_Steel_EN_10210_2_CHC_CHS711x30 = ["European","Steel","EN 10210-2 CHC","CHS711x30"]
	European_Steel_EN_10210_2_CHC_CHS711x40 = ["European","Steel","EN 10210-2 CHC","CHS711x40"]
	European_Steel_EN_10210_2_CHC_CHS711x50 = ["European","Steel","EN 10210-2 CHC","CHS711x50"]
	European_Steel_EN_10210_2_CHC_CHS711x60 = ["European","Steel","EN 10210-2 CHC","CHS711x60"]
	European_Steel_EN_10210_2_CHC_CHS762x6_3 = ["European","Steel","EN 10210-2 CHC","CHS762x6.3"]
	European_Steel_EN_10210_2_CHC_CHS762x8 = ["European","Steel","EN 10210-2 CHC","CHS762x8"]
	European_Steel_EN_10210_2_CHC_CHS762x10 = ["European","Steel","EN 10210-2 CHC","CHS762x10"]
	European_Steel_EN_10210_2_CHC_CHS762x12_5 = ["European","Steel","EN 10210-2 CHC","CHS762x12.5"]
	European_Steel_EN_10210_2_CHC_CHS762x14_2 = ["European","Steel","EN 10210-2 CHC","CHS762x14.2"]
	European_Steel_EN_10210_2_CHC_CHS762x16 = ["European","Steel","EN 10210-2 CHC","CHS762x16"]
	European_Steel_EN_10210_2_CHC_CHS762x20 = ["European","Steel","EN 10210-2 CHC","CHS762x20"]
	European_Steel_EN_10210_2_CHC_CHS762x25 = ["European","Steel","EN 10210-2 CHC","CHS762x25"]
	European_Steel_EN_10210_2_CHC_CHS762x30 = ["European","Steel","EN 10210-2 CHC","CHS762x30"]
	European_Steel_EN_10210_2_CHC_CHS762x40 = ["European","Steel","EN 10210-2 CHC","CHS762x40"]
	European_Steel_EN_10210_2_CHC_CHS762x50 = ["European","Steel","EN 10210-2 CHC","CHS762x50"]
	European_Steel_EN_10210_2_CHC_CHS813x8 = ["European","Steel","EN 10210-2 CHC","CHS813x8"]
	European_Steel_EN_10210_2_CHC_CHS813x10 = ["European","Steel","EN 10210-2 CHC","CHS813x10"]
	European_Steel_EN_10210_2_CHC_CHS813x12_5 = ["European","Steel","EN 10210-2 CHC","CHS813x12.5"]
	European_Steel_EN_10210_2_CHC_CHS813x14_2 = ["European","Steel","EN 10210-2 CHC","CHS813x14.2"]
	European_Steel_EN_10210_2_CHC_CHS813x16 = ["European","Steel","EN 10210-2 CHC","CHS813x16"]
	European_Steel_EN_10210_2_CHC_CHS813x20 = ["European","Steel","EN 10210-2 CHC","CHS813x20"]
	European_Steel_EN_10210_2_CHC_CHS813x25 = ["European","Steel","EN 10210-2 CHC","CHS813x25"]
	European_Steel_EN_10210_2_CHC_CHS813x30 = ["European","Steel","EN 10210-2 CHC","CHS813x30"]
	European_Steel_EN_10210_2_CHC_CHS914x8 = ["European","Steel","EN 10210-2 CHC","CHS914x8"]
	European_Steel_EN_10210_2_CHC_CHS914x10 = ["European","Steel","EN 10210-2 CHC","CHS914x10"]
	European_Steel_EN_10210_2_CHC_CHS914x12_5 = ["European","Steel","EN 10210-2 CHC","CHS914x12.5"]
	European_Steel_EN_10210_2_CHC_CHS914x14_2 = ["European","Steel","EN 10210-2 CHC","CHS914x14.2"]
	European_Steel_EN_10210_2_CHC_CHS914x16 = ["European","Steel","EN 10210-2 CHC","CHS914x16"]
	European_Steel_EN_10210_2_CHC_CHS914x20 = ["European","Steel","EN 10210-2 CHC","CHS914x20"]
	European_Steel_EN_10210_2_CHC_CHS914x25 = ["European","Steel","EN 10210-2 CHC","CHS914x25"]
	European_Steel_EN_10210_2_CHC_CHS914x30 = ["European","Steel","EN 10210-2 CHC","CHS914x30"]
	European_Steel_EN_10210_2_CHC_CHS1016x8 = ["European","Steel","EN 10210-2 CHC","CHS1016x8"]
	European_Steel_EN_10210_2_CHC_CHS1016x10 = ["European","Steel","EN 10210-2 CHC","CHS1016x10"]
	European_Steel_EN_10210_2_CHC_CHS1016x12_5 = ["European","Steel","EN 10210-2 CHC","CHS1016x12.5"]
	European_Steel_EN_10210_2_CHC_CHS1016x14_2 = ["European","Steel","EN 10210-2 CHC","CHS1016x14.2"]
	European_Steel_EN_10210_2_CHC_CHS1016x16 = ["European","Steel","EN 10210-2 CHC","CHS1016x16"]
	European_Steel_EN_10210_2_CHC_CHS1016x20 = ["European","Steel","EN 10210-2 CHC","CHS1016x20"]
	European_Steel_EN_10210_2_CHC_CHS1016x25 = ["European","Steel","EN 10210-2 CHC","CHS1016x25"]
	European_Steel_EN_10210_2_CHC_CHS1016x30 = ["European","Steel","EN 10210-2 CHC","CHS1016x30"]
	European_Steel_EN_10210_2_CHC_CHS1067x10 = ["European","Steel","EN 10210-2 CHC","CHS1067x10"]
	European_Steel_EN_10210_2_CHC_CHS1067x12_5 = ["European","Steel","EN 10210-2 CHC","CHS1067x12.5"]
	European_Steel_EN_10210_2_CHC_CHS1067x14_2 = ["European","Steel","EN 10210-2 CHC","CHS1067x14.2"]
	European_Steel_EN_10210_2_CHC_CHS1067x16 = ["European","Steel","EN 10210-2 CHC","CHS1067x16"]
	European_Steel_EN_10210_2_CHC_CHS1067x20 = ["European","Steel","EN 10210-2 CHC","CHS1067x20"]
	European_Steel_EN_10210_2_CHC_CHS1067x25 = ["European","Steel","EN 10210-2 CHC","CHS1067x25"]
	European_Steel_EN_10210_2_CHC_CHS1067x30 = ["European","Steel","EN 10210-2 CHC","CHS1067x30"]
	European_Steel_EN_10210_2_CHC_CHS1168x10 = ["European","Steel","EN 10210-2 CHC","CHS1168x10"]
	European_Steel_EN_10210_2_CHC_CHS1168x12_5 = ["European","Steel","EN 10210-2 CHC","CHS1168x12.5"]
	European_Steel_EN_10210_2_CHC_CHS1168x14_2 = ["European","Steel","EN 10210-2 CHC","CHS1168x14.2"]
	European_Steel_EN_10210_2_CHC_CHS1168x16 = ["European","Steel","EN 10210-2 CHC","CHS1168x16"]
	European_Steel_EN_10210_2_CHC_CHS1168x20 = ["European","Steel","EN 10210-2 CHC","CHS1168x20"]
	European_Steel_EN_10210_2_CHC_CHS1168x25 = ["European","Steel","EN 10210-2 CHC","CHS1168x25"]
	European_Steel_EN_10210_2_CHC_CHS1219x10 = ["European","Steel","EN 10210-2 CHC","CHS1219x10"]
	European_Steel_EN_10210_2_CHC_CHS1219x12_5 = ["European","Steel","EN 10210-2 CHC","CHS1219x12.5"]
	European_Steel_EN_10210_2_CHC_CHS1219x14_2 = ["European","Steel","EN 10210-2 CHC","CHS1219x14.2"]
	European_Steel_EN_10210_2_CHC_CHS1219x16 = ["European","Steel","EN 10210-2 CHC","CHS1219x16"]
	European_Steel_EN_10210_2_CHC_CHS1219x20 = ["European","Steel","EN 10210-2 CHC","CHS1219x20"]
	European_Steel_EN_10210_2_CHC_CHS1219x25 = ["European","Steel","EN 10210-2 CHC","CHS1219x25"]
	European_Steel_EN_10210_2_RHS_RHS50x30x2_6 = ["European","Steel","EN 10210-2 RHS","RHS50x30x2.6"]
	European_Steel_EN_10210_2_RHS_RHS50x30x3_2 = ["European","Steel","EN 10210-2 RHS","RHS50x30x3.2"]
	European_Steel_EN_10210_2_RHS_RHS50x30x4 = ["European","Steel","EN 10210-2 RHS","RHS50x30x4"]
	European_Steel_EN_10210_2_RHS_RHS50x30x5 = ["European","Steel","EN 10210-2 RHS","RHS50x30x5"]
	European_Steel_EN_10210_2_RHS_RHS60x40x2_6 = ["European","Steel","EN 10210-2 RHS","RHS60x40x2.6"]
	European_Steel_EN_10210_2_RHS_RHS60x40x3_2 = ["European","Steel","EN 10210-2 RHS","RHS60x40x3.2"]
	European_Steel_EN_10210_2_RHS_RHS60x40x4 = ["European","Steel","EN 10210-2 RHS","RHS60x40x4"]
	European_Steel_EN_10210_2_RHS_RHS60x40x5 = ["European","Steel","EN 10210-2 RHS","RHS60x40x5"]
	European_Steel_EN_10210_2_RHS_RHS60x40x6_3 = ["European","Steel","EN 10210-2 RHS","RHS60x40x6.3"]
	European_Steel_EN_10210_2_RHS_RHS70x40x3 = ["European","Steel","EN 10210-2 RHS","RHS70x40x3"]
	European_Steel_EN_10210_2_RHS_RHS70x40x4 = ["European","Steel","EN 10210-2 RHS","RHS70x40x4"]
	European_Steel_EN_10210_2_RHS_RHS80x40x3_2 = ["European","Steel","EN 10210-2 RHS","RHS80x40x3.2"]
	European_Steel_EN_10210_2_RHS_RHS80x40x4 = ["European","Steel","EN 10210-2 RHS","RHS80x40x4"]
	European_Steel_EN_10210_2_RHS_RHS80x40x5 = ["European","Steel","EN 10210-2 RHS","RHS80x40x5"]
	European_Steel_EN_10210_2_RHS_RHS80x40x6_3 = ["European","Steel","EN 10210-2 RHS","RHS80x40x6.3"]
	European_Steel_EN_10210_2_RHS_RHS80x40x8 = ["European","Steel","EN 10210-2 RHS","RHS80x40x8"]
	European_Steel_EN_10210_2_RHS_RHS90x50x3_2 = ["European","Steel","EN 10210-2 RHS","RHS90x50x3.2"]
	European_Steel_EN_10210_2_RHS_RHS90x50x4 = ["European","Steel","EN 10210-2 RHS","RHS90x50x4"]
	European_Steel_EN_10210_2_RHS_RHS90x50x5 = ["European","Steel","EN 10210-2 RHS","RHS90x50x5"]
	European_Steel_EN_10210_2_RHS_RHS90x50x6_3 = ["European","Steel","EN 10210-2 RHS","RHS90x50x6.3"]
	European_Steel_EN_10210_2_RHS_RHS90x50x8 = ["European","Steel","EN 10210-2 RHS","RHS90x50x8"]
	European_Steel_EN_10210_2_RHS_RHS100x50x3_2 = ["European","Steel","EN 10210-2 RHS","RHS100x50x3.2"]
	European_Steel_EN_10210_2_RHS_RHS100x50x4 = ["European","Steel","EN 10210-2 RHS","RHS100x50x4"]
	European_Steel_EN_10210_2_RHS_RHS100x50x5 = ["European","Steel","EN 10210-2 RHS","RHS100x50x5"]
	European_Steel_EN_10210_2_RHS_RHS100x50x6_3 = ["European","Steel","EN 10210-2 RHS","RHS100x50x6.3"]
	European_Steel_EN_10210_2_RHS_RHS100x50x8 = ["European","Steel","EN 10210-2 RHS","RHS100x50x8"]
	European_Steel_EN_10210_2_RHS_RHS100x60x3_2 = ["European","Steel","EN 10210-2 RHS","RHS100x60x3.2"]
	European_Steel_EN_10210_2_RHS_RHS100x60x4 = ["European","Steel","EN 10210-2 RHS","RHS100x60x4"]
	European_Steel_EN_10210_2_RHS_RHS100x60x5 = ["European","Steel","EN 10210-2 RHS","RHS100x60x5"]
	European_Steel_EN_10210_2_RHS_RHS100x60x6_3 = ["European","Steel","EN 10210-2 RHS","RHS100x60x6.3"]
	European_Steel_EN_10210_2_RHS_RHS100x60x8 = ["European","Steel","EN 10210-2 RHS","RHS100x60x8"]
	European_Steel_EN_10210_2_RHS_RHS120x60x4 = ["European","Steel","EN 10210-2 RHS","RHS120x60x4"]
	European_Steel_EN_10210_2_RHS_RHS120x60x5 = ["European","Steel","EN 10210-2 RHS","RHS120x60x5"]
	European_Steel_EN_10210_2_RHS_RHS120x60x6_3 = ["European","Steel","EN 10210-2 RHS","RHS120x60x6.3"]
	European_Steel_EN_10210_2_RHS_RHS120x60x8 = ["European","Steel","EN 10210-2 RHS","RHS120x60x8"]
	European_Steel_EN_10210_2_RHS_RHS120x60x10 = ["European","Steel","EN 10210-2 RHS","RHS120x60x10"]
	European_Steel_EN_10210_2_RHS_RHS120x80x4 = ["European","Steel","EN 10210-2 RHS","RHS120x80x4"]
	European_Steel_EN_10210_2_RHS_RHS120x80x5 = ["European","Steel","EN 10210-2 RHS","RHS120x80x5"]
	European_Steel_EN_10210_2_RHS_RHS120x80x6_3 = ["European","Steel","EN 10210-2 RHS","RHS120x80x6.3"]
	European_Steel_EN_10210_2_RHS_RHS120x80x8 = ["European","Steel","EN 10210-2 RHS","RHS120x80x8"]
	European_Steel_EN_10210_2_RHS_RHS120x80x10 = ["European","Steel","EN 10210-2 RHS","RHS120x80x10"]
	European_Steel_EN_10210_2_RHS_RHS140x80x4 = ["European","Steel","EN 10210-2 RHS","RHS140x80x4"]
	European_Steel_EN_10210_2_RHS_RHS140x80x5 = ["European","Steel","EN 10210-2 RHS","RHS140x80x5"]
	European_Steel_EN_10210_2_RHS_RHS140x80x6_3 = ["European","Steel","EN 10210-2 RHS","RHS140x80x6.3"]
	European_Steel_EN_10210_2_RHS_RHS140x80x8 = ["European","Steel","EN 10210-2 RHS","RHS140x80x8"]
	European_Steel_EN_10210_2_RHS_RHS140x80x10 = ["European","Steel","EN 10210-2 RHS","RHS140x80x10"]
	European_Steel_EN_10210_2_RHS_RHS150x100x4 = ["European","Steel","EN 10210-2 RHS","RHS150x100x4"]
	European_Steel_EN_10210_2_RHS_RHS150x100x5 = ["European","Steel","EN 10210-2 RHS","RHS150x100x5"]
	European_Steel_EN_10210_2_RHS_RHS150x100x6_3 = ["European","Steel","EN 10210-2 RHS","RHS150x100x6.3"]
	European_Steel_EN_10210_2_RHS_RHS150x100x8 = ["European","Steel","EN 10210-2 RHS","RHS150x100x8"]
	European_Steel_EN_10210_2_RHS_RHS150x100x10 = ["European","Steel","EN 10210-2 RHS","RHS150x100x10"]
	European_Steel_EN_10210_2_RHS_RHS150x100x12_5 = ["European","Steel","EN 10210-2 RHS","RHS150x100x12.5"]
	European_Steel_EN_10210_2_RHS_RHS160x80x4 = ["European","Steel","EN 10210-2 RHS","RHS160x80x4"]
	European_Steel_EN_10210_2_RHS_RHS160x80x5 = ["European","Steel","EN 10210-2 RHS","RHS160x80x5"]
	European_Steel_EN_10210_2_RHS_RHS160x80x6_3 = ["European","Steel","EN 10210-2 RHS","RHS160x80x6.3"]
	European_Steel_EN_10210_2_RHS_RHS160x80x8 = ["European","Steel","EN 10210-2 RHS","RHS160x80x8"]
	European_Steel_EN_10210_2_RHS_RHS160x80x10 = ["European","Steel","EN 10210-2 RHS","RHS160x80x10"]
	European_Steel_EN_10210_2_RHS_RHS160x80x12_5 = ["European","Steel","EN 10210-2 RHS","RHS160x80x12.5"]
	European_Steel_EN_10210_2_RHS_RHS180x100x4 = ["European","Steel","EN 10210-2 RHS","RHS180x100x4"]
	European_Steel_EN_10210_2_RHS_RHS180x100x5 = ["European","Steel","EN 10210-2 RHS","RHS180x100x5"]
	European_Steel_EN_10210_2_RHS_RHS180x100x6_3 = ["European","Steel","EN 10210-2 RHS","RHS180x100x6.3"]
	European_Steel_EN_10210_2_RHS_RHS180x100x8 = ["European","Steel","EN 10210-2 RHS","RHS180x100x8"]
	European_Steel_EN_10210_2_RHS_RHS180x100x10 = ["European","Steel","EN 10210-2 RHS","RHS180x100x10"]
	European_Steel_EN_10210_2_RHS_RHS180x100x12_5 = ["European","Steel","EN 10210-2 RHS","RHS180x100x12.5"]
	European_Steel_EN_10210_2_RHS_RHS200x100x4 = ["European","Steel","EN 10210-2 RHS","RHS200x100x4"]
	European_Steel_EN_10210_2_RHS_RHS200x100x5 = ["European","Steel","EN 10210-2 RHS","RHS200x100x5"]
	European_Steel_EN_10210_2_RHS_RHS200x100x6_3 = ["European","Steel","EN 10210-2 RHS","RHS200x100x6.3"]
	European_Steel_EN_10210_2_RHS_RHS200x100x8 = ["European","Steel","EN 10210-2 RHS","RHS200x100x8"]
	European_Steel_EN_10210_2_RHS_RHS200x100x10 = ["European","Steel","EN 10210-2 RHS","RHS200x100x10"]
	European_Steel_EN_10210_2_RHS_RHS200x100x12_5 = ["European","Steel","EN 10210-2 RHS","RHS200x100x12.5"]
	European_Steel_EN_10210_2_RHS_RHS200x100x16 = ["European","Steel","EN 10210-2 RHS","RHS200x100x16"]
	European_Steel_EN_10210_2_RHS_RHS200x120x6_3 = ["European","Steel","EN 10210-2 RHS","RHS200x120x6.3"]
	European_Steel_EN_10210_2_RHS_RHS200x120x8 = ["European","Steel","EN 10210-2 RHS","RHS200x120x8"]
	European_Steel_EN_10210_2_RHS_RHS200x120x10 = ["European","Steel","EN 10210-2 RHS","RHS200x120x10"]
	European_Steel_EN_10210_2_RHS_RHS200x120x12_5 = ["European","Steel","EN 10210-2 RHS","RHS200x120x12.5"]
	European_Steel_EN_10210_2_RHS_RHS250x150x6_3 = ["European","Steel","EN 10210-2 RHS","RHS250x150x6.3"]
	European_Steel_EN_10210_2_RHS_RHS250x150x8 = ["European","Steel","EN 10210-2 RHS","RHS250x150x8"]
	European_Steel_EN_10210_2_RHS_RHS250x150x10 = ["European","Steel","EN 10210-2 RHS","RHS250x150x10"]
	European_Steel_EN_10210_2_RHS_RHS250x150x12_5 = ["European","Steel","EN 10210-2 RHS","RHS250x150x12.5"]
	European_Steel_EN_10210_2_RHS_RHS250x150x14_2 = ["European","Steel","EN 10210-2 RHS","RHS250x150x14.2"]
	European_Steel_EN_10210_2_RHS_RHS250x150x16 = ["European","Steel","EN 10210-2 RHS","RHS250x150x16"]
	European_Steel_EN_10210_2_RHS_RHS260x180x6_3 = ["European","Steel","EN 10210-2 RHS","RHS260x180x6.3"]
	European_Steel_EN_10210_2_RHS_RHS260x180x8 = ["European","Steel","EN 10210-2 RHS","RHS260x180x8"]
	European_Steel_EN_10210_2_RHS_RHS260x180x10 = ["European","Steel","EN 10210-2 RHS","RHS260x180x10"]
	European_Steel_EN_10210_2_RHS_RHS260x180x12_5 = ["European","Steel","EN 10210-2 RHS","RHS260x180x12.5"]
	European_Steel_EN_10210_2_RHS_RHS260x180x14_2 = ["European","Steel","EN 10210-2 RHS","RHS260x180x14.2"]
	European_Steel_EN_10210_2_RHS_RHS260x180x16 = ["European","Steel","EN 10210-2 RHS","RHS260x180x16"]
	European_Steel_EN_10210_2_RHS_RHS300x200x6_3 = ["European","Steel","EN 10210-2 RHS","RHS300x200x6.3"]
	European_Steel_EN_10210_2_RHS_RHS300x200x8 = ["European","Steel","EN 10210-2 RHS","RHS300x200x8"]
	European_Steel_EN_10210_2_RHS_RHS300x200x10 = ["European","Steel","EN 10210-2 RHS","RHS300x200x10"]
	European_Steel_EN_10210_2_RHS_RHS300x200x12_5 = ["European","Steel","EN 10210-2 RHS","RHS300x200x12.5"]
	European_Steel_EN_10210_2_RHS_RHS300x200x14_2 = ["European","Steel","EN 10210-2 RHS","RHS300x200x14.2"]
	European_Steel_EN_10210_2_RHS_RHS300x200x16 = ["European","Steel","EN 10210-2 RHS","RHS300x200x16"]
	European_Steel_EN_10210_2_RHS_RHS350x250x6_3 = ["European","Steel","EN 10210-2 RHS","RHS350x250x6.3"]
	European_Steel_EN_10210_2_RHS_RHS350x250x8 = ["European","Steel","EN 10210-2 RHS","RHS350x250x8"]
	European_Steel_EN_10210_2_RHS_RHS350x250x10 = ["European","Steel","EN 10210-2 RHS","RHS350x250x10"]
	European_Steel_EN_10210_2_RHS_RHS350x250x12_5 = ["European","Steel","EN 10210-2 RHS","RHS350x250x12.5"]
	European_Steel_EN_10210_2_RHS_RHS350x250x14_2 = ["European","Steel","EN 10210-2 RHS","RHS350x250x14.2"]
	European_Steel_EN_10210_2_RHS_RHS350x250x16 = ["European","Steel","EN 10210-2 RHS","RHS350x250x16"]
	European_Steel_EN_10210_2_RHS_RHS400x200x8 = ["European","Steel","EN 10210-2 RHS","RHS400x200x8"]
	European_Steel_EN_10210_2_RHS_RHS400x200x10 = ["European","Steel","EN 10210-2 RHS","RHS400x200x10"]
	European_Steel_EN_10210_2_RHS_RHS400x200x12_5 = ["European","Steel","EN 10210-2 RHS","RHS400x200x12.5"]
	European_Steel_EN_10210_2_RHS_RHS400x200x14_2 = ["European","Steel","EN 10210-2 RHS","RHS400x200x14.2"]
	European_Steel_EN_10210_2_RHS_RHS400x200x16 = ["European","Steel","EN 10210-2 RHS","RHS400x200x16"]
	European_Steel_EN_10210_2_RHS_RHS450x250x8 = ["European","Steel","EN 10210-2 RHS","RHS450x250x8"]
	European_Steel_EN_10210_2_RHS_RHS450x250x10 = ["European","Steel","EN 10210-2 RHS","RHS450x250x10"]
	European_Steel_EN_10210_2_RHS_RHS450x250x12_5 = ["European","Steel","EN 10210-2 RHS","RHS450x250x12.5"]
	European_Steel_EN_10210_2_RHS_RHS450x250x14_2 = ["European","Steel","EN 10210-2 RHS","RHS450x250x14.2"]
	European_Steel_EN_10210_2_RHS_RHS450x250x16 = ["European","Steel","EN 10210-2 RHS","RHS450x250x16"]
	European_Steel_EN_10210_2_RHS_RHS500x300x10 = ["European","Steel","EN 10210-2 RHS","RHS500x300x10"]
	European_Steel_EN_10210_2_RHS_RHS500x300x12_5 = ["European","Steel","EN 10210-2 RHS","RHS500x300x12.5"]
	European_Steel_EN_10210_2_RHS_RHS500x300x14_2 = ["European","Steel","EN 10210-2 RHS","RHS500x300x14.2"]
	European_Steel_EN_10210_2_RHS_RHS500x300x16 = ["European","Steel","EN 10210-2 RHS","RHS500x300x16"]
	European_Steel_EN_10210_2_RHS_RHS500x300x20 = ["European","Steel","EN 10210-2 RHS","RHS500x300x20"]
	European_Steel_EN_10210_2_SHS_SHS40x40x2_6 = ["European","Steel","EN 10210-2 SHS","SHS40x40x2.6"]
	European_Steel_EN_10210_2_SHS_SHS40x40x3_2 = ["European","Steel","EN 10210-2 SHS","SHS40x40x3.2"]
	European_Steel_EN_10210_2_SHS_SHS40x40x4 = ["European","Steel","EN 10210-2 SHS","SHS40x40x4"]
	European_Steel_EN_10210_2_SHS_SHS40x40x5 = ["European","Steel","EN 10210-2 SHS","SHS40x40x5"]
	European_Steel_EN_10210_2_SHS_SHS50x50x2_6 = ["European","Steel","EN 10210-2 SHS","SHS50x50x2.6"]
	European_Steel_EN_10210_2_SHS_SHS50x50x3_2 = ["European","Steel","EN 10210-2 SHS","SHS50x50x3.2"]
	European_Steel_EN_10210_2_SHS_SHS50x50x4 = ["European","Steel","EN 10210-2 SHS","SHS50x50x4"]
	European_Steel_EN_10210_2_SHS_SHS50x50x5 = ["European","Steel","EN 10210-2 SHS","SHS50x50x5"]
	European_Steel_EN_10210_2_SHS_SHS50x50x6_3 = ["European","Steel","EN 10210-2 SHS","SHS50x50x6.3"]
	European_Steel_EN_10210_2_SHS_SHS60x60x2_6 = ["European","Steel","EN 10210-2 SHS","SHS60x60x2.6"]
	European_Steel_EN_10210_2_SHS_SHS60x60x3_2 = ["European","Steel","EN 10210-2 SHS","SHS60x60x3.2"]
	European_Steel_EN_10210_2_SHS_SHS60x60x4 = ["European","Steel","EN 10210-2 SHS","SHS60x60x4"]
	European_Steel_EN_10210_2_SHS_SHS60x60x5 = ["European","Steel","EN 10210-2 SHS","SHS60x60x5"]
	European_Steel_EN_10210_2_SHS_SHS60x60x6_3 = ["European","Steel","EN 10210-2 SHS","SHS60x60x6.3"]
	European_Steel_EN_10210_2_SHS_SHS60x60x8 = ["European","Steel","EN 10210-2 SHS","SHS60x60x8"]
	European_Steel_EN_10210_2_SHS_SHS70x70x3_2 = ["European","Steel","EN 10210-2 SHS","SHS70x70x3.2"]
	European_Steel_EN_10210_2_SHS_SHS70x70x4 = ["European","Steel","EN 10210-2 SHS","SHS70x70x4"]
	European_Steel_EN_10210_2_SHS_SHS70x70x5 = ["European","Steel","EN 10210-2 SHS","SHS70x70x5"]
	European_Steel_EN_10210_2_SHS_SHS70x70x6_3 = ["European","Steel","EN 10210-2 SHS","SHS70x70x6.3"]
	European_Steel_EN_10210_2_SHS_SHS70x70x8 = ["European","Steel","EN 10210-2 SHS","SHS70x70x8"]
	European_Steel_EN_10210_2_SHS_SHS80x80x3_2 = ["European","Steel","EN 10210-2 SHS","SHS80x80x3.2"]
	European_Steel_EN_10210_2_SHS_SHS80x80x4 = ["European","Steel","EN 10210-2 SHS","SHS80x80x4"]
	European_Steel_EN_10210_2_SHS_SHS80x80x5 = ["European","Steel","EN 10210-2 SHS","SHS80x80x5"]
	European_Steel_EN_10210_2_SHS_SHS80x80x6_3 = ["European","Steel","EN 10210-2 SHS","SHS80x80x6.3"]
	European_Steel_EN_10210_2_SHS_SHS80x80x8 = ["European","Steel","EN 10210-2 SHS","SHS80x80x8"]
	European_Steel_EN_10210_2_SHS_SHS90x90x4 = ["European","Steel","EN 10210-2 SHS","SHS90x90x4"]
	European_Steel_EN_10210_2_SHS_SHS90x90x5 = ["European","Steel","EN 10210-2 SHS","SHS90x90x5"]
	European_Steel_EN_10210_2_SHS_SHS90x90x6_3 = ["European","Steel","EN 10210-2 SHS","SHS90x90x6.3"]
	European_Steel_EN_10210_2_SHS_SHS90x90x8 = ["European","Steel","EN 10210-2 SHS","SHS90x90x8"]
	European_Steel_EN_10210_2_SHS_SHS100x100x4 = ["European","Steel","EN 10210-2 SHS","SHS100x100x4"]
	European_Steel_EN_10210_2_SHS_SHS100x100x5 = ["European","Steel","EN 10210-2 SHS","SHS100x100x5"]
	European_Steel_EN_10210_2_SHS_SHS100x100x6_3 = ["European","Steel","EN 10210-2 SHS","SHS100x100x6.3"]
	European_Steel_EN_10210_2_SHS_SHS100x100x8 = ["European","Steel","EN 10210-2 SHS","SHS100x100x8"]
	European_Steel_EN_10210_2_SHS_SHS100x100x10 = ["European","Steel","EN 10210-2 SHS","SHS100x100x10"]
	European_Steel_EN_10210_2_SHS_SHS120x120x5 = ["European","Steel","EN 10210-2 SHS","SHS120x120x5"]
	European_Steel_EN_10210_2_SHS_SHS120x120x6_3 = ["European","Steel","EN 10210-2 SHS","SHS120x120x6.3"]
	European_Steel_EN_10210_2_SHS_SHS120x120x8 = ["European","Steel","EN 10210-2 SHS","SHS120x120x8"]
	European_Steel_EN_10210_2_SHS_SHS120x120x10 = ["European","Steel","EN 10210-2 SHS","SHS120x120x10"]
	European_Steel_EN_10210_2_SHS_SHS120x120x12_5 = ["European","Steel","EN 10210-2 SHS","SHS120x120x12.5"]
	European_Steel_EN_10210_2_SHS_SHS140x140x5 = ["European","Steel","EN 10210-2 SHS","SHS140x140x5"]
	European_Steel_EN_10210_2_SHS_SHS140x140x6_3 = ["European","Steel","EN 10210-2 SHS","SHS140x140x6.3"]
	European_Steel_EN_10210_2_SHS_SHS140x140x8 = ["European","Steel","EN 10210-2 SHS","SHS140x140x8"]
	European_Steel_EN_10210_2_SHS_SHS140x140x10 = ["European","Steel","EN 10210-2 SHS","SHS140x140x10"]
	European_Steel_EN_10210_2_SHS_SHS140x140x12_5 = ["European","Steel","EN 10210-2 SHS","SHS140x140x12.5"]
	European_Steel_EN_10210_2_SHS_SHS150x150x5 = ["European","Steel","EN 10210-2 SHS","SHS150x150x5"]
	European_Steel_EN_10210_2_SHS_SHS150x150x6_3 = ["European","Steel","EN 10210-2 SHS","SHS150x150x6.3"]
	European_Steel_EN_10210_2_SHS_SHS150x150x8 = ["European","Steel","EN 10210-2 SHS","SHS150x150x8"]
	European_Steel_EN_10210_2_SHS_SHS150x150x10 = ["European","Steel","EN 10210-2 SHS","SHS150x150x10"]
	European_Steel_EN_10210_2_SHS_SHS150x150x12_5 = ["European","Steel","EN 10210-2 SHS","SHS150x150x12.5"]
	European_Steel_EN_10210_2_SHS_SHS150x150x14_2 = ["European","Steel","EN 10210-2 SHS","SHS150x150x14.2"]
	European_Steel_EN_10210_2_SHS_SHS150x150x16 = ["European","Steel","EN 10210-2 SHS","SHS150x150x16"]
	European_Steel_EN_10210_2_SHS_SHS160x160x5 = ["European","Steel","EN 10210-2 SHS","SHS160x160x5"]
	European_Steel_EN_10210_2_SHS_SHS160x160x6_3 = ["European","Steel","EN 10210-2 SHS","SHS160x160x6.3"]
	European_Steel_EN_10210_2_SHS_SHS160x160x8 = ["European","Steel","EN 10210-2 SHS","SHS160x160x8"]
	European_Steel_EN_10210_2_SHS_SHS160x160x10 = ["European","Steel","EN 10210-2 SHS","SHS160x160x10"]
	European_Steel_EN_10210_2_SHS_SHS160x160x12_5 = ["European","Steel","EN 10210-2 SHS","SHS160x160x12.5"]
	European_Steel_EN_10210_2_SHS_SHS160x160x14_2 = ["European","Steel","EN 10210-2 SHS","SHS160x160x14.2"]
	European_Steel_EN_10210_2_SHS_SHS160x160x16 = ["European","Steel","EN 10210-2 SHS","SHS160x160x16"]
	European_Steel_EN_10210_2_SHS_SHS180x180x5 = ["European","Steel","EN 10210-2 SHS","SHS180x180x5"]
	European_Steel_EN_10210_2_SHS_SHS180x180x6_3 = ["European","Steel","EN 10210-2 SHS","SHS180x180x6.3"]
	European_Steel_EN_10210_2_SHS_SHS180x180x8 = ["European","Steel","EN 10210-2 SHS","SHS180x180x8"]
	European_Steel_EN_10210_2_SHS_SHS180x180x10 = ["European","Steel","EN 10210-2 SHS","SHS180x180x10"]
	European_Steel_EN_10210_2_SHS_SHS180x180x12_5 = ["European","Steel","EN 10210-2 SHS","SHS180x180x12.5"]
	European_Steel_EN_10210_2_SHS_SHS180x180x14_2 = ["European","Steel","EN 10210-2 SHS","SHS180x180x14.2"]
	European_Steel_EN_10210_2_SHS_SHS180x180x16 = ["European","Steel","EN 10210-2 SHS","SHS180x180x16"]
	European_Steel_EN_10210_2_SHS_SHS200x200x5 = ["European","Steel","EN 10210-2 SHS","SHS200x200x5"]
	European_Steel_EN_10210_2_SHS_SHS200x200x6_3 = ["European","Steel","EN 10210-2 SHS","SHS200x200x6.3"]
	European_Steel_EN_10210_2_SHS_SHS200x200x8 = ["European","Steel","EN 10210-2 SHS","SHS200x200x8"]
	European_Steel_EN_10210_2_SHS_SHS200x200x10 = ["European","Steel","EN 10210-2 SHS","SHS200x200x10"]
	European_Steel_EN_10210_2_SHS_SHS200x200x12_5 = ["European","Steel","EN 10210-2 SHS","SHS200x200x12.5"]
	European_Steel_EN_10210_2_SHS_SHS200x200x14_2 = ["European","Steel","EN 10210-2 SHS","SHS200x200x14.2"]
	European_Steel_EN_10210_2_SHS_SHS200x200x16 = ["European","Steel","EN 10210-2 SHS","SHS200x200x16"]
	European_Steel_EN_10210_2_SHS_SHS220x220x6_3 = ["European","Steel","EN 10210-2 SHS","SHS220x220x6.3"]
	European_Steel_EN_10210_2_SHS_SHS220x220x8 = ["European","Steel","EN 10210-2 SHS","SHS220x220x8"]
	European_Steel_EN_10210_2_SHS_SHS220x220x10 = ["European","Steel","EN 10210-2 SHS","SHS220x220x10"]
	European_Steel_EN_10210_2_SHS_SHS220x220x12_5 = ["European","Steel","EN 10210-2 SHS","SHS220x220x12.5"]
	European_Steel_EN_10210_2_SHS_SHS220x220x14_2 = ["European","Steel","EN 10210-2 SHS","SHS220x220x14.2"]
	European_Steel_EN_10210_2_SHS_SHS220x220x16 = ["European","Steel","EN 10210-2 SHS","SHS220x220x16"]
	European_Steel_EN_10210_2_SHS_SHS250x250x6_3 = ["European","Steel","EN 10210-2 SHS","SHS250x250x6.3"]
	European_Steel_EN_10210_2_SHS_SHS250x250x8 = ["European","Steel","EN 10210-2 SHS","SHS250x250x8"]
	European_Steel_EN_10210_2_SHS_SHS250x250x10 = ["European","Steel","EN 10210-2 SHS","SHS250x250x10"]
	European_Steel_EN_10210_2_SHS_SHS250x250x12_5 = ["European","Steel","EN 10210-2 SHS","SHS250x250x12.5"]
	European_Steel_EN_10210_2_SHS_SHS250x250x14_2 = ["European","Steel","EN 10210-2 SHS","SHS250x250x14.2"]
	European_Steel_EN_10210_2_SHS_SHS250x250x16 = ["European","Steel","EN 10210-2 SHS","SHS250x250x16"]
	European_Steel_EN_10210_2_SHS_SHS260x260x6_3 = ["European","Steel","EN 10210-2 SHS","SHS260x260x6.3"]
	European_Steel_EN_10210_2_SHS_SHS260x260x8 = ["European","Steel","EN 10210-2 SHS","SHS260x260x8"]
	European_Steel_EN_10210_2_SHS_SHS260x260x10 = ["European","Steel","EN 10210-2 SHS","SHS260x260x10"]
	European_Steel_EN_10210_2_SHS_SHS260x260x12_5 = ["European","Steel","EN 10210-2 SHS","SHS260x260x12.5"]
	European_Steel_EN_10210_2_SHS_SHS260x260x14_2 = ["European","Steel","EN 10210-2 SHS","SHS260x260x14.2"]
	European_Steel_EN_10210_2_SHS_SHS260x260x16 = ["European","Steel","EN 10210-2 SHS","SHS260x260x16"]
	European_Steel_EN_10210_2_SHS_SHS300x300x6_3 = ["European","Steel","EN 10210-2 SHS","SHS300x300x6.3"]
	European_Steel_EN_10210_2_SHS_SHS300x300x8 = ["European","Steel","EN 10210-2 SHS","SHS300x300x8"]
	European_Steel_EN_10210_2_SHS_SHS300x300x10 = ["European","Steel","EN 10210-2 SHS","SHS300x300x10"]
	European_Steel_EN_10210_2_SHS_SHS300x300x12_5 = ["European","Steel","EN 10210-2 SHS","SHS300x300x12.5"]
	European_Steel_EN_10210_2_SHS_SHS300x300x14_2 = ["European","Steel","EN 10210-2 SHS","SHS300x300x14.2"]
	European_Steel_EN_10210_2_SHS_SHS300x300x16 = ["European","Steel","EN 10210-2 SHS","SHS300x300x16"]
	European_Steel_EN_10210_2_SHS_SHS350x350x8 = ["European","Steel","EN 10210-2 SHS","SHS350x350x8"]
	European_Steel_EN_10210_2_SHS_SHS350x350x10 = ["European","Steel","EN 10210-2 SHS","SHS350x350x10"]
	European_Steel_EN_10210_2_SHS_SHS350x350x12_5 = ["European","Steel","EN 10210-2 SHS","SHS350x350x12.5"]
	European_Steel_EN_10210_2_SHS_SHS350x350x14_2 = ["European","Steel","EN 10210-2 SHS","SHS350x350x14.2"]
	European_Steel_EN_10210_2_SHS_SHS350x350x16 = ["European","Steel","EN 10210-2 SHS","SHS350x350x16"]
	European_Steel_EN_10210_2_SHS_SHS400x400x10 = ["European","Steel","EN 10210-2 SHS","SHS400x400x10"]
	European_Steel_EN_10210_2_SHS_SHS400x400x12_5 = ["European","Steel","EN 10210-2 SHS","SHS400x400x12.5"]
	European_Steel_EN_10210_2_SHS_SHS400x400x14_2 = ["European","Steel","EN 10210-2 SHS","SHS400x400x14.2"]
	European_Steel_EN_10210_2_SHS_SHS400x400x16 = ["European","Steel","EN 10210-2 SHS","SHS400x400x16"]
	European_Steel_EN_10210_2_SHS_SHS400x400x20 = ["European","Steel","EN 10210-2 SHS","SHS400x400x20"]
	European_Steel_Equal_angles_L_20x20x3 = ["European","Steel","Equal angles","L 20x20x3"]
	European_Steel_Equal_angles_L_25x25x3 = ["European","Steel","Equal angles","L 25x25x3"]
	European_Steel_Equal_angles_L_25x25x4 = ["European","Steel","Equal angles","L 25x25x4"]
	European_Steel_Equal_angles_L_30x30x3 = ["European","Steel","Equal angles","L 30x30x3"]
	European_Steel_Equal_angles_L_30x30x4 = ["European","Steel","Equal angles","L 30x30x4"]
	European_Steel_Equal_angles_L_35x35x4 = ["European","Steel","Equal angles","L 35x35x4"]
	European_Steel_Equal_angles_L_40x40x4 = ["European","Steel","Equal angles","L 40x40x4"]
	European_Steel_Equal_angles_L_40x40x5 = ["European","Steel","Equal angles","L 40x40x5"]
	European_Steel_Equal_angles_L_45x45x4_5 = ["European","Steel","Equal angles","L 45x45x4.5"]
	European_Steel_Equal_angles_L_50x50x4 = ["European","Steel","Equal angles","L 50x50x4"]
	European_Steel_Equal_angles_L_50x50x5 = ["European","Steel","Equal angles","L 50x50x5"]
	European_Steel_Equal_angles_L_50x50x6 = ["European","Steel","Equal angles","L 50x50x6"]
	European_Steel_Equal_angles_L_60x60x5 = ["European","Steel","Equal angles","L 60x60x5"]
	European_Steel_Equal_angles_L_60x60x6 = ["European","Steel","Equal angles","L 60x60x6"]
	European_Steel_Equal_angles_L_60x60x8 = ["European","Steel","Equal angles","L 60x60x8"]
	European_Steel_Equal_angles_L_65x65x7 = ["European","Steel","Equal angles","L 65x65x7"]
	European_Steel_Equal_angles_L_70x70x6 = ["European","Steel","Equal angles","L 70x70x6"]
	European_Steel_Equal_angles_L_70x70x7 = ["European","Steel","Equal angles","L 70x70x7"]
	European_Steel_Equal_angles_L_75x75x6 = ["European","Steel","Equal angles","L 75x75x6"]
	European_Steel_Equal_angles_L_75x75x8 = ["European","Steel","Equal angles","L 75x75x8"]
	European_Steel_Equal_angles_L_80x80x8 = ["European","Steel","Equal angles","L 80x80x8"]
	European_Steel_Equal_angles_L_80x80x10 = ["European","Steel","Equal angles","L 80x80x10"]
	European_Steel_Equal_angles_L_90x90x7 = ["European","Steel","Equal angles","L 90x90x7"]
	European_Steel_Equal_angles_L_90x90x8 = ["European","Steel","Equal angles","L 90x90x8"]
	European_Steel_Equal_angles_L_90x90x9 = ["European","Steel","Equal angles","L 90x90x9"]
	European_Steel_Equal_angles_L_90x90x10 = ["European","Steel","Equal angles","L 90x90x10"]
	European_Steel_Equal_angles_L_100x100x8 = ["European","Steel","Equal angles","L 100x100x8"]
	European_Steel_Equal_angles_L_100x100x10 = ["European","Steel","Equal angles","L 100x100x10"]
	European_Steel_Equal_angles_L_100x100x12 = ["European","Steel","Equal angles","L 100x100x12"]
	European_Steel_Equal_angles_L_110x110x10 = ["European","Steel","Equal angles","L 110x110x10"]
	European_Steel_Equal_angles_L_110x110x12 = ["European","Steel","Equal angles","L 110x110x12"]
	European_Steel_Equal_angles_L_120x120x10 = ["European","Steel","Equal angles","L 120x120x10"]
	European_Steel_Equal_angles_L_120x120x11 = ["European","Steel","Equal angles","L 120x120x11"]
	European_Steel_Equal_angles_L_120x120x12 = ["European","Steel","Equal angles","L 120x120x12"]
	European_Steel_Equal_angles_L_120x120x13 = ["European","Steel","Equal angles","L 120x120x13"]
	European_Steel_Equal_angles_L_120x120x15 = ["European","Steel","Equal angles","L 120x120x15"]
	European_Steel_Equal_angles_L_130x130x12 = ["European","Steel","Equal angles","L 130x130x12"]
	European_Steel_Equal_angles_L_140x140x10 = ["European","Steel","Equal angles","L 140x140x10"]
	European_Steel_Equal_angles_L_140x140x13 = ["European","Steel","Equal angles","L 140x140x13"]
	European_Steel_Equal_angles_L_150x150x10 = ["European","Steel","Equal angles","L 150x150x10"]
	European_Steel_Equal_angles_L_150x150x12 = ["European","Steel","Equal angles","L 150x150x12"]
	European_Steel_Equal_angles_L_150x150x14 = ["European","Steel","Equal angles","L 150x150x14"]
	European_Steel_Equal_angles_L_150x150x15 = ["European","Steel","Equal angles","L 150x150x15"]
	European_Steel_Equal_angles_L_150x150x18 = ["European","Steel","Equal angles","L 150x150x18"]
	European_Steel_Equal_angles_L_160x160x14 = ["European","Steel","Equal angles","L 160x160x14"]
	European_Steel_Equal_angles_L_160x160x15 = ["European","Steel","Equal angles","L 160x160x15"]
	European_Steel_Equal_angles_L_160x160x16 = ["European","Steel","Equal angles","L 160x160x16"]
	European_Steel_Equal_angles_L_160x160x17 = ["European","Steel","Equal angles","L 160x160x17"]
	European_Steel_Equal_angles_L_180x180x13 = ["European","Steel","Equal angles","L 180x180x13"]
	European_Steel_Equal_angles_L_180x180x14 = ["European","Steel","Equal angles","L 180x180x14"]
	European_Steel_Equal_angles_L_180x180x15 = ["European","Steel","Equal angles","L 180x180x15"]
	European_Steel_Equal_angles_L_180x180x16 = ["European","Steel","Equal angles","L 180x180x16"]
	European_Steel_Equal_angles_L_180x180x17 = ["European","Steel","Equal angles","L 180x180x17"]
	European_Steel_Equal_angles_L_180x180x18 = ["European","Steel","Equal angles","L 180x180x18"]
	European_Steel_Equal_angles_L_180x180x19 = ["European","Steel","Equal angles","L 180x180x19"]
	European_Steel_Equal_angles_L_180x180x20 = ["European","Steel","Equal angles","L 180x180x20"]
	European_Steel_Equal_angles_L_200x200x15 = ["European","Steel","Equal angles","L 200x200x15"]
	European_Steel_Equal_angles_L_200x200x16 = ["European","Steel","Equal angles","L 200x200x16"]
	European_Steel_Equal_angles_L_200x200x17 = ["European","Steel","Equal angles","L 200x200x17"]
	European_Steel_Equal_angles_L_200x200x18 = ["European","Steel","Equal angles","L 200x200x18"]
	European_Steel_Equal_angles_L_200x200x19 = ["European","Steel","Equal angles","L 200x200x19"]
	European_Steel_Equal_angles_L_200x200x20 = ["European","Steel","Equal angles","L 200x200x20"]
	European_Steel_Equal_angles_L_200x200x21 = ["European","Steel","Equal angles","L 200x200x21"]
	European_Steel_Equal_angles_L_200x200x22 = ["European","Steel","Equal angles","L 200x200x22"]
	European_Steel_Equal_angles_L_200x200x23 = ["European","Steel","Equal angles","L 200x200x23"]
	European_Steel_Equal_angles_L_200x200x24 = ["European","Steel","Equal angles","L 200x200x24"]
	European_Steel_Equal_angles_L_200x200x25 = ["European","Steel","Equal angles","L 200x200x25"]
	European_Steel_Equal_angles_L_200x200x26 = ["European","Steel","Equal angles","L 200x200x26"]
	European_Steel_Equal_angles_L_203x203x19 = ["European","Steel","Equal angles","L 203x203x19"]
	European_Steel_Equal_angles_L_203x203x22_2 = ["European","Steel","Equal angles","L 203x203x22.2"]
	European_Steel_Equal_angles_L_203x203x25_4 = ["European","Steel","Equal angles","L 203x203x25.4"]
	European_Steel_Equal_angles_L_203x203x28_6 = ["European","Steel","Equal angles","L 203x203x28.6"]
	European_Steel_Equal_angles_L_250x250x20 = ["European","Steel","Equal angles","L 250x250x20"]
	European_Steel_Equal_angles_L_250x250x21 = ["European","Steel","Equal angles","L 250x250x21"]
	European_Steel_Equal_angles_L_250x250x22 = ["European","Steel","Equal angles","L 250x250x22"]
	European_Steel_Equal_angles_L_250x250x23 = ["European","Steel","Equal angles","L 250x250x23"]
	European_Steel_Equal_angles_L_250x250x24 = ["European","Steel","Equal angles","L 250x250x24"]
	European_Steel_Equal_angles_L_250x250x25 = ["European","Steel","Equal angles","L 250x250x25"]
	European_Steel_Equal_angles_L_250x250x26 = ["European","Steel","Equal angles","L 250x250x26"]
	European_Steel_Equal_angles_L_250x250x27 = ["European","Steel","Equal angles","L 250x250x27"]
	European_Steel_Equal_angles_L_250x250x28 = ["European","Steel","Equal angles","L 250x250x28"]
	European_Steel_Equal_angles_L_250x250x35 = ["European","Steel","Equal angles","L 250x250x35"]
	European_Steel_IPE_beams_IPE_80 = ["European","Steel","IPE beams","IPE 80"]
	European_Steel_IPE_beams_IPE_100 = ["European","Steel","IPE beams","IPE 100"]
	European_Steel_IPE_beams_IPE_120 = ["European","Steel","IPE beams","IPE 120"]
	European_Steel_IPE_beams_IPE_140 = ["European","Steel","IPE beams","IPE 140"]
	European_Steel_IPE_beams_IPE_160 = ["European","Steel","IPE beams","IPE 160"]
	European_Steel_IPE_beams_IPE_180 = ["European","Steel","IPE beams","IPE 180"]
	European_Steel_IPE_beams_IPE_200 = ["European","Steel","IPE beams","IPE 200"]
	European_Steel_IPE_beams_IPE_220 = ["European","Steel","IPE beams","IPE 220"]
	European_Steel_IPE_beams_IPE_240 = ["European","Steel","IPE beams","IPE 240"]
	European_Steel_IPE_beams_IPE_270 = ["European","Steel","IPE beams","IPE 270"]
	European_Steel_IPE_beams_IPE_300 = ["European","Steel","IPE beams","IPE 300"]
	European_Steel_IPE_beams_IPE_330 = ["European","Steel","IPE beams","IPE 330"]
	European_Steel_IPE_beams_IPE_360 = ["European","Steel","IPE beams","IPE 360"]
	European_Steel_IPE_beams_IPE_400 = ["European","Steel","IPE beams","IPE 400"]
	European_Steel_IPE_beams_IPE_450 = ["European","Steel","IPE beams","IPE 450"]
	European_Steel_IPE_beams_IPE_500 = ["European","Steel","IPE beams","IPE 500"]
	European_Steel_IPE_beams_IPE_550 = ["European","Steel","IPE beams","IPE 550"]
	European_Steel_IPE_beams_IPE_600 = ["European","Steel","IPE beams","IPE 600"]
	European_Steel_IPE_beams_IPE_750x137 = ["European","Steel","IPE beams","IPE 750x137"]
	European_Steel_IPE_beams_IPE_750x147 = ["European","Steel","IPE beams","IPE 750x147"]
	European_Steel_IPE_beams_IPE_750x173 = ["European","Steel","IPE beams","IPE 750x173"]
	European_Steel_IPE_beams_IPE_750x196 = ["European","Steel","IPE beams","IPE 750x196"]
	European_Steel_IPE_beams_IPE_A_80 = ["European","Steel","IPE beams","IPE A 80"]
	European_Steel_IPE_beams_IPE_A_100 = ["European","Steel","IPE beams","IPE A 100"]
	European_Steel_IPE_beams_IPE_A_120 = ["European","Steel","IPE beams","IPE A 120"]
	European_Steel_IPE_beams_IPE_A_140 = ["European","Steel","IPE beams","IPE A 140"]
	European_Steel_IPE_beams_IPE_A_160 = ["European","Steel","IPE beams","IPE A 160"]
	European_Steel_IPE_beams_IPE_A_180 = ["European","Steel","IPE beams","IPE A 180"]
	European_Steel_IPE_beams_IPE_A_200 = ["European","Steel","IPE beams","IPE A 200"]
	European_Steel_IPE_beams_IPE_A_220 = ["European","Steel","IPE beams","IPE A 220"]
	European_Steel_IPE_beams_IPE_A_240 = ["European","Steel","IPE beams","IPE A 240"]
	European_Steel_IPE_beams_IPE_A_270 = ["European","Steel","IPE beams","IPE A 270"]
	European_Steel_IPE_beams_IPE_A_300 = ["European","Steel","IPE beams","IPE A 300"]
	European_Steel_IPE_beams_IPE_A_330 = ["European","Steel","IPE beams","IPE A 330"]
	European_Steel_IPE_beams_IPE_A_360 = ["European","Steel","IPE beams","IPE A 360"]
	European_Steel_IPE_beams_IPE_A_400 = ["European","Steel","IPE beams","IPE A 400"]
	European_Steel_IPE_beams_IPE_A_450 = ["European","Steel","IPE beams","IPE A 450"]
	European_Steel_IPE_beams_IPE_A_500 = ["European","Steel","IPE beams","IPE A 500"]
	European_Steel_IPE_beams_IPE_A_550 = ["European","Steel","IPE beams","IPE A 550"]
	European_Steel_IPE_beams_IPE_A_600 = ["European","Steel","IPE beams","IPE A 600"]
	European_Steel_IPE_beams_IPE_O_180 = ["European","Steel","IPE beams","IPE O 180"]
	European_Steel_IPE_beams_IPE_O_200 = ["European","Steel","IPE beams","IPE O 200"]
	European_Steel_IPE_beams_IPE_O_220 = ["European","Steel","IPE beams","IPE O 220"]
	European_Steel_IPE_beams_IPE_O_240 = ["European","Steel","IPE beams","IPE O 240"]
	European_Steel_IPE_beams_IPE_O_270 = ["European","Steel","IPE beams","IPE O 270"]
	European_Steel_IPE_beams_IPE_O_300 = ["European","Steel","IPE beams","IPE O 300"]
	European_Steel_IPE_beams_IPE_O_330 = ["European","Steel","IPE beams","IPE O 330"]
	European_Steel_IPE_beams_IPE_O_360 = ["European","Steel","IPE beams","IPE O 360"]
	European_Steel_IPE_beams_IPE_O_400 = ["European","Steel","IPE beams","IPE O 400"]
	European_Steel_IPE_beams_IPE_O_450 = ["European","Steel","IPE beams","IPE O 450"]
	European_Steel_IPE_beams_IPE_O_500 = ["European","Steel","IPE beams","IPE O 500"]
	European_Steel_IPE_beams_IPE_O_550 = ["European","Steel","IPE beams","IPE O 550"]
	European_Steel_IPE_beams_IPE_O_600 = ["European","Steel","IPE beams","IPE O 600"]
	European_Steel_Parallel_flange_UAP_channels_UAP_80 = ["European","Steel","Parallel flange UAP channels","UAP 80"]
	European_Steel_Parallel_flange_UAP_channels_UAP_100 = ["European","Steel","Parallel flange UAP channels","UAP 100"]
	European_Steel_Parallel_flange_UAP_channels_UAP_130 = ["European","Steel","Parallel flange UAP channels","UAP 130"]
	European_Steel_Parallel_flange_UAP_channels_UAP_150 = ["European","Steel","Parallel flange UAP channels","UAP 150"]
	European_Steel_Parallel_flange_UAP_channels_UAP_175 = ["European","Steel","Parallel flange UAP channels","UAP 175"]
	European_Steel_Parallel_flange_UAP_channels_UAP_200 = ["European","Steel","Parallel flange UAP channels","UAP 200"]
	European_Steel_Parallel_flange_UAP_channels_UAP_220 = ["European","Steel","Parallel flange UAP channels","UAP 220"]
	European_Steel_Parallel_flange_UAP_channels_UAP_250 = ["European","Steel","Parallel flange UAP channels","UAP 250"]
	European_Steel_Parallel_flange_UAP_channels_UAP_300 = ["European","Steel","Parallel flange UAP channels","UAP 300"]
	European_Steel_Parallel_flange_UPE_channels_UPE_80 = ["European","Steel","Parallel flange UPE channels","UPE 80"]
	European_Steel_Parallel_flange_UPE_channels_UPE_100 = ["European","Steel","Parallel flange UPE channels","UPE 100"]
	European_Steel_Parallel_flange_UPE_channels_UPE_120 = ["European","Steel","Parallel flange UPE channels","UPE 120"]
	European_Steel_Parallel_flange_UPE_channels_UPE_140 = ["European","Steel","Parallel flange UPE channels","UPE 140"]
	European_Steel_Parallel_flange_UPE_channels_UPE_160 = ["European","Steel","Parallel flange UPE channels","UPE 160"]
	European_Steel_Parallel_flange_UPE_channels_UPE_180 = ["European","Steel","Parallel flange UPE channels","UPE 180"]
	European_Steel_Parallel_flange_UPE_channels_UPE_200 = ["European","Steel","Parallel flange UPE channels","UPE 200"]
	European_Steel_Parallel_flange_UPE_channels_UPE_220 = ["European","Steel","Parallel flange UPE channels","UPE 220"]
	European_Steel_Parallel_flange_UPE_channels_UPE_240 = ["European","Steel","Parallel flange UPE channels","UPE 240"]
	European_Steel_Parallel_flange_UPE_channels_UPE_270 = ["European","Steel","Parallel flange UPE channels","UPE 270"]
	European_Steel_Parallel_flange_UPE_channels_UPE_300 = ["European","Steel","Parallel flange UPE channels","UPE 300"]
	European_Steel_Parallel_flange_UPE_channels_UPE_330 = ["European","Steel","Parallel flange UPE channels","UPE 330"]
	European_Steel_Parallel_flange_UPE_channels_UPE_360 = ["European","Steel","Parallel flange UPE channels","UPE 360"]
	European_Steel_Parallel_flange_UPE_channels_UPE_400 = ["European","Steel","Parallel flange UPE channels","UPE 400"]
	European_Steel_Standard_IPN_beams_IPN_80 = ["European","Steel","Standard IPN beams","IPN 80"]
	European_Steel_Standard_IPN_beams_IPN_100 = ["European","Steel","Standard IPN beams","IPN 100"]
	European_Steel_Standard_IPN_beams_IPN_120 = ["European","Steel","Standard IPN beams","IPN 120"]
	European_Steel_Standard_IPN_beams_IPN_140 = ["European","Steel","Standard IPN beams","IPN 140"]
	European_Steel_Standard_IPN_beams_IPN_160 = ["European","Steel","Standard IPN beams","IPN 160"]
	European_Steel_Standard_IPN_beams_IPN_180 = ["European","Steel","Standard IPN beams","IPN 180"]
	European_Steel_Standard_IPN_beams_IPN_200 = ["European","Steel","Standard IPN beams","IPN 200"]
	European_Steel_Standard_IPN_beams_IPN_220 = ["European","Steel","Standard IPN beams","IPN 220"]
	European_Steel_Standard_IPN_beams_IPN_240 = ["European","Steel","Standard IPN beams","IPN 240"]
	European_Steel_Standard_IPN_beams_IPN_260 = ["European","Steel","Standard IPN beams","IPN 260"]
	European_Steel_Standard_IPN_beams_IPN_280 = ["European","Steel","Standard IPN beams","IPN 280"]
	European_Steel_Standard_IPN_beams_IPN_300 = ["European","Steel","Standard IPN beams","IPN 300"]
	European_Steel_Standard_IPN_beams_IPN_320 = ["European","Steel","Standard IPN beams","IPN 320"]
	European_Steel_Standard_IPN_beams_IPN_340 = ["European","Steel","Standard IPN beams","IPN 340"]
	European_Steel_Standard_IPN_beams_IPN_360 = ["European","Steel","Standard IPN beams","IPN 360"]
	European_Steel_Standard_IPN_beams_IPN_380 = ["European","Steel","Standard IPN beams","IPN 380"]
	European_Steel_Standard_IPN_beams_IPN_400 = ["European","Steel","Standard IPN beams","IPN 400"]
	European_Steel_Standard_IPN_beams_IPN_450 = ["European","Steel","Standard IPN beams","IPN 450"]
	European_Steel_Standard_IPN_beams_IPN_500 = ["European","Steel","Standard IPN beams","IPN 500"]
	European_Steel_Standard_IPN_beams_IPN_550 = ["European","Steel","Standard IPN beams","IPN 550"]
	European_Steel_Standard_IPN_beams_IPN_600 = ["European","Steel","Standard IPN beams","IPN 600"]
	European_Steel_Standard_UPN_U_channels_U_40x20 = ["European","Steel","Standard UPN U channels","U 40x20"]
	European_Steel_Standard_UPN_U_channels_U_50x25 = ["European","Steel","Standard UPN U channels","U 50x25"]
	European_Steel_Standard_UPN_U_channels_U_60x30 = ["European","Steel","Standard UPN U channels","U 60x30"]
	European_Steel_Standard_UPN_U_channels_U_65x42 = ["European","Steel","Standard UPN U channels","U 65x42"]
	European_Steel_Standard_UPN_U_channels_UPN_80 = ["European","Steel","Standard UPN U channels","UPN 80"]
	European_Steel_Standard_UPN_U_channels_UPN_100 = ["European","Steel","Standard UPN U channels","UPN 100"]
	European_Steel_Standard_UPN_U_channels_UPN_120 = ["European","Steel","Standard UPN U channels","UPN 120"]
	European_Steel_Standard_UPN_U_channels_UPN_140 = ["European","Steel","Standard UPN U channels","UPN 140"]
	European_Steel_Standard_UPN_U_channels_UPN_160 = ["European","Steel","Standard UPN U channels","UPN 160"]
	European_Steel_Standard_UPN_U_channels_UPN_180 = ["European","Steel","Standard UPN U channels","UPN 180"]
	European_Steel_Standard_UPN_U_channels_UPN_200 = ["European","Steel","Standard UPN U channels","UPN 200"]
	European_Steel_Standard_UPN_U_channels_UPN_220 = ["European","Steel","Standard UPN U channels","UPN 220"]
	European_Steel_Standard_UPN_U_channels_UPN_240 = ["European","Steel","Standard UPN U channels","UPN 240"]
	European_Steel_Standard_UPN_U_channels_UPN_260 = ["European","Steel","Standard UPN U channels","UPN 260"]
	European_Steel_Standard_UPN_U_channels_UPN_280 = ["European","Steel","Standard UPN U channels","UPN 280"]
	European_Steel_Standard_UPN_U_channels_UPN_300 = ["European","Steel","Standard UPN U channels","UPN 300"]
	European_Steel_Standard_UPN_U_channels_UPN_320 = ["European","Steel","Standard UPN U channels","UPN 320"]
	European_Steel_Standard_UPN_U_channels_UPN_350 = ["European","Steel","Standard UPN U channels","UPN 350"]
	European_Steel_Standard_UPN_U_channels_UPN_380 = ["European","Steel","Standard UPN U channels","UPN 380"]
	European_Steel_Standard_UPN_U_channels_UPN_400 = ["European","Steel","Standard UPN U channels","UPN 400"]
	European_Steel_Unequal_angles_L_120x80x8 = ["European","Steel","Unequal angles","L 120x80x8"]
	European_Steel_Unequal_angles_L_120x80x10 = ["European","Steel","Unequal angles","L 120x80x10"]
	European_Steel_Unequal_angles_L_120x80x12 = ["European","Steel","Unequal angles","L 120x80x12"]
	European_Steel_Unequal_angles_L_130x65x8 = ["European","Steel","Unequal angles","L 130x65x8"]
	European_Steel_Unequal_angles_L_130x65x10 = ["European","Steel","Unequal angles","L 130x65x10"]
	European_Steel_Unequal_angles_L_150x75x9 = ["European","Steel","Unequal angles","L 150x75x9"]
	European_Steel_Unequal_angles_L_150x75x10 = ["European","Steel","Unequal angles","L 150x75x10"]
	European_Steel_Unequal_angles_L_150x75x11 = ["European","Steel","Unequal angles","L 150x75x11"]
	European_Steel_Unequal_angles_L_150x75x12 = ["European","Steel","Unequal angles","L 150x75x12"]
	European_Steel_Unequal_angles_L_150x90x10 = ["European","Steel","Unequal angles","L 150x90x10"]
	European_Steel_Unequal_angles_L_150x90x11 = ["European","Steel","Unequal angles","L 150x90x11"]
	European_Steel_Unequal_angles_L_150x100x10 = ["European","Steel","Unequal angles","L 150x100x10"]
	European_Steel_Unequal_angles_L_150x100x12 = ["European","Steel","Unequal angles","L 150x100x12"]
	European_Steel_Unequal_angles_L_150x100x14 = ["European","Steel","Unequal angles","L 150x100x14"]
	European_Steel_Unequal_angles_L_160x80x10 = ["European","Steel","Unequal angles","L 160x80x10"]
	European_Steel_Unequal_angles_L_160x80x12 = ["European","Steel","Unequal angles","L 160x80x12"]
	European_Steel_Unequal_angles_L_200x100x10 = ["European","Steel","Unequal angles","L 200x100x10"]
	European_Steel_Unequal_angles_L_200x100x12 = ["European","Steel","Unequal angles","L 200x100x12"]
	European_Steel_Unequal_angles_L_200x100x14 = ["European","Steel","Unequal angles","L 200x100x14"]
	European_Steel_Wide_flange_HD_columns_HD_260x54_1 = ["European","Steel","Wide flange HD columns","HD 260x54.1"]
	European_Steel_Wide_flange_HD_columns_HD_260x68_2 = ["European","Steel","Wide flange HD columns","HD 260x68.2"]
	European_Steel_Wide_flange_HD_columns_HD_260x93_0 = ["European","Steel","Wide flange HD columns","HD 260x93.0"]
	European_Steel_Wide_flange_HD_columns_HD_260x114 = ["European","Steel","Wide flange HD columns","HD 260x114"]
	European_Steel_Wide_flange_HD_columns_HD_260x142 = ["European","Steel","Wide flange HD columns","HD 260x142"]
	European_Steel_Wide_flange_HD_columns_HD_260x172 = ["European","Steel","Wide flange HD columns","HD 260x172"]
	European_Steel_Wide_flange_HD_columns_HD_320x74_2 = ["European","Steel","Wide flange HD columns","HD 320x74.2"]
	European_Steel_Wide_flange_HD_columns_HD_320x97_6 = ["European","Steel","Wide flange HD columns","HD 320x97.6"]
	European_Steel_Wide_flange_HD_columns_HD_320x127 = ["European","Steel","Wide flange HD columns","HD 320x127"]
	European_Steel_Wide_flange_HD_columns_HD_320x158 = ["European","Steel","Wide flange HD columns","HD 320x158"]
	European_Steel_Wide_flange_HD_columns_HD_320x198 = ["European","Steel","Wide flange HD columns","HD 320x198"]
	European_Steel_Wide_flange_HD_columns_HD_320x245 = ["European","Steel","Wide flange HD columns","HD 320x245"]
	European_Steel_Wide_flange_HD_columns_HD_320x300 = ["European","Steel","Wide flange HD columns","HD 320x300"]
	European_Steel_Wide_flange_HD_columns_HD_360x134 = ["European","Steel","Wide flange HD columns","HD 360x134"]
	European_Steel_Wide_flange_HD_columns_HD_360x147 = ["European","Steel","Wide flange HD columns","HD 360x147"]
	European_Steel_Wide_flange_HD_columns_HD_360x162 = ["European","Steel","Wide flange HD columns","HD 360x162"]
	European_Steel_Wide_flange_HD_columns_HD_360x179 = ["European","Steel","Wide flange HD columns","HD 360x179"]
	European_Steel_Wide_flange_HD_columns_HD_360x196 = ["European","Steel","Wide flange HD columns","HD 360x196"]
	European_Steel_Wide_flange_HD_columns_HD_400x187 = ["European","Steel","Wide flange HD columns","HD 400x187"]
	European_Steel_Wide_flange_HD_columns_HD_400x216 = ["European","Steel","Wide flange HD columns","HD 400x216"]
	European_Steel_Wide_flange_HD_columns_HD_400x237 = ["European","Steel","Wide flange HD columns","HD 400x237"]
	European_Steel_Wide_flange_HD_columns_HD_400x262 = ["European","Steel","Wide flange HD columns","HD 400x262"]
	European_Steel_Wide_flange_HD_columns_HD_400x287 = ["European","Steel","Wide flange HD columns","HD 400x287"]
	European_Steel_Wide_flange_HD_columns_HD_400x314 = ["European","Steel","Wide flange HD columns","HD 400x314"]
	European_Steel_Wide_flange_HD_columns_HD_400x347 = ["European","Steel","Wide flange HD columns","HD 400x347"]
	European_Steel_Wide_flange_HD_columns_HD_400x382 = ["European","Steel","Wide flange HD columns","HD 400x382"]
	European_Steel_Wide_flange_HD_columns_HD_400x421 = ["European","Steel","Wide flange HD columns","HD 400x421"]
	European_Steel_Wide_flange_HD_columns_HD_400x463 = ["European","Steel","Wide flange HD columns","HD 400x463"]
	European_Steel_Wide_flange_HD_columns_HD_400x509 = ["European","Steel","Wide flange HD columns","HD 400x509"]
	European_Steel_Wide_flange_HD_columns_HD_400x551 = ["European","Steel","Wide flange HD columns","HD 400x551"]
	European_Steel_Wide_flange_HD_columns_HD_400x592 = ["European","Steel","Wide flange HD columns","HD 400x592"]
	European_Steel_Wide_flange_HD_columns_HD_400x634 = ["European","Steel","Wide flange HD columns","HD 400x634"]
	European_Steel_Wide_flange_HD_columns_HD_400x677 = ["European","Steel","Wide flange HD columns","HD 400x677"]
	European_Steel_Wide_flange_HD_columns_HD_400x744 = ["European","Steel","Wide flange HD columns","HD 400x744"]
	European_Steel_Wide_flange_HD_columns_HD_400x818 = ["European","Steel","Wide flange HD columns","HD 400x818"]
	European_Steel_Wide_flange_HD_columns_HD_400x900 = ["European","Steel","Wide flange HD columns","HD 400x900"]
	European_Steel_Wide_flange_HD_columns_HD_400x990 = ["European","Steel","Wide flange HD columns","HD 400x990"]
	European_Steel_Wide_flange_HD_columns_HD_400x1086 = ["European","Steel","Wide flange HD columns","HD 400x1086"]
	European_Steel_Wide_flange_HE_HL_beams_HE_100_A = ["European","Steel","Wide flange HE HL beams","HE 100 A"]
	European_Steel_Wide_flange_HE_HL_beams_HE_100_AA = ["European","Steel","Wide flange HE HL beams","HE 100 AA"]
	European_Steel_Wide_flange_HE_HL_beams_HE_100_B = ["European","Steel","Wide flange HE HL beams","HE 100 B"]
	European_Steel_Wide_flange_HE_HL_beams_HE_100_M = ["European","Steel","Wide flange HE HL beams","HE 100 M"]
	European_Steel_Wide_flange_HE_HL_beams_HE_120_A = ["European","Steel","Wide flange HE HL beams","HE 120 A"]
	European_Steel_Wide_flange_HE_HL_beams_HE_120_AA = ["European","Steel","Wide flange HE HL beams","HE 120 AA"]
	European_Steel_Wide_flange_HE_HL_beams_HE_120_B = ["European","Steel","Wide flange HE HL beams","HE 120 B"]
	European_Steel_Wide_flange_HE_HL_beams_HE_120_M = ["European","Steel","Wide flange HE HL beams","HE 120 M"]
	European_Steel_Wide_flange_HE_HL_beams_HE_140_A = ["European","Steel","Wide flange HE HL beams","HE 140 A"]
	European_Steel_Wide_flange_HE_HL_beams_HE_140_AA = ["European","Steel","Wide flange HE HL beams","HE 140 AA"]
	European_Steel_Wide_flange_HE_HL_beams_HE_140_B = ["European","Steel","Wide flange HE HL beams","HE 140 B"]
	European_Steel_Wide_flange_HE_HL_beams_HE_140_M = ["European","Steel","Wide flange HE HL beams","HE 140 M"]
	European_Steel_Wide_flange_HE_HL_beams_HE_160_A = ["European","Steel","Wide flange HE HL beams","HE 160 A"]
	European_Steel_Wide_flange_HE_HL_beams_HE_160_AA = ["European","Steel","Wide flange HE HL beams","HE 160 AA"]
	European_Steel_Wide_flange_HE_HL_beams_HE_160_B = ["European","Steel","Wide flange HE HL beams","HE 160 B"]
	European_Steel_Wide_flange_HE_HL_beams_HE_160_M = ["European","Steel","Wide flange HE HL beams","HE 160 M"]
	European_Steel_Wide_flange_HE_HL_beams_HE_180_A = ["European","Steel","Wide flange HE HL beams","HE 180 A"]
	European_Steel_Wide_flange_HE_HL_beams_HE_180_AA = ["European","Steel","Wide flange HE HL beams","HE 180 AA"]
	European_Steel_Wide_flange_HE_HL_beams_HE_180_B = ["European","Steel","Wide flange HE HL beams","HE 180 B"]
	European_Steel_Wide_flange_HE_HL_beams_HE_180_M = ["European","Steel","Wide flange HE HL beams","HE 180 M"]
	European_Steel_Wide_flange_HE_HL_beams_HE_200_A = ["European","Steel","Wide flange HE HL beams","HE 200 A"]
	European_Steel_Wide_flange_HE_HL_beams_HE_200_AA = ["European","Steel","Wide flange HE HL beams","HE 200 AA"]
	European_Steel_Wide_flange_HE_HL_beams_HE_200_B = ["European","Steel","Wide flange HE HL beams","HE 200 B"]
	European_Steel_Wide_flange_HE_HL_beams_HE_200_M = ["European","Steel","Wide flange HE HL beams","HE 200 M"]
	European_Steel_Wide_flange_HE_HL_beams_HE_220_A = ["European","Steel","Wide flange HE HL beams","HE 220 A"]
	European_Steel_Wide_flange_HE_HL_beams_HE_220_AA = ["European","Steel","Wide flange HE HL beams","HE 220 AA"]
	European_Steel_Wide_flange_HE_HL_beams_HE_220_B = ["European","Steel","Wide flange HE HL beams","HE 220 B"]
	European_Steel_Wide_flange_HE_HL_beams_HE_220_M = ["European","Steel","Wide flange HE HL beams","HE 220 M"]
	European_Steel_Wide_flange_HE_HL_beams_HE_240_A = ["European","Steel","Wide flange HE HL beams","HE 240 A"]
	European_Steel_Wide_flange_HE_HL_beams_HE_240_AA = ["European","Steel","Wide flange HE HL beams","HE 240 AA"]
	European_Steel_Wide_flange_HE_HL_beams_HE_240_B = ["European","Steel","Wide flange HE HL beams","HE 240 B"]
	European_Steel_Wide_flange_HE_HL_beams_HE_240_M = ["European","Steel","Wide flange HE HL beams","HE 240 M"]
	European_Steel_Wide_flange_HE_HL_beams_HE_260_A = ["European","Steel","Wide flange HE HL beams","HE 260 A"]
	European_Steel_Wide_flange_HE_HL_beams_HE_260_AA = ["European","Steel","Wide flange HE HL beams","HE 260 AA"]
	European_Steel_Wide_flange_HE_HL_beams_HE_260_B = ["European","Steel","Wide flange HE HL beams","HE 260 B"]
	European_Steel_Wide_flange_HE_HL_beams_HE_260_M = ["European","Steel","Wide flange HE HL beams","HE 260 M"]
	European_Steel_Wide_flange_HE_HL_beams_HE_280_A = ["European","Steel","Wide flange HE HL beams","HE 280 A"]
	European_Steel_Wide_flange_HE_HL_beams_HE_280_AA = ["European","Steel","Wide flange HE HL beams","HE 280 AA"]
	European_Steel_Wide_flange_HE_HL_beams_HE_280_B = ["European","Steel","Wide flange HE HL beams","HE 280 B"]
	European_Steel_Wide_flange_HE_HL_beams_HE_280_M = ["European","Steel","Wide flange HE HL beams","HE 280 M"]
	European_Steel_Wide_flange_HE_HL_beams_HE_300_A = ["European","Steel","Wide flange HE HL beams","HE 300 A"]
	European_Steel_Wide_flange_HE_HL_beams_HE_300_AA = ["European","Steel","Wide flange HE HL beams","HE 300 AA"]
	European_Steel_Wide_flange_HE_HL_beams_HE_300_B = ["European","Steel","Wide flange HE HL beams","HE 300 B"]
	European_Steel_Wide_flange_HE_HL_beams_HE_300_M = ["European","Steel","Wide flange HE HL beams","HE 300 M"]
	European_Steel_Wide_flange_HE_HL_beams_HE_320_A = ["European","Steel","Wide flange HE HL beams","HE 320 A"]
	European_Steel_Wide_flange_HE_HL_beams_HE_320_AA = ["European","Steel","Wide flange HE HL beams","HE 320 AA"]
	European_Steel_Wide_flange_HE_HL_beams_HE_320_B = ["European","Steel","Wide flange HE HL beams","HE 320 B"]
	European_Steel_Wide_flange_HE_HL_beams_HE_320_M = ["European","Steel","Wide flange HE HL beams","HE 320 M"]
	European_Steel_Wide_flange_HE_HL_beams_HE_340_A = ["European","Steel","Wide flange HE HL beams","HE 340 A"]
	European_Steel_Wide_flange_HE_HL_beams_HE_340_AA = ["European","Steel","Wide flange HE HL beams","HE 340 AA"]
	European_Steel_Wide_flange_HE_HL_beams_HE_340_B = ["European","Steel","Wide flange HE HL beams","HE 340 B"]
	European_Steel_Wide_flange_HE_HL_beams_HE_340_M = ["European","Steel","Wide flange HE HL beams","HE 340 M"]
	European_Steel_Wide_flange_HE_HL_beams_HE_360_A = ["European","Steel","Wide flange HE HL beams","HE 360 A"]
	European_Steel_Wide_flange_HE_HL_beams_HE_360_AA = ["European","Steel","Wide flange HE HL beams","HE 360 AA"]
	European_Steel_Wide_flange_HE_HL_beams_HE_360_B = ["European","Steel","Wide flange HE HL beams","HE 360 B"]
	European_Steel_Wide_flange_HE_HL_beams_HE_360_M = ["European","Steel","Wide flange HE HL beams","HE 360 M"]
	European_Steel_Wide_flange_HE_HL_beams_HE_400_A = ["European","Steel","Wide flange HE HL beams","HE 400 A"]
	European_Steel_Wide_flange_HE_HL_beams_HE_400_AA = ["European","Steel","Wide flange HE HL beams","HE 400 AA"]
	European_Steel_Wide_flange_HE_HL_beams_HE_400_B = ["European","Steel","Wide flange HE HL beams","HE 400 B"]
	European_Steel_Wide_flange_HE_HL_beams_HE_400_M = ["European","Steel","Wide flange HE HL beams","HE 400 M"]
	European_Steel_Wide_flange_HE_HL_beams_HE_450_A = ["European","Steel","Wide flange HE HL beams","HE 450 A"]
	European_Steel_Wide_flange_HE_HL_beams_HE_450_AA = ["European","Steel","Wide flange HE HL beams","HE 450 AA"]
	European_Steel_Wide_flange_HE_HL_beams_HE_450_B = ["European","Steel","Wide flange HE HL beams","HE 450 B"]
	European_Steel_Wide_flange_HE_HL_beams_HE_450_M = ["European","Steel","Wide flange HE HL beams","HE 450 M"]
	European_Steel_Wide_flange_HE_HL_beams_HE_500_A = ["European","Steel","Wide flange HE HL beams","HE 500 A"]
	European_Steel_Wide_flange_HE_HL_beams_HE_500_AA = ["European","Steel","Wide flange HE HL beams","HE 500 AA"]
	European_Steel_Wide_flange_HE_HL_beams_HE_500_B = ["European","Steel","Wide flange HE HL beams","HE 500 B"]
	European_Steel_Wide_flange_HE_HL_beams_HE_500_M = ["European","Steel","Wide flange HE HL beams","HE 500 M"]
	European_Steel_Wide_flange_HE_HL_beams_HE_550_A = ["European","Steel","Wide flange HE HL beams","HE 550 A"]
	European_Steel_Wide_flange_HE_HL_beams_HE_550_AA = ["European","Steel","Wide flange HE HL beams","HE 550 AA"]
	European_Steel_Wide_flange_HE_HL_beams_HE_550_B = ["European","Steel","Wide flange HE HL beams","HE 550 B"]
	European_Steel_Wide_flange_HE_HL_beams_HE_550_M = ["European","Steel","Wide flange HE HL beams","HE 550 M"]
	European_Steel_Wide_flange_HE_HL_beams_HE_600_A = ["European","Steel","Wide flange HE HL beams","HE 600 A"]
	European_Steel_Wide_flange_HE_HL_beams_HE_600_AA = ["European","Steel","Wide flange HE HL beams","HE 600 AA"]
	European_Steel_Wide_flange_HE_HL_beams_HE_600_B = ["European","Steel","Wide flange HE HL beams","HE 600 B"]
	European_Steel_Wide_flange_HE_HL_beams_HE_600_M = ["European","Steel","Wide flange HE HL beams","HE 600 M"]
	European_Steel_Wide_flange_HE_HL_beams_HE_600x337 = ["European","Steel","Wide flange HE HL beams","HE 600x337"]
	European_Steel_Wide_flange_HE_HL_beams_HE_600x340 = ["European","Steel","Wide flange HE HL beams","HE 600x340"]
	European_Steel_Wide_flange_HE_HL_beams_HE_600x399 = ["European","Steel","Wide flange HE HL beams","HE 600x399"]
	European_Steel_Wide_flange_HE_HL_beams_HE_600x402 = ["European","Steel","Wide flange HE HL beams","HE 600x402"]
	European_Steel_Wide_flange_HE_HL_beams_HE_650_A = ["European","Steel","Wide flange HE HL beams","HE 650 A"]
	European_Steel_Wide_flange_HE_HL_beams_HE_650_AA = ["European","Steel","Wide flange HE HL beams","HE 650 AA"]
	European_Steel_Wide_flange_HE_HL_beams_HE_650_B = ["European","Steel","Wide flange HE HL beams","HE 650 B"]
	European_Steel_Wide_flange_HE_HL_beams_HE_650_M = ["European","Steel","Wide flange HE HL beams","HE 650 M"]
	European_Steel_Wide_flange_HE_HL_beams_HE_650x343 = ["European","Steel","Wide flange HE HL beams","HE 650x343"]
	European_Steel_Wide_flange_HE_HL_beams_HE_650x347 = ["European","Steel","Wide flange HE HL beams","HE 650x347"]
	European_Steel_Wide_flange_HE_HL_beams_HE_650x407 = ["European","Steel","Wide flange HE HL beams","HE 650x407"]
	European_Steel_Wide_flange_HE_HL_beams_HE_650x410 = ["European","Steel","Wide flange HE HL beams","HE 650x410"]
	European_Steel_Wide_flange_HE_HL_beams_HE_700_A = ["European","Steel","Wide flange HE HL beams","HE 700 A"]
	European_Steel_Wide_flange_HE_HL_beams_HE_700_AA = ["European","Steel","Wide flange HE HL beams","HE 700 AA"]
	European_Steel_Wide_flange_HE_HL_beams_HE_700_B = ["European","Steel","Wide flange HE HL beams","HE 700 B"]
	European_Steel_Wide_flange_HE_HL_beams_HE_700_M = ["European","Steel","Wide flange HE HL beams","HE 700 M"]
	European_Steel_Wide_flange_HE_HL_beams_HE_700x352 = ["European","Steel","Wide flange HE HL beams","HE 700x352"]
	European_Steel_Wide_flange_HE_HL_beams_HE_700x356 = ["European","Steel","Wide flange HE HL beams","HE 700x356"]
	European_Steel_Wide_flange_HE_HL_beams_HE_700x418 = ["European","Steel","Wide flange HE HL beams","HE 700x418"]
	European_Steel_Wide_flange_HE_HL_beams_HE_700x421 = ["European","Steel","Wide flange HE HL beams","HE 700x421"]
	European_Steel_Wide_flange_HE_HL_beams_HE_800_A = ["European","Steel","Wide flange HE HL beams","HE 800 A"]
	European_Steel_Wide_flange_HE_HL_beams_HE_800_AA = ["European","Steel","Wide flange HE HL beams","HE 800 AA"]
	European_Steel_Wide_flange_HE_HL_beams_HE_800_B = ["European","Steel","Wide flange HE HL beams","HE 800 B"]
	European_Steel_Wide_flange_HE_HL_beams_HE_800_M = ["European","Steel","Wide flange HE HL beams","HE 800 M"]
	European_Steel_Wide_flange_HE_HL_beams_HE_800x373 = ["European","Steel","Wide flange HE HL beams","HE 800x373"]
	European_Steel_Wide_flange_HE_HL_beams_HE_800x377 = ["European","Steel","Wide flange HE HL beams","HE 800x377"]
	European_Steel_Wide_flange_HE_HL_beams_HE_800x444 = ["European","Steel","Wide flange HE HL beams","HE 800x444"]
	European_Steel_Wide_flange_HE_HL_beams_HE_800x448 = ["European","Steel","Wide flange HE HL beams","HE 800x448"]
	European_Steel_Wide_flange_HE_HL_beams_HE_900_A = ["European","Steel","Wide flange HE HL beams","HE 900 A"]
	European_Steel_Wide_flange_HE_HL_beams_HE_900_AA = ["European","Steel","Wide flange HE HL beams","HE 900 AA"]
	European_Steel_Wide_flange_HE_HL_beams_HE_900_B = ["European","Steel","Wide flange HE HL beams","HE 900 B"]
	European_Steel_Wide_flange_HE_HL_beams_HE_900_M = ["European","Steel","Wide flange HE HL beams","HE 900 M"]
	European_Steel_Wide_flange_HE_HL_beams_HE_900x391 = ["European","Steel","Wide flange HE HL beams","HE 900x391"]
	European_Steel_Wide_flange_HE_HL_beams_HE_900x396 = ["European","Steel","Wide flange HE HL beams","HE 900x396"]
	European_Steel_Wide_flange_HE_HL_beams_HE_900x466 = ["European","Steel","Wide flange HE HL beams","HE 900x466"]
	European_Steel_Wide_flange_HE_HL_beams_HE_900x471 = ["European","Steel","Wide flange HE HL beams","HE 900x471"]
	European_Steel_Wide_flange_HE_HL_beams_HE_1000_A = ["European","Steel","Wide flange HE HL beams","HE 1000 A"]
	European_Steel_Wide_flange_HE_HL_beams_HE_1000_AA = ["European","Steel","Wide flange HE HL beams","HE 1000 AA"]
	European_Steel_Wide_flange_HE_HL_beams_HE_1000_B = ["European","Steel","Wide flange HE HL beams","HE 1000 B"]
	European_Steel_Wide_flange_HE_HL_beams_HE_1000_M = ["European","Steel","Wide flange HE HL beams","HE 1000 M"]
	European_Steel_Wide_flange_HE_HL_beams_HE_1000x249 = ["European","Steel","Wide flange HE HL beams","HE 1000x249"]
	European_Steel_Wide_flange_HE_HL_beams_HE_1000x393 = ["European","Steel","Wide flange HE HL beams","HE 1000x393"]
	European_Steel_Wide_flange_HE_HL_beams_HE_1000x415 = ["European","Steel","Wide flange HE HL beams","HE 1000x415"]
	European_Steel_Wide_flange_HE_HL_beams_HE_1000x438 = ["European","Steel","Wide flange HE HL beams","HE 1000x438"]
	European_Steel_Wide_flange_HE_HL_beams_HE_1000x494 = ["European","Steel","Wide flange HE HL beams","HE 1000x494"]
	European_Steel_Wide_flange_HE_HL_beams_HE_1000x584 = ["European","Steel","Wide flange HE HL beams","HE 1000x584"]
	European_Steel_Wide_flange_HE_HL_beams_HL_920x345 = ["European","Steel","Wide flange HE HL beams","HL 920x345"]
	European_Steel_Wide_flange_HE_HL_beams_HL_920x368 = ["European","Steel","Wide flange HE HL beams","HL 920x368"]
	European_Steel_Wide_flange_HE_HL_beams_HL_920x390 = ["European","Steel","Wide flange HE HL beams","HL 920x390"]
	European_Steel_Wide_flange_HE_HL_beams_HL_920x420 = ["European","Steel","Wide flange HE HL beams","HL 920x420"]
	European_Steel_Wide_flange_HE_HL_beams_HL_920x449 = ["European","Steel","Wide flange HE HL beams","HL 920x449"]
	European_Steel_Wide_flange_HE_HL_beams_HL_920x491 = ["European","Steel","Wide flange HE HL beams","HL 920x491"]
	European_Steel_Wide_flange_HE_HL_beams_HL_920x537 = ["European","Steel","Wide flange HE HL beams","HL 920x537"]
	European_Steel_Wide_flange_HE_HL_beams_HL_920x588 = ["European","Steel","Wide flange HE HL beams","HL 920x588"]
	European_Steel_Wide_flange_HE_HL_beams_HL_920x656 = ["European","Steel","Wide flange HE HL beams","HL 920x656"]
	European_Steel_Wide_flange_HE_HL_beams_HL_920x725 = ["European","Steel","Wide flange HE HL beams","HL 920x725"]
	European_Steel_Wide_flange_HE_HL_beams_HL_920x787 = ["European","Steel","Wide flange HE HL beams","HL 920x787"]
	European_Steel_Wide_flange_HE_HL_beams_HL_920x970 = ["European","Steel","Wide flange HE HL beams","HL 920x970"]
	European_Steel_Wide_flange_HE_HL_beams_HL_1000_A = ["European","Steel","Wide flange HE HL beams","HL 1000 A"]
	European_Steel_Wide_flange_HE_HL_beams_HL_1000_AA = ["European","Steel","Wide flange HE HL beams","HL 1000 AA"]
	European_Steel_Wide_flange_HE_HL_beams_HL_1000_B = ["European","Steel","Wide flange HE HL beams","HL 1000 B"]
	European_Steel_Wide_flange_HE_HL_beams_HL_1000_M = ["European","Steel","Wide flange HE HL beams","HL 1000 M"]
	European_Steel_Wide_flange_HE_HL_beams_HL_1000x296 = ["European","Steel","Wide flange HE HL beams","HL 1000x296"]
	European_Steel_Wide_flange_HE_HL_beams_HL_1000x443 = ["European","Steel","Wide flange HE HL beams","HL 1000x443"]
	European_Steel_Wide_flange_HE_HL_beams_HL_1000x477 = ["European","Steel","Wide flange HE HL beams","HL 1000x477"]
	European_Steel_Wide_flange_HE_HL_beams_HL_1000x483 = ["European","Steel","Wide flange HE HL beams","HL 1000x483"]
	European_Steel_Wide_flange_HE_HL_beams_HL_1000x539 = ["European","Steel","Wide flange HE HL beams","HL 1000x539"]
	European_Steel_Wide_flange_HE_HL_beams_HL_1000x554 = ["European","Steel","Wide flange HE HL beams","HL 1000x554"]
	European_Steel_Wide_flange_HE_HL_beams_HL_1000x591 = ["European","Steel","Wide flange HE HL beams","HL 1000x591"]
	European_Steel_Wide_flange_HE_HL_beams_HL_1000x642 = ["European","Steel","Wide flange HE HL beams","HL 1000x642"]
	European_Steel_Wide_flange_HE_HL_beams_HL_1000x748 = ["European","Steel","Wide flange HE HL beams","HL 1000x748"]
	European_Steel_Wide_flange_HE_HL_beams_HL_1000x883 = ["European","Steel","Wide flange HE HL beams","HL 1000x883"]
	European_Steel_Wide_flange_HE_HL_beams_HL_1100_A = ["European","Steel","Wide flange HE HL beams","HL 1100 A"]
	European_Steel_Wide_flange_HE_HL_beams_HL_1100_B = ["European","Steel","Wide flange HE HL beams","HL 1100 B"]
	European_Steel_Wide_flange_HE_HL_beams_HL_1100_M = ["European","Steel","Wide flange HE HL beams","HL 1100 M"]
	European_Steel_Wide_flange_HE_HL_beams_HL_1100_R = ["European","Steel","Wide flange HE HL beams","HL 1100 R"]
	European_Steel_Wide_flange_HP_piles_HP_200x43 = ["European","Steel","Wide flange HP piles","HP 200x43"]
	European_Steel_Wide_flange_HP_piles_HP_200x53 = ["European","Steel","Wide flange HP piles","HP 200x53"]
	European_Steel_Wide_flange_HP_piles_HP_220x57 = ["European","Steel","Wide flange HP piles","HP 220x57"]
	European_Steel_Wide_flange_HP_piles_HP_260x75 = ["European","Steel","Wide flange HP piles","HP 260x75"]
	European_Steel_Wide_flange_HP_piles_HP_260x87 = ["European","Steel","Wide flange HP piles","HP 260x87"]
	European_Steel_Wide_flange_HP_piles_HP_305x79 = ["European","Steel","Wide flange HP piles","HP 305x79"]
	European_Steel_Wide_flange_HP_piles_HP_305x88 = ["European","Steel","Wide flange HP piles","HP 305x88"]
	European_Steel_Wide_flange_HP_piles_HP_305x95 = ["European","Steel","Wide flange HP piles","HP 305x95"]
	European_Steel_Wide_flange_HP_piles_HP_305x110 = ["European","Steel","Wide flange HP piles","HP 305x110"]
	European_Steel_Wide_flange_HP_piles_HP_305x126 = ["European","Steel","Wide flange HP piles","HP 305x126"]
	European_Steel_Wide_flange_HP_piles_HP_305x149 = ["European","Steel","Wide flange HP piles","HP 305x149"]
	European_Steel_Wide_flange_HP_piles_HP_305x180 = ["European","Steel","Wide flange HP piles","HP 305x180"]
	European_Steel_Wide_flange_HP_piles_HP_305x186 = ["European","Steel","Wide flange HP piles","HP 305x186"]
	European_Steel_Wide_flange_HP_piles_HP_305x223 = ["European","Steel","Wide flange HP piles","HP 305x223"]
	European_Steel_Wide_flange_HP_piles_HP_320x88 = ["European","Steel","Wide flange HP piles","HP 320x88"]
	European_Steel_Wide_flange_HP_piles_HP_320x103 = ["European","Steel","Wide flange HP piles","HP 320x103"]
	European_Steel_Wide_flange_HP_piles_HP_320x117 = ["European","Steel","Wide flange HP piles","HP 320x117"]
	European_Steel_Wide_flange_HP_piles_HP_320x147 = ["European","Steel","Wide flange HP piles","HP 320x147"]
	European_Steel_Wide_flange_HP_piles_HP_320x184 = ["European","Steel","Wide flange HP piles","HP 320x184"]
	European_Steel_Wide_flange_HP_piles_HP_360x84 = ["European","Steel","Wide flange HP piles","HP 360x84"]
	European_Steel_Wide_flange_HP_piles_HP_360x109 = ["European","Steel","Wide flange HP piles","HP 360x109"]
	European_Steel_Wide_flange_HP_piles_HP_360x133 = ["European","Steel","Wide flange HP piles","HP 360x133"]
	European_Steel_Wide_flange_HP_piles_HP_360x152 = ["European","Steel","Wide flange HP piles","HP 360x152"]
	European_Steel_Wide_flange_HP_piles_HP_360x174 = ["European","Steel","Wide flange HP piles","HP 360x174"]
	European_Steel_Wide_flange_HP_piles_HP_360x180 = ["European","Steel","Wide flange HP piles","HP 360x180"]
	European_Steel_Wide_flange_HP_piles_HP_400x122 = ["European","Steel","Wide flange HP piles","HP 400x122"]
	European_Steel_Wide_flange_HP_piles_HP_400x140 = ["European","Steel","Wide flange HP piles","HP 400x140"]
	European_Steel_Wide_flange_HP_piles_HP_400x158 = ["European","Steel","Wide flange HP piles","HP 400x158"]
	European_Steel_Wide_flange_HP_piles_HP_400x176 = ["European","Steel","Wide flange HP piles","HP 400x176"]
	European_Steel_Wide_flange_HP_piles_HP_400x194 = ["European","Steel","Wide flange HP piles","HP 400x194"]
	European_Steel_Wide_flange_HP_piles_HP_400x213 = ["European","Steel","Wide flange HP piles","HP 400x213"]
	European_Steel_Wide_flange_HP_piles_HP_400x231 = ["European","Steel","Wide flange HP piles","HP 400x231"]
	European_Eurotruss_Multi_Truss_FDHD_FD31_Single_Tube = ["European","Eurotruss","Multi Truss (FD/HD)","FD31 Single Tube"]
	European_Eurotruss_Multi_Truss_FDHD_HD31_Single_Tube = ["European","Eurotruss","Multi Truss (FD/HD)","HD31 Single Tube"]
	European_Eurotruss_Multi_Truss_FDHD_HD22_Ladder_Truss = ["European","Eurotruss","Multi Truss (FD/HD)","HD22 Ladder Truss"]
	European_Eurotruss_Multi_Truss_FDHD_FD32_Ladder_Truss = ["European","Eurotruss","Multi Truss (FD/HD)","FD32 Ladder Truss"]
	European_Eurotruss_Multi_Truss_FDHD_HD32_Ladder_Truss = ["European","Eurotruss","Multi Truss (FD/HD)","HD32 Ladder Truss"]
	European_Eurotruss_Multi_Truss_FDHD_FD33_Triangle_Truss = ["European","Eurotruss","Multi Truss (FD/HD)","FD33 Triangle Truss"]
	European_Eurotruss_Multi_Truss_FDHD_HD33_Triangle_Truss = ["European","Eurotruss","Multi Truss (FD/HD)","HD33 Triangle Truss"]
	European_Eurotruss_Multi_Truss_FDHD_FD34_Square_Truss = ["European","Eurotruss","Multi Truss (FD/HD)","FD34 Square Truss"]
	European_Eurotruss_Multi_Truss_FDHD_HD34_Square_Truss = ["European","Eurotruss","Multi Truss (FD/HD)","HD34 Square Truss"]
	European_Eurotruss_Multi_Truss_FDHD_HD44_Square_Truss = ["European","Eurotruss","Multi Truss (FD/HD)","HD44 Square Truss"]
	European_Eurotruss_Heavy_Truss_XDFTST_XD_Rectangular_Truss = ["European","Eurotruss","Heavy Truss (XD/FT/ST)","XD Rectangular Truss"]
	European_Eurotruss_Heavy_Truss_XDFTST_ST_Square_Truss = ["European","Eurotruss","Heavy Truss (XD/FT/ST)","ST Square Truss"]
	European_Eurotruss_Heavy_Truss_XDFTST_FT50_Folding_Truss = ["European","Eurotruss","Heavy Truss (XD/FT/ST)","FT50 Folding Truss"]
	Indian_Steel_Medium_Flange_Beams_MB100 = ["Indian","Steel","Medium Flange Beams","MB100"]
	Indian_Steel_Medium_Flange_Beams_MB125 = ["Indian","Steel","Medium Flange Beams","MB125"]
	Indian_Steel_Medium_Flange_Beams_MB150 = ["Indian","Steel","Medium Flange Beams","MB150"]
	Indian_Steel_Medium_Flange_Beams_MB175 = ["Indian","Steel","Medium Flange Beams","MB175"]
	Indian_Steel_Medium_Flange_Beams_MB200 = ["Indian","Steel","Medium Flange Beams","MB200"]
	Indian_Steel_Medium_Flange_Beams_MB225 = ["Indian","Steel","Medium Flange Beams","MB225"]
	Indian_Steel_Medium_Flange_Beams_MB250 = ["Indian","Steel","Medium Flange Beams","MB250"]
	Indian_Steel_Medium_Flange_Beams_MB300 = ["Indian","Steel","Medium Flange Beams","MB300"]
	Indian_Steel_Medium_Flange_Beams_MB350 = ["Indian","Steel","Medium Flange Beams","MB350"]
	Indian_Steel_Medium_Flange_Beams_MB400 = ["Indian","Steel","Medium Flange Beams","MB400"]
	Indian_Steel_Medium_Flange_Beams_MB450 = ["Indian","Steel","Medium Flange Beams","MB450"]
	Indian_Steel_Medium_Flange_Beams_MB500 = ["Indian","Steel","Medium Flange Beams","MB500"]
	Indian_Steel_Medium_Flange_Beams_MB550 = ["Indian","Steel","Medium Flange Beams","MB550"]
	Indian_Steel_Medium_Flange_Beams_MB600 = ["Indian","Steel","Medium Flange Beams","MB600"]
	Indian_Steel_Junior_Beams_JB150 = ["Indian","Steel","Junior Beams","JB150"]
	Indian_Steel_Junior_Beams_JB175 = ["Indian","Steel","Junior Beams","JB175"]
	Indian_Steel_Junior_Beams_JB200 = ["Indian","Steel","Junior Beams","JB200"]
	Indian_Steel_Junior_Beams_JB225 = ["Indian","Steel","Junior Beams","JB225"]
	Indian_Steel_Light_Weight_Beams_LBP100 = ["Indian","Steel","Light Weight Beams","LB(P)100"]
	Indian_Steel_Light_Weight_Beams_LBP175 = ["Indian","Steel","Light Weight Beams","LB(P)175"]
	Indian_Steel_Light_Weight_Beams_LBP200 = ["Indian","Steel","Light Weight Beams","LB(P)200"]
	Indian_Steel_Light_Weight_Beams_LBP300 = ["Indian","Steel","Light Weight Beams","LB(P)300"]
	Indian_Steel_Light_Weight_Beams_LB75 = ["Indian","Steel","Light Weight Beams","LB75"]
	Indian_Steel_Light_Weight_Beams_LB100 = ["Indian","Steel","Light Weight Beams","LB100"]
	Indian_Steel_Light_Weight_Beams_LB125 = ["Indian","Steel","Light Weight Beams","LB125"]
	Indian_Steel_Light_Weight_Beams_LB150 = ["Indian","Steel","Light Weight Beams","LB150"]
	Indian_Steel_Light_Weight_Beams_LB175 = ["Indian","Steel","Light Weight Beams","LB175"]
	Indian_Steel_Light_Weight_Beams_LB200 = ["Indian","Steel","Light Weight Beams","LB200"]
	Indian_Steel_Light_Weight_Beams_LB225 = ["Indian","Steel","Light Weight Beams","LB225"]
	Indian_Steel_Light_Weight_Beams_LB250 = ["Indian","Steel","Light Weight Beams","LB250"]
	Indian_Steel_Light_Weight_Beams_LB275 = ["Indian","Steel","Light Weight Beams","LB275"]
	Indian_Steel_Light_Weight_Beams_LB300 = ["Indian","Steel","Light Weight Beams","LB300"]
	Indian_Steel_Light_Weight_Beams_LB325 = ["Indian","Steel","Light Weight Beams","LB325"]
	Indian_Steel_Light_Weight_Beams_LB350 = ["Indian","Steel","Light Weight Beams","LB350"]
	Indian_Steel_Light_Weight_Beams_LB400 = ["Indian","Steel","Light Weight Beams","LB400"]
	Indian_Steel_Light_Weight_Beams_LB450 = ["Indian","Steel","Light Weight Beams","LB450"]
	Indian_Steel_Light_Weight_Beams_LB500 = ["Indian","Steel","Light Weight Beams","LB500"]
	Indian_Steel_Light_Weight_Beams_LB550 = ["Indian","Steel","Light Weight Beams","LB550"]
	Indian_Steel_Light_Weight_Beams_LB600 = ["Indian","Steel","Light Weight Beams","LB600"]
	Indian_Steel_Wide_Flange_Beams_WB150 = ["Indian","Steel","Wide Flange Beams","WB150"]
	Indian_Steel_Wide_Flange_Beams_WB175 = ["Indian","Steel","Wide Flange Beams","WB175"]
	Indian_Steel_Wide_Flange_Beams_WB200 = ["Indian","Steel","Wide Flange Beams","WB200"]
	Indian_Steel_Wide_Flange_Beams_WB200x = ["Indian","Steel","Wide Flange Beams","WB200x"]
	Indian_Steel_Wide_Flange_Beams_WB225 = ["Indian","Steel","Wide Flange Beams","WB225"]
	Indian_Steel_Wide_Flange_Beams_WB250 = ["Indian","Steel","Wide Flange Beams","WB250"]
	Indian_Steel_Wide_Flange_Beams_WB300 = ["Indian","Steel","Wide Flange Beams","WB300"]
	Indian_Steel_Wide_Flange_Beams_WB350 = ["Indian","Steel","Wide Flange Beams","WB350"]
	Indian_Steel_Wide_Flange_Beams_WB400 = ["Indian","Steel","Wide Flange Beams","WB400"]
	Indian_Steel_Wide_Flange_Beams_WB450 = ["Indian","Steel","Wide Flange Beams","WB450"]
	Indian_Steel_Wide_Flange_Beams_WB500 = ["Indian","Steel","Wide Flange Beams","WB500"]
	Indian_Steel_Wide_Flange_Beams_WB550 = ["Indian","Steel","Wide Flange Beams","WB550"]
	Indian_Steel_Wide_Flange_Beams_WB600 = ["Indian","Steel","Wide Flange Beams","WB600"]
	Indian_Steel_Wide_Flange_Beams_WB600x = ["Indian","Steel","Wide Flange Beams","WB600x"]
	Indian_Steel_Standard_Columns_SC100 = ["Indian","Steel","Standard Columns","SC100"]
	Indian_Steel_Standard_Columns_SC120 = ["Indian","Steel","Standard Columns","SC120"]
	Indian_Steel_Standard_Columns_SC140 = ["Indian","Steel","Standard Columns","SC140"]
	Indian_Steel_Standard_Columns_SC150x = ["Indian","Steel","Standard Columns","SC150x"]
	Indian_Steel_Standard_Columns_SC160 = ["Indian","Steel","Standard Columns","SC160"]
	Indian_Steel_Standard_Columns_SC180 = ["Indian","Steel","Standard Columns","SC180"]
	Indian_Steel_Standard_Columns_SC200 = ["Indian","Steel","Standard Columns","SC200"]
	Indian_Steel_Standard_Columns_SC220 = ["Indian","Steel","Standard Columns","SC220"]
	Indian_Steel_Standard_Columns_SC250 = ["Indian","Steel","Standard Columns","SC250"]
	Indian_Steel_Heavy_Weight_Beams_and_Columns_HB150 = ["Indian","Steel","Heavy Weight Beams and Columns","HB150"]
	Indian_Steel_Heavy_Weight_Beams_and_Columns_HB150x = ["Indian","Steel","Heavy Weight Beams and Columns","HB150x"]
	Indian_Steel_Heavy_Weight_Beams_and_Columns_HB150xx = ["Indian","Steel","Heavy Weight Beams and Columns","HB150xx"]
	Indian_Steel_Heavy_Weight_Beams_and_Columns_HB200 = ["Indian","Steel","Heavy Weight Beams and Columns","HB200"]
	Indian_Steel_Heavy_Weight_Beams_and_Columns_HB200x = ["Indian","Steel","Heavy Weight Beams and Columns","HB200x"]
	Indian_Steel_Heavy_Weight_Beams_and_Columns_HB225 = ["Indian","Steel","Heavy Weight Beams and Columns","HB225"]
	Indian_Steel_Heavy_Weight_Beams_and_Columns_HB225x = ["Indian","Steel","Heavy Weight Beams and Columns","HB225x"]
	Indian_Steel_Heavy_Weight_Beams_and_Columns_HB250 = ["Indian","Steel","Heavy Weight Beams and Columns","HB250"]
	Indian_Steel_Heavy_Weight_Beams_and_Columns_HB250x = ["Indian","Steel","Heavy Weight Beams and Columns","HB250x"]
	Indian_Steel_Heavy_Weight_Beams_and_Columns_HB300 = ["Indian","Steel","Heavy Weight Beams and Columns","HB300"]
	Indian_Steel_Heavy_Weight_Beams_and_Columns_HB300x = ["Indian","Steel","Heavy Weight Beams and Columns","HB300x"]
	Indian_Steel_Heavy_Weight_Beams_and_Columns_HB350 = ["Indian","Steel","Heavy Weight Beams and Columns","HB350"]
	Indian_Steel_Heavy_Weight_Beams_and_Columns_HB350x = ["Indian","Steel","Heavy Weight Beams and Columns","HB350x"]
	Indian_Steel_Heavy_Weight_Beams_and_Columns_HB400 = ["Indian","Steel","Heavy Weight Beams and Columns","HB400"]
	Indian_Steel_Heavy_Weight_Beams_and_Columns_HB400x = ["Indian","Steel","Heavy Weight Beams and Columns","HB400x"]
	Indian_Steel_Heavy_Weight_Beams_and_Columns_HB450 = ["Indian","Steel","Heavy Weight Beams and Columns","HB450"]
	Indian_Steel_Heavy_Weight_Beams_and_Columns_HB450x = ["Indian","Steel","Heavy Weight Beams and Columns","HB450x"]
	Indian_Steel_Medium_Weight_Channels_MC75 = ["Indian","Steel","Medium Weight Channels","MC75"]
	Indian_Steel_Medium_Weight_Channels_MC100 = ["Indian","Steel","Medium Weight Channels","MC100"]
	Indian_Steel_Medium_Weight_Channels_MC125 = ["Indian","Steel","Medium Weight Channels","MC125"]
	Indian_Steel_Medium_Weight_Channels_MC125x = ["Indian","Steel","Medium Weight Channels","MC125x"]
	Indian_Steel_Medium_Weight_Channels_MC150 = ["Indian","Steel","Medium Weight Channels","MC150"]
	Indian_Steel_Medium_Weight_Channels_MC150x = ["Indian","Steel","Medium Weight Channels","MC150x"]
	Indian_Steel_Medium_Weight_Channels_MC175 = ["Indian","Steel","Medium Weight Channels","MC175"]
	Indian_Steel_Medium_Weight_Channels_MC175x = ["Indian","Steel","Medium Weight Channels","MC175x"]
	Indian_Steel_Medium_Weight_Channels_MC200 = ["Indian","Steel","Medium Weight Channels","MC200"]
	Indian_Steel_Medium_Weight_Channels_MC200x = ["Indian","Steel","Medium Weight Channels","MC200x"]
	Indian_Steel_Medium_Weight_Channels_MC225 = ["Indian","Steel","Medium Weight Channels","MC225"]
	Indian_Steel_Medium_Weight_Channels_MC225x = ["Indian","Steel","Medium Weight Channels","MC225x"]
	Indian_Steel_Medium_Weight_Channels_MC250 = ["Indian","Steel","Medium Weight Channels","MC250"]
	Indian_Steel_Medium_Weight_Channels_MC250x = ["Indian","Steel","Medium Weight Channels","MC250x"]
	Indian_Steel_Medium_Weight_Channels_MC250xx = ["Indian","Steel","Medium Weight Channels","MC250xx"]
	Indian_Steel_Medium_Weight_Channels_MC300 = ["Indian","Steel","Medium Weight Channels","MC300"]
	Indian_Steel_Medium_Weight_Channels_MC300x = ["Indian","Steel","Medium Weight Channels","MC300x"]
	Indian_Steel_Medium_Weight_Channels_MC300xx = ["Indian","Steel","Medium Weight Channels","MC300xx"]
	Indian_Steel_Medium_Weight_Channels_MC350 = ["Indian","Steel","Medium Weight Channels","MC350"]
	Indian_Steel_Medium_Weight_Channels_MC400 = ["Indian","Steel","Medium Weight Channels","MC400"]
	Indian_Steel_Junior_Channels_JC100 = ["Indian","Steel","Junior Channels","JC100"]
	Indian_Steel_Junior_Channels_JC125 = ["Indian","Steel","Junior Channels","JC125"]
	Indian_Steel_Junior_Channels_JC150 = ["Indian","Steel","Junior Channels","JC150"]
	Indian_Steel_Junior_Channels_JC175 = ["Indian","Steel","Junior Channels","JC175"]
	Indian_Steel_Junior_Channels_JC200 = ["Indian","Steel","Junior Channels","JC200"]
	Indian_Steel_Light_Weight_Channels_LCP125 = ["Indian","Steel","Light Weight Channels","LC(P)125"]
	Indian_Steel_Light_Weight_Channels_LCP150 = ["Indian","Steel","Light Weight Channels","LC(P)150"]
	Indian_Steel_Light_Weight_Channels_LCP200 = ["Indian","Steel","Light Weight Channels","LC(P)200"]
	Indian_Steel_Light_Weight_Channels_LCP300 = ["Indian","Steel","Light Weight Channels","LC(P)300"]
	Indian_Steel_Light_Weight_Channels_LC75 = ["Indian","Steel","Light Weight Channels","LC75"]
	Indian_Steel_Light_Weight_Channels_LC100 = ["Indian","Steel","Light Weight Channels","LC100"]
	Indian_Steel_Light_Weight_Channels_LC125 = ["Indian","Steel","Light Weight Channels","LC125"]
	Indian_Steel_Light_Weight_Channels_LC150 = ["Indian","Steel","Light Weight Channels","LC150"]
	Indian_Steel_Light_Weight_Channels_LC175 = ["Indian","Steel","Light Weight Channels","LC175"]
	Indian_Steel_Light_Weight_Channels_LC200 = ["Indian","Steel","Light Weight Channels","LC200"]
	Indian_Steel_Light_Weight_Channels_LC225 = ["Indian","Steel","Light Weight Channels","LC225"]
	Indian_Steel_Light_Weight_Channels_LC250 = ["Indian","Steel","Light Weight Channels","LC250"]
	Indian_Steel_Light_Weight_Channels_LC300 = ["Indian","Steel","Light Weight Channels","LC300"]
	Indian_Steel_Light_Weight_Channels_LC350 = ["Indian","Steel","Light Weight Channels","LC350"]
	Indian_Steel_Light_Weight_Channels_LC400 = ["Indian","Steel","Light Weight Channels","LC400"]
	Indian_Steel_Parallel_Flange_Channels_MCP75 = ["Indian","Steel","Parallel Flange Channels","MCP75"]
	Indian_Steel_Parallel_Flange_Channels_MCP100 = ["Indian","Steel","Parallel Flange Channels","MCP100"]
	Indian_Steel_Parallel_Flange_Channels_MCP125 = ["Indian","Steel","Parallel Flange Channels","MCP125"]
	Indian_Steel_Parallel_Flange_Channels_MCP125x = ["Indian","Steel","Parallel Flange Channels","MCP125x"]
	Indian_Steel_Parallel_Flange_Channels_MCP150 = ["Indian","Steel","Parallel Flange Channels","MCP150"]
	Indian_Steel_Parallel_Flange_Channels_MCP150x = ["Indian","Steel","Parallel Flange Channels","MCP150x"]
	Indian_Steel_Parallel_Flange_Channels_MCP175 = ["Indian","Steel","Parallel Flange Channels","MCP175"]
	Indian_Steel_Parallel_Flange_Channels_MCP175x = ["Indian","Steel","Parallel Flange Channels","MCP175x"]
	Indian_Steel_Parallel_Flange_Channels_MCP200 = ["Indian","Steel","Parallel Flange Channels","MCP200"]
	Indian_Steel_Parallel_Flange_Channels_MCP200x = ["Indian","Steel","Parallel Flange Channels","MCP200x"]
	Indian_Steel_Parallel_Flange_Channels_MCP225 = ["Indian","Steel","Parallel Flange Channels","MCP225"]
	Indian_Steel_Parallel_Flange_Channels_MCP225x = ["Indian","Steel","Parallel Flange Channels","MCP225x"]
	Indian_Steel_Parallel_Flange_Channels_MCP250 = ["Indian","Steel","Parallel Flange Channels","MCP250"]
	Indian_Steel_Parallel_Flange_Channels_MCP250x = ["Indian","Steel","Parallel Flange Channels","MCP250x"]
	Indian_Steel_Parallel_Flange_Channels_MCP250xx = ["Indian","Steel","Parallel Flange Channels","MCP250xx"]
	Indian_Steel_Parallel_Flange_Channels_MCP300 = ["Indian","Steel","Parallel Flange Channels","MCP300"]
	Indian_Steel_Parallel_Flange_Channels_MCP300x = ["Indian","Steel","Parallel Flange Channels","MCP300x"]
	Indian_Steel_Parallel_Flange_Channels_MCP300xx = ["Indian","Steel","Parallel Flange Channels","MCP300xx"]
	Indian_Steel_Parallel_Flange_Channels_MCP350 = ["Indian","Steel","Parallel Flange Channels","MCP350"]
	Indian_Steel_Parallel_Flange_Channels_MCP400 = ["Indian","Steel","Parallel Flange Channels","MCP400"]
	Indian_Steel_Equal_Leg_Angles_A2020x3 = ["Indian","Steel","Equal Leg Angles","A2020x3"]
	Indian_Steel_Equal_Leg_Angles_A2020x4 = ["Indian","Steel","Equal Leg Angles","A2020x4"]
	Indian_Steel_Equal_Leg_Angles_A2525x3 = ["Indian","Steel","Equal Leg Angles","A2525x3"]
	Indian_Steel_Equal_Leg_Angles_A2525x4 = ["Indian","Steel","Equal Leg Angles","A2525x4"]
	Indian_Steel_Equal_Leg_Angles_A2525x5 = ["Indian","Steel","Equal Leg Angles","A2525x5"]
	Indian_Steel_Equal_Leg_Angles_A3030x3 = ["Indian","Steel","Equal Leg Angles","A3030x3"]
	Indian_Steel_Equal_Leg_Angles_A3030x4 = ["Indian","Steel","Equal Leg Angles","A3030x4"]
	Indian_Steel_Equal_Leg_Angles_A3030x5 = ["Indian","Steel","Equal Leg Angles","A3030x5"]
	Indian_Steel_Equal_Leg_Angles_A3535x3 = ["Indian","Steel","Equal Leg Angles","A3535x3"]
	Indian_Steel_Equal_Leg_Angles_A3535x4 = ["Indian","Steel","Equal Leg Angles","A3535x4"]
	Indian_Steel_Equal_Leg_Angles_A3535x5 = ["Indian","Steel","Equal Leg Angles","A3535x5"]
	Indian_Steel_Equal_Leg_Angles_A3535x6 = ["Indian","Steel","Equal Leg Angles","A3535x6"]
	Indian_Steel_Equal_Leg_Angles_A4040x3 = ["Indian","Steel","Equal Leg Angles","A4040x3"]
	Indian_Steel_Equal_Leg_Angles_A4040x4 = ["Indian","Steel","Equal Leg Angles","A4040x4"]
	Indian_Steel_Equal_Leg_Angles_A4040x5 = ["Indian","Steel","Equal Leg Angles","A4040x5"]
	Indian_Steel_Equal_Leg_Angles_A4040x6 = ["Indian","Steel","Equal Leg Angles","A4040x6"]
	Indian_Steel_Equal_Leg_Angles_A4545x3 = ["Indian","Steel","Equal Leg Angles","A4545x3"]
	Indian_Steel_Equal_Leg_Angles_A4545x4 = ["Indian","Steel","Equal Leg Angles","A4545x4"]
	Indian_Steel_Equal_Leg_Angles_A4545x5 = ["Indian","Steel","Equal Leg Angles","A4545x5"]
	Indian_Steel_Equal_Leg_Angles_A4545x6 = ["Indian","Steel","Equal Leg Angles","A4545x6"]
	Indian_Steel_Equal_Leg_Angles_A5050x3 = ["Indian","Steel","Equal Leg Angles","A5050x3"]
	Indian_Steel_Equal_Leg_Angles_A5050x4 = ["Indian","Steel","Equal Leg Angles","A5050x4"]
	Indian_Steel_Equal_Leg_Angles_A5050x5 = ["Indian","Steel","Equal Leg Angles","A5050x5"]
	Indian_Steel_Equal_Leg_Angles_A5050x6 = ["Indian","Steel","Equal Leg Angles","A5050x6"]
	Indian_Steel_Equal_Leg_Angles_A5555x4 = ["Indian","Steel","Equal Leg Angles","A5555x4"]
	Indian_Steel_Equal_Leg_Angles_A5555x5 = ["Indian","Steel","Equal Leg Angles","A5555x5"]
	Indian_Steel_Equal_Leg_Angles_A5555x6 = ["Indian","Steel","Equal Leg Angles","A5555x6"]
	Indian_Steel_Equal_Leg_Angles_A5555x8 = ["Indian","Steel","Equal Leg Angles","A5555x8"]
	Indian_Steel_Equal_Leg_Angles_A6060x4 = ["Indian","Steel","Equal Leg Angles","A6060x4"]
	Indian_Steel_Equal_Leg_Angles_A6060x5 = ["Indian","Steel","Equal Leg Angles","A6060x5"]
	Indian_Steel_Equal_Leg_Angles_A6060x6 = ["Indian","Steel","Equal Leg Angles","A6060x6"]
	Indian_Steel_Equal_Leg_Angles_A6060x8 = ["Indian","Steel","Equal Leg Angles","A6060x8"]
	Indian_Steel_Equal_Leg_Angles_A6565x4 = ["Indian","Steel","Equal Leg Angles","A6565x4"]
	Indian_Steel_Equal_Leg_Angles_A6565x5 = ["Indian","Steel","Equal Leg Angles","A6565x5"]
	Indian_Steel_Equal_Leg_Angles_A6565x6 = ["Indian","Steel","Equal Leg Angles","A6565x6"]
	Indian_Steel_Equal_Leg_Angles_A6565x8 = ["Indian","Steel","Equal Leg Angles","A6565x8"]
	Indian_Steel_Equal_Leg_Angles_A7070x5 = ["Indian","Steel","Equal Leg Angles","A7070x5"]
	Indian_Steel_Equal_Leg_Angles_A7070x6 = ["Indian","Steel","Equal Leg Angles","A7070x6"]
	Indian_Steel_Equal_Leg_Angles_A7070x8 = ["Indian","Steel","Equal Leg Angles","A7070x8"]
	Indian_Steel_Equal_Leg_Angles_A7070x10 = ["Indian","Steel","Equal Leg Angles","A7070x10"]
	Indian_Steel_Equal_Leg_Angles_A7575x5 = ["Indian","Steel","Equal Leg Angles","A7575x5"]
	Indian_Steel_Equal_Leg_Angles_A7575x6 = ["Indian","Steel","Equal Leg Angles","A7575x6"]
	Indian_Steel_Equal_Leg_Angles_A7575x8 = ["Indian","Steel","Equal Leg Angles","A7575x8"]
	Indian_Steel_Equal_Leg_Angles_A7575x10 = ["Indian","Steel","Equal Leg Angles","A7575x10"]
	Indian_Steel_Equal_Leg_Angles_A8080x6 = ["Indian","Steel","Equal Leg Angles","A8080x6"]
	Indian_Steel_Equal_Leg_Angles_A8080x8 = ["Indian","Steel","Equal Leg Angles","A8080x8"]
	Indian_Steel_Equal_Leg_Angles_A8080x10 = ["Indian","Steel","Equal Leg Angles","A8080x10"]
	Indian_Steel_Equal_Leg_Angles_A8080x12 = ["Indian","Steel","Equal Leg Angles","A8080x12"]
	Indian_Steel_Equal_Leg_Angles_A9090x6 = ["Indian","Steel","Equal Leg Angles","A9090x6"]
	Indian_Steel_Equal_Leg_Angles_A9090x8 = ["Indian","Steel","Equal Leg Angles","A9090x8"]
	Indian_Steel_Equal_Leg_Angles_A9090x10 = ["Indian","Steel","Equal Leg Angles","A9090x10"]
	Indian_Steel_Equal_Leg_Angles_A9090x12 = ["Indian","Steel","Equal Leg Angles","A9090x12"]
	Indian_Steel_Equal_Leg_Angles_A100100x6 = ["Indian","Steel","Equal Leg Angles","A100100x6"]
	Indian_Steel_Equal_Leg_Angles_A100100x8 = ["Indian","Steel","Equal Leg Angles","A100100x8"]
	Indian_Steel_Equal_Leg_Angles_A100100x10 = ["Indian","Steel","Equal Leg Angles","A100100x10"]
	Indian_Steel_Equal_Leg_Angles_A100100x12 = ["Indian","Steel","Equal Leg Angles","A100100x12"]
	Indian_Steel_Equal_Leg_Angles_A110110x8 = ["Indian","Steel","Equal Leg Angles","A110110x8"]
	Indian_Steel_Equal_Leg_Angles_A110110x10 = ["Indian","Steel","Equal Leg Angles","A110110x10"]
	Indian_Steel_Equal_Leg_Angles_A110110x12 = ["Indian","Steel","Equal Leg Angles","A110110x12"]
	Indian_Steel_Equal_Leg_Angles_A110110x16 = ["Indian","Steel","Equal Leg Angles","A110110x16"]
	Indian_Steel_Equal_Leg_Angles_A130130x8 = ["Indian","Steel","Equal Leg Angles","A130130x8"]
	Indian_Steel_Equal_Leg_Angles_A130130x10 = ["Indian","Steel","Equal Leg Angles","A130130x10"]
	Indian_Steel_Equal_Leg_Angles_A130130x12 = ["Indian","Steel","Equal Leg Angles","A130130x12"]
	Indian_Steel_Equal_Leg_Angles_A130130x16 = ["Indian","Steel","Equal Leg Angles","A130130x16"]
	Indian_Steel_Equal_Leg_Angles_A150150x10 = ["Indian","Steel","Equal Leg Angles","A150150x10"]
	Indian_Steel_Equal_Leg_Angles_A150150x12 = ["Indian","Steel","Equal Leg Angles","A150150x12"]
	Indian_Steel_Equal_Leg_Angles_A150150x16 = ["Indian","Steel","Equal Leg Angles","A150150x16"]
	Indian_Steel_Equal_Leg_Angles_A150150x20 = ["Indian","Steel","Equal Leg Angles","A150150x20"]
	Indian_Steel_Equal_Leg_Angles_A200200x12 = ["Indian","Steel","Equal Leg Angles","A200200x12"]
	Indian_Steel_Equal_Leg_Angles_A200200x16 = ["Indian","Steel","Equal Leg Angles","A200200x16"]
	Indian_Steel_Equal_Leg_Angles_A200200x20 = ["Indian","Steel","Equal Leg Angles","A200200x20"]
	Indian_Steel_Equal_Leg_Angles_A200200x25 = ["Indian","Steel","Equal Leg Angles","A200200x25"]
	Indian_Steel_Unequal_Leg_Angles_A3020x3 = ["Indian","Steel","Unequal Leg Angles","A3020x3"]
	Indian_Steel_Unequal_Leg_Angles_A3020x4 = ["Indian","Steel","Unequal Leg Angles","A3020x4"]
	Indian_Steel_Unequal_Leg_Angles_A3020x5 = ["Indian","Steel","Unequal Leg Angles","A3020x5"]
	Indian_Steel_Unequal_Leg_Angles_A4025x3 = ["Indian","Steel","Unequal Leg Angles","A4025x3"]
	Indian_Steel_Unequal_Leg_Angles_A4025x4 = ["Indian","Steel","Unequal Leg Angles","A4025x4"]
	Indian_Steel_Unequal_Leg_Angles_A4025x5 = ["Indian","Steel","Unequal Leg Angles","A4025x5"]
	Indian_Steel_Unequal_Leg_Angles_A4025x6 = ["Indian","Steel","Unequal Leg Angles","A4025x6"]
	Indian_Steel_Unequal_Leg_Angles_A4530x3 = ["Indian","Steel","Unequal Leg Angles","A4530x3"]
	Indian_Steel_Unequal_Leg_Angles_A4530x4 = ["Indian","Steel","Unequal Leg Angles","A4530x4"]
	Indian_Steel_Unequal_Leg_Angles_A4530x5 = ["Indian","Steel","Unequal Leg Angles","A4530x5"]
	Indian_Steel_Unequal_Leg_Angles_A4530x6 = ["Indian","Steel","Unequal Leg Angles","A4530x6"]
	Indian_Steel_Unequal_Leg_Angles_A5030x3 = ["Indian","Steel","Unequal Leg Angles","A5030x3"]
	Indian_Steel_Unequal_Leg_Angles_A5030x4 = ["Indian","Steel","Unequal Leg Angles","A5030x4"]
	Indian_Steel_Unequal_Leg_Angles_A5030x5 = ["Indian","Steel","Unequal Leg Angles","A5030x5"]
	Indian_Steel_Unequal_Leg_Angles_A5030x6 = ["Indian","Steel","Unequal Leg Angles","A5030x6"]
	Indian_Steel_Unequal_Leg_Angles_A6040x5 = ["Indian","Steel","Unequal Leg Angles","A6040x5"]
	Indian_Steel_Unequal_Leg_Angles_A6040x6 = ["Indian","Steel","Unequal Leg Angles","A6040x6"]
	Indian_Steel_Unequal_Leg_Angles_A6040x8 = ["Indian","Steel","Unequal Leg Angles","A6040x8"]
	Indian_Steel_Unequal_Leg_Angles_A6545x5 = ["Indian","Steel","Unequal Leg Angles","A6545x5"]
	Indian_Steel_Unequal_Leg_Angles_A6545x6 = ["Indian","Steel","Unequal Leg Angles","A6545x6"]
	Indian_Steel_Unequal_Leg_Angles_A6545x8 = ["Indian","Steel","Unequal Leg Angles","A6545x8"]
	Indian_Steel_Unequal_Leg_Angles_A7045x5 = ["Indian","Steel","Unequal Leg Angles","A7045x5"]
	Indian_Steel_Unequal_Leg_Angles_A7045x6 = ["Indian","Steel","Unequal Leg Angles","A7045x6"]
	Indian_Steel_Unequal_Leg_Angles_A7045x8 = ["Indian","Steel","Unequal Leg Angles","A7045x8"]
	Indian_Steel_Unequal_Leg_Angles_A7045x10 = ["Indian","Steel","Unequal Leg Angles","A7045x10"]
	Indian_Steel_Unequal_Leg_Angles_A7550x5 = ["Indian","Steel","Unequal Leg Angles","A7550x5"]
	Indian_Steel_Unequal_Leg_Angles_A7550x6 = ["Indian","Steel","Unequal Leg Angles","A7550x6"]
	Indian_Steel_Unequal_Leg_Angles_A7550x8 = ["Indian","Steel","Unequal Leg Angles","A7550x8"]
	Indian_Steel_Unequal_Leg_Angles_A7550x10 = ["Indian","Steel","Unequal Leg Angles","A7550x10"]
	Indian_Steel_Unequal_Leg_Angles_A8050x5 = ["Indian","Steel","Unequal Leg Angles","A8050x5"]
	Indian_Steel_Unequal_Leg_Angles_A8050x6 = ["Indian","Steel","Unequal Leg Angles","A8050x6"]
	Indian_Steel_Unequal_Leg_Angles_A8050x8 = ["Indian","Steel","Unequal Leg Angles","A8050x8"]
	Indian_Steel_Unequal_Leg_Angles_A8050x10 = ["Indian","Steel","Unequal Leg Angles","A8050x10"]
	Indian_Steel_Unequal_Leg_Angles_A9060x6 = ["Indian","Steel","Unequal Leg Angles","A9060x6"]
	Indian_Steel_Unequal_Leg_Angles_A9060x8 = ["Indian","Steel","Unequal Leg Angles","A9060x8"]
	Indian_Steel_Unequal_Leg_Angles_A9060x10 = ["Indian","Steel","Unequal Leg Angles","A9060x10"]
	Indian_Steel_Unequal_Leg_Angles_A9060x12 = ["Indian","Steel","Unequal Leg Angles","A9060x12"]
	Indian_Steel_Unequal_Leg_Angles_A10065x6 = ["Indian","Steel","Unequal Leg Angles","A10065x6"]
	Indian_Steel_Unequal_Leg_Angles_A10065x8 = ["Indian","Steel","Unequal Leg Angles","A10065x8"]
	Indian_Steel_Unequal_Leg_Angles_A10065x10 = ["Indian","Steel","Unequal Leg Angles","A10065x10"]
	Indian_Steel_Unequal_Leg_Angles_A10075x6 = ["Indian","Steel","Unequal Leg Angles","A10075x6"]
	Indian_Steel_Unequal_Leg_Angles_A10075x8 = ["Indian","Steel","Unequal Leg Angles","A10075x8"]
	Indian_Steel_Unequal_Leg_Angles_A10075x10 = ["Indian","Steel","Unequal Leg Angles","A10075x10"]
	Indian_Steel_Unequal_Leg_Angles_A10075x12 = ["Indian","Steel","Unequal Leg Angles","A10075x12"]
	Indian_Steel_Unequal_Leg_Angles_A12575x6 = ["Indian","Steel","Unequal Leg Angles","A12575x6"]
	Indian_Steel_Unequal_Leg_Angles_A12575x8 = ["Indian","Steel","Unequal Leg Angles","A12575x8"]
	Indian_Steel_Unequal_Leg_Angles_A12575x10 = ["Indian","Steel","Unequal Leg Angles","A12575x10"]
	Indian_Steel_Unequal_Leg_Angles_A12595x6 = ["Indian","Steel","Unequal Leg Angles","A12595x6"]
	Indian_Steel_Unequal_Leg_Angles_A12595x8 = ["Indian","Steel","Unequal Leg Angles","A12595x8"]
	Indian_Steel_Unequal_Leg_Angles_A12595x10 = ["Indian","Steel","Unequal Leg Angles","A12595x10"]
	Indian_Steel_Unequal_Leg_Angles_A12595x12 = ["Indian","Steel","Unequal Leg Angles","A12595x12"]
	Indian_Steel_Unequal_Leg_Angles_A15075x8 = ["Indian","Steel","Unequal Leg Angles","A15075x8"]
	Indian_Steel_Unequal_Leg_Angles_A15075x10 = ["Indian","Steel","Unequal Leg Angles","A15075x10"]
	Indian_Steel_Unequal_Leg_Angles_A15075x12 = ["Indian","Steel","Unequal Leg Angles","A15075x12"]
	Indian_Steel_Unequal_Leg_Angles_A150115x8 = ["Indian","Steel","Unequal Leg Angles","A150115x8"]
	Indian_Steel_Unequal_Leg_Angles_A150115x10 = ["Indian","Steel","Unequal Leg Angles","A150115x10"]
	Indian_Steel_Unequal_Leg_Angles_A150115x12 = ["Indian","Steel","Unequal Leg Angles","A150115x12"]
	Indian_Steel_Unequal_Leg_Angles_A150115x16 = ["Indian","Steel","Unequal Leg Angles","A150115x16"]
	Indian_Steel_Unequal_Leg_Angles_A200100x10 = ["Indian","Steel","Unequal Leg Angles","A200100x10"]
	Indian_Steel_Unequal_Leg_Angles_A200100x12 = ["Indian","Steel","Unequal Leg Angles","A200100x12"]
	Indian_Steel_Unequal_Leg_Angles_A200100x16 = ["Indian","Steel","Unequal Leg Angles","A200100x16"]
	Indian_Steel_Unequal_Leg_Angles_A200150x10 = ["Indian","Steel","Unequal Leg Angles","A200150x10"]
	Indian_Steel_Unequal_Leg_Angles_A200150x12 = ["Indian","Steel","Unequal Leg Angles","A200150x12"]
	Indian_Steel_Unequal_Leg_Angles_A200150x16 = ["Indian","Steel","Unequal Leg Angles","A200150x16"]
	Indian_Steel_Unequal_Leg_Angles_A200150x20 = ["Indian","Steel","Unequal Leg Angles","A200150x20"]
	Indian_Steel_Supplementary_Equal_Angles_A5050x7 = ["Indian","Steel","Supplementary Equal Angles","A5050x7"]
	Indian_Steel_Supplementary_Equal_Angles_A5050x8 = ["Indian","Steel","Supplementary Equal Angles","A5050x8"]
	Indian_Steel_Supplementary_Equal_Angles_A5555x10 = ["Indian","Steel","Supplementary Equal Angles","A5555x10"]
	Indian_Steel_Supplementary_Equal_Angles_A6060x10 = ["Indian","Steel","Supplementary Equal Angles","A6060x10"]
	Indian_Steel_Supplementary_Equal_Angles_A6565x10 = ["Indian","Steel","Supplementary Equal Angles","A6565x10"]
	Indian_Steel_Supplementary_Equal_Angles_A7070x7 = ["Indian","Steel","Supplementary Equal Angles","A7070x7"]
	Indian_Steel_Supplementary_Equal_Angles_A100100x7 = ["Indian","Steel","Supplementary Equal Angles","A100100x7"]
	Indian_Steel_Supplementary_Equal_Angles_A100100x15 = ["Indian","Steel","Supplementary Equal Angles","A100100x15"]
	Indian_Steel_Supplementary_Equal_Angles_A120120x8 = ["Indian","Steel","Supplementary Equal Angles","A120120x8"]
	Indian_Steel_Supplementary_Equal_Angles_A120120x10 = ["Indian","Steel","Supplementary Equal Angles","A120120x10"]
	Indian_Steel_Supplementary_Equal_Angles_A120120x12 = ["Indian","Steel","Supplementary Equal Angles","A120120x12"]
	Indian_Steel_Supplementary_Equal_Angles_A120120x15 = ["Indian","Steel","Supplementary Equal Angles","A120120x15"]
	Indian_Steel_Supplementary_Equal_Angles_A130130x9 = ["Indian","Steel","Supplementary Equal Angles","A130130x9"]
	Indian_Steel_Supplementary_Equal_Angles_A150150x15 = ["Indian","Steel","Supplementary Equal Angles","A150150x15"]
	Indian_Steel_Supplementary_Equal_Angles_A150150x18 = ["Indian","Steel","Supplementary Equal Angles","A150150x18"]
	Indian_Steel_Supplementary_Equal_Angles_A180180x15 = ["Indian","Steel","Supplementary Equal Angles","A180180x15"]
	Indian_Steel_Supplementary_Equal_Angles_A180180x18 = ["Indian","Steel","Supplementary Equal Angles","A180180x18"]
	Indian_Steel_Supplementary_Equal_Angles_A180180x20 = ["Indian","Steel","Supplementary Equal Angles","A180180x20"]
	Indian_Steel_Supplementary_Equal_Angles_A200200x24 = ["Indian","Steel","Supplementary Equal Angles","A200200x24"]
	Indian_Steel_Supplementary_Unequal_Angles_A4020x3 = ["Indian","Steel","Supplementary Unequal Angles","A4020x3"]
	Indian_Steel_Supplementary_Unequal_Angles_A4020x4 = ["Indian","Steel","Supplementary Unequal Angles","A4020x4"]
	Indian_Steel_Supplementary_Unequal_Angles_A4020x5 = ["Indian","Steel","Supplementary Unequal Angles","A4020x5"]
	Indian_Steel_Supplementary_Unequal_Angles_A6030x5 = ["Indian","Steel","Supplementary Unequal Angles","A6030x5"]
	Indian_Steel_Supplementary_Unequal_Angles_A6030x6 = ["Indian","Steel","Supplementary Unequal Angles","A6030x6"]
	Indian_Steel_Supplementary_Unequal_Angles_A6040x7 = ["Indian","Steel","Supplementary Unequal Angles","A6040x7"]
	Indian_Steel_Supplementary_Unequal_Angles_A6550x5 = ["Indian","Steel","Supplementary Unequal Angles","A6550x5"]
	Indian_Steel_Supplementary_Unequal_Angles_A6550x6 = ["Indian","Steel","Supplementary Unequal Angles","A6550x6"]
	Indian_Steel_Supplementary_Unequal_Angles_A6550x7 = ["Indian","Steel","Supplementary Unequal Angles","A6550x7"]
	Indian_Steel_Supplementary_Unequal_Angles_A6550x8 = ["Indian","Steel","Supplementary Unequal Angles","A6550x8"]
	Indian_Steel_Supplementary_Unequal_Angles_A7050x5 = ["Indian","Steel","Supplementary Unequal Angles","A7050x5"]
	Indian_Steel_Supplementary_Unequal_Angles_A7050x6 = ["Indian","Steel","Supplementary Unequal Angles","A7050x6"]
	Indian_Steel_Supplementary_Unequal_Angles_A7050x7 = ["Indian","Steel","Supplementary Unequal Angles","A7050x7"]
	Indian_Steel_Supplementary_Unequal_Angles_A7050x8 = ["Indian","Steel","Supplementary Unequal Angles","A7050x8"]
	Indian_Steel_Supplementary_Unequal_Angles_A7550x7 = ["Indian","Steel","Supplementary Unequal Angles","A7550x7"]
	Indian_Steel_Supplementary_Unequal_Angles_A8040x5 = ["Indian","Steel","Supplementary Unequal Angles","A8040x5"]
	Indian_Steel_Supplementary_Unequal_Angles_A8040x6 = ["Indian","Steel","Supplementary Unequal Angles","A8040x6"]
	Indian_Steel_Supplementary_Unequal_Angles_A8040x7 = ["Indian","Steel","Supplementary Unequal Angles","A8040x7"]
	Indian_Steel_Supplementary_Unequal_Angles_A8040x8 = ["Indian","Steel","Supplementary Unequal Angles","A8040x8"]
	Indian_Steel_Supplementary_Unequal_Angles_A8060x6 = ["Indian","Steel","Supplementary Unequal Angles","A8060x6"]
	Indian_Steel_Supplementary_Unequal_Angles_A8060x7 = ["Indian","Steel","Supplementary Unequal Angles","A8060x7"]
	Indian_Steel_Supplementary_Unequal_Angles_A8060x8 = ["Indian","Steel","Supplementary Unequal Angles","A8060x8"]
	Indian_Steel_Supplementary_Unequal_Angles_A9065x6 = ["Indian","Steel","Supplementary Unequal Angles","A9065x6"]
	Indian_Steel_Supplementary_Unequal_Angles_A9065x7 = ["Indian","Steel","Supplementary Unequal Angles","A9065x7"]
	Indian_Steel_Supplementary_Unequal_Angles_A9065x8 = ["Indian","Steel","Supplementary Unequal Angles","A9065x8"]
	Indian_Steel_Supplementary_Unequal_Angles_A9065x10 = ["Indian","Steel","Supplementary Unequal Angles","A9065x10"]
	Indian_Steel_Supplementary_Unequal_Angles_A10050x6 = ["Indian","Steel","Supplementary Unequal Angles","A10050x6"]
	Indian_Steel_Supplementary_Unequal_Angles_A10050x7 = ["Indian","Steel","Supplementary Unequal Angles","A10050x7"]
	Indian_Steel_Supplementary_Unequal_Angles_A10050x8 = ["Indian","Steel","Supplementary Unequal Angles","A10050x8"]
	Indian_Steel_Supplementary_Unequal_Angles_A10050x10 = ["Indian","Steel","Supplementary Unequal Angles","A10050x10"]
	Indian_Steel_Supplementary_Unequal_Angles_A10060x7 = ["Indian","Steel","Supplementary Unequal Angles","A10060x7"]
	Indian_Steel_Supplementary_Unequal_Angles_A12080x8 = ["Indian","Steel","Supplementary Unequal Angles","A12080x8"]
	Indian_Steel_Supplementary_Unequal_Angles_A12080x10 = ["Indian","Steel","Supplementary Unequal Angles","A12080x10"]
	Indian_Steel_Supplementary_Unequal_Angles_A12080x12 = ["Indian","Steel","Supplementary Unequal Angles","A12080x12"]
	Indian_Steel_Supplementary_Unequal_Angles_A12575x12 = ["Indian","Steel","Supplementary Unequal Angles","A12575x12"]
	Indian_Steel_Supplementary_Unequal_Angles_A13565x8 = ["Indian","Steel","Supplementary Unequal Angles","A13565x8"]
	Indian_Steel_Supplementary_Unequal_Angles_A13565x10 = ["Indian","Steel","Supplementary Unequal Angles","A13565x10"]
	Indian_Steel_Supplementary_Unequal_Angles_A13565x12 = ["Indian","Steel","Supplementary Unequal Angles","A13565x12"]
	Indian_Steel_Supplementary_Unequal_Angles_A15075x9 = ["Indian","Steel","Supplementary Unequal Angles","A15075x9"]
	Indian_Steel_Supplementary_Unequal_Angles_A15075x15 = ["Indian","Steel","Supplementary Unequal Angles","A15075x15"]
	Indian_Steel_Supplementary_Unequal_Angles_A15090x10 = ["Indian","Steel","Supplementary Unequal Angles","A15090x10"]
	Indian_Steel_Supplementary_Unequal_Angles_A15090x12 = ["Indian","Steel","Supplementary Unequal Angles","A15090x12"]
	Indian_Steel_Supplementary_Unequal_Angles_A15090x15 = ["Indian","Steel","Supplementary Unequal Angles","A15090x15"]
	Indian_Steel_Supplementary_Unequal_Angles_A200100x15 = ["Indian","Steel","Supplementary Unequal Angles","A200100x15"]
	Indian_Steel_Supplementary_Unequal_Angles_A200150x15 = ["Indian","Steel","Supplementary Unequal Angles","A200150x15"]
	Indian_Steel_Supplementary_Unequal_Angles_A200150x18 = ["Indian","Steel","Supplementary Unequal Angles","A200150x18"]
	Indian_Steel_Rectangular_Hollow_Sections_50_0x25_0x2_9 = ["Indian","Steel","Rectangular Hollow Sections","50.0x25.0x2.9"]
	Indian_Steel_Rectangular_Hollow_Sections_50_0x25_0x3_2 = ["Indian","Steel","Rectangular Hollow Sections","50.0x25.0x3.2"]
	Indian_Steel_Rectangular_Hollow_Sections_60_0x40_0x2_9 = ["Indian","Steel","Rectangular Hollow Sections","60.0x40.0x2.9"]
	Indian_Steel_Rectangular_Hollow_Sections_66_0x33_0x2_9 = ["Indian","Steel","Rectangular Hollow Sections","66.0x33.0x2.9"]
	Indian_Steel_Rectangular_Hollow_Sections_66_0x33_0x3_6 = ["Indian","Steel","Rectangular Hollow Sections","66.0x33.0x3.6"]
	Indian_Steel_Rectangular_Hollow_Sections_66_0x33_0x4_5 = ["Indian","Steel","Rectangular Hollow Sections","66.0x33.0x4.5"]
	Indian_Steel_Rectangular_Hollow_Sections_70_0x30_0x2_9 = ["Indian","Steel","Rectangular Hollow Sections","70.0x30.0x2.9"]
	Indian_Steel_Rectangular_Hollow_Sections_70_0x30_0x3_2 = ["Indian","Steel","Rectangular Hollow Sections","70.0x30.0x3.2"]
	Indian_Steel_Rectangular_Hollow_Sections_70_0x30_0x4_0 = ["Indian","Steel","Rectangular Hollow Sections","70.0x30.0x4.0"]
	Indian_Steel_Rectangular_Hollow_Sections_80_0x40_0x2_9 = ["Indian","Steel","Rectangular Hollow Sections","80.0x40.0x2.9"]
	Indian_Steel_Rectangular_Hollow_Sections_80_0x40_0x3_2 = ["Indian","Steel","Rectangular Hollow Sections","80.0x40.0x3.2"]
	Indian_Steel_Rectangular_Hollow_Sections_80_0x40_0x4_0 = ["Indian","Steel","Rectangular Hollow Sections","80.0x40.0x4.0"]
	Indian_Steel_Rectangular_Hollow_Sections_96_0x48_0x3_2 = ["Indian","Steel","Rectangular Hollow Sections","96.0x48.0x3.2"]
	Indian_Steel_Rectangular_Hollow_Sections_96_0x48_0x4_0 = ["Indian","Steel","Rectangular Hollow Sections","96.0x48.0x4.0"]
	Indian_Steel_Rectangular_Hollow_Sections_96_0x48_0x4_8 = ["Indian","Steel","Rectangular Hollow Sections","96.0x48.0x4.8"]
	Indian_Steel_Rectangular_Hollow_Sections_100_0x50_0x3_2 = ["Indian","Steel","Rectangular Hollow Sections","100.0x50.0x3.2"]
	Indian_Steel_Rectangular_Hollow_Sections_100_0x50_0x4_0 = ["Indian","Steel","Rectangular Hollow Sections","100.0x50.0x4.0"]
	Indian_Steel_Rectangular_Hollow_Sections_122_0x61_0x3_6 = ["Indian","Steel","Rectangular Hollow Sections","122.0x61.0x3.6"]
	Indian_Steel_Rectangular_Hollow_Sections_122_0x61_0x4_5 = ["Indian","Steel","Rectangular Hollow Sections","122.0x61.0x4.5"]
	Indian_Steel_Rectangular_Hollow_Sections_122_0x61_0x5_4 = ["Indian","Steel","Rectangular Hollow Sections","122.0x61.0x5.4"]
	Indian_Steel_Rectangular_Hollow_Sections_127_0x50_0x3_6 = ["Indian","Steel","Rectangular Hollow Sections","127.0x50.0x3.6"]
	Indian_Steel_Rectangular_Hollow_Sections_127_0x50_0x4_6 = ["Indian","Steel","Rectangular Hollow Sections","127.0x50.0x4.6"]
	Indian_Steel_Rectangular_Hollow_Sections_145_0x82_0x4_8 = ["Indian","Steel","Rectangular Hollow Sections","145.0x82.0x4.8"]
	Indian_Steel_Rectangular_Hollow_Sections_145_0x82_0x5_4 = ["Indian","Steel","Rectangular Hollow Sections","145.0x82.0x5.4"]
	Indian_Steel_Rectangular_Hollow_Sections_172_0x92_0x4_8 = ["Indian","Steel","Rectangular Hollow Sections","172.0x92.0x4.8"]
	Indian_Steel_Rectangular_Hollow_Sections_172_0x92_0x5_4 = ["Indian","Steel","Rectangular Hollow Sections","172.0x92.0x5.4"]
	Indian_Steel_Square_Hollow_Sections_25_0x25_0x2_6 = ["Indian","Steel","Square Hollow Sections","25.0x25.0x2.6"]
	Indian_Steel_Square_Hollow_Sections_25_0x25_0x3_2 = ["Indian","Steel","Square Hollow Sections","25.0x25.0x3.2"]
	Indian_Steel_Square_Hollow_Sections_30_0x30_0x2_6 = ["Indian","Steel","Square Hollow Sections","30.0x30.0x2.6"]
	Indian_Steel_Square_Hollow_Sections_30_0x30_0x3_2 = ["Indian","Steel","Square Hollow Sections","30.0x30.0x3.2"]
	Indian_Steel_Square_Hollow_Sections_30_0x30_0x4_0 = ["Indian","Steel","Square Hollow Sections","30.0x30.0x4.0"]
	Indian_Steel_Square_Hollow_Sections_32_0x32_0x2_6 = ["Indian","Steel","Square Hollow Sections","32.0x32.0x2.6"]
	Indian_Steel_Square_Hollow_Sections_32_0x32_0x3_2 = ["Indian","Steel","Square Hollow Sections","32.0x32.0x3.2"]
	Indian_Steel_Square_Hollow_Sections_32_0x32_0x4_0 = ["Indian","Steel","Square Hollow Sections","32.0x32.0x4.0"]
	Indian_Steel_Square_Hollow_Sections_35_0x35_0x2_6 = ["Indian","Steel","Square Hollow Sections","35.0x35.0x2.6"]
	Indian_Steel_Square_Hollow_Sections_35_0x35_0x3_2 = ["Indian","Steel","Square Hollow Sections","35.0x35.0x3.2"]
	Indian_Steel_Square_Hollow_Sections_35_0x35_0x4_0 = ["Indian","Steel","Square Hollow Sections","35.0x35.0x4.0"]
	Indian_Steel_Square_Hollow_Sections_38_0x38_0x2_6 = ["Indian","Steel","Square Hollow Sections","38.0x38.0x2.6"]
	Indian_Steel_Square_Hollow_Sections_38_0x38_0x2_9 = ["Indian","Steel","Square Hollow Sections","38.0x38.0x2.9"]
	Indian_Steel_Square_Hollow_Sections_38_0x38_0x3_2 = ["Indian","Steel","Square Hollow Sections","38.0x38.0x3.2"]
	Indian_Steel_Square_Hollow_Sections_38_0x38_0x3_6 = ["Indian","Steel","Square Hollow Sections","38.0x38.0x3.6"]
	Indian_Steel_Square_Hollow_Sections_38_0x38_0x4_0 = ["Indian","Steel","Square Hollow Sections","38.0x38.0x4.0"]
	Indian_Steel_Square_Hollow_Sections_40_0x40_0x2_6 = ["Indian","Steel","Square Hollow Sections","40.0x40.0x2.6"]
	Indian_Steel_Square_Hollow_Sections_40_0x40_0x3_2 = ["Indian","Steel","Square Hollow Sections","40.0x40.0x3.2"]
	Indian_Steel_Square_Hollow_Sections_40_0x40_0x3_6 = ["Indian","Steel","Square Hollow Sections","40.0x40.0x3.6"]
	Indian_Steel_Square_Hollow_Sections_40_0x40_0x4_0 = ["Indian","Steel","Square Hollow Sections","40.0x40.0x4.0"]
	Indian_Steel_Square_Hollow_Sections_45_0x45_0x2_6 = ["Indian","Steel","Square Hollow Sections","45.0x45.0x2.6"]
	Indian_Steel_Square_Hollow_Sections_45_0x45_0x2_9 = ["Indian","Steel","Square Hollow Sections","45.0x45.0x2.9"]
	Indian_Steel_Square_Hollow_Sections_45_0x45_0x3_2 = ["Indian","Steel","Square Hollow Sections","45.0x45.0x3.2"]
	Indian_Steel_Square_Hollow_Sections_45_0x45_0x3_6 = ["Indian","Steel","Square Hollow Sections","45.0x45.0x3.6"]
	Indian_Steel_Square_Hollow_Sections_45_0x45_0x4_5 = ["Indian","Steel","Square Hollow Sections","45.0x45.0x4.5"]
	Indian_Steel_Square_Hollow_Sections_49_5x49_5x2_9 = ["Indian","Steel","Square Hollow Sections","49.5x49.5x2.9"]
	Indian_Steel_Square_Hollow_Sections_49_5x49_5x3_6 = ["Indian","Steel","Square Hollow Sections","49.5x49.5x3.6"]
	Indian_Steel_Square_Hollow_Sections_49_5x49_5x4_5 = ["Indian","Steel","Square Hollow Sections","49.5x49.5x4.5"]
	Indian_Steel_Square_Hollow_Sections_63_5x63_5x3_2 = ["Indian","Steel","Square Hollow Sections","63.5x63.5x3.2"]
	Indian_Steel_Square_Hollow_Sections_63_5x63_5x3_6 = ["Indian","Steel","Square Hollow Sections","63.5x63.5x3.6"]
	Indian_Steel_Square_Hollow_Sections_63_5x63_5x4_5 = ["Indian","Steel","Square Hollow Sections","63.5x63.5x4.5"]
	Indian_Steel_Square_Hollow_Sections_72_0x72_0x3_2 = ["Indian","Steel","Square Hollow Sections","72.0x72.0x3.2"]
	Indian_Steel_Square_Hollow_Sections_72_0x72_0x4_0 = ["Indian","Steel","Square Hollow Sections","72.0x72.0x4.0"]
	Indian_Steel_Square_Hollow_Sections_72_0x72_0x4_8 = ["Indian","Steel","Square Hollow Sections","72.0x72.0x4.8"]
	Indian_Steel_Square_Hollow_Sections_75_0x75_0x3_2 = ["Indian","Steel","Square Hollow Sections","75.0x75.0x3.2"]
	Indian_Steel_Square_Hollow_Sections_75_0x75_0x4_0 = ["Indian","Steel","Square Hollow Sections","75.0x75.0x4.0"]
	Indian_Steel_Square_Hollow_Sections_75_0x75_0x4_9 = ["Indian","Steel","Square Hollow Sections","75.0x75.0x4.9"]
	Indian_Steel_Square_Hollow_Sections_88_9x88_9x3_6 = ["Indian","Steel","Square Hollow Sections","88.9x88.9x3.6"]
	Indian_Steel_Square_Hollow_Sections_88_9x88_9x4_5 = ["Indian","Steel","Square Hollow Sections","88.9x88.9x4.5"]
	Indian_Steel_Square_Hollow_Sections_88_9x88_9x4_9 = ["Indian","Steel","Square Hollow Sections","88.9x88.9x4.9"]
	Indian_Steel_Square_Hollow_Sections_91_5x91_5x3_6 = ["Indian","Steel","Square Hollow Sections","91.5x91.5x3.6"]
	Indian_Steel_Square_Hollow_Sections_91_5x91_5x4_5 = ["Indian","Steel","Square Hollow Sections","91.5x91.5x4.5"]
	Indian_Steel_Square_Hollow_Sections_91_5x91_5x5_4 = ["Indian","Steel","Square Hollow Sections","91.5x91.5x5.4"]
	Indian_Steel_Square_Hollow_Sections_100_0x100_0x4_0 = ["Indian","Steel","Square Hollow Sections","100.0x100.0x4.0"]
	Indian_Steel_Square_Hollow_Sections_100_0x100_0x5_0 = ["Indian","Steel","Square Hollow Sections","100.0x100.0x5.0"]
	Indian_Steel_Square_Hollow_Sections_100_0x100_0x6_0 = ["Indian","Steel","Square Hollow Sections","100.0x100.0x6.0"]
	Indian_Steel_Square_Hollow_Sections_113_5x113_5x4_5 = ["Indian","Steel","Square Hollow Sections","113.5x113.5x4.5"]
	Indian_Steel_Square_Hollow_Sections_113_5x113_5x4_8 = ["Indian","Steel","Square Hollow Sections","113.5x113.5x4.8"]
	Indian_Steel_Square_Hollow_Sections_113_5x113_5x5_4 = ["Indian","Steel","Square Hollow Sections","113.5x113.5x5.4"]
	Indian_Steel_Square_Hollow_Sections_113_5x113_5x6_0 = ["Indian","Steel","Square Hollow Sections","113.5x113.5x6.0"]
	Indian_Steel_Square_Hollow_Sections_125_0x125_0x4_5 = ["Indian","Steel","Square Hollow Sections","125.0x125.0x4.5"]
	Indian_Steel_Square_Hollow_Sections_125_0x125_0x5_0 = ["Indian","Steel","Square Hollow Sections","125.0x125.0x5.0"]
	Indian_Steel_Square_Hollow_Sections_125_0x125_0x6_0 = ["Indian","Steel","Square Hollow Sections","125.0x125.0x6.0"]
	Indian_Steel_Square_Hollow_Sections_132_0x132_0x4_8 = ["Indian","Steel","Square Hollow Sections","132.0x132.0x4.8"]
	Indian_Steel_Square_Hollow_Sections_132_0x132_0x5_4 = ["Indian","Steel","Square Hollow Sections","132.0x132.0x5.4"]
	Indian_Steel_Square_Hollow_Sections_132_0x132_0x6_0 = ["Indian","Steel","Square Hollow Sections","132.0x132.0x6.0"]
	Indian_Steel_Square_Hollow_Sections_150_0x150_0x5_0 = ["Indian","Steel","Square Hollow Sections","150.0x150.0x5.0"]
	Indian_Steel_Square_Hollow_Sections_150_0x150_0x6_0 = ["Indian","Steel","Square Hollow Sections","150.0x150.0x6.0"]
	Indian_Steel_Square_Hollow_Sections_180_0x180_0x4_0 = ["Indian","Steel","Square Hollow Sections","180.0x180.0x4.0"]
	Indian_Steel_Square_Hollow_Sections_180_0x180_0x5_0 = ["Indian","Steel","Square Hollow Sections","180.0x180.0x5.0"]
	Indian_Steel_Square_Hollow_Sections_180_0x180_0x6_0 = ["Indian","Steel","Square Hollow Sections","180.0x180.0x6.0"]
	Indian_Steel_Square_Hollow_Sections_180_0x180_0x8_0 = ["Indian","Steel","Square Hollow Sections","180.0x180.0x8.0"]
	Indian_Steel_Circular_Hollow_Sections_15_NB_21_3x2_0 = ["Indian","Steel","Circular Hollow Sections","15 NB: 21.3x2.0"]
	Indian_Steel_Circular_Hollow_Sections_15_NB_21_3x2_6 = ["Indian","Steel","Circular Hollow Sections","15 NB: 21.3x2.6"]
	Indian_Steel_Circular_Hollow_Sections_15_NB_21_3x3_2 = ["Indian","Steel","Circular Hollow Sections","15 NB: 21.3x3.2"]
	Indian_Steel_Circular_Hollow_Sections_20_NB_26_9x2_3 = ["Indian","Steel","Circular Hollow Sections","20 NB: 26.9x2.3"]
	Indian_Steel_Circular_Hollow_Sections_20_NB_26_9x2_6 = ["Indian","Steel","Circular Hollow Sections","20 NB: 26.9x2.6"]
	Indian_Steel_Circular_Hollow_Sections_20_NB_26_9x3_2 = ["Indian","Steel","Circular Hollow Sections","20 NB: 26.9x3.2"]
	Indian_Steel_Circular_Hollow_Sections_25_NB_33_7x2_6 = ["Indian","Steel","Circular Hollow Sections","25 NB: 33.7x2.6"]
	Indian_Steel_Circular_Hollow_Sections_25_NB_33_7x3_2 = ["Indian","Steel","Circular Hollow Sections","25 NB: 33.7x3.2"]
	Indian_Steel_Circular_Hollow_Sections_25_NB_33_7x4_0 = ["Indian","Steel","Circular Hollow Sections","25 NB: 33.7x4.0"]
	Indian_Steel_Circular_Hollow_Sections_32_NB_42_4x2_6 = ["Indian","Steel","Circular Hollow Sections","32 NB: 42.4x2.6"]
	Indian_Steel_Circular_Hollow_Sections_32_NB_42_4x3_2 = ["Indian","Steel","Circular Hollow Sections","32 NB: 42.4x3.2"]
	Indian_Steel_Circular_Hollow_Sections_32_NB_42_4x4_0 = ["Indian","Steel","Circular Hollow Sections","32 NB: 42.4x4.0"]
	Indian_Steel_Circular_Hollow_Sections_40_NB_48_3x2_9 = ["Indian","Steel","Circular Hollow Sections","40 NB: 48.3x2.9"]
	Indian_Steel_Circular_Hollow_Sections_40_NB_48_3x3_2 = ["Indian","Steel","Circular Hollow Sections","40 NB: 48.3x3.2"]
	Indian_Steel_Circular_Hollow_Sections_40_NB_48_3x4_0 = ["Indian","Steel","Circular Hollow Sections","40 NB: 48.3x4.0"]
	Indian_Steel_Circular_Hollow_Sections_50_NB_60_3x2_9 = ["Indian","Steel","Circular Hollow Sections","50 NB: 60.3x2.9"]
	Indian_Steel_Circular_Hollow_Sections_50_NB_60_3x3_6 = ["Indian","Steel","Circular Hollow Sections","50 NB: 60.3x3.6"]
	Indian_Steel_Circular_Hollow_Sections_50_NB_60_3x4_5 = ["Indian","Steel","Circular Hollow Sections","50 NB: 60.3x4.5"]
	Indian_Steel_Circular_Hollow_Sections_65_NB_76_1x2_9 = ["Indian","Steel","Circular Hollow Sections","65 NB: 76.1x2.9"]
	Indian_Steel_Circular_Hollow_Sections_65_NB_76_1x3_6 = ["Indian","Steel","Circular Hollow Sections","65 NB: 76.1x3.6"]
	Indian_Steel_Circular_Hollow_Sections_65_NB_76_1x4_5 = ["Indian","Steel","Circular Hollow Sections","65 NB: 76.1x4.5"]
	Indian_Steel_Circular_Hollow_Sections_80_NB_88_9x3_2 = ["Indian","Steel","Circular Hollow Sections","80 NB: 88.9x3.2"]
	Indian_Steel_Circular_Hollow_Sections_80_NB_88_9x4_0 = ["Indian","Steel","Circular Hollow Sections","80 NB: 88.9x4.0"]
	Indian_Steel_Circular_Hollow_Sections_80_NB_88_9x4_8 = ["Indian","Steel","Circular Hollow Sections","80 NB: 88.9x4.8"]
	Indian_Steel_Circular_Hollow_Sections_90_NB_101_6x3_6 = ["Indian","Steel","Circular Hollow Sections","90 NB: 101.6x3.6"]
	Indian_Steel_Circular_Hollow_Sections_90_NB_101_6x4_0 = ["Indian","Steel","Circular Hollow Sections","90 NB: 101.6x4.0"]
	Indian_Steel_Circular_Hollow_Sections_90_NB_101_6x4_8 = ["Indian","Steel","Circular Hollow Sections","90 NB: 101.6x4.8"]
	Indian_Steel_Circular_Hollow_Sections_100_NB_114_3x3_6 = ["Indian","Steel","Circular Hollow Sections","100 NB: 114.3x3.6"]
	Indian_Steel_Circular_Hollow_Sections_100_NB_114_3x4_5 = ["Indian","Steel","Circular Hollow Sections","100 NB: 114.3x4.5"]
	Indian_Steel_Circular_Hollow_Sections_100_NB_114_3x5_4 = ["Indian","Steel","Circular Hollow Sections","100 NB: 114.3x5.4"]
	Indian_Steel_Circular_Hollow_Sections_110_NB_127x4_5 = ["Indian","Steel","Circular Hollow Sections","110 NB: 127x4.5"]
	Indian_Steel_Circular_Hollow_Sections_110_NB_127x4_8 = ["Indian","Steel","Circular Hollow Sections","110 NB: 127x4.8"]
	Indian_Steel_Circular_Hollow_Sections_110_NB_127x5_4 = ["Indian","Steel","Circular Hollow Sections","110 NB: 127x5.4"]
	Indian_Steel_Circular_Hollow_Sections_125_NB_139_7x4_5 = ["Indian","Steel","Circular Hollow Sections","125 NB: 139.7x4.5"]
	Indian_Steel_Circular_Hollow_Sections_125_NB_139_7x4_8 = ["Indian","Steel","Circular Hollow Sections","125 NB: 139.7x4.8"]
	Indian_Steel_Circular_Hollow_Sections_125_NB_139_7x5_4 = ["Indian","Steel","Circular Hollow Sections","125 NB: 139.7x5.4"]
	Indian_Steel_Circular_Hollow_Sections_135_NB_152_4x4_5 = ["Indian","Steel","Circular Hollow Sections","135 NB: 152.4x4.5"]
	Indian_Steel_Circular_Hollow_Sections_135_NB_152_4x4_8 = ["Indian","Steel","Circular Hollow Sections","135 NB: 152.4x4.8"]
	Indian_Steel_Circular_Hollow_Sections_135_NB_152_4x5_4 = ["Indian","Steel","Circular Hollow Sections","135 NB: 152.4x5.4"]
	Indian_Steel_Circular_Hollow_Sections_150_NB_165_1x4_5 = ["Indian","Steel","Circular Hollow Sections","150 NB: 165.1x4.5"]
	Indian_Steel_Circular_Hollow_Sections_150_NB_165_1x4_8 = ["Indian","Steel","Circular Hollow Sections","150 NB: 165.1x4.8"]
	Indian_Steel_Circular_Hollow_Sections_150_NB_165_1x5_4 = ["Indian","Steel","Circular Hollow Sections","150 NB: 165.1x5.4"]
	Indian_Steel_Circular_Hollow_Sections_150_NB_165_1x5_9 = ["Indian","Steel","Circular Hollow Sections","150 NB: 165.1x5.9"]
	Indian_Steel_Circular_Hollow_Sections_150_NB_165_1x6_3 = ["Indian","Steel","Circular Hollow Sections","150 NB: 165.1x6.3"]
	Indian_Steel_Circular_Hollow_Sections_150_NB_165_1x8_0 = ["Indian","Steel","Circular Hollow Sections","150 NB: 165.1x8.0"]
	Indian_Steel_Circular_Hollow_Sections_150A_NB_168_3x4_5 = ["Indian","Steel","Circular Hollow Sections","150A NB: 168.3x4.5"]
	Indian_Steel_Circular_Hollow_Sections_150A_NB_168_3x4_8 = ["Indian","Steel","Circular Hollow Sections","150A NB: 168.3x4.8"]
	Indian_Steel_Circular_Hollow_Sections_150A_NB_168_3x5_4 = ["Indian","Steel","Circular Hollow Sections","150A NB: 168.3x5.4"]
	Indian_Steel_Circular_Hollow_Sections_150A_NB_168_3x6_3 = ["Indian","Steel","Circular Hollow Sections","150A NB: 168.3x6.3"]
	Indian_Steel_Circular_Hollow_Sections_150A_NB_168_3x8_0 = ["Indian","Steel","Circular Hollow Sections","150A NB: 168.3x8.0"]
	Indian_Steel_Circular_Hollow_Sections_150A_NB_168_3x10_0 = ["Indian","Steel","Circular Hollow Sections","150A NB: 168.3x10.0"]
	Indian_Steel_Circular_Hollow_Sections_175_NB_193_7x4_8 = ["Indian","Steel","Circular Hollow Sections","175 NB: 193.7x4.8"]
	Indian_Steel_Circular_Hollow_Sections_175_NB_193_7x5_4 = ["Indian","Steel","Circular Hollow Sections","175 NB: 193.7x5.4"]
	Indian_Steel_Circular_Hollow_Sections_175_NB_193_7x5_9 = ["Indian","Steel","Circular Hollow Sections","175 NB: 193.7x5.9"]
	Indian_Steel_Circular_Hollow_Sections_175_NB_193_7x6_3 = ["Indian","Steel","Circular Hollow Sections","175 NB: 193.7x6.3"]
	Indian_Steel_Circular_Hollow_Sections_175_NB_193_7x8_0 = ["Indian","Steel","Circular Hollow Sections","175 NB: 193.7x8.0"]
	Indian_Steel_Circular_Hollow_Sections_175_NB_193_7x10_0 = ["Indian","Steel","Circular Hollow Sections","175 NB: 193.7x10.0"]
	Indian_Steel_Circular_Hollow_Sections_175_NB_193_7x12_0 = ["Indian","Steel","Circular Hollow Sections","175 NB: 193.7x12.0"]
	Indian_Steel_Circular_Hollow_Sections_200_NB_219_1x4_8 = ["Indian","Steel","Circular Hollow Sections","200 NB: 219.1x4.8"]
	Indian_Steel_Circular_Hollow_Sections_200_NB_219_1x5_6 = ["Indian","Steel","Circular Hollow Sections","200 NB: 219.1x5.6"]
	Indian_Steel_Circular_Hollow_Sections_200_NB_219_1x5_9 = ["Indian","Steel","Circular Hollow Sections","200 NB: 219.1x5.9"]
	Indian_Steel_Circular_Hollow_Sections_200_NB_219_1x6_3 = ["Indian","Steel","Circular Hollow Sections","200 NB: 219.1x6.3"]
	Indian_Steel_Circular_Hollow_Sections_200_NB_219_1x8 = ["Indian","Steel","Circular Hollow Sections","200 NB: 219.1x8"]
	Indian_Steel_Circular_Hollow_Sections_200_NB_219_1x10 = ["Indian","Steel","Circular Hollow Sections","200 NB: 219.1x10"]
	Indian_Steel_Circular_Hollow_Sections_200_NB_219_1x12 = ["Indian","Steel","Circular Hollow Sections","200 NB: 219.1x12"]
	Indian_Steel_Circular_Hollow_Sections_225_NB_244_5x5_9 = ["Indian","Steel","Circular Hollow Sections","225 NB: 244.5x5.9"]
	Indian_Steel_Circular_Hollow_Sections_225_NB_244_5x6_3 = ["Indian","Steel","Circular Hollow Sections","225 NB: 244.5x6.3"]
	Indian_Steel_Circular_Hollow_Sections_225_NB_244_5x8 = ["Indian","Steel","Circular Hollow Sections","225 NB: 244.5x8"]
	Indian_Steel_Circular_Hollow_Sections_225_NB_244_5x10 = ["Indian","Steel","Circular Hollow Sections","225 NB: 244.5x10"]
	Indian_Steel_Circular_Hollow_Sections_250_NB_273x5_9 = ["Indian","Steel","Circular Hollow Sections","250 NB: 273x5.9"]
	Indian_Steel_Circular_Hollow_Sections_250_NB_273x6_3 = ["Indian","Steel","Circular Hollow Sections","250 NB: 273x6.3"]
	Indian_Steel_Circular_Hollow_Sections_250_NB_273x8 = ["Indian","Steel","Circular Hollow Sections","250 NB: 273x8"]
	Indian_Steel_Circular_Hollow_Sections_250_NB_273x10 = ["Indian","Steel","Circular Hollow Sections","250 NB: 273x10"]
	Indian_Steel_Circular_Hollow_Sections_250_NB_273x12 = ["Indian","Steel","Circular Hollow Sections","250 NB: 273x12"]
	Indian_Steel_Circular_Hollow_Sections_300_NB_323_9x6_3 = ["Indian","Steel","Circular Hollow Sections","300 NB: 323.9x6.3"]
	Indian_Steel_Circular_Hollow_Sections_300_NB_323_9x8 = ["Indian","Steel","Circular Hollow Sections","300 NB: 323.9x8"]
	Indian_Steel_Circular_Hollow_Sections_300_NB_323_9x10 = ["Indian","Steel","Circular Hollow Sections","300 NB: 323.9x10"]
	Indian_Steel_Circular_Hollow_Sections_300_NB_323_9x12 = ["Indian","Steel","Circular Hollow Sections","300 NB: 323.9x12"]
	Indian_Steel_Circular_Hollow_Sections_350_NB_355_6x8 = ["Indian","Steel","Circular Hollow Sections","350 NB: 355.6x8"]
	Indian_Steel_Circular_Hollow_Sections_350_NB_355_6x10 = ["Indian","Steel","Circular Hollow Sections","350 NB: 355.6x10"]
	Indian_Steel_Circular_Hollow_Sections_350_NB_355_6x12 = ["Indian","Steel","Circular Hollow Sections","350 NB: 355.6x12"]
	Indian_Steel_T_Sections_NT_20 = ["Indian","Steel","T Sections","NT 20"]
	Indian_Steel_T_Sections_NT_30 = ["Indian","Steel","T Sections","NT 30"]
	Indian_Steel_T_Sections_NT_40 = ["Indian","Steel","T Sections","NT 40"]
	Indian_Steel_T_Sections_NT_50 = ["Indian","Steel","T Sections","NT 50"]
	Indian_Steel_T_Sections_NT_60 = ["Indian","Steel","T Sections","NT 60"]
	Indian_Steel_T_Sections_NT_80 = ["Indian","Steel","T Sections","NT 80"]
	Indian_Steel_T_Sections_NT_100 = ["Indian","Steel","T Sections","NT 100"]
	Indian_Steel_T_Sections_NT_150 = ["Indian","Steel","T Sections","NT 150"]
